*====================== PROGRAM: PQI09_ALL_CONTROL.SAS ======================;
* -------------------------------------------------------------------------- ;
*       AHRQ QI VERSION V6.0.2 ICD-09-CM
*       VERSION DATE AUGUST 2017
* -------------------------------------------------------------------------- ;
 * The PATIENT QUALITY INDICATOR PQI 09 STAND ALONE module of the AHRQ 
   Quality Indicators software includes the following programs:
   
    1. PQI09_ALL_CONTROL.sas  Assigns user inputs required by other programs
                              and optional output options.  

    2. PQI09_ALL_FORMATS.sas  Creates SAS format library used by other programs.

    3. PQI09_ALL_MEASURES.sas  Assigns HCUP PEDIATRIC Quality                    
                               Indicators to inpatient records.     
 
    4. PQI09_AREA_OBSERVED.sas Calculates observed area rates for               
                               Pediatric Quality Indicators.                 
 
    5. PQI09_AREA_RISKADJ.sas  Calculates risk-adjusted area rates for          
                               Pediatric Quality Indicators.   

 * The software also requires the following files:
 
    1. discharges.sas7bdat  User supplied discharge level file organized according 
                            to the layout in the software instructions.
                            The file name is up to the user but must be listed below.
                            
    2. PQ09_Dx_Px_Macros.sas Standard processes used by the other SAS programs.
                            The user does not need to open.
                            
    3. pop95t15.txt         Population file with counts by area, age, and sex.
                            Required for area rate calculation.

    4. PQI_AREA_SIGVAR_ARRAY_v60.SAS  File with noise and signal variance estimates 
                            and reference rates for smoothing by age and sex.

    5. PQI09_AREA_SIGVAR_ARRAY_SES_v60.SAS  File with noise and signal variance estimates 
                            and reference rates for smoothing by age, sex and SES.

    6. PQI09_POVCAT_FMT_2015.sas Format for County Poverty Deciles - Based on 2015 Census Data.
                            
*   See the AHRQ_QI_V6_ICD9_Release_Notes.txt file for version change details.

***************************************************************************** ;
******************************* PLEASE READ ********************************* ;
***************************************************************************** ;
 * The AHRQ Quality Indicator software is intended for use with discharges
   coded according to the standards in place at the date of the discharge. 
   Discharges should be classified under the ICD-09-CM/PCS specifications 
   effective 10/1/2007 to 09/30/2015. All diagnosis codes require a corresponding 
   Present On Admission, POA, value coded according to UB04 standards. 
   
 * The USER MUST modify portions of the following code in order to
   run this software.  With one exception (see NOTE immediately
   following this paragraph), the only changes necessary to run
   this software are changes in this program (PQI09_ALL_CONTROL.SAS). 
   The modifications include such items as specifying the name and location
   of the input data set, the year of population data to be used, and the 
   name and location of output data sets.
 
 * NOTE:  PQI09_ALL_CONTROL.SAS provides the option to read data in and write 
          data out to different locations.  For example, "libname INMSR" points
          to the location of the input data set for the PQI09_ALL_MEASURES program
          and "libname OUTMSR" points to the location of the output data set
          created by the PQI09_ALL_MEASURES program.  The location and file name of 
          each input and output can be assigned separately below. The default 
          values will place output in a SASData folder with standard names for
          each file based on the location of the PQI09 folder listed in the 
          PATHNAME variable.
          
 * NOTE:  In the other programs included with this package there is a 
          line of code that begins with "filename CONTROL".  
          The USER MUST include after "filename CONTROL" the location
          of the PQI09_ALL_CONTROL.SAS file.

 Generally speaking, a first-time user of this software would proceed 
 as outlined below:

    1. Modify and save PQI09_ALL_CONTROL.SAS (This program. - MUST be done.)
    2. Open PQI09_ALL_FORMATS.SAS and specify location (path name) of
       PQI09_ALL_CONTROL.SAS. (MUST be done.)
    3. Run PQI09_ALL_FORMATS.SAS.  (MUST be done.) 
    4. Open PQI09_ALL_MEASURES.SAS and specify location of PQI09_ALL_CONTROL.SAS
       program.  (MUST be done.)
    5. Run PQI09_ALL_MEASURES.SAS.  (MUST be done.)
    6. To calculate area level rates for Patient Safety Indicators:
         a.  Open PQI09_AREA_OBSERVED.SAS and specify location
             of PQI09_ALL_CONTROL.SAS program.  (MUST be done.) 
         b.  Run PQI09_AREA_OBSERVED.SAS.  (MUST have run PQI09_ALL_MEASURES.SAS.)

 * ---------------------------------------------------------------- ;
 * ---                       All Programs                       --- ;
 * ---------------------------------------------------------------- ;
*PATHNAME specifies the main working folder which includes 
 ParmFiles, SASdata, Programs, etc. subfolders;
%LET PATHNAME=c:\Pathname\PQI_09;               *<===USER MUST modify;

*DISFOLDER specifies the folder that contains the discharge data;
%LET DISFOLDER=c:\Pathname\SASdata\;            *<===USER MUST modify;

*DISCHARGE specifies the name of the discharge data file;
%LET DISCHARGE=discharges;                      *<===USER MUST modify;

*SUFX specifies an identifier suffix to be placed on all output datasets;
%LET SUFX=v6_ICD09;                              *<===USER may modify;

title "TITLE - PQI09 Module - &SUFX.";
libname LIBRARY "&PATHNAME.\SASData";

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF COUNTY-LEVEL AREAS SHOULD BE CONVERTED TO MAs -- ;
 * ---     0 - County level with U.S. Census FIPS                -- ;
 * ---     1 - County level with Modified FIPS                   -- ;
 * ---     2 - Metro Area level with OMB 1999 definition         -- ;
 * ---     3 - Metro Area level with OMB 2003 definition         -- ;
 * ---------------------------------------------------------------- ;
%LET MALEVL = 0;                                 *<===USER may modify;
                                                                     
 * ---------------------------------------------------------------- ;
 * NOTE:  In program PQI09_AREA_OBSERVED, the user should select    ;
 *          the population data for the year that best              ;
 *          matches the discharge data.  Data are available for     ;
 *          1995 to 2015.                                           ;
 * ---------------------------------------------------------------- ;
%LET POPYEAR = 2015;                             *<===USER MUST modify;
                                                                     
 * ---------------------------------------------------------------- ;
 * --- SET NAME OF POPULATION FILE -------------------------------- ;
 * ---------------------------------------------------------------- ;
filename POPFILE  "&PATHNAME.\SASData\pop95t15.txt";*<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF RECORDS SHOULD BE PRINTED AT END OF EACH PGM --- ;
 * ---------------------------------------------------------------- ;
%LET PRINT = 0;                                 *<===USER may modify; 

 * ---------------------------------------------------------------- ;
 * ----------- SET LOCATION OF SAS MACRO LIBRARY ------------------ ;
 * ---------------------------------------------------------------- ;
filename MacLib "&PATHNAME.\Macros" ;

 * ---------------------------------------------------------------- ;
 * --- COMMENT OUT TO CREATE AN UCOMPRESSED FILE                --- ;
 * ---------------------------------------------------------------- ;
options compress=YES; 
  
 * ---------------------------------------------------------------- ;
 * ---              Program : PQI09_ALL_MEASURES                --- ;
 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PQI09_ALL_MEASURES INPUT DATA            --- ;
 * ---------------------------------------------------------------- ;
libname INMSR  "&DISFOLDER.";                     *<==USER may modify;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PQI09_ALL_MEASURES OUTPUT DATA           --- ;
 * ---------------------------------------------------------------- ;
libname OUTMSR "&PATHNAME.\SASdata";              *<==USER may modify;
 * --- SET NAME OF OUTPUT FILE FROM PQI09_ALL_MEASURES.SAS      --- ;    
%LET OUTFILE_MEAS = pq09msr_&SUFX.;              *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- MODIFY INPUT AND OUTPUT FILE                             --- ;
 * ---------------------------------------------------------------- ;
 * --- PROGRAM DEFAULT ASSUMES THERE ARE                        --- ;
 * ---     35 DIAGNOSES (DX1-DX35)                              --- ;
 * ---     30 PROCEDURES (PR1-PR30)                             --- ;
 * ---------------------------------------------------------------- ;
 * --- MODIFY NUMBER OF DIAGNOSIS AND PROCEDURE VARIABLES TO    --- ;
 * --- MATCH USER DISCHARGE INPUT DATA                          --- ;
 * ---------------------------------------------------------------- ;
%LET NDX = 35;                                    *<===USER may modify;
%LET NPR = 30;                                    *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * - SET PRDAY TO 1 IF DATA AVAILABLE REGARDING NUMBER OF DAYS  --- ;
 * - FROM ADMISSION TO SECONDARY PROCEDURES                     --- ;
 * ---------------------------------------------------------------- ;
%LET PRDAY = 1;                                 *<===USER may modify;
  
 * --------------------------------------------------------------------- ;
 * - CREATE PERMANENT SAS DATASET TO STORE RECORDS THAT WILL         --- ;
 * - NOT BE INCLUDED IN CALCULATIONS BECAUSE KEY VARIABLE            --- ;
 * - VALUES ARE MISSING.  THIS DATASET SHOULD BE REVIEWED AFTER      --- ;
 * - RUNNING PQI09_MEASURES.                                     --- ;
 * --------------------------------------------------------------------- ;
%LET DELFILE1  = PQ09_DELETED_&SUFX.;                      *<===USER may modify;

 * ======================================================================;
 * ============AREA-LEVEL PEDIATRIC QUALITY INDICATORS===================;
 * ======================================================================;
 * ---             PQI09_AREA_OBSERVED : Observed Rates              --- ;
 * --------------------------------------------------------------------- ;
libname OUTAOBS "&PATHNAME.\SASdata\";                 *<==USER may modify;

 * --------------------------------------------------------------------- ;
 * --- TYPELVLA indicates the levels (or _TYPES_) of                 --- ;
 * --- summarization to be kept in the output.                       --- ;
 * ---                                                               --- ;
 * ---  TYPELVLA      stratification                                 --- ;
 * ---  --------  -------------------------                          --- ;
 * ---     0      overall                                            --- ;
 * ---     1                           race                          --- ;
 * ---     2                     sex                                 --- ;
 * ---     3                     sex * race                          --- ;
 * ---     4               age                                       --- ;
 * ---     5               age *       race                          --- ;
 * ---     6               age * sex                                 --- ;
 * ---     7               age * sex * race                          --- ;
 * ---     8       area                                              --- ;
 * ---     9       area  *             race                          --- ;
 * ---    10       area  *       sex                                 --- ;
 * ---    11       area  *       sex * race                          --- ;
 * ---    12       area  * age                                       --- ;
 * ---    13       area  * age *       race                          --- ;
 * ---    14       area  * age * sex                                 --- ;
 * ---    15       area  * age * sex * race                          --- ;
 * ---                                                               --- ;
 * --- The default TYPELVLA (0,8) will provide an overall            --- ;
 * --- and area-level totals                                         --- ;
 * ---                                                               --- ;
 * --------------------------------------------------------------------- ;
%LET TYPELVLA = IN (0,8);                             *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- TO USE SES IN RISK ADJUSTMENT, SET USE_SES=1 BELOW.      --- ;
 * ---------------------------------------------------------------- ;
%LET USE_SES = 0;

 * --------------------------------------------------------------------- ;
 * --- SET NAME OF MICRODATA INPUT (OUTPUT FROM PQI09_AREA_OBSERVED) --- ;
 * --- AND SUMMARY OUTPUT FILE OF OBSERVED AREA RATES.               --- ;
 * --------------------------------------------------------------------- ;
%LET  OUTFILE_AREAOBS = PQ09AOBS_&SUFX.;               *<===USER may modify;
 
 * --------------------------------------------------------------------- ;
 * --- INDICATE IF WANT TO CREATE A COMMA-DELIMITED FILE FOR         --- ;
 * --- EXPORT INTO A SPREADSHEET.                                    --- ;
 * --------------------------------------------------------------------- ;
%LET TEXTAOBS = 1;                                *<===USER may modify;   

 * --------------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION      - ;
 * --- OF THE FILE.                                                  --- ;
 * --------------------------------------------------------------------- ;
filename PDAOBS "&PATHNAME.\SASdata\PQ09ABS_&SUFX..CSV";  *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * ---   PQI09_AREA_RISKADJ : Risk-Adjusted and Smoothed Rates       --- ;
 * --------------------------------------------------------------------- ;
libname OUTARSK "&PATHNAME.\SASdata";

 * ---------------------------------------------------------------- ;
 * --- SET NAME OF COVARIATE FILE.                                - ;
 * --- THESE FILES CONTAIN THE REGRESSION COEFFICIENTS FOR EACH   - ;
 * --- COVARIATE.  THERE IS ONE OBSERVATION PER PEDIATRIC QUALITY - ;
 * --- INDICATOR.                                                 - ;
 * ---------------------------------------------------------------- ;
filename COVAR    "&PATHNAME.\ParmFiles\PQI09_Area_Covariates_v60.TXT";  *<===USER may modify;
filename COVARSES "&PATHNAME.\ParmFiles\PQI09_Area_Covariates_SES_v60.TXT";  *<===USER may modify;

 * --------------------------------------------------------------------- ;
 * --- SET NAME OF INPUT RATES FILE (OUTPUT FROM PQI09_AREA_RISKADJ) --- ;
 * --- AND AREA LEVEL OUTPUT FILE.                                   --- ;
 * --------------------------------------------------------------------- ;
%LET OUTFILE_AREARISK = PQ09ARSK_&SUFX.; 

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF WANT TO CREATE A COMMA-DELIMITED FILE FOR    --- ;
 * --- EXPORT INTO A SPREADSHEET.                               --- ;
 * ---------------------------------------------------------------- ;
%LET TEXTARSK = 0;                                *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION - ;
 * --- OF THE FILE.                                             --- ;
 * ---------------------------------------------------------------- ;
filename PDARSK "&PATHNAME.\SASdata\PQ09AR_&SUFX..CSV"; *<===USER may modify;

