*===================== PROGRAM: PQI09_ALL_FORMATS.SAS ===========================;
*============================================================================
*
* Description:
*     FORMAT LIB FOR AHRQ PATIENT SAFETY INDICATORS;
*
*     AHRQ QI VERSION V6.0.2 ICD-09-CM
*     VERSION DATE AUGUST 2017
*
*     Note: Codes valid from 10/1/2007 to 9/30/2015 (FY 2015)
*
*============================================================================;
filename CONTROL 'c:\Pathname\PQI_09\Programs\PQI09_ALL_CONTROL.SAS';
%include CONTROL;

/* -------------------------------------------------------------- */
/* --- FORMATS FOR COUNTY POVERTY DECILES ----------------------- */
/* -------------------------------------------------------------- */
 * County Poverty Deciles based on 2015 Census data.;
%include Maclib(PQI09_POVCAT_FMT_2015.sas);

proc Format library=LIBRARY;

/* -------------------------------------------------------------- */
/* --- FORMATS FOR STRATIFIERS ---------------------------------- */
/* -------------------------------------------------------------- */

/* --- FORMAT FOR SEX CATEGORY ---------------------------------- */
value SEXCAT
1 = 'Male'
2 = 'Female';
 
/* --- FORMAT FOR AGE CATEGORY ---------------------------------- */
value PAGECAT
1 = "<1"
2 = "1 TO 2"
3 = "3 TO 5"
4 = "6 TO 12"
5 = "13 TO 17";
 
/* --- FORMAT FOR AGEDAY CATEGORY ------------------------------- */
value AGEDCAT
0 = "NA"
1 = "0 TO 28"
2 = "29 TO 60"
3 = "61 TO 90"
4 = "91+";
 
/* --- FORMAT FOR BIRTH WEIGHT CATEGORY ------------------------- */
value BWHTCAT
0 = "NA"
1 = "0 TO 499g"
2 = "500 TO 749g"
3 = "750 TO 999g"
4 = "1000 TO 1249g"
5 = "1250 TO 1499g"
6 = "1500 TO 1749g"
7 = "1750 TO 1999g"
8 = "2000 TO 2499g"
9 = "2500g or more";
 
/* --- FORMAT FOR RACE CATEGORY --------------------------------- */
value RACECAT
1 = 'White'
2 = 'Black'
3 = 'Hispanic'
4 = 'Asian and NH/PI'
5 = 'Amer Indian/AN'
6 = 'Other';
 
/* --- FORMAT FOR PAYER CATEGORY ---------------------------------- */
value PAYCAT
1 = 'Medicare'
2 = 'Medicaid'
3 = 'Private'
4 = 'Self Pay'
5 = 'No Charge'
6 = 'Other';
 
/* --- FORMAT FOR POPULATION CATEGORY ----------------------------- */
value POPCAT
1 = '0 to 4'
2 = '5 to 9'
3 = '10 to 14'
4 = '15 to 17';
 
/* -------------------------------------------------------------- */
/* --- FORMATS FOR stratification variables--------------------- */
/* -------------------------------------------------------------- */
/* ---ACCIDENTAL PUNCTURE AND LACERATION------------- */
/* --- DECUBITUS ULCER------------- */
/* --- POSTOPERATIVE HEMORRHAGE OR HEMATOMA------------- */
/* --- POSTOPERATIVE SEPSIS------------- */
/* --- POSTOPERATIVE WOUND DEHISCENCE------------- */
/* --- SELECTED INFECTION DUE TO MEDICAL CARE----- */
* --------------------------------------------------------------
* --- PDI DEFINING FORMATS -------------------------------------
* --------------------------------------------------------------
* --------------------------------------------------------------
* --- FORMATS - PROVIDER AND AREA LEVEL INDICATORS -------------
* --------------------------------------------------------------;
/* ----------------------------------------- */
/* Palliative Care                           */
/* ----------------------------------------- */
value $PALLIAD
'V667 ' = '1' /* ENCOUNTR PALLIATIVE CARE */
other = '0';
/* ------------------------------ */
/* NEONATE AND NEWBORN            */
/* ------------------------------ */
/* Liveborn (Populaton at Risk)           */
/* ICD-9-CM Diagnosis Codes:              */
value $LIVEBND
'V3000' = 1  /* SINGLE LB IN-HOSP W/O CS */
'V3001' = 1  /* SINGLE LB IN-HOSP W CS */
'V3100' = 1  /* TWIN-MATE LB-HOSP W/O CS */
'V3101' = 1  /* TWIN-MATE LB-IN HOS W CS */
'V3200' = 1  /* TWIN-MATE SB-HOSP W/O CS */
'V3201' = 1  /* TWIN-MATE SB-HOSP W CS */
'V3300' = 1  /* TWIN-NOS-IN HOSP W/O CS */
'V3301' = 1  /* TWIN-NOS-IN HOSP W CS */
'V3400' = 1  /* OTH MULT LB-HOSP W/O CS */
'V3401' = 1  /* OTH MULT LB-IN HOSP W CS */
'V3500' = 1  /* OTH MULT SB-HOSP W/O CS */
'V3501' = 1  /* OTH MULT SB-IN HOSP W CS */
'V3600' = 1  /* MULT LB/SB-IN HOS W/O CS */
'V3601' = 1  /* MULT LB/SB-IN HOSP W CS */
'V3700' = 1  /* MULT BRTH NOS-HOS W/O CS */
'V3701' = 1  /* MULT BIRTH NOS-HOSP W CS */
'V3900' = 1  /* LIVEBORN NOS-HOSP W/O CS */
'V3901' = 1  /* LIVEBORN NOS-HOSP W CS */
other   = 0;
value $V29D
"V290"  = "1" /* OBSERVATIONS FOR SUSPECTED INFECTIOUS CONDITION */
"V291"  = "1" /* OBSERVATIONS FOR SUSPECTED NEUROLOGICAL CONDITION */
"V292"  = "1" /* OBSERVATIONS FOR SUSPECTED RESPIRATORY CONDITION */
"V293"  = "1" /* OBSERVATIONS FOR SUSPECTED GENETIC OR METABOLIC CONDITION */
"V298"  = "1" /* OBSERVATIONS FOR OTHER SPECIFIED SUSPECTED CONDITION */
"V299"  = "1" /* OBSERVATIONS FOR UNSPECIFIED SUSPECTED CONDITION */
other   = "0";
value $ORPROC
"0050" = "1" /* IMPL CRT PACEMAKER SYS */
"0051" = "1" /* IMPL CRT DEFIBRILLAT SYS */
"0052" = "1" /* IMP/REP LEAD LF VEN SYS */
"0053" = "1" /* IMP/REP CRT PACEMAKR GEN */
"0054" = "1" /* IMP/REP CRT DEFIB GENAT */
"0056" = "1" /* INS/REP IMPL SENSOR LEAD */
"0057" = "1" /* IMP/REP SUBCUE CARD DEV */
"0061" = "1" /* PERC ANGIO PRECEREB VESS */
"0062" = "1" /* PERC ANGIO INTRACRAN VES */
"0066" = "1" /* PTCA OR CORONARY ATHER */
"0070" = "1" /* REV HIP REPL-ACETAB/FEM */
"0071" = "1" /* REV HIP REPL-ACETAB COMP */
"0072" = "1" /* REV HIP REPL-FEM COMP */
"0073" = "1" /* REV HIP REPL-LINER/HEAD */
"0080" = "1" /* REV KNEE REPLACEMT-TOTAL */
"0081" = "1" /* REV KNEE REPL-TIBIA COMP */
"0082" = "1" /* REV KNEE REPL-FEMUR COMP */
"0083" = "1" /* REV KNEE REPLACE-PATELLA */
"0084" = "1" /* REV KNEE REPL-TIBIA LIN */
"0085" = "1" /* RESRF HIPTOTAL-ACET/FEM */
"0086" = "1" /* RESRF HIPPART-FEM HEAD */
"0087" = "1" /* RESRF HIPPART-ACETABLUM */
"0112" = "1" /* OPEN CEREB MENINGES BX */
"0114" = "1" /* OPEN BRAIN BIOPSY */
"0115" = "1" /* SKULL BIOPSY */
"0118" = "1" /* OTHER BRAIN DX PROCEDURE */
"0119" = "1" /* OTHER SKULL DX PROCEDURE */
"0120" = "1" /* IMP/REPL BRAIN PULSE GEN */
"0121" = "1" /* CRANIAL SINUS I & D */
"0122" = "1" /* REMOV INTRACRAN STIMULAT */
"0123" = "1" /* REOPEN CRANIOTOMY SITE */
"0124" = "1" /* OTHER CRANIOTOMY */
"0125" = "1" /* OTHER CRANIECTOMY */
"0128" = "1" /* INTRACEREB CTH-BURR HOLE */
"0129" = "1" /* REM BRAIN PULSE GENERATR */
"0131" = "1" /* INCISE CEREBRAL MENINGES */
"0132" = "1" /* LOBOTOMY & TRACTOTOMY */
"0139" = "1" /* OTHER BRAIN INCISION */
"0141" = "1" /* THALAMUS OPERATIONS */
"0142" = "1" /* GLOBUS PALLIDUS OPS */
"0151" = "1" /* EX CEREB MENINGEAL LES */
"0152" = "1" /* HEMISPHERECTOMY */
"0153" = "1" /* BRAIN LOBECTOMY */
"0159" = "1" /* OTHER BRAIN EXCISION */
"016 " = "1" /* EXCISE SKULL LESION */
"0201" = "1" /* LINEAR CRANIECTOMY */
"0202" = "1" /* ELEVATE SKULL FX FRAGMNT */
"0203" = "1" /* SKULL FLAP FORMATION */
"0204" = "1" /* BONE GRAFT TO SKULL */
"0205" = "1" /* SKULL PLATE INSERTION */
"0206" = "1" /* CRANIAL OSTEOPLASTY NEC */
"0207" = "1" /* SKULL PLATE REMOVAL */
"0211" = "1" /* SIMPLE SUTURE OF DURA */
"0212" = "1" /* BRAIN MENINGE REPAIR NEC */
"0213" = "1" /* MENINGE VESSEL LIGATION */
"0214" = "1" /* CHOROID PLEXECTOMY */
"022 " = "1" /* VENTRICULOSTOMY */
"0221" = "1" /*	INSERTION OR REPLACEMENT OF EXTERNAL VENTICULAR DRAIN [EVD] */
"0222" = "1" /*	INTRACRANIAL VENTICULAR SHUNT OR ANASTOMOSIS */
"0231" = "1" /* VENTRICL SHUNT-HEAD/NECK */
"0232" = "1" /* VENTRI SHUNT-CIRCULA SYS */
"0233" = "1" /* VENTRICL SHUNT-THORAX */
"0234" = "1" /* VENTRICL SHUNT-ABDOMEN */
"0235" = "1" /* VENTRI SHUNT-UNINARY SYS */
"0239" = "1" /* OTHER VENTRICULAR SHUNT */
"0242" = "1" /* REPLACE VENTRICLE SHUNT */
"0243" = "1" /* REMOVE VENTRICLE SHUNT */
"0291" = "1" /* LYSIS CORTICAL ADHESION */
"0292" = "1" /* BRAIN REPAIR */
"0293" = "1" /* IMPLANT BRAIN STIMULATOR */
"0294" = "1" /* INSERT/REPLAC SKULL TONG */
"0299" = "1" /* SKULL & BRAIN OP NEC */
"0301" = "1" /* REMOVAL FB SPINAL CANAL */
"0302" = "1" /* REOPEN LAMINECTOMY SITE */
"0309" = "1" /* SPINAL CANAL EXPLOR NEC */
"031 " = "1" /* INTRASPIN NERVE ROOT DIV */
"0321" = "1" /* PERCUTANEOUS CHORDOTOMY */
"0329" = "1" /* OTHER CHORDOTOMY */
"0332" = "1" /* SPINAL CORD/MENINGES BX */
"0339" = "1" /* OTHER SPINAL DX PROC */
"034 " = "1" /* EXCIS SPINAL CORD LESION */
"0351" = "1" /* SPINE MENINGOCELE REPAIR */
"0352" = "1" /* MYELOMENINGOCEL REPAIR */
"0353" = "1" /* VERTEBRAL FX REPAIR */
"0359" = "1" /* SPINAL STRUCT REPAIR NEC */
"036 " = "1" /* SPINAL CORD ADHESIOLYSIS */
"0371" = "1" /* SUBARACH-PERITON SHUNT */
"0372" = "1" /* SUBARACH-URETERAL SHUNT */
"0379" = "1" /* OTH SPINAL THECAL SHUNT */
"0393" = "1" /* INSERT SPINAL STIMULATOR */
"0394" = "1" /* REMOVE SPINAL STIMULATOR */
"0397" = "1" /* REVISE SPINE THECA SHUNT */
"0398" = "1" /* REMOVE SPINE THECA SHUNT */
"0399" = "1" /* SPINE CANAL STRUC OP NEC */
"0401" = "1" /* EXCISION ACOUSTC NEUROMA */
"0402" = "1" /* TRIGEMINAL NERV DIVISION */
"0403" = "1" /* PERIPH NERVE DIV NEC */
"0404" = "1" /* PERIPH NERVE INCIS NEC */
"0405" = "1" /* GASSERIAN GANGLIONECTOMY */
"0406" = "1" /* PERIPH GANGLIONECT NEC */
"0407" = "1" /* PERIPH NERV EXCISION NEC */
"0412" = "1" /* OPEN PERIPH NERVE BIOPSY */
"0419" = "1" /* PERIPH NERVE DX PROC NEC */
"043 " = "1" /* PERIPHERAL NERVE SUTURE */
"0441" = "1" /* DECOMPRESS TRIGEM ROOT */
"0442" = "1" /* CRAN NERV ROOT DECOM NEC */
"0443" = "1" /* CARPAL TUNNEL RELEASE */
"0444" = "1" /* TARSAL TUNNEL RELEASE */
"0449" = "1" /* PER NERVE ADHESIOLYS NEC */
"045 " = "1" /* PERIPHERAL NERVE GRAFT */
"046 " = "1" /* PERIPH NERVE TRANSPOSIT */
"0471" = "1" /* HYPOGLOSS-FACIAL ANASTOM */
"0472" = "1" /* ACCESSORY-FACIAL ANASTOM */
"0473" = "1" /* ACCESS-HYPOGLOSS ANASTOM */
"0474" = "1" /* PERIPH NERV ANASTOM NEC */
"0475" = "1" /* POSTOP REVIS PER NERV OP */
"0476" = "1" /* LATE REPAIR PER NERV INJ */
"0479" = "1" /* OTHER NEUROPLASTY */
"0491" = "1" /* NEURECTASIS */
"0492" = "1" /* IMPLANT PERIPH STIMULAT */
"0493" = "1" /* REMOVE PERIPH STIMULATOR */
"0499" = "1" /* PERIPHERAL NERVE OPS NEC */
"050 " = "1" /* SYMPATH NERVE DIVISION */
"0511" = "1" /* SYMPATHETIC NERVE BIOPSY */
"0519" = "1" /* SYMPATH NRV DX PROC NEC */
"0521" = "1" /* SPHENOPALATIN GANGLIONEC */
"0522" = "1" /* CERVICAL SYMPATHECTOMY */
"0523" = "1" /* LUMBAR SYMPATHECTOMY */
"0524" = "1" /* PRESACRAL SYMPATHECTOMY */
"0525" = "1" /* PERIART SYMPATHECTOMY */
"0529" = "1" /* OTHER SYMPATHECTOMY */
"0581" = "1" /* SYMPATHETIC NERVE REPAIR */
"0589" = "1" /* SYMPATHETIC NERVE OP NEC */
"059 " = "1" /* OTHER NERVOUS SYSTEM OPS */
"0602" = "1" /* REOPEN THYROID FIELD WND */
"0609" = "1" /* INCIS THYROID FIELD NEC */
"0612" = "1" /* OPEN THYROID GLAND BX */
"0613" = "1" /* PARATHYROID BIOPSY */
"0619" = "1" /* THYR/PARATHY DX PROC NEC */
"062 " = "1" /* UNILAT THYROID LOBECTOMY */
"0631" = "1" /* EXCISION THYROID LESION */
"0639" = "1" /* PART THYROIDECTOMY NEC */
"064 " = "1" /* COMPLETE THYROIDECTOMY */
"0650" = "1" /* SUBSTERN THYROIDECT NOS */
"0651" = "1" /* PART SUBSTERN THYROIDECT */
"0652" = "1" /* TOT SUBSTERN THYROIDECT */
"066 " = "1" /* LINGUAL THYROID EXCISION */
"067 " = "1" /* THYROGLOSS DUCT EXCISION */
"0681" = "1" /* TOTAL PARATHYROIDECTOMY */
"0689" = "1" /* OTHER PARATHYROIDECTOMY */
"0691" = "1" /* THYROID ISTHMUS DIVISION */
"0692" = "1" /* THYROID VESSEL LIGATION */
"0693" = "1" /* THYROID SUTURE */
"0694" = "1" /* THYROID REIMPLANTATION */
"0695" = "1" /* PARATHYROID REIMPLANT */
"0698" = "1" /* OTHER THYROID OPERATIONS */
"0699" = "1" /* OTHER PARATHYROID OPS */
"0700" = "1" /* ADRENAL EXPLORATION NOS */
"0701" = "1" /* UNILAT ADRENAL EXPLORAT */
"0702" = "1" /* BILAT ADRENAL EXPLORAT */
"0712" = "1" /* OPEN ADRENAL GLAND BX */
"0713" = "1" /* TRANSFRONT PITUITARY BX */
"0714" = "1" /* TRANSPHEN PITUITARY BX */
"0715" = "1" /* PITUITARY BIOPSY NOS */
"0716" = "1" /* THYMUS BIOPSY */
"0717" = "1" /* PINEAL BIOPSY */
"0719" = "1" /* ENDOCRINE DX PROC NEC */
"0721" = "1" /* ADRENAL LESION EXCISION */
"0722" = "1" /* UNILATERAL ADRENALECTOMY */
"0729" = "1" /* PART ADRENALECTOMY NEC */
"073 " = "1" /* BILATERAL ADRENALECTOMY */
"0741" = "1" /* ADRENAL INCISION */
"0742" = "1" /* ADRENAL NERVE DIVISION */
"0743" = "1" /* ADRENAL VESSEL LIGATION */
"0744" = "1" /* ADRENAL REPAIR */
"0745" = "1" /* ADRENAL REIMPLANTATION */
"0749" = "1" /* ADRENAL OPERATION NEC */
"0751" = "1" /* PINEAL FIELD EXPLORATION */
"0752" = "1" /* PINEAL GLAND INCISION */
"0753" = "1" /* PARTIAL PINEALECTOMY */
"0754" = "1" /* TOTAL PINEALECTOMY */
"0759" = "1" /* PINEAL OPERATION NEC */
"0761" = "1" /* EXC PITUIT LES-TRANSFRON */
"0762" = "1" /* EXC PITUIT LES-TRANSPHEN */
"0763" = "1" /* PART EXCIS PITUITARY NOS */
"0764" = "1" /* TOT EXC PITUIT-TRANSFRON */
"0765" = "1" /* TOT EXC PITUIT-TRANSPHEN */
"0768" = "1" /* TOTAL EXC PITUITARY NEC */
"0769" = "1" /* TOTAL EXC PITUITARY NOS */
"0771" = "1" /* PITUITARY FOSSA EXPLORAT */
"0772" = "1" /* PITUITARY GLAND INCISION */
"0779" = "1" /* PITUITARY OPERATION NEC */
"0780" = "1" /* THYMECTOMY NOS */
"0781" = "1" /* PART EXCISION OF THYMUS */
"0782" = "1" /* TOTAL EXCISION OF THYMUS */
"0783" = "1" /* THORAC PART EXISN THYMUS */
"0784" = "1" /* THORAC TOTAL EXC THYMUS */
"0791" = "1" /* THYMUS FIELD EXPLORATION */
"0792" = "1" /* INCISION OF THYMUS */
"0793" = "1" /* REPAIR OF THYMUS */
"0794" = "1" /* THYMUS TRANSPLANTATION */
"0795" = "1" /* THORAC INCISION THYMUS */
"0798" = "1" /* OTH THORAC OP THYMUS NOS */
"0799" = "1" /* THYMUS OPERATION NEC */
"0811" = "1" /* EYELID BIOPSY */
"0820" = "1" /* REMOVE EYELID LESION NOS */
"0821" = "1" /* CHALAZION EXCISION */
"0822" = "1" /* EXCISE MINOR LES LID NEC */
"0823" = "1" /* EXC MAJ LES LID PRT-THIC */
"0824" = "1" /* EXC MAJ LES LID FUL-THIC */
"0825" = "1" /* DESTRUCTION LID LESION */
"0831" = "1" /* PTOSIS REP-FRONT MUS SUT */
"0832" = "1" /* PTOSIS REP-FRON MUS SLNG */
"0833" = "1" /* PTOSIS REP-LEVAT MUS ADV */
"0834" = "1" /* PTOSIS REP-LEVAT MUS NEC */
"0835" = "1" /* PTOS REP-TARSAL TECHNIQ */
"0836" = "1" /* BLEPHAROPTOS REPAIR NEC */
"0837" = "1" /* REDUC OVERCORRECT PTOSIS */
"0838" = "1" /* CORRECT LID RETRACTION */
"0841" = "1" /* THERMOCAUT/ENTROPION REP */
"0842" = "1" /* SUTURE ENTROPION REPAIR */
"0843" = "1" /* WEDG RESEC ENTROPION REP */
"0844" = "1" /* LID RECONS ENTROPION REP */
"0849" = "1" /* ENTROPION/ECTROP REP NEC */
"0851" = "1" /* CANTHOTOMY */
"0852" = "1" /* BLEPHARORRHAPHY */
"0859" = "1" /* ADJUST LID POSITION NEC */
"0861" = "1" /* LID RECONST W SKIN GRAFT */
"0862" = "1" /* LID RECONST W MUC GRAFT */
"0863" = "1" /* LID RECONST W HAIR GRAFT */
"0864" = "1" /* LID RECON-TARSOCONJ FLAP */
"0869" = "1" /* LID RECONSTR W GRAFT NEC */
"0870" = "1" /* LID RECONSTRUCTION NOS */
"0871" = "1" /* LID MARG RECON-PART THIC */
"0872" = "1" /* LID RECONS-PART THIC NEC */
"0873" = "1" /* LID MARG RECONS FUL THIC */
"0874" = "1" /* LID RECONST-FUL THIC NEC */
"0891" = "1" /* ELECTROSURG LID EPILAT */
"0892" = "1" /* CRYOSURG LID EPILATION */
"0893" = "1" /* EYELID EPILATION NEC */
"0899" = "1" /* EYELID OPERATION NEC */
"090 " = "1" /* LACRIMAL GLAND INCISION */
"0911" = "1" /* LACRIMAL GLAND BIOPSY */
"0912" = "1" /* LACRIMAL SAC BIOPSY */
"0919" = "1" /* LACRIMAL SYS DX PROC NEC */
"0920" = "1" /* EXC LACRIMAL GLAND NOS */
"0921" = "1" /* EXCIS LES LACRIMAL GLAND */
"0922" = "1" /* PART DACRYOADENECT NEC */
"0923" = "1" /* TOTAL DACRYOADENECTOMY */
"093 " = "1" /* OTHER LACRIMAL GLAND OPS */
"0941" = "1" /* LACRIMAL PUNCTUM PROBE */
"0942" = "1" /* LAC CANALICULI PROBE */
"0943" = "1" /* NASOLACRIMAL DUCT PROBE */
"0944" = "1" /* NASOLAC DUCT INTUBAT */
"0949" = "1" /* LAC PASSAGE MANIP NEC */
"0951" = "1" /* LAC PUNCTUM INCISION */
"0952" = "1" /* LAC CANALICULI INCISION */
"0953" = "1" /* LACRIMAL SAC INCISION */
"0959" = "1" /* LACRIM PASSAGE INCIS NEC */
"096 " = "1" /* LACRIM SAC/PASSAGE EXCIS */
"0971" = "1" /* CORRECT EVERTED PUNCTUM */
"0972" = "1" /* PUNCTUM REPAIR NEC */
"0973" = "1" /* CANALICULUS REPAIR */
"0981" = "1" /* DACRYOCYSTORHINOSTOMY */
"0982" = "1" /* CONJUNCTIVOCYSTORHINOST */
"0983" = "1" /* CONJUNCTIVORHINOS W TUBE */
"0991" = "1" /* LAC PUNCTUM OBLITERATION */
"0999" = "1" /* LACRIMAL SYSTEM OP NEC */
"100 " = "1" /* INCISE/REMOV CONJUNCT FB */
"101 " = "1" /* CONJUNCTIVA INCISION NEC */
"1021" = "1" /* CONJUNCTIVAL BIOPSY */
"1029" = "1" /* CONJUNCTIVA DX PROC NEC */
"1031" = "1" /* EXCISE CONJUNCTIV LESION */
"1032" = "1" /* DESTRUCT CONJUNC LES NEC */
"1033" = "1" /* OTH CONJUNC DESTRUC PROC */
"1041" = "1" /* SYMBLEPH REP W FREE GRFT */
"1042" = "1" /* GRAFT CONJUNC CUL-DE-SAC */
"1043" = "1" /* CONJUN CUL-DE-SAC RX NEC */
"1044" = "1" /* CONJUNC FREE GRAFT NEC */
"1049" = "1" /* CONJUNCTIVOPLASTY NEC */
"105 " = "1" /* CONJUNC/LID ADHESIOLYSIS */
"106 " = "1" /* REPAIR CONJUNCT LACERAT */
"1091" = "1" /* SUBCONJUNCTIVAL INJECT */
"1099" = "1" /* CONJUNCTIVAL OP NEC */
"110 " = "1" /* MAGNET REMOVAL CORNEA FB */
"111 " = "1" /* CORNEAL INCISION */
"1121" = "1" /* CORNEAL SCRAPE FOR SMEAR */
"1122" = "1" /* CORNEAL BIOPSY */
"1129" = "1" /* CORNEAL DX PROC NEC */
"1131" = "1" /* PTERYGIUM TRANSPOSITION */
"1132" = "1" /* PTERYG EXC W CORNEA GRFT */
"1139" = "1" /* PTERYGIUM EXCISION NEC */
"1141" = "1" /* MECH REMOV CORNEA EPITH */
"1142" = "1" /* THERMOCAUT CORNEA LESION */
"1143" = "1" /* CRYOTHERAP CORNEA LESION */
"1149" = "1" /* DESTRUCT CORNEA LES NEC */
"1151" = "1" /* SUTURE CORNEA LACERATION */
"1152" = "1" /* REP CORNEA POSTOP DEHISC */
"1153" = "1" /* RX CORNEA LAC W CONJ FLP */
"1159" = "1" /* CORNEAL REPAIR NEC */
"1160" = "1" /* CORNEAL TRANSPLANT NOS */
"1161" = "1" /* LAM KERATPLAST W AUTGRFT */
"1162" = "1" /* LAMELLAR KERATOPLAST NEC */
"1163" = "1" /* PERF KERATOPL W AUTOGRFT */
"1164" = "1" /* PERFORAT KERATOPLAST NEC */
"1169" = "1" /* CORNEAL TRANSPLANT NEC */
"1171" = "1" /* KERATOMILEUSIS */
"1172" = "1" /* KERATOPHAKIA */
"1173" = "1" /* KERATOPROSTHESIS */
"1174" = "1" /* THERMOKERATOPLASTY */
"1175" = "1" /* RADIAL KERATOTOMY */
"1176" = "1" /* EPIKERATOPHAKIA */
"1179" = "1" /* CORNEA RECONSTRUCT NEC */
"1191" = "1" /* CORNEAL TATTOOING */
"1192" = "1" /* REMOVE CORNEAL IMPLANT */
"1199" = "1" /* CORNEAL OPERATION NEC */
"1200" = "1" /* REMOV ANT SEGMNT FB NOS */
"1201" = "1" /* MAGNET REMOV ANT SEG FB */
"1202" = "1" /* NONMAG REMOV ANT SEG FB */
"1211" = "1" /* IRIDOTOMY W TRANSFIXION */
"1212" = "1" /* IRIDOTOMY NEC */
"1213" = "1" /* PROLAPSED IRIS EXCISION */
"1214" = "1" /* IRIDECTOMY NEC */
"1221" = "1" /* DX ASPIRAT-ANT CHAMBER */
"1222" = "1" /* IRIS BIOPSY */
"1229" = "1" /* ANT SEGMENT DX PROC NEC */
"1231" = "1" /* GONIOSYNECHIAE LYSIS */
"1232" = "1" /* ANT SYNECHIA LYSIS NEC */
"1233" = "1" /* POST SYNECHIAE LYSIS */
"1234" = "1" /* CORNEOVITREAL ADHESIOLYS */
"1235" = "1" /* COREOPLASTY */
"1239" = "1" /* IRIDOPLASTY NEC */
"1240" = "1" /* REMOV ANT SEGMNT LES NOS */
"1241" = "1" /* NONEXC DESTRUC IRIS LES */
"1242" = "1" /* EXCISION OF IRIS LESION */
"1243" = "1" /* NONEXC DESTR CIL BOD LES */
"1244" = "1" /* EXCISE CILIARY BODY LES */
"1251" = "1" /* GONIOPUNCTURE */
"1252" = "1" /* GONIOTOMY */
"1253" = "1" /* GONIOTOMY W GONIOPUNCTUR */
"1254" = "1" /* TRABECULOTOMY AB EXTERNO */
"1255" = "1" /* CYCLODIALYSIS */
"1259" = "1" /* FACILIT INTRAOC CIRC NEC */
"1261" = "1" /* TREPHIN SCLERA W IRIDECT */
"1262" = "1" /* THERMCAUT SCLER W IRIDEC */
"1263" = "1" /* IRIDENCLEISIS/IRIDOTASIS */
"1264" = "1" /* TRABECULECTOM AB EXTERNO */
"1265" = "1" /* SCLER FISTULIZ W IRIDECT */
"1266" = "1" /* POSTOP REVIS SCL FISTUL */
"1267" = "1" /*	INSERTION OF AQUEOUS DRAINAGE DEVICE */
"1269" = "1" /* SCLER FISTULIZING OP NEC */
"1271" = "1" /* CYCLODIATHERMY */
"1272" = "1" /* CYCLOCRYOTHERAPY */
"1273" = "1" /* CYCLOPHOTOCOAGULATION */
"1274" = "1" /* CIL BODY DIMINUTION NOS */
"1279" = "1" /* GLAUCOMA PROCEDURE NEC */
"1281" = "1" /* SUTURE SCLERAL LACER */
"1282" = "1" /* SCLERAL FISTULA REPAIR */
"1283" = "1" /* REVIS ANT SEG OP WND NEC */
"1284" = "1" /* DESTRUCT SCLERAL LESION */
"1285" = "1" /* REPAIR STAPHYLOM W GRAFT */
"1286" = "1" /* REP SCLER STAPHYLOMA NEC */
"1287" = "1" /* GRAFT REINFORCE SCLERA */
"1288" = "1" /* SCLERA REINFORCEMENT NEC */
"1289" = "1" /* SCLERAL OPERATION NEC */
"1291" = "1" /* THERAPEUT EVAC ANT CHAMB */
"1292" = "1" /* ANTERIOR CHAMBER INJECT */
"1293" = "1" /* REMOV EPITHEL DOWNGROWTH */
"1297" = "1" /* IRIS OPERATION NEC */
"1298" = "1" /* CILIARY BODY OP NEC */
"1299" = "1" /* ANTERIOR CHAMBER OP NEC */
"1300" = "1" /* REMOVE FB LENS NOS */
"1301" = "1" /* MAGNET REMOVE FB LENS */
"1302" = "1" /* NONMAGNET REMOVE FB LENS */
"1311" = "1" /* TEMP-INF INTRCAP LENS EX */
"1319" = "1" /* INTRACAPSUL LENS EXT NEC */
"132 " = "1" /* LINEAR EXTRACAP LENS EXT */
"133 " = "1" /* SIMPL ASPIR LENS EXTRACT */
"1341" = "1" /* CATARAC PHACOEMULS/ASPIR */
"1342" = "1" /* POST CATARAC FRAG/ASPIR */
"1343" = "1" /* CATARACT FRAG/ASPIR NEC */
"1351" = "1" /* TEMP-INF XTRACAP LENS EX */
"1359" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1361" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1362" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1363" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1364" = "1" /* AFTER-CATAR DISCISSION */
"1365" = "1" /* AFTER-CATARACT EXCISION */
"1366" = "1" /* AFTER CATAR FRAGMNTATION */
"1369" = "1" /* CATARACT EXTRACTION NEC */
"1370" = "1" /* INSERT PSEUDOPHAKOS NOS */
"1371" = "1" /* INSERT LENS AT CATAR EXT */
"1372" = "1" /* SECONDARY INSERT LENS */
"138 " = "1" /* IMPLANTED LENS REMOVAL */
"139 " = "1" /* OTHER OPERATIONS ON LENS */
"1390" = "1" /* OPERATION ON LENS NEC */
"1391" = "1" /* IMPL INTRAOC TELESC PROS */
"1400" = "1" /* REMOV POST SEGMNT FB NOS */
"1401" = "1" /* MAGNET REMOV POST SEG FB */
"1402" = "1" /* NONMAG REMOV POST SEG FB */
"1411" = "1" /* DIAGNOST VITREOUS ASPIR */
"1419" = "1" /* DX PROC POST SEG NEC */
"1421" = "1" /* CHORIORET LES DIATHERMY */
"1422" = "1" /* CHORIORETIN LES CRYOTHER */
"1426" = "1" /* CHORIORET LES RADIOTHER */
"1427" = "1" /* CHORIORET LES RAD IMPLAN */
"1429" = "1" /* CHORIORET LES DESTR NEC */
"1431" = "1" /* RETINAL TEAR DIATHERMY */
"1432" = "1" /* RETINAL TEAR CRYOTHERAPY */
"1439" = "1" /* RETINAL TEAR REPAIR NEC */
"1441" = "1" /* SCLERAL BUCKLE W IMPLANT */
"1449" = "1" /* SCLERAL BUCKLING NEC */
"1451" = "1" /* DETACH RETINA-DIATHERMY */
"1452" = "1" /* DETACH RETINA-CRYOTHERAP */
"1453" = "1" /* DETACH RETINA XENON COAG */
"1454" = "1" /* DETACH RETINA LASER COAG */
"1455" = "1" /* DETACH RET PHOTOCOAG NOS */
"1459" = "1" /* REPAIR RETINA DETACH NEC */
"146 " = "1" /* REMOV PROS MAT POST SEG */
"1471" = "1" /* ANTERIOR REMOV VITREOUS */
"1472" = "1" /* VITREOUS REMOVAL NEC */
"1473" = "1" /* ANTERIOR MECHAN VITRECT */
"1474" = "1" /* MECH VITRECTOMY NEC */
"1475" = "1" /* VITREOUS SUBSTITUT INJEC */
"1479" = "1" /* VITREOUS OPERATION NEC */
"1481" = "1" /* IMP EPIRETINAL PROSTH */
"1482" = "1" /* REM EPIRETINAL PROSTH */
"1483" = "1" /* REV/REPL EPIRETINAL PROSTH */
"149 " = "1" /* OTHER POST SEGMENT OPS */
"1501" = "1" /* EXTRAOC MUSC-TEND BIOPSY */
"1509" = "1" /* EXTRAOC MUSC DX PROC NEC */
"1511" = "1" /* ONE EXTRAOC MUS RECESS */
"1512" = "1" /* 1 EXTRAOC MUSCL ADVANCE */
"1513" = "1" /* 1 EXTRAOC MUSCL RESECT */
"1519" = "1" /* XTRAOC MUS OP/DETACH NEC */
"1521" = "1" /* LENGTHEN 1 EXTRAOC MUSC */
"1522" = "1" /* SHORTEN 1 EXTRAOC MUSC */
"1529" = "1" /* OP ON 1 EXTRAOC MUSC NEC */
"153 " = "1" /* TEMP DETACH >1 XTROC MUS */
"154 " = "1" /* OTH OP ON >L EXTRAOC MUS */
"155 " = "1" /* EXTRAOCUL MUS TRANSPOSIT */
"156 " = "1" /* REVIS EXTRAOC MUSC SURG */
"157 " = "1" /* EXTRAOC MUSC INJ REPAIR */
"159 " = "1" /* OTH EXTRAOC MUS-TEND OP */
"1601" = "1" /* ORBITOTOMY W BONE FLAP */
"1602" = "1" /* ORBITOTOMY W IMPLANT */
"1609" = "1" /* ORBITOTOMY NEC */
"161 " = "1" /* REMOVE PENETRAT FB EYE */
"1622" = "1" /* DIAGNOSTIC ASP OF ORBIT */
"1623" = "1" /* EYEBALL & ORBIT BIOPSY */
"1629" = "1" /* EYEBAL/ORBIT DX PROC NEC */
"1631" = "1" /* EYE EVISC W SYNCH IMPLAN */
"1639" = "1" /* EYEBALL EVISCERATION NEC */
"1641" = "1" /* EYE ENUC/IMPLAN/MUSC ATT */
"1642" = "1" /* EYE ENUC W IMPLANT NEC */
"1649" = "1" /* EYEBALL ENUCLEATION NEC */
"1651" = "1" /* RADICAL ORBITOMAXILLECT */
"1652" = "1" /* ORBIT EXENT W BONE REMOV */
"1659" = "1" /* ORBITAL EXENTERATION NEC */
"1661" = "1" /* 2NDRY OCULAR IMP INSERT */
"1662" = "1" /* REVIS/REINSERT OCUL IMP */
"1663" = "1" /* REVIS ENUC SOCKET W GRFT */
"1664" = "1" /* ENUC SOCKET REVIS NEC */
"1665" = "1" /* 2NDRY EXENT CAVITY GRAFT */
"1666" = "1" /* REVIS EXENTER CAVITY NEC */
"1669" = "1" /* 2ND OP POST EYE REM NEC */
"1671" = "1" /* REMOVE OCULAR IMPLANT */
"1672" = "1" /* REMOVE ORBITAL IMPLANT */
"1681" = "1" /* REPAIR OF ORBITAL WOUND */
"1682" = "1" /* REPAIR EYEBALL RUPTURE */
"1689" = "1" /* EYE/ORBIT INJ REPAIR NEC */
"1692" = "1" /* EXCISION ORBITAL LESION */
"1693" = "1" /* EXCISION EYE LESION NOS */
"1698" = "1" /* OPERATION ON ORBIT NEC */
"1699" = "1" /* OPERATION ON EYEBALL NEC */
"1711" = "1" /* LAP DIR ING HERN-GRAFT */
"1712" = "1" /* LAP INDIR ING HERN-GRAFT */
"1713" = "1" /* LAP ING HERN-GRAFT NOS */
"1721" = "1" /* LAP BIL DIR ING HRN-GRFT */
"1722" = "1" /* LAP BI INDIR ING HRN-GRF */
"1723" = "1" /* LAP BI DR/IND ING HRN-GR */
"1724" = "1" /* LAP BIL ING HERN-GRF NOS */
"1731" = "1" /* LAP MUL SEG RES LG INTES */
"1732" = "1" /* LAPAROSCOPIC CECECTOMY */
"1733" = "1" /* LAP RIGHT HEMICOLECTOMY */
"1734" = "1" /* LAP RES TRANSVERSE COLON */
"1735" = "1" /* LAP LEFT HEMICOLECTOMY */
"1736" = "1" /* LAP SIGMOIDECTOMY */
"1739" = "1" /* LAP PT EX LRG INTEST NEC */
"1751" = "1" /* IMPLANT CCM,TOTAL SYSTEM */
"1752" = "1" /* IMPLANT CCM PULSE GENRTR */
"1753" = "1" /*	PERCUTANEOUS ATHERECTOMY OF EXTRACRANIAL VESSEL(S) */
"1754" = "1" /*	PERCUTANEOUS ATHERECTOMY OF INTRACRANIAL VESSEL(S) */
"1755" = "1" /*	TRANSLUMINAL CORONARY ATHERECTOMY */
"1756" = "1" /*	ATHERECTOMY OF OTHER NON-CORONARY VESSEL(S) */
"1761" = "1" /* LITT LESN BRAIN,GUIDANCE */
"1762" = "1" /* LITT LES HD/NCK,GUIDANCE */
"1763" = "1" /* LITT LESN LIVER,GUIDANCE */
"1769" = "1" /* LITT LESN, GUIDE OTH/NOS */
"1821" = "1" /* PREAURICULAR SINUS EXCIS */
"1831" = "1" /* RAD EXCIS EXT EAR LES */
"1839" = "1" /* EXCIS EXTERNAL EAR NEC */
"185 " = "1" /* CORRECTION PROMINENT EAR */
"186 " = "1" /* EXT AUDIT CANAL RECONSTR */
"1871" = "1" /* CONSTRUCTION EAR AURICLE */
"1872" = "1" /* REATTACH AMPUTATED EAR */
"1879" = "1" /* PLASTIC REP EXT EAR NEC */
"189 " = "1" /* OTHER EXT EAR OPERATIONS */
"190 " = "1" /* STAPES MOBILIZATION */
"1911" = "1" /* STAPEDECT W REPLAC INCUS */
"1919" = "1" /* STAPEDECTOMY NEC */
"1921" = "1" /* REV STAPDEC W INCUS REPL */
"1929" = "1" /* STAPEDECTOMY REVIS NEC */
"193 " = "1" /* OSSICULAR CHAIN OP NEC */
"194 " = "1" /* MYRINGOPLASTY */
"1952" = "1" /* TYPE 2 TYMPANOPLASTY */
"1953" = "1" /* TYPE 3 TYMPANOPLASTY */
"1954" = "1" /* TYPE 4 TYMPANOPLASTY */
"1955" = "1" /* TYPE 5 TYMPANOPLASTY */
"196 " = "1" /* TYMPANOPLASTY REVISION */
"199 " = "1" /* MIDDLE EAR REPAIR NEC */
"2001" = "1" /* MYRINGOTOMY W INTUBATION */
"2021" = "1" /* MASTOID INCISION */
"2022" = "1" /* PETRUS PYRAM AIR CEL INC */
"2023" = "1" /* MIDDLE EAR INCISION */
"2032" = "1" /* MID & INNER EAR BIOPSY */
"2039" = "1" /* MID/IN EAR DX PROC NEC */
"2041" = "1" /* SIMPLE MASTOIDECTOMY */
"2042" = "1" /* RADICAL MASTOIDECTOMY */
"2049" = "1" /* MASTOIDECTOMY NEC */
"2051" = "1" /* EXCISE MIDDLE EAR LESION */
"2059" = "1" /* MIDDLE EAR EXCISION NEC */
"2061" = "1" /* INNER EAR FENESTRATION */
"2062" = "1" /* REVIS INNER EAR FENESTRA */
"2071" = "1" /* ENDOLYMPHATIC SHUNT */
"2072" = "1" /* INNER EAR INJECTION */
"2079" = "1" /* INC/EXC/DESTR IN EAR NEC */
"2091" = "1" /* TYMPANOSYMPATHECTOMY */
"2092" = "1" /* MASTOIDECTOMY REVISION */
"2093" = "1" /* REPAIR OVAL/ROUND WINDOW */
"2095" = "1" /* ELECMAG HEAR DEV IMPLANT */
"2096" = "1" /* IMPLT COCHLEAR PROST NOS */
"2097" = "1" /* IMP/REP SCHAN COCH PROS */
"2098" = "1" /* IMP/REP MCHAN COCHL PROS */
"2099" = "1" /* MID-INNER EAR OPS NEC */
"2104" = "1" /* ETHMOID ART LIGAT-EPIST */
"2105" = "1" /* MAX ART LIG FOR EPISTAX */
"2106" = "1" /* EXT CAROT ART LIG-EPIST */
"2107" = "1" /* NASAL SEPT GRFT-EPISTAX */
"2109" = "1" /* EPISTAXIS CONTROL NEC */
"214 " = "1" /* RESECTION OF NOSE */
"215 " = "1" /* SUBMUC NASAL SEPT RESECT */
"2161" = "1" /* DIATHER/CRYO TURBINECTOM */
"2162" = "1" /* TURBINATE FRACTURE */
"2169" = "1" /* TURBINECTOMY NEC */
"2172" = "1" /* OPEN REDUCTION NASAL FX */
"2182" = "1" /* NASAL FISTULA CLOSURE */
"2183" = "1" /* TOT NASAL RECONSTRUCTION */
"2184" = "1" /* REVISION RHINOPLASTY */
"2185" = "1" /* AUGMENTATION RHINOPLASTY */
"2186" = "1" /* LIMITED RHINOPLASTY */
"2187" = "1" /* RHINOPLASTY NEC */
"2188" = "1" /* SEPTOPLASTY NEC */
"2189" = "1" /* NASAL REPAIR NEC */
"2199" = "1" /* NASAL OPERATION NEC */
"2212" = "1" /* OPEN BIOPSY NASAL SINUS */
"2231" = "1" /* RADICAL MAXILLARY ANTROT */
"2239" = "1" /* EXT MAXILLARY ANTROT NEC */
"2241" = "1" /* FRONTAL SINUSOTOMY */
"2242" = "1" /* FRONTAL SINUSECTOMY */
"2250" = "1" /* SINUSOTOMY NOS */
"2251" = "1" /* ETHMOIDOTOMY */
"2252" = "1" /* SPHENOIDOTOMY */
"2253" = "1" /* MULTIPLE SINUS INCISION */
"2260" = "1" /* SINUSECTOMY NOS */
"2261" = "1" /* C-LUC EXC MAX SINUS LES */
"2262" = "1" /* EXC MAX SINUS LESION NEC */
"2263" = "1" /* ETHMOIDECTOMY */
"2264" = "1" /* SPHENOIDECTOMY */
"2271" = "1" /* NASAL SINUS FISTULA CLOS */
"2279" = "1" /* NASAL SINUS REPAIR NEC */
"229 " = "1" /* OTHER NASAL SINUS OPS */
"242 " = "1" /* GINGIVOPLASTY */
"244 " = "1" /* EXC OF DENTAL LES OF JAW */
"245 " = "1" /* ALVEOLOPLASTY */
"2502" = "1" /* OPEN BIOPSY OF TONGUE */
"251 " = "1" /* DESTRUCTION TONGUE LES */
"252 " = "1" /* PARTIAL GLOSSECTOMY */
"253 " = "1" /* COMPLETE GLOSSECTOMY */
"254 " = "1" /* RADICAL GLOSSECTOMY */
"2559" = "1" /* REPAIR OF TONGUE NEC */
"2594" = "1" /* OTHER GLOSSOTOMY */
"2599" = "1" /* TONGUE OPERATION NEC */
"2612" = "1" /* OPEN BX SALIV GLAND/DUCT */
"2621" = "1" /* SALIVARY CYST MARSUPIAL */
"2629" = "1" /* SALIV LESION EXCIS NEC */
"2630" = "1" /* SIALOADENECTOMY NOS */
"2631" = "1" /* PARTIAL SIALOADENECTOMY */
"2632" = "1" /* COMPLETE SIALOADENECTOMY */
"2641" = "1" /* SUTURE OF SALIV GLND LAC */
"2642" = "1" /* SALIVARY FISTULA CLOSURE */
"2649" = "1" /* SALIVARY REPAIR NEC */
"2699" = "1" /* SALIVARY OPERATION NEC */
"270 " = "1" /* DRAIN FACE & MOUTH FLOOR */
"271 " = "1" /* INCISION OF PALATE */
"2721" = "1" /* BONY PALATE BIOPSY */
"2722" = "1" /* UVULA AND SOFT PALATE BX */
"2731" = "1" /* LOC EXC BONY PALATE LES */
"2732" = "1" /* WIDE EXC BONY PALATE LES */
"2742" = "1" /* WIDE EXCISION OF LIP LES */
"2743" = "1" /* EXCISION OF LIP LES NEC */
"2749" = "1" /* EXCISION OF MOUTH NEC */
"2753" = "1" /* CLOSURE OF MOUTH FISTULA */
"2754" = "1" /* REPAIR OF CLEFT LIP */
"2755" = "1" /* FULL-THICK GRFT TO MOUTH */
"2756" = "1" /* SKIN GRAFT TO MOUTH NEC */
"2757" = "1" /* PEDICLE ATTACH TO MOUTH */
"2759" = "1" /* MOUTH REPAIR NEC */
"2761" = "1" /* SUTURE OF PALATE LACERAT */
"2762" = "1" /* CLEFT PALATE CORRECTION */
"2763" = "1" /* REVIS CLEFT PALAT REPAIR */
"2769" = "1" /* OTH PLASTIC REPAIR PALAT */
"2771" = "1" /* INCISION OF UVULA */
"2772" = "1" /* EXCISION OF UVULA */
"2773" = "1" /* REPAIR OF UVULA */
"2779" = "1" /* OTHER UVULA OPERATIONS */
"2792" = "1" /* MOUTH INCISION NOS */
"2799" = "1" /* ORAL CAVITY OPS NEC */
"280 " = "1" /* PERITONSILLAR I & D */
"2811" = "1" /* TONSIL&ADENOID BIOPSY */
"2819" = "1" /* TONSIL&ADENOID DX OP NEC */
"282 " = "1" /* TONSILLECTOMY */
"283 " = "1" /* TONSILLECTOMY/ADENOIDEC */
"284 " = "1" /* EXCISION OF TONSIL TAG */
"285 " = "1" /* EXCISION LINGUAL TONSIL */
"286 " = "1" /* ADENOIDECTOMY */
"287 " = "1" /* HEMORR CONTRL POST T & A */
"2891" = "1" /* INCIS TO REMOV TONSIL FB */
"2892" = "1" /* EXCIS TONSIL/ADENOID LES */
"2899" = "1" /* TONSIL/ADENOID OPS NEC */
"290 " = "1" /* PHARYNGOTOMY */
"292 " = "1" /* EXC BRANCHIAL CLEFT CYST */
"293 " = "1" /* EXC BRANCHIAL CLEFT CYST */
"2931" = "1" /* CRICOPHARYNGEAL MYOTOMY */
"2932" = "1" /* PHARYNGEAL DIVERTICULEC */
"2933" = "1" /* PHARYNGECTOMY */
"2939" = "1" /* EXCIS/DESTR LES PHAR NEC */
"294 " = "1" /* PLASTIC OP ON PHARYNX */
"2951" = "1" /* SUTURE OF PHARYNGEAL LAC */
"2952" = "1" /* CLOS BRANCH CLEFT FISTUL */
"2953" = "1" /* CLOS PHARYNX FISTULA NEC */
"2954" = "1" /* LYSIS PHARYNGEAL ADHES */
"2959" = "1" /* PHARYNGEAL REPAIR NEC */
"2992" = "1" /* DIVIS GLOSSOPHARYNG NERV */
"2999" = "1" /* PHARYNGEAL OPERATION NEC */
"3001" = "1" /* LARYNX CYST MARSUPIALIZ */
"3009" = "1" /* DESTRUCT LARYNX LES NEC */
"301 " = "1" /* HEMILARYNGECTOMY */
"3021" = "1" /* EPIGLOTTIDECTOMY */
"3022" = "1" /* VOCAL CORDECTOMY */
"3029" = "1" /* OTHER PART LARYNGECTOMY */
"303 " = "1" /* COMPLETE LARYNGECTOMY */
"304 " = "1" /* RADICAL LARYNGECTOMY */
"3121" = "1" /* MEDIASTINAL TRACHEOSTOMY */
"3129" = "1" /* OTHER PERM TRACHEOSTOMY */
"313 " = "1" /* INCIS LARYNX TRACHEA NEC */
"3145" = "1" /* OPN BX LARYNX OR TRACHEA */
"315 " = "1" /* LOCAL DESTRUC TRACH LES */
"3161" = "1" /* SUTURE OF LARYNGEAL LAC */
"3162" = "1" /* LARYNGEAL FISTULA CLOS */
"3163" = "1" /* LARYNGOSTOMY REVISION */
"3164" = "1" /* LARYNGEAL FX REPAIR */
"3169" = "1" /* OTHER LARYNGEAL REPAIR */
"3171" = "1" /* SUTURE OF TRACHEAL LACER */
"3172" = "1" /* CLOSURE OF TRACHEOSTOMY */
"3173" = "1" /* TRACHEA FISTULA CLOS NEC */
"3174" = "1" /* REVISION OF TRACHEOSTOMY */
"3175" = "1" /* TRACHEAL RECONSTRUCTION */
"3179" = "1" /* OTHER TRACHEAL REPAIR */
"3191" = "1" /* LARYNGEAL NERV DIVISION */
"3192" = "1" /* LYSIS TRACH/LARYNX ADHES */
"3198" = "1" /* OTH LARYNGEAL OPERATION */
"3199" = "1" /* OTHER TRACHEAL OPERATION */
"320 " = "1" /* OTHER TRACHEAL OPERATION */
"3209" = "1" /* OTHER DESTRUC BRONC LES */
"321 " = "1" /* OTHER BRONCHIAL EXCISION */
"3220" = "1" /* THORAC EXC LUNG LESION */
"3221" = "1" /* EMPHYSEMA BLEB PLICATION */
"3222" = "1" /* LUNG VOL REDUCTION SURG */
"3223" = "1" /* OPEN ABLTN LUNG LES/TISS */
"3224" = "1" /* PERC ABLTN LUNG LES/TISS */
"3225" = "1" /* THOR ABLTN LUNG LES/TISS */
"3226" = "1" /* ABLTN LUNG TISS NEC/NOS */
"3227" = "1" /* BRNC THRMPLSTYABLT MSCL	 */
"3229" = "1" /* DESTROY LOC LUNG LES NEC */
"323 " = "1" /* SEGMENTAL LUNG RESECTION */
"3230" = "1" /* THORAC SEG LUNG RESECT */
"3239" = "1" /* OTH SEG LUNG RESECT NOS */
"324 " = "1" /* LOBECTOMY OF LUNG */
"3241" = "1" /* THORAC LOBECTOMY LUNG */
"3249" = "1" /* LOBECTOMY OF LUNG NEC */
"325 " = "1" /* COMPLETE PNEUMONECTOMY */
"3250" = "1" /* THORACOSPC PNEUMONECTOMY */
"3259" = "1" /* OTHER PNEUMONECTOMY NOS */
"326 " = "1" /* RAD DISSEC THORAC STRUCT */
"329 " = "1" /* OTHER EXCISION OF LUNG */
"330 " = "1" /* INCISION OF BRONCHUS */
"331 " = "1" /* INCISION OF LUNG */
"3320" = "1" /* THORACOSCOPC LUNG BIOPSY */
"3325" = "1" /* OPEN BRONCHIAL BIOPSY */
"3327" = "1" /* CLOS ENDOSCOPIC LUNG BX */
"3328" = "1" /* OPEN LUNG BIOPSY */
"3329" = "1" /* BRONCH/LUNG DX PROC NEC */
"3334" = "1" /* THORACOPLASTY */
"3339" = "1" /* SURG COLLAPS OF LUNG NEC */
"3341" = "1" /* BRONCHIAL LACERAT SUTURE */
"3342" = "1" /* BRONCHIAL FISTULA CLOS */
"3343" = "1" /* LUNG LACERATION CLOSURE */
"3348" = "1" /* BRONCHIAL REPAIR NEC */
"3349" = "1" /* LUNG REPAIR NEC */
"335 " = "1" /* LUNG REPAIR NEC */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336 " = "1" /* COMB HEART/LUNG TRANSPLA */
"3392" = "1" /* BRONCHIAL LIGATION */
"3393" = "1" /* PUNCTURE OF LUNG */
"3398" = "1" /* BRONCHIAL OPERATION NEC */
"3399" = "1" /* LUNG OPERATION NEC */
"3402" = "1" /* EXPLORATORY THORACOTOMY */
"3403" = "1" /* REOPEN THORACOTOMY SITE */
"3406" = "1" /* THORAC DRAIN PLEURL CAV */
"341 " = "1" /* INCISION OF MEDIASTINUM */
"3420" = "1" /* THORACOSCOPIC PLEURAL BX */
"3421" = "1" /* TRANSPLEURA THORACOSCOPY */
"3422" = "1" /* MEDIASTINOSCOPY */
"3426" = "1" /* OPEN MEDIASTINAL BIOPSY */
"3427" = "1" /* BIOPSY OF DIAPHRAGM */
"3428" = "1" /* DX PROCEDURE THORAX NEC */
"3429" = "1" /* DX PROC MEDIASTINUM NEC */
"343 " = "1" /* DESTRUCT MEDIASTIN LES */
"344 " = "1" /* DESTRUCT CHEST WALL LES */
"3451" = "1" /* DECORTICATION OF LUNG */
"3452" = "1" /* THORACOSCOPC DECORT LUNG */
"3459" = "1" /* OTHER PLEURAL EXCISION */
"346 " = "1" /* SCARIFICATION OF PLEURA */
"3473" = "1" /* CLOS THORACIC FISTUL NEC */
"3474" = "1" /* PECTUS DEFORMITY REPAIR */
"3479" = "1" /* OTHER CHEST WALL REPAIR */
"3481" = "1" /* EXCISE DIAPHRAGM LESION */
"3482" = "1" /* SUTURE DIAPHRAGM LACERAT */
"3483" = "1" /* CLOSE DIAPHRAGM FISTULA */
"3484" = "1" /* OTHER DIAPHRAGM REPAIR */
"3485" = "1" /* IMPLANT DIAPHRA PACEMAKE */
"3489" = "1" /* DIAPHRAGM OPERATION NEC */
"3493" = "1" /* REPAIR OF PLEURA */
"3499" = "1" /* THORACIC OPERATION NEC */
"3500" = "1" /* CLOSED VALVOTOMY NOS */
"3501" = "1" /* CLOSED AORTIC VALVOTOMY */
"3502" = "1" /* CLOSED MITRAL VALVOTOMY */
"3503" = "1" /* CLOSED PULMON VALVOTOMY */
"3504" = "1" /* CLOSED TRICUSP VALVOTOMY */
"3505" = "1" /*	ENDOVASCULAR REPLACEMENT OF AORTIC VALVE */
"3506" = "1" /*	TRANSAPICAL REPLACEMENT OF AORTIC VALVE */
"3507" = "1" /*	ENDOVASCULAR REPLACEMENT OF PULMONARY  VALVE  */
"3508" = "1" /*	TRANSAPICAL REPLACEMENT OF PULMONARY VALVE  */
"3509" = "1" /*	ENDOVASCULAR REPLACEMENT OF UNSPECIFIED HEART VALVE */
"3510" = "1" /* OPEN VALVULOPLASTY NOS */
"3511" = "1" /* OPN AORTIC VALVULOPLASTY */
"3512" = "1" /* OPN MITRAL VALVULOPLASTY */
"3513" = "1" /* OPN PULMON VALVULOPLASTY */
"3514" = "1" /* OPN TRICUS VALVULOPLASTY */
"3520" = "1" /* REPLACE HEART VALVE NOS */
"3521" = "1" /* REPLACE AORT VALV-TISSUE */
"3522" = "1" /* REPLACE AORTIC VALVE NEC */
"3523" = "1" /* REPLACE MITR VALV-TISSUE */
"3524" = "1" /* REPLACE MITRAL VALVE NEC */
"3525" = "1" /* REPLACE PULM VALV-TISSUE */
"3526" = "1" /* REPLACE PULMON VALVE NEC */
"3527" = "1" /* REPLACE TRIC VALV-TISSUE */
"3528" = "1" /* REPLACE TRICUSP VALV NEC */
"3531" = "1" /* PAPILLARY MUSCLE OPS */
"3532" = "1" /* CHORDAE TENDINEAE OPS */
"3533" = "1" /* ANNULOPLASTY */
"3534" = "1" /* INFUNDIBULECTOMY */
"3535" = "1" /* TRABECUL CARNEAE CORD OP */
"3539" = "1" /* TISS ADJ TO VALV OPS NEC */
"3542" = "1" /* CREATE SEPTAL DEFECT */
"3550" = "1" /* PROSTH REP HRT SEPTA NOS */
"3551" = "1" /* PROS REP ATRIAL DEF-OPN */
"3552" = "1" /* PROS REPAIR ATRIA DEF-CL */
"3553" = "1" /* PROST REPAIR VENTRIC DEF */
"3554" = "1" /* PROS REP ENDOCAR CUSHION */
"3555" = "1" /* PROS REP VENTRC DEF-CLOS */
"3560" = "1" /* GRFT REPAIR HRT SEPT NOS */
"3561" = "1" /* GRAFT REPAIR ATRIAL DEF */
"3562" = "1" /* GRAFT REPAIR VENTRIC DEF */
"3563" = "1" /* GRFT REP ENDOCAR CUSHION */
"3570" = "1" /* HEART SEPTA REPAIR NOS */
"3571" = "1" /* ATRIA SEPTA DEF REP NEC */
"3572" = "1" /* VENTR SEPTA DEF REP NEC */
"3573" = "1" /* ENDOCAR CUSHION REP NEC */
"3581" = "1" /* TOT REPAIR TETRAL FALLOT */
"3582" = "1" /* TOTAL REPAIR OF TAPVC */
"3583" = "1" /* TOT REP TRUNCUS ARTERIOS */
"3584" = "1" /* TOT COR TRANSPOS GRT VES */
"3591" = "1" /* INTERAT VEN RETRN TRANSP */
"3592" = "1" /* CONDUIT RT VENT-PUL ART */
"3593" = "1" /* CONDUIT LEFT VENTR-AORTA */
"3594" = "1" /* CONDUIT ARTIUM-PULM ART */
"3595" = "1" /* HEART REPAIR REVISION */
"3596" = "1" /* PERC HEART VALVULOPLASTY */
"3597" = "1" /* PERC MTRL VLV REPR W IMP */	
"3598" = "1" /* OTHER HEART SEPTA OPS */
"3599" = "1" /* OTHER HEART VALVE OPS */
"3600" = "1" /* OTHER HEART VALVE OPS */
"3601" = "1" /* PTCA-1 VES/ATH W/O AGENT */
"3602" = "1" /* PTCA-1 VES/ATH W AGENT */
"3603" = "1" /* OPEN CORONRY ANGIOPLASTY */
"3605" = "1" /* PTCA-MULTIPLE VESSEL/ATH */
"3609" = "1" /* REM OF COR ART OBSTR NEC */
"3610" = "1" /* AORTOCORONARY BYPASS NOS */
"3611" = "1" /* AORTOCOR BYPAS-1 COR ART */
"3612" = "1" /* AORTOCOR BYPAS-2 COR ART */
"3613" = "1" /* AORTOCOR BYPAS-3 COR ART */
"3614" = "1" /* AORTCOR BYPAS-4+ COR ART */
"3615" = "1" /* 1 INT MAM-COR ART BYPASS */
"3616" = "1" /* 2 INT MAM-COR ART BYPASS */
"3617" = "1" /* ABD-CORON ARTERY BYPASS */
"3619" = "1" /* HRT REVAS BYPS ANAS NEC */
"362 " = "1" /* ARTERIAL IMPLANT REVASC */
"363 " = "1" /* ARTERIAL IMPLANT REVASC */
"3631" = "1" /* OPEN CHEST TRANS REVASC */
"3632" = "1" /* OTH TRANSMYO REVASCULAR */
"3633" = "1" /* ENDO TRANSMYO REVASCULAR */
"3634" = "1" /* PERC TRANSMYO REVASCULAR */
"3639" = "1" /* OTH HEART REVASCULAR */
"3691" = "1" /* CORON VESS ANEURYSM REP */
"3699" = "1" /* HEART VESSEL OP NEC */
"3710" = "1" /* INCISION OF HEART NOS */
"3711" = "1" /* CARDIOTOMY */
"3712" = "1" /* PERICARDIOTOMY */
"3724" = "1" /* PERICARDIAL BIOPSY */
"3731" = "1" /* PERICARDIECTOMY */
"3732" = "1" /* HEART ANEURYSM EXCISION */
"3733" = "1" /* EXC/DEST HRT LESION OPEN */
"3734" = "1" /* EXC/DEST HRT LES OTHER */
"3735" = "1" /* PARTIAL VENTRICULECTOMY */
"3737" = "1" /* EXC/DEST HRT LES THRSPC	 */
"374 " = "1" /* HEART & PERICARD REPAIR */
"3741" = "1" /* IMPL CARDIAC SUPPORT DEV */
"3749" = "1" /* HEART/PERICARD REPR NEC */
"375 " = "1" /* HEART & PERICARD REPAIR */
"3751" = "1" /* HEART TRANSPLANTATION */
"3752" = "1" /* IMPLANT TOT REP HRT SYS */
"3753" = "1" /* REPL/REP THORAC UNIT HRT */
"3754" = "1" /* REPL/REP OTH TOT HRT SYS */
"3755" = "1" /* REM INT BIVENT HRT SYS */
"3760" = "1" /* IMP BIVN EXT HRT AST SYS */
"3761" = "1" /* PULSATION BALLOON IMPLAN */
"3762" = "1" /* IMPLANT HRT ASST SYS NEC */
"3763" = "1" /* REPLACE HRT ASSIST SYST */
"3764" = "1" /* REMOVE HEART ASSIST SYS */
"3765" = "1" /* IMP EXT PUL HRT ASST SYS */
"3766" = "1" /* IMP IMP PUL HRT ASST SYS */
"3767" = "1" /* IMP CARDIOMYOSTIMUL SYS */
"3768" = "1" /* PERCUTAN HRT ASSIST SYST */
"3774" = "1" /* INT OR REPL LEAD EPICAR */
"3775" = "1" /* REVISION OF LEAD */
"3776" = "1" /* REPL TV ATRI-VENT LEAD */
"3777" = "1" /* REMOVAL OF LEAD W/O REPL */
"3779" = "1" /* REVIS OR RELOCATE POCKET */
"3780" = "1" /* INT OR REPL PERM PACEMKR */
"3785" = "1" /* REPL PACEM W 1-CHAM, NON */
"3786" = "1" /* REPL PACEM 1-CHAM, RATE */
"3787" = "1" /* REPL PACEM W DUAL-CHAM */
"3789" = "1" /* REVISE OR REMOVE PACEMAK */
"3791" = "1" /* OPN CHEST CARDIAC MASSAG */
"3794" = "1" /* IMPLT/REPL CARDDEFIB TOT */
"3795" = "1" /* IMPLT CARDIODEFIB LEADS */
"3796" = "1" /* IMPLT CARDIODEFIB GENATR */
"3797" = "1" /* REPL CARDIODEFIB LEADS */
"3798" = "1" /* REPL CARDIODEFIB GENRATR */
"3799" = "1" /* OTHER HEART/PERICARD OPS */
"3800" = "1" /* INCISION OF VESSEL NOS */
"3801" = "1" /* INTRACRAN VESSEL INCIS */
"3802" = "1" /* HEAD/NECK VES INCIS NEC */
"3803" = "1" /* UPPER LIMB VESSEL INCIS */
"3804" = "1" /* INCISION OF AORTA */
"3805" = "1" /* THORACIC VESSEL INC NEC */
"3806" = "1" /* ABDOMEN ARTERY INCISION */
"3807" = "1" /* ABDOMINAL VEIN INCISION */
"3808" = "1" /* LOWER LIMB ARTERY INCIS */
"3809" = "1" /* LOWER LIMB VEIN INCISION */
"3810" = "1" /* ENDARTERECTOMY NOS */
"3811" = "1" /* INTRACRAN ENDARTERECTOMY */
"3812" = "1" /* HEAD & NECK ENDARTER NEC */
"3813" = "1" /* UPPER LIMB ENDARTERECTOM */
"3814" = "1" /* ENDARTERECTOMY OF AORTA */
"3815" = "1" /* THORACIC ENDARTERECTOMY */
"3816" = "1" /* ABDOMINAL ENDARTERECTOMY */
"3818" = "1" /* LOWER LIMB ENDARTERECT */
"3821" = "1" /* BLOOD VESSEL BIOPSY */
"3826" = "1" /* INSERTION OF IMPLANTABLE PRESSURE SENSOR WITHOUT LEAD FOR INTRACARDIAC OR GREAT VESSEL HEMODYNAMIC MONITORING */
"3829" = "1" /* BLOOD VESSEL DX PROC NEC */
"3830" = "1" /* VESSEL RESECT/ANAST NOS */
"3831" = "1" /* INTRACRAN VES RESEC-ANAS */
"3832" = "1" /* HEAD/NECK VES RESEC-ANAS */
"3833" = "1" /* ARM VESSEL RESECT/ANAST */
"3834" = "1" /* AORTA RESECTION & ANAST */
"3835" = "1" /* THOR VESSEL RESECT/ANAST */
"3836" = "1" /* ABD VESSEL RESECT/ANAST */
"3837" = "1" /* ABD VEIN RESECT & ANAST */
"3838" = "1" /* LEG ARTERY RESECT/ANAST */
"3839" = "1" /* LEG VEIN RESECT/ANASTOM */
"3840" = "1" /* VESSEL RESECT/REPLAC NOS */
"3841" = "1" /* INTRACRAN VES RESEC-REPL */
"3842" = "1" /* HEAD/NECK VES RESEC-REPL */
"3843" = "1" /* ARM VES RESECT W REPLACE */
"3844" = "1" /* RESECT ABDM AORTA W REPL */
"3845" = "1" /* RESECT THORAC VES W REPL */
"3846" = "1" /* ABD ARTERY RESEC W REPLA */
"3847" = "1" /* ABD VEIN RESECT W REPLAC */
"3848" = "1" /* LEG ARTERY RESEC W REPLA */
"3849" = "1" /* LEG VEIN RESECT W REPLAC */
"3850" = "1" /* VARICOSE V LIG-STRIP NOS */
"3851" = "1" /* INTCRAN VAR V LIG-STRIP */
"3852" = "1" /* HEAD/NECK VAR V LIG-STR */
"3853" = "1" /* ARM VARICOSE V LIG-STRIP */
"3855" = "1" /* THORAC VAR V LIG-STRIP */
"3857" = "1" /* ABD VARICOS V LIGA-STRIP */
"3859" = "1" /* LEG VARICOS V LIGA-STRIP */
"3860" = "1" /* EXCISION OF VESSEL NOS */
"3861" = "1" /* INTRACRAN VESSEL EXCIS */
"3862" = "1" /* HEAD/NECK VESSEL EXCIS */
"3863" = "1" /* ARM VESSEL EXCISION */
"3864" = "1" /* EXCISION OF AORTA */
"3865" = "1" /* THORACIC VESSEL EXCISION */
"3866" = "1" /* ABDOMINAL ARTERY EXCIS */
"3867" = "1" /* ABDOMINAL VEIN EXCISION */
"3868" = "1" /* LEG ARTERY EXCISION */
"3869" = "1" /* LEG VEIN EXCISION */
"3880" = "1" /* SURG VESSEL OCCLUS NEC */
"3881" = "1" /* OCCLUS INTRACRAN VES NEC */
"3882" = "1" /* OCCLUS HEAD/NECK VES NEC */
"3883" = "1" /* OCCLUDE ARM VESSEL NEC */
"3884" = "1" /* OCCLUDE AORTA NEC */
"3885" = "1" /* OCCLUDE THORACIC VES NEC */
"3886" = "1" /* OCCLUDE ABD ARTERY NEC */
"3887" = "1" /* OCCLUDE ABD VEIN NEC */
"3888" = "1" /* OCCLUDE LEG ARTERY NEC */
"3889" = "1" /* OCCLUDE LEG VEIN NEC */
"390 " = "1" /* SYSTEMIC-PULM ART SHUNT */
"391 " = "1" /* INTRA-ABD VENOUS SHUNT */
"3921" = "1" /* CAVAL-PULMON ART ANASTOM */
"3922" = "1" /* AORTA-SUBCLV-CAROT BYPAS */
"3923" = "1" /* INTRATHORACIC SHUNT NEC */
"3924" = "1" /* AORTA-RENAL BYPASS */
"3925" = "1" /* AORTA-ILIAC-FEMOR BYPASS */
"3926" = "1" /* INTRA-ABDOMIN SHUNT NEC */
"3927" = "1" /* DIALYSIS ARTERIOVENOSTOM */
"3928" = "1" /* EXTRACRAN-INTRACR BYPASS */
"3929" = "1" /* VASC SHUNT & BYPASS NEC */
"3930" = "1" /* SUTURE OF VESSEL NOS */
"3931" = "1" /* SUTURE OF ARTERY */
"3932" = "1" /* SUTURE OF VEIN */
"3941" = "1" /* POSTOP VASC OP HEM CONTR */
"3942" = "1" /* REVIS REN DIALYSIS SHUNT */
"3943" = "1" /* REMOV REN DIALYSIS SHUNT */
"3949" = "1" /* VASC PROC REVISION NEC */
"3950" = "1" /* ANGIO/ATH NON-CORO VES */
"3951" = "1" /* CLIPPING OF ANEURYSM */
"3952" = "1" /* ANEURYSM REPAIR NEC */
"3953" = "1" /* ARTERIOVEN FISTULA REP */
"3954" = "1" /* RE-ENTRY OPERATION */
"3955" = "1" /* REIMPLAN ABERR RENAL VES */
"3956" = "1" /* REPAIR VESS W TIS PATCH */
"3957" = "1" /* REP VESS W SYNTH PATCH */
"3958" = "1" /* REPAIR VESS W PATCH NOS */
"3959" = "1" /* REPAIR OF VESSEL NEC */
"397 " = "1" /* PER CARDIOPULMON BYPASS */
"3971" = "1" /* ENDO IMPL GRFT ABD AORTA */
"3972" = "1" /* ENDOVASC REPAIR HEAD VES */
"3973" = "1" /* ENDO IMP GRFT THOR AORTA */
"3974" = "1" /* ENDO REM OBS HD/NECK VES */
"3975" = "1" /* ENDO EMB HD/NK,BARE COIL */
"3976" = "1" /* ENDO EM HD/NK,BIOAC COIL */
"3977" = "1" /*	TEMPORARY (PARTIAL) THERAPEUTIC ENDOVASCULAR OCCLUSION OF VESSEL */
"3978" = "1" /*	ENDOVASCULAR IMPLANTATION OF BRANCHING OR FENESTRATED GRAFT(S) IN AORTA*/
"3979" = "1" /* ENDO REPAIR OTHER VESSEL */
"398 " = "1" /* CARTD BODY/SINUS/VASC OP */
"3981" = "1" /* IMP CRTD SINUS STMTOTL	 */
"3982" = "1" /* IMP/REP CRTD SINUS LEAD	 */
"3983" = "1" /* IMP/REP CRTD SINUS GNRTR */	
"3984" = "1" /* REV CRTD SINUS STM LEADS */	
"3985" = "1" /* REV CRTD SINUS PULSE GEN */	
"3986" = "1" /* REM CRTD SINUS STM TOTL	 */
"3987" = "1" /* REM CRTD SINUS STM LEAD	 */
"3988" = "1" /* REM CRTD SINUS PULSE GEN */	
"3989" = "1" /* OTH CARTD BODY/SINUS OP	 */
"3991" = "1" /* FREEING OF VESSEL */
"3992" = "1" /* VEIN INJECT-SCLEROS AGNT */
"3993" = "1" /* INSERT VES-TO-VES CANNUL */
"3994" = "1" /* REPLAC VES-TO-VES CANNUL */
"3998" = "1" /* HEMORRHAGE CONTROL NOS */
"3999" = "1" /* VESSEL OPERATION NEC */
"400 " = "1" /* INCIS LYMPHATIC STRUCTUR */
"4011" = "1" /* LYMPHATIC STRUCT BIOPSY */
"4019" = "1" /* LYMPHATIC DIAG PROC NEC */
"4021" = "1" /* EXCIS DEEP CERVICAL NODE */
"4022" = "1" /* EXCISE INT MAMMARY NODE */
"4023" = "1" /* EXCISE AXILLARY NODE */
"4024" = "1" /* EXCISE INGUINAL NODE */
"4029" = "1" /* SIMP EXC LYMPH STRUC NEC */
"403 " = "1" /* REGIONAL LYMPH NODE EXC */
"4040" = "1" /* RAD NECK DISSECTION NOS */
"4041" = "1" /* UNILAT RAD NECK DISSECT */
"4042" = "1" /* BILAT RAD NECK DISSECT */
"4050" = "1" /* RAD NODE DISSECTION NOS */
"4051" = "1" /* RAD DISSEC AXILLARY NODE */
"4052" = "1" /* RAD DISSEC PERIAORT NODE */
"4053" = "1" /* RAD DISSECT ILIAC NODES */
"4054" = "1" /* RADICAL GROIN DISSECTION */
"4059" = "1" /* RAD NODE DISSECTION NEC */
"4061" = "1" /* THORAC DUCT CANNULATION */
"4062" = "1" /* THORACIC DUCT FISTULIZAT */
"4063" = "1" /* CLOSE THORACIC DUCT FIST */
"4064" = "1" /* LIGATE THORACIC DUCT */
"4069" = "1" /* THORACIC DUCT OP NEC */
"409 " = "1" /* LYMPH STRUCTURE OP NEC */
"412 " = "1" /* SPLENOTOMY */
"4133" = "1" /* OPEN SPLEEN BIOPSY */
"4141" = "1" /* SPLENIC CYST MARSUPIAL */
"4142" = "1" /* EXC SPLENIC LESION/TISS */
"4143" = "1" /* PARTIAL SPLENECTOMY */
"415 " = "1" /* TOTAL SPLENECTOMY */
"4193" = "1" /* EXC OF ACCESSORY SPLEEN */
"4194" = "1" /* SPLEEN TRANSPLANTATION */
"4195" = "1" /* REPAIR OF SPLEEN */
"4199" = "1" /* SPLEEN OPERATION NEC */
"4201" = "1" /* ESOPHAGEAL WEB INCISION */
"4209" = "1" /* ESOPHAGEAL INCISION NEC */
"4210" = "1" /* ESOPHAGOSTOMY NOS */
"4211" = "1" /* CERVICAL ESOPHAGOSTOMY */
"4212" = "1" /* ESOPH POUCH EXTERIORIZAT */
"4219" = "1" /* EXT FISTULIZAT ESOPH NEC */
"4221" = "1" /* ESOPHAGOSCOPY BY INCIS */
"4225" = "1" /* OPEN BIOPSY OF ESOPHAGUS */
"4231" = "1" /* LOC EXCIS ESOPH DIVERTIC */
"4232" = "1" /* LOCAL EXCIS ESOPHAG NEC */
"4239" = "1" /* DESTRUCT ESOPHAG LES NEC */
"4240" = "1" /* ESOPHAGECTOMY NOS */
"4241" = "1" /* PARTIAL ESOPHAGECTOMY */
"4242" = "1" /* TOTAL ESOPHAGECTOMY */
"4251" = "1" /* THORAC ESOPHAGOESOPHAGOS */
"4252" = "1" /* THORAC ESOPHAGOGASTROST */
"4253" = "1" /* THORAC SM BOWEL INTERPOS */
"4254" = "1" /* THORAC ESOPHAGOENTER NEC */
"4255" = "1" /* THORAC LG BOWEL INTERPOS */
"4256" = "1" /* THORAC ESOPHAGOCOLOS NEC */
"4258" = "1" /* THORAC INTERPOSITION NEC */
"4259" = "1" /* THORAC ESOPHAG ANAST NEC */
"4261" = "1" /* STERN ESOPHAGOESOPHAGOST */
"4262" = "1" /* STERN ESOPHAGOGASTROSTOM */
"4263" = "1" /* STERN SM BOWEL INTERPOS */
"4264" = "1" /* STERN ESOPHAGOENTER NEC */
"4265" = "1" /* STERN LG BOWEL INTERPOS */
"4266" = "1" /* STERN ESOPHAGOCOLOS NEC */
"4268" = "1" /* STERN INTERPOSITION NEC */
"4269" = "1" /* STERN ESOPHAG ANAST NEC */
"427 " = "1" /* ESOPHAGOMYOTOMY */
"4282" = "1" /* SUTURE ESOPHAGEAL LACER */
"4283" = "1" /* ESOPHAGOSTOMY CLOSURE */
"4284" = "1" /* ESOPH FISTULA REPAIR NEC */
"4285" = "1" /* ESOPHAG STRICTURE REPAIR */
"4286" = "1" /* PROD SUBQ TUNNEL NO ANAS */
"4287" = "1" /* ESOPHAGEAL GRAFT NEC */
"4289" = "1" /* ESOPHAGEAL REPAIR NEC */
"4291" = "1" /* LIGATION ESOPH VARIX */
"430 " = "1" /* GASTROTOMY */
"431 " = "1" /* GASTROTOMY */
"432 " = "1" /* OTHER GASTROSTOMY */
"433 " = "1" /* PYLOROMYOTOMY */
"4342" = "1" /* LOCAL GASTR EXCISION NEC */
"4349" = "1" /* LOCAL GASTR DESTRUCT NEC */
"435 " = "1" /* PROXIMAL GASTRECTOMY */
"436 " = "1" /* DISTAL GASTRECTOMY */
"437 " = "1" /* PART GASTREC W JEJ ANAST */
"4381" = "1" /* PART GAST W JEJ TRANSPOS */
"4382" = "1" /*	LAPAROSCOPIC VERTICAL (SLEEVE) GASTERECTOMY  */
"4389" = "1" /* PARTIAL GASTRECTOMY NEC */
"4391" = "1" /* TOT GAST W INTES INTERPO */
"4399" = "1" /* TOTAL GASTRECTOMY NEC */
"4400" = "1" /* VAGOTOMY NOS */
"4401" = "1" /* TRUNCAL VAGOTOMY */
"4402" = "1" /* HIGHLY SELECT VAGOTOMY */
"4403" = "1" /* SELECTIVE VAGOTOMY NEC */
"4411" = "1" /* TRANSABDOMIN GASTROSCOPY */
"4415" = "1" /* OPEN GASTRIC BIOPSY */
"442 " = "1" /* GASTRIC DIAGNOS PROC NEC */
"4421" = "1" /* DILATE PYLORUS, INCISION */
"4429" = "1" /* OTHER PYLOROPLASTY */
"4431" = "1" /* HIGH GASTRIC BYPASS */
"4432" = "1" /* PERCU GASTROJEJUNOSTOMY */
"4438" = "1" /* LAP GASTROENTEROSTOMY */
"4439" = "1" /* GASTROENTEROSTOMY NEC */
"4440" = "1" /* SUTURE PEPTIC ULCER NOS */
"4441" = "1" /* SUT GASTRIC ULCER SITE */
"4442" = "1" /* SUTURE DUODEN ULCER SITE */
"445 " = "1" /* REVISION GASTRIC ANASTOM */
"4461" = "1" /* SUTURE GASTRIC LACERAT */
"4463" = "1" /* CLOSE GASTRIC FISTUL NEC */
"4464" = "1" /* GASTROPEXY */
"4465" = "1" /* ESOPHAGOGASTROPLASTY */
"4466" = "1" /* CREAT ESOPHAGASTR SPHINC */
"4467" = "1" /* LAP CREAT ESOPH SPHINCT */
"4468" = "1" /* LAPAROSCOP GASTROPLASTY */
"4469" = "1" /* GASTRIC REPAIR NEC */
"4491" = "1" /* LIGATE GASTRIC VARICES */
"4492" = "1" /* INTRAOP GASTRIC MANIPUL */
"4495" = "1" /* LAP GASTRIC RESTRIC PROC */
"4496" = "1" /* LAP REV GAST RESTRI PROC */
"4497" = "1" /* LAP REM GAST RESTRIC DEV */
"4498" = "1" /* ADJUST GAST RESTRICT DEV */
"4499" = "1" /* GASTRIC OPERATION NEC */
"4500" = "1" /* INTESTINAL INCISION NOS */
"4501" = "1" /* DUODENAL INCISION */
"4502" = "1" /* SMALL BOWEL INCISION NEC */
"4503" = "1" /* LARGE BOWEL INCISION */
"4511" = "1" /* TRANSAB SM BOWEL ENDOSC */
"4515" = "1" /* OPEN SMALL BOWEL BIOPSY */
"4521" = "1" /* TRANSAB LG BOWEL ENDOSC */
"4526" = "1" /* OPEN LARGE BOWEL BIOPSY */
"4531" = "1" /* OTH EXCISE DUODENUM LES */
"4532" = "1" /* DESTRUCT DUODEN LES NEC */
"4533" = "1" /* LOCAL EXCIS SM BOWEL NEC */
"4534" = "1" /* DESTR SM BOWEL LES NEC */
"4541" = "1" /* EXCISE LG INTESTINE LES */
"4549" = "1" /* DESTRUC LG BOWEL LES NEC */
"4550" = "1" /* INTEST SEG ISOLAT NOS */
"4551" = "1" /* SM BOWEL SEGMENT ISOLAT */
"4552" = "1" /* LG BOWEL SEGMENT ISOLAT */
"4561" = "1" /* MULT SEG SM BOWEL EXCIS */
"4562" = "1" /* PART SM BOWEL RESECT NEC */
"4563" = "1" /* TOTAL REMOVAL SM BOWEL */
"4571" = "1" /* MULT SEG LG BOWEL EXCIS */
"4572" = "1" /* CECECTOMY */
"4573" = "1" /* RIGHT HEMICOLECTOMY */
"4574" = "1" /* TRANSVERSE COLON RESECT */
"4575" = "1" /* LEFT HEMICOLECTOMY */
"4576" = "1" /* SIGMOIDECTOMY */
"4579" = "1" /* PART LG BOWEL EXCIS NEC */
"458 " = "1" /* TOT INTRA-ABD COLECTOMY */
"4581" = "1" /* LAP TOT INTR-AB COLECTMY */
"4582" = "1" /* OP TOT INTR-ABD COLECTMY */
"4583" = "1" /* TOT ABD COLECTMY NEC/NOS */
"4590" = "1" /* INTESTINAL ANASTOM NOS */
"4591" = "1" /* SM-TO-SM BOWEL ANASTOM */
"4592" = "1" /* SM BOWEL-RECT STUMP ANAS */
"4593" = "1" /* SMALL-TO-LARGE BOWEL NEC */
"4594" = "1" /* LG-TO-LG BOWEL ANASTOM */
"4595" = "1" /* ANAL ANASTOMOSIS */
"4601" = "1" /* SM BOWEL EXTERIORIZATION */
"4602" = "1" /* RESECT EXT SEG SM BOWEL */
"4603" = "1" /* LG BOWEL EXTERIORIZATION */
"4604" = "1" /* RESECT EXT SEG LG BOWEL */
"4610" = "1" /* COLOSTOMY NOS */
"4611" = "1" /* TEMPORARY COLOSTOMY */
"4612" = "1" /* TEMPORARY COLOSTOMY */
"4613" = "1" /* PERMANENT COLOSTOMY */
"4620" = "1" /* ILEOSTOMY NOS */
"4621" = "1" /* TEMPORARY ILEOSTOMY */
"4622" = "1" /* CONTINENT ILEOSTOMY */
"4623" = "1" /* PERMANENT ILEOSTOMY NEC */
"4640" = "1" /* INTEST STOMA REVIS NOS */
"4641" = "1" /* SM BOWEL STOMA REVISION */
"4642" = "1" /* PERICOLOST HERNIA REPAIR */
"4643" = "1" /* LG BOWEL STOMA REVIS NEC */
"4650" = "1" /* INTEST STOMA CLOSURE NOS */
"4651" = "1" /* SM BOWEL STOMA CLOSURE */
"4652" = "1" /* LG BOWEL STOMA CLOSURE */
"4660" = "1" /* INTESTINAL FIXATION NOS */
"4661" = "1" /* SM BOWEL-ABD WALL FIXAT */
"4662" = "1" /* SMALL BOWEL FIXATION NEC */
"4663" = "1" /* LG BOWEL-ABD WALL FIXAT */
"4664" = "1" /* LARGE BOWEL FIXATION NEC */
"4671" = "1" /* DUODENAL LACERAT SUTURE */
"4672" = "1" /* DUODENAL FISTULA CLOSURE */
"4673" = "1" /* SMALL BOWEL SUTURE NEC */
"4674" = "1" /* CLOSE SM BOWEL FIST NEC */
"4675" = "1" /* SUTURE LG BOWEL LACERAT */
"4676" = "1" /* CLOSE LG BOWEL FISTULA */
"4679" = "1" /* REPAIR OF INTESTINE NEC */
"4680" = "1" /* INTRA-AB BOWEL MANIP NOS */
"4681" = "1" /* INTRA-ABD SM BOWEL MANIP */
"4682" = "1" /* INTRA-ABD LG BOWEL MANIP */
"4691" = "1" /* MYOTOMY OF SIGMOID COLON */
"4692" = "1" /* MYOTOMY OF COLON NEC */
"4693" = "1" /* REVISE SM BOWEL ANASTOM */
"4694" = "1" /* REVISE LG BOWEL ANASTOM */
"4697" = "1" /* TRANSPLANT OF INTESTINE */
"4699" = "1" /* INTESTINAL OP NEC */
"470 " = "1" /* INTESTINAL OP NEC */
"4701" = "1" /* LAP APPENDECTOMY */
"4709" = "1" /* OTHER APPENDECTOMY */
"471 " = "1" /* OTHER APPENDECTOMY */
"4711" = "1" /* LAP INCID APPENDECTOMY */
"4719" = "1" /* OTHER INCID APPENDECTOMY */
"472 " = "1" /* DRAIN APPENDICEAL ABSC */
"4791" = "1" /* APPENDICOSTOMY */
"4792" = "1" /* CLOSE APPENDICEAL FISTUL */
"4799" = "1" /* APPENDICEAL OPS NEC */
"480 " = "1" /* PROCTOTOMY */
"481 " = "1" /* PROCTOSTOMY */
"4821" = "1" /* TRANSAB PROCTOSIGMOIDOSC */
"4825" = "1" /* OPEN RECTAL BIOPSY */
"4835" = "1" /* LOCAL EXCIS RECTAL LES */
"4840" = "1" /* PULL-THRU RES RECTUM NOS */
"4841" = "1" /* SOAVE SUBMUC RECT RESECT */
"4842" = "1" /* LAP PULL-THRU RES RECTUM */
"4843" = "1" /* OPN PULL-THRU RES RECTUM */
"4849" = "1" /* PULL-THRU RECT RESEC NEC */
"485 " = "1" /* ABD-PERINEAL RECT RESECT */
"4850" = "1" /* ABDPERNEAL RES RECTM NOS */
"4851" = "1" /* LAP ABDPERNEAL RESC REC */
"4852" = "1" /* OPN ABDPERNEAL RESC REC */
"4859" = "1" /* ABDPERNEAL RESC RECT NEC */
"4861" = "1" /* TRANSSAC RECTOSIGMOIDECT */
"4862" = "1" /* ANT RECT RESECT W COLOST */
"4863" = "1" /* ANTERIOR RECT RESECT NEC */
"4864" = "1" /* POSTERIOR RECT RESECTION */
"4865" = "1" /* DUHAMEL RECTAL RESECTION */
"4866" = "1" /* DUHAMEL RECTAL RESECTION */
"4869" = "1" /* RECTAL RESECTION NEC */
"4871" = "1" /* SUTURE OF RECTAL LACER */
"4872" = "1" /* CLOSURE OF PROCTOSTOMY */
"4873" = "1" /* CLOSE RECTAL FIST NEC */
"4874" = "1" /* RECTORECTOSTOMY */
"4875" = "1" /* ABDOMINAL PROCTOPEXY */
"4876" = "1" /* PROCTOPEXY NEC */
"4879" = "1" /* REPAIR OF RECTUM NEC */
"4881" = "1" /* PERIRECTAL INCISION */
"4882" = "1" /* PERIRECTAL EXCISION */
"4891" = "1" /* INCIS RECTAL STRICTURE */
"4892" = "1" /* ANORECTAL MYOMECTOMY */
"4893" = "1" /* REPAIR PERIRECT FISTULA */
"4899" = "1" /* RECTAL PERIRECT OP NEC */
"4901" = "1" /* INCIS PERIANAL ABSCESS */
"4902" = "1" /* PERIANAL INCISION NEC */
"4904" = "1" /* PERIANAL EXCISION NEC */
"4911" = "1" /* ANAL FISTULOTOMY */
"4912" = "1" /* ANAL FISTULECTOMY */
"493 " = "1" /* ANAL/PERIAN DX PROC NEC */
"4939" = "1" /* OTHER DESTRUC ANUS LES */
"4944" = "1" /* HEMORRHOID CRYOTHERAPY */
"4945" = "1" /* HEMORRHOID LIGATION */
"4946" = "1" /* HEMORRHOIDECTOMY */
"4949" = "1" /* HEMORRHOID PROCEDURE NEC */
"4951" = "1" /* LEFT LAT SPHINCTEROTOMY */
"4952" = "1" /* POST SPHINCTEROTOMY */
"4959" = "1" /* ANAL SPHINCTEROTOMY NEC */
"496 " = "1" /* EXCISION OF ANUS */
"4971" = "1" /* SUTURE ANAL LACERATION */
"4972" = "1" /* ANAL CERCLAGE */
"4973" = "1" /* CLOSURE OF ANAL FISTULA */
"4974" = "1" /* GRACILIS MUSC TRANSPLAN */
"4975" = "1" /* IMPL OR REV ART ANAL SPH */
"4976" = "1" /* REMOV ART ANAL SPHINCTER */
"4979" = "1" /* ANAL SPHINCT REPAIR NEC */
"4991" = "1" /* INCISION OF ANAL SEPTUM */
"4992" = "1" /* INSERT SUBQ ANAL STIMUL */
"4993" = "1" /* ANAL INCISION NEC */
"4994" = "1" /* REDUCTION ANAL PROLAPSE */
"4995" = "1" /* CONTROL ANAL HEMORRHAGE */
"4999" = "1" /* ANAL OPERATION NEC */
"500 " = "1" /* HEPATOTOMY */
"5012" = "1" /* OPEN LIVER BIOPSY */
"5014" = "1" /* LAPAROSCOPIC LIVER BX */
"5019" = "1" /* HEPATIC DX PROC NEC */
"5021" = "1" /* MARSUPIALIZAT LIVER LES */
"5022" = "1" /* PARTIAL HEPATECTOMY */
"5023" = "1" /* OPN ABLTN LIVER LES/TISS */
"5024" = "1" /* PERC ABLTN LIVER LES/TIS */
"5025" = "1" /* LAP ABLTN LIVER LES/TISS */
"5026" = "1" /* ABLTN LIVER LES/TISS NEC */
"5029" = "1" /* DESTRUC HEPATIC LES NEC */
"503 " = "1" /* HEPATIC LOBECTOMY */
"504 " = "1" /* TOTAL HEPATECTOMY */
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5061" = "1" /* CLOSURE LIVER LACERAT */
"5069" = "1" /* LIVER REPAIR NEC */
"5102" = "1" /* TROCAR CHOLECYSTOSTOMY */
"5103" = "1" /* CHOLECYSTOSTOMY NEC */
"5104" = "1" /* CHOLECYSTOTOMY NEC */
"5113" = "1" /* OPEN BILIARY TRACT BX */
"5119" = "1" /* BILIARY TR DX PROC NEC */
"5121" = "1" /* OTH PART CHOLECYSTECTOMY */
"5122" = "1" /* CHOLECYSTECTOMY */
"5123" = "1" /* LAPAROSCOPIC CHOLECYSTEC */
"5124" = "1" /* LAP PART CHOLECYSTECTOMY */
"5131" = "1" /* GB-TO-HEPAT DUCT ANAST */
"5132" = "1" /* GB-TO-INTESTINE ANASTOM */
"5133" = "1" /* GB-TO-PANCREAS ANASTOM */
"5134" = "1" /* GB-TO-STOMACH ANASTOMOS */
"5135" = "1" /* GALLBLADDER ANASTOM NEC */
"5136" = "1" /* CHOLEDOCHOENTEROSTOMY */
"5137" = "1" /* HEPATIC DUCT-GI ANASTOM */
"5139" = "1" /* BILE DUCT ANASTOMOS NEC */
"5141" = "1" /* CDE FOR CALCULUS REMOV */
"5142" = "1" /* CDE FOR OBSTRUCTION NEC */
"5143" = "1" /* CHOLEDOCHOHEPAT INTUBAT */
"5149" = "1" /* INCIS OBSTR BILE DUC NEC */
"5151" = "1" /* COMMON DUCT EXPLORATION */
"5159" = "1" /* BILE DUCT INCISION NEC */
"5161" = "1" /* EXCIS CYST DUCT REMNANT */
"5162" = "1" /* EXCIS AMPULLA OF VATER */
"5163" = "1" /* COMMON DUCT EXCIS NEC */
"5169" = "1" /* BILE DUCT EXCISION NEC */
"5171" = "1" /* SIMPLE SUT-COMMON DUCT */
"5172" = "1" /* CHOLEDOCHOPLASTY */
"5179" = "1" /* BILE DUCT REPAIR NEC */
"5181" = "1" /* SPHINCTER OF ODDI DILAT */
"5182" = "1" /* PANCREAT SPHINCTEROTOM */
"5183" = "1" /* PANCREAT SPHINCTEROPLAS */
"5189" = "1" /* SPHINCT OF ODDI OP NEC */
"5191" = "1" /* REPAIR GB LACERATION */
"5192" = "1" /* CLOSURE CHOLECYSTOSTOMY */
"5193" = "1" /* CLOS BILIARY FISTUL NEC */
"5194" = "1" /* REVIS BILE TRACT ANASTOM */
"5195" = "1" /* REMOVE BILE DUCT PROSTH */
"5199" = "1" /* BILIARY TRACT OP NEC */
"5201" = "1" /* CATH DRAIN-PANCREAT CYST */
"5209" = "1" /* PANCREATOTOMY NEC */
"5212" = "1" /* OPEN PANCREATIC BIOPSY */
"5219" = "1" /* PANCREATIC DX PROC NEC */
"522 " = "1" /* PANCREATIC DX PROC NEC */
"5222" = "1" /* OTHER DESTRU PANCREA LES */
"523 " = "1" /* PANCREAT CYST MARSUPIALI */
"524 " = "1" /* INT DRAIN PANCREAT CYST */
"5251" = "1" /* PROXIMAL PANCREATECTOMY */
"5252" = "1" /* DISTAL PANCREATECTOMY */
"5253" = "1" /* RAD SUBTOT PANCREATECTOM */
"5259" = "1" /* PARTIAL PANCREATECT NEC */
"526 " = "1" /* TOTAL PANCREATECTOMY */
"527 " = "1" /* RAD PANCREATICODUODENECT */
"5280" = "1" /* PANCREAT TRANSPLANT NOS */
"5281" = "1" /* REIMPLANT PANCREATIC TIS */
"5282" = "1" /* PANCREATIC HOMOTRANSPLAN */
"5283" = "1" /* PANCREATIC HETEROTRANSPL */
"5291" = "1" /* TRNSPLNT ISLETS LANG NOS */
"5292" = "1" /* CANNULATION PANCREA DUC */
"5295" = "1" /* PANCREATIC REPAIR NEC */
"5296" = "1" /* PANCREATIC ANASTOMOSIS */
"5299" = "1" /* PANCREATIC OPERATION NEC */
"5300" = "1" /* UNILAT ING HERN REP NOS */
"5301" = "1" /* REPAIR DIRECT ING HERNIA */
"5302" = "1" /* REPAIR INDIR ING HERNIA */
"5303" = "1" /* DIR ING HERNIA REP-GRAFT */
"5304" = "1" /* IND ING HERNIA REP-GRAFT */
"5305" = "1" /* ING HERNIA REP-GRAFT NOS */
"5310" = "1" /* BILAT ING HERNIA REP NOS */
"5311" = "1" /* BILAT DIR ING HERN REP */
"5312" = "1" /* BILAT IND ING HERN REP */
"5313" = "1" /* BIL DIR/IND ING HRN REP */
"5314" = "1" /* BIL DIR ING HRN REP-GRFT */
"5315" = "1" /* BIL IND ING HRN REP-GRFT */
"5316" = "1" /* BIL DIR/IND ING HERN-PRO */
"5317" = "1" /* BIL ING HRN REP-GRFT NOS */
"5321" = "1" /* UNIL FEMOR HRN REP-GRFT */
"5329" = "1" /* UNIL FEMOR HERN REP NEC */
"5331" = "1" /* BIL FEM HERN REPAIR-GRFT */
"5339" = "1" /* BIL FEM HERN REPAIR NEC */
"5341" = "1" /* UMBIL HERNIA REPAIR-GRFT */
"5342" = "1" /* LAP UMBIL HERNIA-GRAFT */
"5343" = "1" /* LAP UMBILICAL HERNIA NEC */
"5349" = "1" /* UMBIL HERNIA REPAIR NEC */
"5351" = "1" /* INCISIONAL HERNIA REPAIR */
"5359" = "1" /* ABD WALL HERN REPAIR NEC */
"5361" = "1" /* INCIS HERNIA REPAIR-GRFT */
"5362" = "1" /* LAP INCIS HERN REPR-GRFT */
"5363" = "1" /* LAP HERN ANT ABD-GFT NEC */
"5369" = "1" /* ABD HERN REPAIR-GRFT NEC */
"537 " = "1" /* ABD REPAIR-DIAPHR HERNIA */
"5371" = "1" /* LAP ABD REP-DIAPHR HERN */
"5372" = "1" /* OPN ABD DIAPHRM HERN NEC */
"5375" = "1" /* ABD REP-DIAPHR HERN NOS */
"5380" = "1" /* THOR REP-DIAPH HERN NOS */
"5381" = "1" /* DIAPHRAGMATIC PLICATION */
"5382" = "1" /* PARASTERN HERNIA REPAIR */
"5383" = "1" /* LAP THORC APP-DIAPH HERN */
"5384" = "1" /* OPN THORC DIAPH HERN NEC */
"539 " = "1" /* OTHER HERNIA REPAIR */
"540 " = "1" /* ABDOMINAL WALL INCISION */
"5411" = "1" /* EXPLORATORY LAPAROTOMY */
"5412" = "1" /* REOPEN RECENT LAP SITE */
"5419" = "1" /* LAPAROTOMY NEC */
"5421" = "1" /* LAPAROSCOPY */
"5422" = "1" /* ABDOMINAL WALL BIOPSY */
"5423" = "1" /* PERITONEAL BIOPSY */
"5429" = "1" /* ABD REGION DX PROC NEC */
"543 " = "1" /* DESTRUCT ABD WALL LESION */
"544 " = "1" /* DESTRUCT PERITONEAL TISS */
"545 " = "1" /* DESTRUCT PERITONEAL TISS */
"5451" = "1" /* LAP PERITON ADHESIOLYSIS */
"5459" = "1" /* OTH PERITON ADHESIOLYSIS */
"5461" = "1" /* RECLOSE POST OP DISRUPT */
"5462" = "1" /* DELAYED CLOS ABD WOUND */
"5463" = "1" /* ABD WALL SUTURE NEC */
"5464" = "1" /* PERITONEAL SUTURE */
"5471" = "1" /* REPAIR OF GASTROSCHISIS */
"5472" = "1" /* ABDOMEN WALL REPAIR NEC */
"5473" = "1" /* PERITONEAL REPAIR NEC */
"5474" = "1" /* OMENTAL REPAIR NEC */
"5475" = "1" /* MESENTERIC REPAIR NEC */
"5492" = "1" /* REMOVE FB FROM PERITON */
"5493" = "1" /* CREATE CUTANPERITON FIST */
"5494" = "1" /* CREAT PERITONEOVAS SHUNT */
"5495" = "1" /* PERITONEAL INCISION */
"5501" = "1" /* NEPHROTOMY */
"5502" = "1" /* NEPHROSTOMY */
"5503" = "1" /* PERCU NEPHROSTM W/O FRAG */
"5504" = "1" /* PERCU NEPHROSTMY W FRAG */
"5511" = "1" /* PYELOTOMY */
"5512" = "1" /* PYELOSTOMY */
"5524" = "1" /* OPEN RENAL BIOPSY */
"5529" = "1" /* RENAL DIAGNOST PROC NEC */
"5531" = "1" /* RENAL LES MARSUPIALIZAT */
"5532" = "1" /* OPN ABLTN RENAL LES/TISS */
"5533" = "1" /* PERC ABLTN RENL LES/TISS */
"5534" = "1" /* LAP ABLTN RENAL LES/TISS */
"5535" = "1" /* ABLTN RENAL LES/TISS NEC */
"5539" = "1" /* LOC DESTR RENAL LES NEC */
"554 " = "1" /* PARTIAL NEPHRECTOMY */
"5551" = "1" /* NEPHROURETERECTOMY */
"5552" = "1" /* SOLITARY KIDNEY NEPHRECT */
"5553" = "1" /* REJECTED KIDNEY NEPHRECT */
"5554" = "1" /* BILATERAL NEPHRECTOMY */
"5561" = "1" /* RENAL AUTOTRANSPLANT */
"5569" = "1" /* KIDNEY TRANSPLANT NEC */
"557 " = "1" /* NEPHROPEXY */
"5581" = "1" /* SUTURE KIDNEY LACERATION */
"5582" = "1" /* CLOSE NEPHROST & PYELOST */
"5583" = "1" /* CLOSE RENAL FISTULA NEC */
"5584" = "1" /* REDUCE RENAL PEDICL TORS */
"5585" = "1" /* SYMPHYSIOTOMY */
"5586" = "1" /* RENAL ANASTOMOSIS */
"5587" = "1" /* CORRECT URETEROPELV JUNC */
"5589" = "1" /* RENAL REPAIR NEC */
"5591" = "1" /* RENAL DECAPSULATION */
"5597" = "1" /* IMPLANT MECHANIC KIDNEY */
"5598" = "1" /* REMOV MECHANICAL KIDNEY */
"5599" = "1" /* RENAL OPERATION NEC */
"560 " = "1" /* TU REMOV URETER OBSTRUCT */
"561 " = "1" /* URETERAL MEATOTOMY */
"562 " = "1" /* URETEROTOMY */
"5634" = "1" /* OPEN URETERAL BIOPSY */
"5639" = "1" /* URETERAL DX PROCEDUR NEC */
"5640" = "1" /* URETERECTOMY NOS */
"5641" = "1" /* PARTIAL URETERECTOMY */
"5642" = "1" /* TOTAL URETERECTOMY */
"5651" = "1" /* FORM CUTAN ILEOURETEROST */
"5652" = "1" /* REVIS CUTAN ILEOURETEROS */
"5661" = "1" /* FORM CUTAN URETEROSTOMY */
"5662" = "1" /* REVIS CUTAN URETEROS NEC */
"5671" = "1" /* URIN DIVERSION TO BOWEL */
"5672" = "1" /* REVIS URETEROENTEROSTOMY */
"5673" = "1" /* NEPHROCYSTANASTOMOSI NOS */
"5674" = "1" /* URETERONEOCYSTOSTOMY */
"5675" = "1" /* TRANSURETEROURETEROSTOMY */
"5679" = "1" /* URETERAL ANASTOMOSIS NEC */
"5681" = "1" /* INTRALUM URETE ADHESIOLY */
"5682" = "1" /* SUTURE URETERAL LACERAT */
"5683" = "1" /* URETEROSTOMY CLOSURE */
"5684" = "1" /* CLOSE URETER FISTULA NEC */
"5685" = "1" /* URETEROPEXY */
"5686" = "1" /* REMOVE URETERAL LIGATURE */
"5689" = "1" /* REPAIR OF URETER NEC */
"5692" = "1" /* IMPLANT URETERAL STIMUL */
"5693" = "1" /* REPLACE URETERAL STIMUL */
"5694" = "1" /* REMOVE URETERAL STIMULAT */
"5695" = "1" /* LIGATION OF URETER */
"5699" = "1" /* URETERAL OPERATION NEC */
"5712" = "1" /* CYSTOTOMY & ADHESIOLYSIS */
"5718" = "1" /* OTHER SUPRAPU CYSTOSTOMY */
"5719" = "1" /* CYSTOTOMY NEC */
"5721" = "1" /* VESICOSTOMY */
"5722" = "1" /* REVISE CLO VESICOSTOMY */
"5733" = "1" /* CLOS TRANSURETH BLADD BX */
"5734" = "1" /* OPEN BLADDER BIOPSY */
"5739" = "1" /* BLADDER DIAGNOS PROC NEC */
"5741" = "1" /* TU ADHESIOLYSIS BLADDER */
"5749" = "1" /* TU DESTRUC BLADD LES NEC */
"5751" = "1" /* EXCISION OF URACHUS */
"5759" = "1" /* BLADDER LES DESTRUCT NEC */
"576 " = "1" /* PARTIAL CYSTECTOMY */
"5771" = "1" /* RADICAL CYSTECTOMY */
"5779" = "1" /* TOTAL CYSTECTOMY NEC */
"5781" = "1" /* SUTURE BLADDER LACERAT */
"5782" = "1" /* CYSTOSTOMY CLOSURE */
"5783" = "1" /* ENTEROVESICO FIST REPAIR */
"5784" = "1" /* VESIC FISTULA REPAIR NEC */
"5785" = "1" /* CYSTOURETHROPLASTY */
"5786" = "1" /* BLADDER EXSTROPHY REPAIR */
"5787" = "1" /* BLADDER RECONSTRUCTION */
"5788" = "1" /* BLADDER ANASTOMOSIS NEC */
"5789" = "1" /* BLADDER REPAIR NEC */
"5791" = "1" /* BLADDER SPHINCTEROTOMY */
"5793" = "1" /* CONTROL BLADD HEMORRHAGE */
"5796" = "1" /* IMPLANT BLADDER STIMULAT */
"5797" = "1" /* REPLACE BLADDER STIMULAT */
"5798" = "1" /* REMOVE BLADDER STIMULAT */
"5799" = "1" /* BLADDER OPERATION NEC */
"580 " = "1" /* URETHROTOMY */
"581 " = "1" /* URETHRAL MEATOTOMY */
"5841" = "1" /* SUTURE URETHRAL LACERAT */
"5842" = "1" /* URETHROSTOMY CLOSURE */
"5843" = "1" /* CLOSE URETH FISTULA NEC */
"5844" = "1" /* URETHRAL REANASTOMOSIS */
"5845" = "1" /* HYPO-EPISPADIUS REPAIR */
"5846" = "1" /* URETH RECONSTRUCTION NEC */
"5847" = "1" /* URETHRAL MEATOPLASTY */
"5849" = "1" /* URETHRAL REPAIR NEC */
"585 " = "1" /* URETH STRICTURE RELEASE */
"5891" = "1" /* PERIURETHRAL INCISION */
"5892" = "1" /* PERIURETHRAL EXCISION */
"5893" = "1" /* IMPLT ARTF URIN SPHINCT */
"5899" = "1" /* URETH/PERIURETH OP NEC */
"5900" = "1" /* RETROPERIT DISSECT NOS */
"5901" = "1" /* RETROPERIT DISSECT NOS */
"5902" = "1" /* PERIREN ADHESIOLYS NEC */
"5903" = "1" /* LAP LYS PERIREN/URET ADH */
"5909" = "1" /* PERIREN/URETER INCIS NEC */
"5911" = "1" /* OTH LYS PERIVES ADHESIO */
"5912" = "1" /* LAP LYS PERIVESURETH ADH */
"5919" = "1" /* PERIVESICAL INCISION NEC */
"5921" = "1" /* PERIREN/URETERAL BIOPSY */
"5929" = "1" /* PERIREN/URET DX PROC NEC */
"593 " = "1" /* URETHROVES JUNCT PLICAT */
"594 " = "1" /* SUPRAPUBIC SLING OP */
"595 " = "1" /* RETROPUBIC URETH SUSPENS */
"596 " = "1" /* PARAURETHRAL SUSPENSION */
"5971" = "1" /* LEVATOR MUSC SUSPENSION */
"5979" = "1" /* URIN INCONTIN REPAIR NEC */
"5991" = "1" /* PERIREN/VESICLE EXCISION */
"5992" = "1" /* PERIREN/VESICLE OP NEC */
"600 " = "1" /* INCISION OF PROSTATE */
"6012" = "1" /* OPEN PROSTATIC BIOPSY */
"6014" = "1" /* OPEN SEMINAL VESICLES BX */
"6015" = "1" /* PERIPROSTATIC BIOPSY */
"6018" = "1" /* PROSTATIC DX PROCED NEC */
"6019" = "1" /* SEMIN VES DX PROCED NEC */
"602 " = "1" /* SEMIN VES DX PROCED NEC */
"6021" = "1" /* TRANSURETH PROSTATECTOMY */
"6029" = "1" /* OTH TRANSURETH PROSTATEC */
"603 " = "1" /* SUPRAPUBIC PROSTATECTOMY */
"604 " = "1" /* RETROPUBIC PROSTATECTOMY */
"605 " = "1" /* RADICAL PROSTATECTOMY */
"6061" = "1" /* LOS EXCIS PROSTATIC LES */
"6062" = "1" /* PERINEAL PROSTATECTOMY */
"6069" = "1" /* PROSTATECTOMY NEC */
"6072" = "1" /* SEMINAL VESICLE INCISION */
"6073" = "1" /* SEMINAL VESICLE EXCISION */
"6079" = "1" /* SEMINAL VESICLE OP NEC */
"6081" = "1" /* PERIPROSTATIC INCISION */
"6082" = "1" /* PERIPROSTATIC EXCISION */
"6093" = "1" /* REPAIR OF PROSTATE */
"6094" = "1" /* CONTROL PROSTATE HEMORR */
"6095" = "1" /* TRANS BAL DIL PROS URETH */
"6096" = "1" /* TU DESTR PROSTATE BY MT */
"6097" = "1" /* OTH TU DESTR PROS - RT */
"6099" = "1" /* PROSTATIC OPERATION NEC */
"612 " = "1" /* EXCISION OF HYDROCELE */
"6142" = "1" /* SCROTAL FISTULA REPAIR */
"6149" = "1" /* SCROTUM/TUNIC REPAIR NEC */
"6192" = "1" /* EXCISION TUNICA LES NEC */
"6199" = "1" /* SCROTUM & TUNICA OP NEC */
"620 " = "1" /* INCISION OF TESTES */
"6212" = "1" /* OPEN TESTICULAR BIOPSY */
"6219" = "1" /* TESTES DX PROCEDURE NEC */
"622 " = "1" /* TESTICULAR LES DESTRUCT */
"623 " = "1" /* UNILATERAL ORCHIECTOMY */
"6241" = "1" /* REMOVE BOTH TESTES */
"6242" = "1" /* REMOVE SOLITARY TESTIS */
"625 " = "1" /* ORCHIOPEXY */
"6261" = "1" /* SUTURE TESTICULAR LACER */
"6269" = "1" /* TESTICULAR REPAIR NEC */
"627 " = "1" /* INSERT TESTICULAR PROSTH */
"6299" = "1" /* TESTICULAR OPERATION NEC */
"6309" = "1" /* SPERMAT CORD/VAS DX NEC */
"631 " = "1" /* EXC SPERMATIC VARICOCELE */
"632 " = "1" /* EXCISE EPIDIDYMIS CYST */
"633 " = "1" /* EXCISE CORD/EPID LES NEC */
"634 " = "1" /* EPIDIDYMECTOMY */
"6351" = "1" /* SUTURE CORD & EPID LACER */
"6353" = "1" /* TRANSPLANT SPERMAT CORD */
"6359" = "1" /* CORD & EPIDID REPAIR NEC */
"6381" = "1" /* SUTURE VAS & EPIDID LAC */
"6382" = "1" /* POSTOP VAS RECONSTRUCT */
"6383" = "1" /* EPIDIDYMOVASOSTOMY */
"6385" = "1" /* REMOV VAS DEFERENS VALVE */
"6389" = "1" /* VAS & EPIDIDY REPAIR NEC */
"6392" = "1" /* EPIDIDYMOTOMY */
"6393" = "1" /* SPERMATIC CORD INCISION */
"6394" = "1" /* SPERM CORD ADHESIOLYSIS */
"6395" = "1" /* INSERT VALVE IN VAS DEF */
"6399" = "1" /* CORD/EPID/VAS OPS NEC */
"6411" = "1" /* PENILE BIOPSY */
"642 " = "1" /* LOCAL EXCIS PENILE LES */
"643 " = "1" /* AMPUTATION OF PENIS */
"6441" = "1" /* SUTURE PENILE LACERATION */
"6442" = "1" /* RELEASE OF CHORDEE */
"6443" = "1" /* CONSTRUCTION OF PENIS */
"6444" = "1" /* RECONSTRUCTION OF PENIS */
"6445" = "1" /* REPLANTATION OF PENIS */
"6449" = "1" /* PENILE REPAIR NEC */
"645 " = "1" /* SEX TRANSFORMAT OP NEC */
"6492" = "1" /* INCISION OF PENIS */
"6493" = "1" /* DIVISION OF PENILE ADHES */
"6495" = "1" /* INS NONINFL PENIS PROSTH */
"6496" = "1" /* REMOVE INT PENILE PROSTH */
"6497" = "1" /* INS INFLATE PENIS PROSTH */
"6498" = "1" /* PENILE OPERATION NEC */
"6499" = "1" /* MALE GENITAL OP NEC */
"650 " = "1" /* MALE GENITAL OP NEC */
"6501" = "1" /* LAPAROSCOPIC OOPHOROTOMY */
"6509" = "1" /* OTHER OOPHOROTOMY */
"6511" = "1" /* OVARIAN ASPIRAT BIOPSY */
"6512" = "1" /* OVARIAN BIOPSY NEC */
"6513" = "1" /* LAP BIOPSY OF OVARY */
"6514" = "1" /* OTH LAP DX PROC OVARIES */
"6519" = "1" /* OVARIAN DX PROCEDURE NEC */
"6521" = "1" /* OVARIAN CYST MARSUPIALIZ */
"6522" = "1" /* OVARIAN WEDGE RESECTION */
"6523" = "1" /* LAP MARSUP OVARIAN CYST */
"6524" = "1" /* LAP WEDGE RESECT OVARY */
"6525" = "1" /* OTH LAP LOC EXC DEST OVA */
"6529" = "1" /* LOCAL DESTR OVA LES NEC */
"653 " = "1" /* LOCAL DESTR OVA LES NEC */
"6531" = "1" /* LAP UNILAT OOPHORECTOMY */
"6539" = "1" /* OTH UNILAT OOPHORECTOMY */
"654 " = "1" /* OTH UNILAT OOPHORECTOMY */
"6541" = "1" /* LAP UNI SALPINGO-OOPHOR */
"6549" = "1" /* OTH UNI SALPINGO-OOPHOR */
"6551" = "1" /* OTH REMOVE BOTH OVARIES */
"6552" = "1" /* OTH REMOVE REMAIN OVARY */
"6553" = "1" /* LAP REMOVE BOTH OVARIES */
"6554" = "1" /* LAP REMOVE REMAIN OVARY */
"6561" = "1" /* OTH REMOVE OVARIES/TUBES */
"6562" = "1" /* OTH REMOVE REM OVA/TUBE */
"6563" = "1" /* LAP REMOVE OVARIES/TUBES */
"6564" = "1" /* LAP REMOVE REM OVA/TUBE */
"6571" = "1" /* OTH SIMPLE SUTURE OVARY */
"6572" = "1" /* OTH REIMPLANT OF OVARY */
"6573" = "1" /* OTH SALPINGO-OOPHOROPLAS */
"6574" = "1" /* LAP SIMPLE SUTURE OVARY */
"6575" = "1" /* LAP REIMPLANT OF OVARY */
"6576" = "1" /* LAP SALPINGO-OOPHOROPLAS */
"6579" = "1" /* REPAIR OF OVARY NEC */
"658 " = "1" /* REPAIR OF OVARY NEC */
"6581" = "1" /* LAP ADHESIOLYS OVA/TUBE */
"6589" = "1" /* ADHESIOLYSIS OVARY/TUBE */
"6591" = "1" /* ASPIRATION OF OVARY */
"6592" = "1" /* TRANSPLANTATION OF OVARY */
"6593" = "1" /* MANUAL RUPT OVARIAN CYST */
"6594" = "1" /* OVARIAN DENERVATION */
"6595" = "1" /* OVARIAN TORSION RELEASE */
"6599" = "1" /* OVARIAN OPERATION NEC */
"660 " = "1" /* OVARIAN OPERATION NEC */
"6601" = "1" /* SALPINGOTOMY */
"6602" = "1" /* SALPINGOSTOMY */
"6611" = "1" /* FALLOPIAN TUBE BIOPSY */
"6619" = "1" /* FALLOP TUBE DX PROC NEC */
"6621" = "1" /* BILAT ENDOSC CRUSH TUBE */
"6622" = "1" /* BILAT ENDOSC DIVIS TUBE */
"6629" = "1" /* BILAT ENDOS OCC TUBE NEC */
"6631" = "1" /* BILAT TUBAL CRUSHING NEC */
"6632" = "1" /* BILAT TUBAL DIVISION NEC */
"6639" = "1" /* BILAT TUBAL DESTRUCT NEC */
"664 " = "1" /* TOTAL UNILAT SALPINGECT */
"6651" = "1" /* REMOVE BOTH FALLOP TUBES */
"6652" = "1" /* REMOVE SOLITARY FAL TUBE */
"6661" = "1" /* DESTROY FALLOP TUBE LES */
"6662" = "1" /* REMOV TUBE & ECTOP PREG */
"6663" = "1" /* BILAT PART SALPINGEC NOS */
"6669" = "1" /* PARTIAL SALPINGECTOM NEC */
"6671" = "1" /* SIMPL SUTURE FALLOP TUBE */
"6672" = "1" /* SALPINGO-OOPHOROSTOMY */
"6673" = "1" /* SALPINGO-SALPINGOSTOMY */
"6674" = "1" /* SALPINGO-UTEROSTOMY */
"6679" = "1" /* FALLOP TUBE REPAIR NEC */
"6692" = "1" /* UNILAT FALLOP TUBE DESTR */
"6693" = "1" /* IMPL FALLOP TUBE PROSTH */
"6694" = "1" /* REMOV FALLOP TUBE PROSTH */
"6695" = "1" /* BLOW THERAPEUT INTO TUBE */
"6696" = "1" /* FALLOPIAN TUBE DILATION */
"6697" = "1" /* BURY FIMBRIAE IN UTERUS */
"6699" = "1" /* FALLOPIAN TUBE OP NEC */
"6711" = "1" /* ENDOCERVICAL BIOPSY */
"6712" = "1" /* CERVICAL BIOPSY NEC */
"6719" = "1" /* CERVICAL DX PROCEDUR NEC */
"672 " = "1" /* CONIZATION OF CERVIX */
"6731" = "1" /* CERVICAL CYST MARSUPIAL */
"6732" = "1" /* CERVICAL LES CAUTERIZAT */
"6733" = "1" /* CERVICAL LES CRYOTHERAPY */
"6739" = "1" /* CERVICAL LES DESTRUC NEC */
"674 " = "1" /* AMPUTATION OF CERVIX */
"675 " = "1" /* AMPUTATION OF CERVIX */
"6751" = "1" /* TRANSAB CERCLAGE CERVIX */
"6759" = "1" /* OTH REP INT CERVICAL OS */
"6761" = "1" /* SUTURE CERVICAL LACERAT */
"6762" = "1" /* CERVICAL FISTULA REPAIR */
"6769" = "1" /* CERVICAL REPAIR NEC */
"680 " = "1" /* HYSTEROTOMY */
"6813" = "1" /* OPEN UTERINE BIOPSY */
"6814" = "1" /* OPEN UTERINE LIGAMENT BX */
"6815" = "1" /* CLOS UTERINE LIGAMENT BX */
"6816" = "1" /* CLOSED UTERINE BIOPSY */
"6819" = "1" /* UTERUS/ADNEX DX PROC NEC */
"6821" = "1" /* ENDOMET SYNECHIAE DIVIS */
"6822" = "1" /* INCISION UTERINE SEPTUM */
"6823" = "1" /* ENDOMETRIAL ABLATION */
"6824" = "1" /*	UTERINE ARTERY EMBOLIZATION [UAE] WITH COILS */
"6825" = "1" /*	UTERINE ARTERY EMBOLIZATION [UAE] WITHOUT COILS  */
"6829" = "1" /* UTERINE LES DESTRUCT NEC */
"683 " = "1" /* UTERINE LES DESTRUCT NEC */
"6831" = "1" /* LAP SCERVIC HYSTERECTOMY */
"6839" = "1" /* OTH SUBTOT ABD HYSTERECT */
"684 " = "1" /* TOTAL ABD HYSTERECTOMY */
"6841" = "1" /* LAP TOTAL ABDOMINAL HYST */
"6849" = "1" /* TOTAL ABD HYST NEC/NOS */
"685 " = "1" /* TOTAL ABD HYSTERECTOMY */
"6851" = "1" /* LAP AST VAG HYSTERECTOMY */
"6859" = "1" /* OTHER VAG HYSTERECTOMY */
"686 " = "1" /* RADICAL ABD HYSTERECTOMY */
"6861" = "1" /* LAP RADICAL ABDOMNL HYST */
"6869" = "1" /* RADICAL ABD HYST NEC/NOS */
"687 " = "1" /* RADICAL VAG HYSTERECTOMY */
"6871" = "1" /* LAP RADICAL VAGINAL HYST */
"6879" = "1" /* RADICAL VAG HYST NEC/NOS */
"688 " = "1" /* PELVIC EVISCERATION */
"689 " = "1" /* HYSTERECTOMY NEC/NOS */
"6901" = "1" /* D & C FOR PREG TERMINAT */
"6902" = "1" /* D & C POST DELIVERY */
"6909" = "1" /* D & C NEC */
"6911" = "1" /* D & C NEC */
"6919" = "1" /* DESTRUC UTER SUPPORT NEC */
"6921" = "1" /* INTERPOSIT OP UTERIN LIG */
"6922" = "1" /* UTERINE SUSPENSION NEC */
"6923" = "1" /* VAG REPAIR INVERS UTERUS */
"6929" = "1" /* UTERUS/ADNEXA REPAIR NEC */
"693 " = "1" /* PARACERV UTERINE DENERV */
"6941" = "1" /* SUTURE UTERINE LACERAT */
"6942" = "1" /* CLOSURE UTERINE FISTULA */
"6949" = "1" /* UTERINE REPAIR NEC */
"6951" = "1" /* ASPIRAT CURET-PREG TERMI */
"6952" = "1" /* ASPIRAT CURET-POST DELIV */
"6995" = "1" /* INCISION OF CERVIX */
"6997" = "1" /* REMOVE PENETRAT CERV FB */
"6998" = "1" /* UTERINE SUPPORT OP NEC */
"6999" = "1" /* UTERINE OPERATION NEC */
"7012" = "1" /* CULDOTOMY */
"7013" = "1" /* INTRALUM VAG ADHESIOLYS */
"7014" = "1" /* VAGINOTOMY NEC */
"7023" = "1" /* CUL-DE-SAC BIOPSY */
"7024" = "1" /* VAGINAL BIOPSY */
"7029" = "1" /* VAGIN/CUL-DE-SAC DX NEC */
"7031" = "1" /* HYMENECTOMY */
"7032" = "1" /* EXCIS CUL-DE-SAC LESION */
"7033" = "1" /* EXCISION VAGINAL LESION */
"704 " = "1" /* VAGINAL OBLITERATION */
"7050" = "1" /* CYSTOCEL/RECTOCEL REPAIR */
"7051" = "1" /* CYSTOCELE REPAIR */
"7052" = "1" /* RECTOCELE REPAIR */
"7053" = "1" /* CYSTO & RECTO W GRF/PROS */
"7054" = "1" /* REP CYSTOCEL W GRFT/PROS */
"7055" = "1" /* REP RECTOCELE W GRF/PROS */
"7061" = "1" /* VAGINAL CONSTRUCTION */
"7062" = "1" /* VAGINAL RECONSTRUCTION */
"7063" = "1" /* VAGINAL CONST W GRF/PROS */
"7064" = "1" /* VAG RECONST W GRFT/PROS */
"7071" = "1" /* SUTURE VAGINA LACERATION */
"7072" = "1" /* REPAIR COLOVAGIN FISTULA */
"7073" = "1" /* REPAIR RECTOVAG FISTULA */
"7074" = "1" /* REP VAGINOENT FISTUL NEC */
"7075" = "1" /* REPAIR VAG FISTULA NEC */
"7076" = "1" /* HYMENORRHAPHY */
"7077" = "1" /* VAGINAL SUSPENS & FIXAT */
"7078" = "1" /* VAG SUSP/FIX W GRFT/PROS */
"7079" = "1" /* VAGINAL REPAIR NEC */
"708 " = "1" /* VAGINAL VAULT OBLITERAT */
"7091" = "1" /* VAGINAL OPERATION NEC */
"7092" = "1" /* CUL-DE-SAC OPERATION NEC */
"7093" = "1" /* CUL-DE-SAC GRF/PROS NEC */
"7101" = "1" /* VULVAR ADHESIOLYSIS */
"7109" = "1" /* INCIS VULVA/PERINEUM NEC */
"7111" = "1" /* VULVAR BIOPSY */
"7119" = "1" /* VULVAR DIAGNOS PROC NEC */
"7122" = "1" /* INCISE BARTHOLIN"S GLAND */
"7123" = "1" /* BARTHOLIN GLAND MARSUP */
"7124" = "1" /* DESTRUC BARTHOLIN GLAND */
"7129" = "1" /* BARTHOLIN"S GLAND OP NEC */
"713 " = "1" /* LOCAL VULVAR EXCIS NEC */
"714 " = "1" /* OPERATIONS ON CLITORIS */
"715 " = "1" /* RADICAL VULVECTOMY */
"7161" = "1" /* UNILATERAL VULVECTOMY */
"7162" = "1" /* BILATERAL VULVECTOMY */
"7171" = "1" /* SUTURE VULVAR LACERATION */
"7172" = "1" /* REPAIR VULVAR FISTULA */
"7179" = "1" /* VULVAR/PERIN REPAIR NEC */
"718 " = "1" /* OTHER VULVAR OPERATIONS */
"719 " = "1" /* OTHER FEMALE GENITAL OPS */
"7394" = "1" /* PUBIOTOMY TO ASSIST DEL */
"7399" = "1" /* OPS ASSISTING DELIV NEC */
"740 " = "1" /* CLASSICAL C-SECTION */
"741 " = "1" /* LOW CERVICAL C-SECTION */
"742 " = "1" /* EXTRAPERITONEAL C-SECT */
"743 " = "1" /* REM EXTRATUB ECTOP PREG */
"744 " = "1" /* CESAREAN SECTION NEC */
"7491" = "1" /* HYSTEROTOMY TO TERMIN PG */
"7499" = "1" /* CESAREAN SECTION NOS */
"7536" = "1" /* CORRECTION FETAL DEFECT */
"7550" = "1" /* REPAIR OB LAC UTERUS NOS */
"7551" = "1" /* REPAIR OB LACERAT CERVIX */
"7552" = "1" /* REPAIR OB LAC CORP UTERI */
"7561" = "1" /* REPAIR OB LAC BLAD/URETH */
"7593" = "1" /* SURG CORR INVERT UTERUS */
"7599" = "1" /* OBSTETRIC OPERATION NEC */
"7601" = "1" /* FACIAL BONE SEQUESTRECT */
"7609" = "1" /* FACIAL BONE INCISION NEC */
"7611" = "1" /* FACIAL BONE BIOPSY */
"7619" = "1" /* FACIAL BONE DX PROC NEC */
"762 " = "1" /* DESTRUCT FACIAL BONE LES */
"7631" = "1" /* PARTIAL MANDIBULECTOMY */
"7639" = "1" /* PART FACIAL OSTECTOM NEC */
"7641" = "1" /* TOT MANDIBULEC W RECONST */
"7642" = "1" /* TOTAL MANDIBULECTOMY NEC */
"7643" = "1" /* MANDIBULAR RECONST NEC */
"7644" = "1" /* TOT FACE OSTECT W RECONS */
"7645" = "1" /* TOT FACE BONE OSTECT NEC */
"7646" = "1" /* FACIAL BONE RECONSTR NEC */
"765 " = "1" /* TEMPOROMAND ARTHROPLASTY */
"7661" = "1" /* CL OSTEOPLASTY MAND RAMI */
"7662" = "1" /* OPEN OSTEOPLAS MAND RAMI */
"7663" = "1" /* OSTEOPLASTY MANDIBLE BDY */
"7664" = "1" /* MAND ORTHOGNATHIC OP NEC */
"7665" = "1" /* SEG OSTEOPLASTY MAXILLA */
"7666" = "1" /* TOT OSTEOPLASTY MAXILLA */
"7667" = "1" /* REDUCTION GENIOPLASTY */
"7668" = "1" /* AUGMENTATION GENIOPLASTY */
"7669" = "1" /* FACIAL BONE REPAIR NEC */
"7670" = "1" /* REDUCTION FACIAL FX NOS */
"7672" = "1" /* OPN REDUCT MALAR/ZYGO FX */
"7674" = "1" /* OPEN REDUCT MAXILLARY FX */
"7676" = "1" /* OPEN REDUCT MANDIBLE FX */
"7677" = "1" /* OPEN REDUCT ALVEOLAR FX */
"7679" = "1" /* OPEN REDUCT FACE FX NEC */
"7691" = "1" /* BONE GRAFT TO FACE BONE */
"7692" = "1" /* SYN IMPLANT TO FACE BONE */
"7694" = "1" /* OPEN REDUCT TM DISLOCAT */
"7697" = "1" /* REMOVE INT FIX FACE BONE */
"7699" = "1" /* FACIAL BONE/JNT OP NEC */
"7700" = "1" /* SEQUESTRECTOMY NOS */
"7701" = "1" /* CHEST CAGE SEQUESTREC */
"7702" = "1" /* HUMERUS SEQUESTRECTOMY */
"7703" = "1" /* RADIUS & ULNA SEQUESTREC */
"7704" = "1" /* METACARP/CARP SEQUESTREC */
"7705" = "1" /* FEMORAL SEQUESTRECTOMY */
"7706" = "1" /* PATELLAR SEQUESTRECTOMY */
"7707" = "1" /* TIBIA/FIBULA SEQUESTREC */
"7708" = "1" /* METATAR/TAR SEQUESTREC */
"7709" = "1" /* SEQUESTRECTOMY NEC */
"7710" = "1" /* OTHER BONE INCISION NOS */
"7711" = "1" /* OTHER CHEST CAGE INCIS */
"7712" = "1" /* OTHER HUMERUS INCISION */
"7713" = "1" /* OTHER RADIUS/ULNA INCIS */
"7714" = "1" /* OTH METACARP/CARP INCIS */
"7715" = "1" /* OTHER FEMORAL INCISION */
"7716" = "1" /* OTHER PATELLAR INCISION */
"7717" = "1" /* OTHER TIBIA/FIBULA INCIS */
"7718" = "1" /* OTH METATARS/TARS INCIS */
"7719" = "1" /* BONE INCIS W/O DIV NEC */
"7720" = "1" /* WEDGE OSTEOTOMY NOS */
"7721" = "1" /* CHEST CAGE WEDG OSTEOTOM */
"7722" = "1" /* HUMERUS WEDGE OSTEOTOMY */
"7723" = "1" /* RADIUS/ULNA WEDG OSTEOTO */
"7724" = "1" /* METACAR/CAR WEDG OSTEOTO */
"7725" = "1" /* FEMORAL WEDGE OSTEOTOMY */
"7726" = "1" /* PATELLAR WEDGE OSTEOTOMY */
"7727" = "1" /* TIBIA/FIBUL WEDG OSTEOT */
"7728" = "1" /* METATAR/TAR WEDG OSTEOT */
"7729" = "1" /* WEDGE OSTEOTOMY NEC */
"7730" = "1" /* OTHER BONE DIVISION NOS */
"7731" = "1" /* CHEST CAGE BONE DIV NEC */
"7732" = "1" /* HUMERUS DIVISION NEC */
"7733" = "1" /* RADIUS/ULNA DIVISION NEC */
"7734" = "1" /* METACAR/CAR DIVISION NEC */
"7735" = "1" /* FEMORAL DIVISION NEC */
"7736" = "1" /* PATELLAR DIVISION NEC */
"7737" = "1" /* TIBIA/FIBULA DIV NEC */
"7738" = "1" /* METATAR/TAR DIVISION NEC */
"7739" = "1" /* BONE DIVISION NEC */
"7740" = "1" /* BONE BIOPSY NOS */
"7741" = "1" /* CHEST CAGE BONE BIOPSY */
"7742" = "1" /* HUMERUS BIOPSY */
"7743" = "1" /* RADIUS & ULNA BIOPSY */
"7744" = "1" /* METACARPAL/CARPAL BIOPSY */
"7745" = "1" /* FEMORAL BIOPSY */
"7746" = "1" /* PATELLAR BIOPSY */
"7747" = "1" /* TIBIA & FIBULA BIOPSY */
"7748" = "1" /* METATARSAL/TARSAL BIOPSY */
"7749" = "1" /* BONE BIOPSY NEC */
"7751" = "1" /* BUNIONECT/SFT/OSTEOTOMY */
"7752" = "1" /* BUNIONECT/SFT/ARTHRODES */
"7753" = "1" /* OTH BUNIONECT W SFT CORR */
"7754" = "1" /* EXC CORRECT BUNIONETTE */
"7756" = "1" /* REPAIR OF HAMMER TOE */
"7757" = "1" /* REPAIR OF CLAW TOE */
"7758" = "1" /* OTH EXC, FUS, REPAIR TOE */
"7759" = "1" /* BUNIONECTOMY NEC */
"7760" = "1" /* LOC EXC BONE LESION NOS */
"7761" = "1" /* EXC CHEST CAGE BONE LES */
"7762" = "1" /* LOC EXC BONE LES HUMERUS */
"7763" = "1" /* LOC EXC LES RADIUS/ULNA */
"7764" = "1" /* LOC EXC LES METACAR/CAR */
"7765" = "1" /* LOC EXC BONE LES FEMUR */
"7766" = "1" /* LOC EXC BONE LES PATELLA */
"7767" = "1" /* LOC EXC LES TIBIA/FIBULA */
"7768" = "1" /* LOC EXC LES METATAR/TAR */
"7769" = "1" /* LOC EXC BONE LESION NEC */
"7770" = "1" /* EXCISE BONE FOR GRFT NOS */
"7771" = "1" /* EX CHEST CAGE BONE-GFT */
"7772" = "1" /* EXCISE HUMERUS FOR GRAFT */
"7773" = "1" /* EXCIS RADIUS/ULNA-GRAFT */
"7774" = "1" /* EXCIS METACAR/CAR-GRAFT */
"7775" = "1" /* EXCISE FEMUR FOR GRAFT */
"7776" = "1" /* EXCISE PATELLA FOR GRAFT */
"7777" = "1" /* EXCISE TIB/FIB FOR GRAFT */
"7778" = "1" /* EXCIS METATAR/TAR-GRAFT */
"7779" = "1" /* EXCISE BONE FOR GFT NEC */
"7780" = "1" /* OTH PART OSTECTOMY NOS */
"7781" = "1" /* OTH CHEST CAGE OSTECTOMY */
"7782" = "1" /* PARTIAL HUMERECTOMY NEC */
"7783" = "1" /* PART OSTECT-RADIUS/ULNA */
"7784" = "1" /* PART OSTECT-METACAR/CAR */
"7785" = "1" /* PART OSTECTOMY-FEMUR */
"7786" = "1" /* PARTIAL PATELLECTOMY */
"7787" = "1" /* PART OSTECT-TIBIA/FIBULA */
"7788" = "1" /* PART OSTECT-METATAR/TAR */
"7789" = "1" /* PARTIAL OSTECTOMY NEC */
"7790" = "1" /* TOTAL OSTECTOMY NOS */
"7791" = "1" /* TOT CHEST CAGE OSTECTOMY */
"7792" = "1" /* TOTAL OSTECTOMY-HUMERUS */
"7793" = "1" /* TOT OSTECT-RADIUS/ULNA */
"7794" = "1" /* TOT OSTECT-METACARP/CARP */
"7795" = "1" /* TOT OSTECTOMY-FEMUR */
"7796" = "1" /* TOTAL PATELLECTOMY */
"7797" = "1" /* TOT OSTECT-TIBIA/FIBULA */
"7798" = "1" /* TOT OSTECT-METATARS/TARS */
"7799" = "1" /* TOTAL OSTECTOMY NEC */
"7800" = "1" /* BONE GRAFT NOS */
"7801" = "1" /* BONE GRAFT TO CHEST CAGE */
"7802" = "1" /* BONE GRAFT TO HUMERUS */
"7803" = "1" /* BONE GRAFT-RADIUS/ULNA */
"7804" = "1" /* BONE GRFT TO METACAR/CAR */
"7805" = "1" /* BONE GRAFT TO FEMUR */
"7806" = "1" /* BONE GRAFT TO PATELLA */
"7807" = "1" /* BONE GRAFT-TIBIA/FIBULA */
"7808" = "1" /* BONE GRAFT-METATAR/TAR */
"7809" = "1" /* BONE GRAFT NEC */
"7810" = "1" /* APPLIC EXT FIX DEV NOS */
"7811" = "1" /* APPL EXT FIX-CHEST CAGE */
"7812" = "1" /* APPLIC EXT FIX-HUMERUS */
"7813" = "1" /* APPL EXT FIX-RADIUS/ULNA */
"7814" = "1" /* APPL EXT FIX-METACAR/CAR */
"7815" = "1" /* APPLIC EXT FIX DEV-FEMUR */
"7816" = "1" /* APPL EXT FIX DEV-PATELLA */
"7817" = "1" /* APPL EXT FIX-TIB/FIBULA */
"7818" = "1" /* APPL EXT FIX-METATAR/TAR */
"7819" = "1" /* APPLIC EXT FIX DEV NEC */
"7820" = "1" /* LIMB SHORTEN PROC NOS */
"7822" = "1" /* LIMB SHORT PROC-HUMERUS */
"7823" = "1" /* LIMB SHORTEN-RADIUS/ULNA */
"7824" = "1" /* LIMB SHORTEN-METACAR/CAR */
"7825" = "1" /* LIMB SHORT PROC-FEMUR */
"7827" = "1" /* LIMB SHORTEN-TIB/FIBULA */
"7828" = "1" /* LIMB SHORTEN-METATAR/TAR */
"7829" = "1" /* LIMB SHORTEN PROC NEC */
"7830" = "1" /* LIMB LENGTHEN PROC NOS */
"7831" = "1" /* LIMB LENGTHEN PROC NOS */
"7832" = "1" /* LIMB LENGTH PROC-HUMERUS */
"7833" = "1" /* LIMB LENGTH-RADIUS/ULNA */
"7834" = "1" /* LIMB LENGTH-METACAR/CAR */
"7835" = "1" /* LIMB LENGTH PROC-FEMUR */
"7837" = "1" /* LIMB LENGTHEN-TIB/FIBULA */
"7838" = "1" /* LIMB LENGTHN-METATAR/TAR */
"7839" = "1" /* LIMB LENGTHEN PROC NEC */
"7840" = "1" /* OTH BONE REPAIR/PLAST OP */
"7841" = "1" /* OTH CHEST CAGE REP/PLAST */
"7842" = "1" /* OTH HUMERUS REPAIR/PLAST */
"7843" = "1" /* OTH RAD/ULN REPAIR/PLAST */
"7844" = "1" /* OTH METAC/CARP REP/PLAST */
"7845" = "1" /* OTH FEMUR REPAIR/PLASTIC */
"7846" = "1" /* OTH PATELLA REPAIR/PLAST */
"7847" = "1" /* OTH TIB/FIB REPAIR/PLAST */
"7848" = "1" /* OTH META/TAR REPA/PLAST */
"7849" = "1" /* OTH BONE REPA/PLAST NEC */
"7850" = "1" /* INT FIX W/O FX REDUC NOS */
"7851" = "1" /* INT FIXATION-CHEST CAGE */
"7852" = "1" /* INT FIXATION-HUMERUS */
"7853" = "1" /* INT FIXATION-RADIUS/ULNA */
"7854" = "1" /* INT FIXATION-METACAR/CAR */
"7855" = "1" /* INTERNAL FIXATION-FEMUR */
"7856" = "1" /* INTERNAL FIX-PATELLA */
"7857" = "1" /* INT FIXATION-TIBIA/FIBUL */
"7858" = "1" /* INT FIXATION-METATAR/TAR */
"7859" = "1" /* INT FIX-NO FX REDUCT NEC */
"7860" = "1" /* REMOVE IMP DEVICE NOS */
"7861" = "1" /* REMOV IMP DEV-CHEST CAGE */
"7862" = "1" /* REMOVE IMPL DEV-HUMERUS */
"7863" = "1" /* REMOV IMP DEV-RADIUS/ULN */
"7864" = "1" /* REMOV IMP DEV-METAC/CARP */
"7865" = "1" /* REMOVE IMP DEVICE-FEMUR */
"7866" = "1" /* REMOV IMP DEVICE-PATELLA */
"7867" = "1" /* REMOV IMP DEV-TIB/FIBULA */
"7868" = "1" /* REMOVE IMP DEV-METAT/TAR */
"7869" = "1" /* REMOVE IMPL DEVICE NEC */
"7870" = "1" /* OSTEOCLASIS NOS */
"7871" = "1" /* OSTEOCLASIS-CHEST CAGE */
"7872" = "1" /* OSTEOCLASIS-HUMERUS */
"7873" = "1" /* OSTEOCLASIS-RADIUS/ULNA */
"7874" = "1" /* OSTEOCLASIS-METACAR/CAR */
"7875" = "1" /* OSTEOCLASIS-FEMUR */
"7876" = "1" /* OSTEOCLASIS-PATELLA */
"7877" = "1" /* OSTEOCLASIS-TIBIA/FIBULA */
"7878" = "1" /* OSTEOCLASIS-METATAR/TAR */
"7879" = "1" /* OSTEOCLASIS NEC */
"7880" = "1" /* OTHER BONE DX PROC NOS */
"7881" = "1" /* OTH DX PROCED-CHEST CAGE */
"7882" = "1" /* OTH DX PROCED-HUMERUS */
"7883" = "1" /* OTH DX PROC-RADIUS/ULNA */
"7884" = "1" /* OTH DX PROC-METACAR/CAR */
"7885" = "1" /* OTH DX PROCED-FEMUR */
"7886" = "1" /* OTH DX PROCED-PATELLA */
"7887" = "1" /* OTH DX PROC-TIBIA/FIBULA */
"7888" = "1" /* OTH DX PROC-METATAR/TAR */
"7889" = "1" /* OTHER BONE DX PROC NEC */
"7890" = "1" /* INSERT BONE STIMUL NOS */
"7891" = "1" /* INSERT BONE STIMUL-CHEST */
"7892" = "1" /* INSERT BONE STIM-HUMERUS */
"7893" = "1" /* INSER BONE STIM-RAD/ULNA */
"7894" = "1" /* INSER BONE STIM-META/CAR */
"7895" = "1" /* INSERT BONE STIM-FEMUR */
"7896" = "1" /* INSERT BONE STIM-PATELLA */
"7897" = "1" /* INSER BONE STIM-TIB/FIB */
"7898" = "1" /* INSER BONE STIM-META/TAR */
"7899" = "1" /* INSERT BONE STIMUL NEC */
"7910" = "1" /* CL FX REDUC-INT FIX NOS */
"7911" = "1" /* CLOS RED-INT FIX HUMERUS */
"7912" = "1" /* CL RED-INT FIX RAD/ULNA */
"7913" = "1" /* CL RED-INT FIX METAC/CAR */
"7914" = "1" /* CLOSE RED-INT FIX FINGER */
"7915" = "1" /* CLOSED RED-INT FIX FEMUR */
"7916" = "1" /* CL RED-INT FIX TIB/FIBU */
"7917" = "1" /* CL RED-INT FIX METAT/TAR */
"7918" = "1" /* CLOSE RED-INT FIX TOE FX */
"7919" = "1" /* CL FX REDUC-INT FIX NEC */
"7920" = "1" /* OPEN FX REDUCTION NOS */
"7921" = "1" /* OPEN REDUC-HUMERUS FX */
"7922" = "1" /* OPEN REDUC-RADIUS/ULN FX */
"7923" = "1" /* OPEN REDUC-METAC/CAR FX */
"7924" = "1" /* OPEN REDUCTION-FINGER FX */
"7925" = "1" /* OPEN REDUCTION-FEMUR FX */
"7926" = "1" /* OPEN REDUC-TIBIA/FIB FX */
"7927" = "1" /* OPEN REDUC-METAT/TARS FX */
"7928" = "1" /* OPEN REDUCTION-TOE FX */
"7929" = "1" /* OPEN FX REDUCTION NEC */
"7930" = "1" /* OPN FX RED W INT FIX NOS */
"7931" = "1" /* OPEN RED-INT FIX HUMERUS */
"7932" = "1" /* OP RED-INT FIX RAD/ULNA */
"7933" = "1" /* OP RED-INT FIX METAC/CAR */
"7934" = "1" /* OPEN RED-INT FIX FINGER */
"7935" = "1" /* OPEN REDUC-INT FIX FEMUR */
"7936" = "1" /* OP RED-INT FIX TIB/FIBUL */
"7937" = "1" /* OP RED-INT FIX METAT/TAR */
"7938" = "1" /* OPEN REDUCT-INT FIX TOE */
"7939" = "1" /* OPN FX RED W INT FIX NEC */
"7940" = "1" /* CLS REDUC-SEP EPIPHY NOS */
"7941" = "1" /* CLOSE RED-HUMERUS EPIPHY */
"7942" = "1" /* CLS RED-RADIUS/UL EPIPHY */
"7945" = "1" /* CLOSE REDUC-FEMUR EPIPHY */
"7946" = "1" /* CLS RED-TIBIA/FIB EPIPHY */
"7949" = "1" /* CLS REDUC-SEP EPIPHY NEC */
"7950" = "1" /* OPEN RED-SEP EPIPHY NOS */
"7951" = "1" /* OPN RED-SEP EPIPHY-HUMER */
"7952" = "1" /* OP RED-RADIUS/ULN EPIPHY */
"7955" = "1" /* OPN RED-SEP EPIPHY-FEMUR */
"7956" = "1" /* OP RED-TIBIA/FIB EPIPHYS */
"7959" = "1" /* OPEN RED-SEP EPIPHY NEC */
"7960" = "1" /* OPEN FX SITE DEBRIDE NOS */
"7961" = "1" /* DEBRID OPEN FX-HUMERUS */
"7962" = "1" /* DEBRID OPN FX-RADIUS/ULN */
"7963" = "1" /* DEBRID OPN FX-METAC/CAR */
"7964" = "1" /* DEBRID OPN FX-FINGER */
"7965" = "1" /* DEBRID OPN FX-FEMUR */
"7966" = "1" /* DEBRID OPN FX-TIBIA/FIB */
"7967" = "1" /* DEBRID OPN FX-METAT/TAR */
"7968" = "1" /* DEBRID OPN FX-TOE */
"7969" = "1" /* OPEN FX SITE DEBRIDE NEC */
"7980" = "1" /* OPEN REDUC-DISLOCAT NOS */
"7981" = "1" /* OPN REDUC DISLOC-SHOULDR */
"7982" = "1" /* OPEN REDUC-ELBOW DISLOC */
"7983" = "1" /* OPEN REDUC-WRIST DISLOC */
"7984" = "1" /* OPN REDUC DISLOC-HAND */
"7985" = "1" /* OPEN REDUC-HIP DISLOCAT */
"7986" = "1" /* OPEN REDUC-KNEE DISLOCAT */
"7987" = "1" /* OPEN REDUC-ANKLE DISLOC */
"7988" = "1" /* OPN REDUC DISLOC-FT/TOE */
"7989" = "1" /* OPEN REDUC-DISLOCAT NEC */
"7990" = "1" /* UNSPEC OP BONE INJ NOS */
"7991" = "1" /* HUMERUS INJURY OP NOS */
"7992" = "1" /* RADIUS/ULNA INJ OP NOS */
"7993" = "1" /* METACARP/CARP INJ OP NOS */
"7994" = "1" /* FINGER INJURY OP NOS */
"7995" = "1" /* FEMUR INJURY OP NOS */
"7996" = "1" /* TIBIA/FIBULA INJ OP NOS */
"7997" = "1" /* METATARS/TARS INJ OP NOS */
"7998" = "1" /* TOE INJURY OPERATION NOS */
"7999" = "1" /* UNSPEC OP-BONE INJ NEC */
"8000" = "1" /* ARTHROT & PROS REMOV NOS */
"8001" = "1" /* ARTHROT/PROS REMOV-SHLDR */
"8002" = "1" /* ARTHROT/PROS REMOV-ELBOW */
"8003" = "1" /* ARTHROT/PROS REMOV-WRIST */
"8004" = "1" /* ARTHROT/PROS REMOV-HAND */
"8005" = "1" /* ARTHROT/PROS REMOV-HIP */
"8006" = "1" /* ARTHROT/PROS REMOV-KNEE */
"8007" = "1" /* ARTHROT/PROS REMOV-ANKLE */
"8008" = "1" /* ARTHROT/PROS REMOV-FOOT */
"8009" = "1" /* ARTHROT & PROS REMOV NEC */
"8010" = "1" /* OTHER ARTHROTOMY NOS */
"8011" = "1" /* OTH ARTHROTOMY-SHOULDER */
"8012" = "1" /* OTH ARTHROTOMY-ELBOW */
"8013" = "1" /* OTH ARTHROTOMY-WRIST */
"8014" = "1" /* OTH ARTHROTOMY-HAND/FNGR */
"8015" = "1" /* OTH ARTHROTOMY-HIP */
"8016" = "1" /* OTH ARTHROTOMY-KNEE */
"8017" = "1" /* OTH ARTHROTOMY-ANKLE */
"8018" = "1" /* OTH ARTHROTOMY-FOOT/TOE */
"8019" = "1" /* OTHER ARTHROTOMY NEC */
"8020" = "1" /* ARTHROSCOPY NOS */
"8021" = "1" /* SHOULDER ARTHROSCOPY */
"8022" = "1" /* ELBOW ARTHROSCOPY */
"8023" = "1" /* WRIST ARTHROSCOPY */
"8024" = "1" /* HAND & FINGER ARTHROSCOP */
"8025" = "1" /* HIP ARTHROSCOPY */
"8026" = "1" /* KNEE ARTHROSCOPY */
"8027" = "1" /* ANKLE ARTHROSCOPY */
"8028" = "1" /* FOOT & TOE ARTHROSCOPY */
"8029" = "1" /* ARTHROSCOPY NEC */
"8040" = "1" /* JT STRUCTUR DIVISION NOS */
"8041" = "1" /* SHOULDER STRUCT DIVISION */
"8042" = "1" /* ELBOW STRUCTURE DIVISION */
"8043" = "1" /* WRIST STRUCTURE DIVISION */
"8044" = "1" /* HAND JOINT STRUCT DIVIS */
"8045" = "1" /* HIP STRUCTURE DIVISION */
"8046" = "1" /* KNEE STRUCTURE DIVISION */
"8047" = "1" /* ANKLE STRUCTURE DIVISION */
"8048" = "1" /* FOOT JOINT STRUCT DIVIS */
"8049" = "1" /* JT STRUCTUR DIVISION NEC */
"805 " = "1" /* JT STRUCTUR DIVISION NEC */
"8050" = "1" /* EXC/DEST INTVRT DISC NOS */
"8051" = "1" /* EXCISION INTERVERT DISC */
"8053" = "1" /* REP ANULUS FIBROSUS-GRFT */
"8054" = "1" /* REP ANULS FIBROS NEC/NOS */
"8059" = "1" /* OTH EXC/DEST INTVRT DISC */
"806 " = "1" /* EXCIS KNEE SEMILUN CARTL */
"8070" = "1" /* SYNOVECTOMY-SITE NOS */
"8071" = "1" /* SHOULDER SYNOVECTOMY */
"8072" = "1" /* ELBOW SYNOVECTOMY */
"8073" = "1" /* WRIST SYNOVECTOMY */
"8074" = "1" /* HAND SYNOVECTOMY */
"8075" = "1" /* HIP SYNOVECTOMY */
"8076" = "1" /* KNEE SYNOVECTOMY */
"8077" = "1" /* ANKLE SYNOVECTOMY */
"8078" = "1" /* FOOT SYNOVECTOMY */
"8079" = "1" /* SYNOVECTOMY-SITE NEC */
"8080" = "1" /* DESTRUCT JOINT LES NOS */
"8081" = "1" /* DESTRUC-SHOULDER LES NEC */
"8082" = "1" /* DESTRUC-ELBOW LESION NEC */
"8083" = "1" /* DESTRUC-WRIST LESION NEC */
"8084" = "1" /* DESTRUC-HAND JT LES NEC */
"8085" = "1" /* DESTRUCT-HIP LESION NEC */
"8086" = "1" /* DESTRUCT-KNEE LESION NEC */
"8087" = "1" /* DESTRUC-ANKLE LESION NEC */
"8088" = "1" /* DESTRUC-FOOT JT LES NEC */
"8089" = "1" /* DESTRUCT JOINT LES NEC */
"8090" = "1" /* EXCISION OF JOINT NOS */
"8091" = "1" /* EXCISION OF SHOULDER NEC */
"8092" = "1" /* EXCISION OF ELBOW NEC */
"8093" = "1" /* EXCISION OF WRIST NEC */
"8094" = "1" /* EXCISION HAND JOINT NEC */
"8095" = "1" /* EXCISION OF HIP NEC */
"8096" = "1" /* EXCISION OF KNEE NEC */
"8097" = "1" /* EXCISION OF ANKLE NEC */
"8098" = "1" /* EXCISION FOOT JOINT NEC */
"8099" = "1" /* EXCISION OF JOINT NEC */
"8100" = "1" /* SPINAL FUSION NOS */
"8101" = "1" /* ATLAS-AXIS FUSION */
"8102" = "1" /* OTHER CERVICAL FUS ANT */
"8103" = "1" /* OTHER CERVICAL FUS POST */
"8104" = "1" /* DORSAL/DORSOLUM FUS ANT */
"8105" = "1" /* DORSAL/DORSOLUM FUS POST */
"8106" = "1" /* LUMBAR/LUMBOSAC FUS ANT */
"8107" = "1" /* LUMBAR/LUMBOSAC FUS LAT */
"8108" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8109" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8111" = "1" /* ANKLE FUSION */
"8112" = "1" /* TRIPLE ARTHRODESIS */
"8113" = "1" /* SUBTALAR FUSION */
"8114" = "1" /* MIDTARSAL FUSION */
"8115" = "1" /* TARSOMETATARSAL FUSION */
"8116" = "1" /* METATARSOPHALANGEAL FUS */
"8117" = "1" /* OTHER FUSION OF FOOT */
"8118" = "1" /* OTHER FUSION OF FOOT */
"8120" = "1" /* ARTHRODESIS NOS */
"8121" = "1" /* ARTHRODESIS OF HIP */
"8122" = "1" /* ARTHRODESIS OF KNEE */
"8123" = "1" /* ARTHRODESIS OF SHOULDER */
"8124" = "1" /* ARTHRODESIS OF ELBOW */
"8125" = "1" /* CARPORADIAL FUSION */
"8126" = "1" /* METACARPOCARPAL FUSION */
"8127" = "1" /* METACARPOPHALANGEAL FUS */
"8128" = "1" /* INTERPHALANGEAL FUSION */
"8129" = "1" /* ARTHRODESIS NEC */
"8130" = "1" /* SPINAL REFUSION NOS */
"8131" = "1" /* REFUSION OF ATLAS-AXIS */
"8132" = "1" /* REFUSION OF OTH CERV ANT */
"8133" = "1" /* REFUS OF OTH CERV POST */
"8134" = "1" /* REFUSION OF DORSAL ANT */
"8135" = "1" /* REFUSION OF DORSAL POST */
"8136" = "1" /* REFUSION OF LUMBAR ANT */
"8137" = "1" /* REFUSION OF LUMBAR LAT */
"8138" = "1" /* REFUSION OF LUMBAR POST */
"8139" = "1" /* REFUSION OF SPINE NEC */
"8140" = "1" /* REPAIR OF HIP, NEC */
"8141" = "1" /* REPAIR OF HIP, NEC */
"8142" = "1" /* FIVE-IN-ONE KNEE REPAIR */
"8143" = "1" /* TRIAD KNEE REPAIR */
"8144" = "1" /* PATELLAR STABILIZATION */
"8145" = "1" /* CRUCIATE LIG REPAIR NEC */
"8146" = "1" /* COLLATERL LIG REPAIR NEC */
"8147" = "1" /* OTHER REPAIR OF KNEE */
"8148" = "1" /* OTHER REPAIR OF KNEE */
"8149" = "1" /* OTHER REPAIR OF ANKLE */
"8151" = "1" /* TOTAL HIP REPLACEMENT */
"8152" = "1" /* PARTIAL HIP REPLACEMENT */
"8153" = "1" /* REVISE HIP REPLACEMENT */
"8154" = "1" /* TOTAL KNEE REPLACEMENT */
"8155" = "1" /* REVISE KNEE REPLACEMENT */
"8156" = "1" /* TOTAL ANKLE REPLACEMENT */
"8157" = "1" /* REPL JOINT OF FOOT, TOE */
"8159" = "1" /* REV JT REPL LOW EXT NEC */
"8161" = "1" /* 360 SPINAL FUSION */
"8162" = "1" /* FUS/REFUS 2-3 VERTEBRAE */
"8163" = "1" /* FUS/REFUS 4-8 VERTEBRAE */
"8164" = "1" /* FUS/REFUS 9 VERTEBRAE */
"8165" = "1" /* VERTEBROPLASTY */
"8166" = "1" /* KYPHOPLASTY */
"8169" = "1" /* OTH HIP REPAIR  JAN80--SEP89 */
"8171" = "1" /* ARTHROPLAS METACARP WIT */
"8172" = "1" /* ARTHROPLASTY METACAR W/O */
"8173" = "1" /* TOTAL WRIST REPLACEMENT */
"8174" = "1" /* ARTHROPLASTY CARPAL WIT */
"8175" = "1" /* ARTHROPLASTY CARPAL W/O */
"8179" = "1" /* OTH REPAIR HAN/FIN/WRIS */
"8180" = "1" /* TOTAL SHOULDER REPLACE */
"8181" = "1" /* PARTIAL SHOULDER REPLACE */
"8182" = "1" /* REP RECUR SHLDER DISLOC */
"8183" = "1" /* SHOULDER ARTHROPLAST NEC */
"8184" = "1" /* TOTAL ELBOW REPLACEMENT */
"8185" = "1" /* ELBOW ARTHROPLASTY NEC */
"8186" = "1" /* ELBOW ARTHROPLASTY NEC */
"8187" = "1" /* ELBOW ARTHROPLASTY NEC */
"8188" = "1" /* RVRS TOTL SHLDR REPLACMT */	
"8193" = "1" /* SUTUR CAPSUL/LIGAMEN ARM */
"8194" = "1" /* SUTURE CAPSUL/LIG ANK/FT */
"8195" = "1" /* SUTUR CAPSUL/LIG LEG NEC */
"8196" = "1" /* OTHER REPAIR OF JOINT */
"8197" = "1" /* REV JT REPL UPPER EXTREM */
"8198" = "1" /* OTHER JOINT DX PROCEDURE */
"8199" = "1" /* JOINT STRUCTURE OP NEC */
"8201" = "1" /* EXPLOR TEND SHEATH-HAND */
"8202" = "1" /* MYOTOMY OF HAND */
"8203" = "1" /* BURSOTOMY OF HAND */
"8209" = "1" /* INC SOFT TISSUE HAND NEC */
"8211" = "1" /* TENOTOMY OF HAND */
"8212" = "1" /* FASCIOTOMY OF HAND */
"8219" = "1" /* DIV SOFT TISSUE HAND NEC */
"8221" = "1" /* EXC LES TEND SHEATH HAND */
"8222" = "1" /* EXCISION HAND MUSCLE LES */
"8229" = "1" /* EXC LES SFT TISS HND NEC */
"8231" = "1" /* BURSECTOMY OF HAND */
"8232" = "1" /* EXCIS HAND TEND FOR GRFT */
"8233" = "1" /* HAND TENONECTOMY NEC */
"8234" = "1" /* EXC HND MUS/FAS FOR GRFT */
"8235" = "1" /* HAND FASCIECTOMY NEC */
"8236" = "1" /* OTHER MYECTOMY OF HAND */
"8239" = "1" /* HAND SOFT TISSUE EXC NEC */
"8241" = "1" /* SUTURE TENDN SHEATH HAND */
"8242" = "1" /* DELAY SUT FLEX TEND HAND */
"8243" = "1" /* DELAY SUT HAND TEND NEC */
"8244" = "1" /* SUTUR FLEX TEND HAND NEC */
"8245" = "1" /* SUTURE HAND TENDON NEC */
"8246" = "1" /* SUTURE HAND MUSCLE/FASC */
"8251" = "1" /* HAND TENDON ADVANCEMENT */
"8252" = "1" /* HAND TENDON RECESSION */
"8253" = "1" /* HAND TENDON REATTACHMENT */
"8254" = "1" /* HAND MUSCLE REATTACHMENT */
"8255" = "1" /* CHNG HND MUS/TEN LNG NEC */
"8256" = "1" /* TRANSPLANT HAND TEND NEC */
"8257" = "1" /* TRANSPOSIT HAND TEND NEC */
"8258" = "1" /* TRANSPLANT HAND MUSC NEC */
"8259" = "1" /* TRANSPOSIT HAND MUSC NEC */
"8261" = "1" /* POLLICIZATION OPERATION */
"8269" = "1" /* THUMB RECONSTRUCTION NEC */
"8271" = "1" /* HAND TEND PULLEY RECONST */
"8272" = "1" /* PLAST OP HND-MUS/FAS GRF */
"8279" = "1" /* PLAST OP HAND W GRFT NEC */
"8281" = "1" /* TRANSFER OF FINGER */
"8282" = "1" /* REPAIR OF CLEFT HAND */
"8283" = "1" /* REPAIR OF MACRODACTYLY */
"8284" = "1" /* REPAIR OF MALLET FINGER */
"8285" = "1" /* OTHER TENODESIS OF HAND */
"8286" = "1" /* OTHER TENOPLASTY OF HAND */
"8289" = "1" /* HAND PLASTIC OP NEC */
"8291" = "1" /* LYSIS OF HAND ADHESIONS */
"8299" = "1" /* HAND MUS/TEN/FAS/OPS NEC */
"8301" = "1" /* TENDON SHEATH EXPLORAT */
"8302" = "1" /* MYOTOMY */
"8303" = "1" /* BURSOTOMY */
"8309" = "1" /* SOFT TISSUE INCISION NEC */
"8311" = "1" /* ACHILLOTENOTOMY */
"8312" = "1" /* ADDUCTOR TENOTOMY OF HIP */
"8313" = "1" /* OTHER TENOTOMY */
"8314" = "1" /* FASCIOTOMY */
"8319" = "1" /* SOFT TISSUE DIVISION NEC */
"8321" = "1" /* SOFT TISSUE BIOPSY */
"8329" = "1" /* SOFT TISSUE DX PROC NEC */
"8331" = "1" /* EXCIS LES TENDON SHEATH */
"8332" = "1" /* EXCIS LESION OF MUSCLE */
"8339" = "1" /* EXC LES SOFT TISSUE NEC */
"8341" = "1" /* TENDON EXCISION FOR GRFT */
"8342" = "1" /* OTHER TENONECTOMY */
"8343" = "1" /* MUSC/FASC EXCIS FOR GRFT */
"8344" = "1" /* OTHER FASCIECTOMY */
"8345" = "1" /* OTHER MYECTOMY */
"8349" = "1" /* OTHER SOFT TISSUE EXCIS */
"835 " = "1" /* BURSECTOMY */
"8361" = "1" /* TENDON SHEATH SUTURE */
"8362" = "1" /* DELAYED TENDON SUTURE */
"8363" = "1" /* ROTATOR CUFF REPAIR */
"8364" = "1" /* OTHER SUTURE OF TENDON */
"8365" = "1" /* OTHER MUSCLE/FASC SUTURE */
"8371" = "1" /* TENDON ADVANCEMENT */
"8372" = "1" /* TENDON RECESSION */
"8373" = "1" /* TENDON REATTACHMENT */
"8374" = "1" /* MUSCLE REATTACHMENT */
"8375" = "1" /* TENDON TRNSFR/TRANSPLANT */
"8376" = "1" /* OTHER TENDON TRANSPOSIT */
"8377" = "1" /* MUSCLE TRNSFR/TRANSPLANT */
"8379" = "1" /* OTHER MUSCLE TRANSPOSIT */
"8381" = "1" /* TENDON GRAFT */
"8382" = "1" /* MUSCLE OR FASCIA GRAFT */
"8383" = "1" /* TENDON PULLEY RECONSTRUC */
"8384" = "1" /* CLUBFOOT RELEASE NEC */
"8385" = "1" /* MUSC/TEND LNG CHANGE NEC */
"8386" = "1" /* QUADRICEPSPLASTY */
"8387" = "1" /* OTHER PLASTIC OPS MUSCLE */
"8388" = "1" /* OTHER PLASTIC OPS TENDON */
"8389" = "1" /* OTHER PLASTIC OPS FASCIA */
"8391" = "1" /* ADHESIOLYSIS MUS/TEN/FAS */
"8392" = "1" /* INSERT SKEL MUSC STIMULA */
"8393" = "1" /* REMOV SKEL MUSC STIMULAT */
"8399" = "1" /* MUS/TEN/FAS/BUR OP NEC */
"8400" = "1" /* UPPER LIMB AMPUTAT NOS */
"8401" = "1" /* FINGER AMPUTATION */
"8402" = "1" /* THUMB AMPUTATION */
"8403" = "1" /* AMPUTATION THROUGH HAND */
"8404" = "1" /* DISARTICULATION OF WRIST */
"8405" = "1" /* AMPUTATION THRU FOREARM */
"8406" = "1" /* DISARTICULATION OF ELBOW */
"8407" = "1" /* AMPUTATION THRU HUMERUS */
"8408" = "1" /* SHOULDER DISARTICULATION */
"8409" = "1" /* FOREQUARTER AMPUTATION */
"8410" = "1" /* LOWER LIMB AMPUTAT NOS */
"8411" = "1" /* TOE AMPUTATION */
"8412" = "1" /* AMPUTATION THROUGH FOOT */
"8413" = "1" /* DISARTICULATION OF ANKLE */
"8414" = "1" /* AMPUTAT THROUGH MALLEOLI */
"8415" = "1" /* BELOW KNEE AMPUTAT NEC */
"8416" = "1" /* DISARTICULATION OF KNEE */
"8417" = "1" /* ABOVE KNEE AMPUTATION */
"8418" = "1" /* DISARTICULATION OF HIP */
"8419" = "1" /* HINDQUARTER AMPUTATION */
"8421" = "1" /* THUMB REATTACHMENT */
"8422" = "1" /* FINGER REATTACHMENT */
"8423" = "1" /* FOREARM/WRIST/HAND REATT */
"8424" = "1" /* UPPER ARM REATTACHMENT */
"8425" = "1" /* TOE REATTACHMENT */
"8426" = "1" /* FOOT REATTACHMENT */
"8427" = "1" /* LOWER LEG/ANKLE REATTACH */
"8428" = "1" /* THIGH REATTACHMENT */
"8429" = "1" /* REATTACHMENT NEC */
"843 " = "1" /* AMPUTATION STUMP REVIS */
"8440" = "1" /* IMPLNT/FIT PROS LIMB NOS */
"8444" = "1" /* IMPLANT ARM PROSTHESIS */
"8448" = "1" /* IMPLANT LEG PROSTHESIS */
"8458" = "1" /* IMP INTRSPINE DECOMP DEV */
"8459" = "1" /* INSERT OTHR SPIN DEVICE */
"8460" = "1" /* INSERT DISC PROS NOS */
"8461" = "1" /* INS PART DISC PROS CERV */
"8462" = "1" /* INS TOT DISC PROST CERV */
"8463" = "1" /* INS SPIN DISC PROS THOR */
"8464" = "1" /* INS PART DISC PROS LUMB */
"8465" = "1" /* INS TOTL DISC PROS LUMB */
"8466" = "1" /* REVISE DISC PROST CERV */
"8467" = "1" /* REVISE DISC PROST THORA */
"8468" = "1" /* REVISE DISC PROSTH LUMB */
"8469" = "1" /* REVISE DISC PROSTH NOS */
"8480" = "1" /* INS/REPL INTERSPINE DEV */
"8481" = "1" /* REV INTERSPINE DEVICE */
"8482" = "1" /* INS/REPL PDCL STABIL DEV */
"8483" = "1" /* REV PEDCL DYN STABIL DEV */
"8484" = "1" /* INS/REPL FACET REPLC DEV */
"8485" = "1" /* REV FACET REPLACE DEVICE */
"8491" = "1" /* AMPUTATION NOS */
"8492" = "1" /* SEPARAT EQUAL JOIN TWIN */
"8493" = "1" /* SEPARAT UNEQUL JOIN TWIN */
"8494" = "1" /* INS STRN FIX W RGD PLATE */	
"8499" = "1" /* MUSCULOSKELETAL OP NEC */
"8512" = "1" /* OPEN BREAST BIOPSY */
"8520" = "1" /* BREAST TISSU DESTRUC NOS */
"8521" = "1" /* LOCAL EXCIS BREAST LES */
"8522" = "1" /* QUADRANT RESECT BREAST */
"8523" = "1" /* SUBTOTAL MASTECTOMY */
"8524" = "1" /* EXC ECTOPIC BREAST TISSU */
"8525" = "1" /* EXCISION OF NIPPLE */
"8531" = "1" /* UNILAT REDUCT MAMMOPLAST */
"8532" = "1" /* BILAT REDUCT MAMMOPLASTY */
"8533" = "1" /* UNIL SUBQ MAMMECT-IMPLNT */
"8534" = "1" /* UNILAT SUBQ MAMMECT NEC */
"8535" = "1" /* BIL SUBQ MAMMECT-IMPLANT */
"8536" = "1" /* BILAT SUBQ MAMMECTOM NEC */
"8541" = "1" /* UNILAT SIMPLE MASTECTOMY */
"8542" = "1" /* BILAT SIMPLE MASTECTOMY */
"8543" = "1" /* UNILAT EXTEN SIMP MASTEC */
"8544" = "1" /* BILAT EXTEND SIMP MASTEC */
"8545" = "1" /* UNILAT RADICAL MASTECTOM */
"8546" = "1" /* BILAT RADICAL MASTECTOMY */
"8547" = "1" /* UNIL EXT RAD MASTECTOMY */
"8548" = "1" /* BIL EXTEN RAD MASTECTOMY */
"8550" = "1" /* AUGMENT MAMMOPLASTY NOS */
"8553" = "1" /* UNILAT BREAST IMPLANT */
"8554" = "1" /* BILATERAL BREAST IMPLANT */
"8555" = "1" /* FAT GRAFT TO BREAST	  	 */
"856 " = "1" /* MASTOPEXY */
"857 " = "1" /* TOTAL BREAST RECONSTRUCT */
"8570" = "1" /* TOTL RECONSTC BREAST NOS */
"8571" = "1" /* LATISS DORSI MYOCUT FLAP */
"8572" = "1" /* TRAM FLAP, PEDICLED */
"8573" = "1" /* TRAM FLAP, FREE */
"8574" = "1" /* DIEP FLAP, FREE */
"8575" = "1" /* SIEA FLAP, FREE */
"8576" = "1" /* GAP FLAP, FREE */
"8579" = "1" /* TOTL RECONST BREAST NEC */
"8582" = "1" /* BREAST SPLIT-THICK GRAFT */
"8583" = "1" /* BREAST FULL-THICK GRAFT */
"8584" = "1" /* BREAST PEDICLE GRAFT */
"8585" = "1" /* BREAST MUSCLE FLAP GRAFT */
"8586" = "1" /* TRANSPOSITION OF NIPPLE */
"8587" = "1" /* NIPPLE REPAIR NEC */
"8589" = "1" /* MAMMOPLASTY NEC */
"8593" = "1" /* BREAST IMPLANT REVISION */
"8594" = "1" /* BREAST IMPLANT REMOVAL */
"8595" = "1" /* INSER BREAST TISSU EXPAN */
"8596" = "1" /* REMOV BREAST TISSU EXPAN */
"8599" = "1" /* BREAST OPERATION NEC */
"8606" = "1" /* INSERT INFUSION PUMP */
"8621" = "1" /* EXCISION OF PILONID CYST */
"8622" = "1" /* EXC WOUND DEBRIDEMENT */
"8625" = "1" /* DERMABRASION */
"864 " = "1" /* RADICAL EXCIS SKIN LES */
"8660" = "1" /* FREE SKIN GRAFT NOS */
"8661" = "1" /* FULL-THICK HAND SKIN GRF */
"8662" = "1" /* HAND SKIN GRAFT NEC */
"8663" = "1" /* FULL-THICK SKIN GRFT NEC */
"8665" = "1" /* HETEROGRAFT TO SKIN */
"8666" = "1" /* HOMOGRAFT TO SKIN */
"8667" = "1" /* DERMAL REGENER GRAFT */
"8669" = "1" /* FREE SKIN GRAFT NEC */
"8670" = "1" /* PEDICLE GRAFT/FLAP NOS */
"8671" = "1" /* CUT & PREP PEDICLE GRAFT */
"8672" = "1" /* PEDICLE GRAFT ADVANCEMEN */
"8673" = "1" /* ATTACH PEDICLE TO HAND */
"8674" = "1" /* ATTACH PEDICLE GRAFT NEC */
"8675" = "1" /* REVISION OF PEDICLE GRFT */
"8681" = "1" /* REPAIR FACIAL WEAKNESS */
"8682" = "1" /* FACIAL RHYTIDECTOMY */
"8683" = "1" /* SIZE REDUCT PLASTIC OP */
"8684" = "1" /* RELAXATION OF SCAR */
"8685" = "1" /* SYNDACTYLY CORRECTION */
"8686" = "1" /* ONYCHOPLASTY */
"8687" = "1" /* FAT GRFT SKIN/SUBQ TISS	 */
"8689" = "1" /* SKIN REPAIR & PLASTY NEC */
"8690" = "1" /* EXT FAT FOR GRFT/BANKING */
"8691" = "1" /* SKIN EXCISION FOR GRAFT */
"8693" = "1" /* INSERT TISSUE EXPANDER */
"8694" = "1" /* INS/REPL SINGLE PUL GEN */
"8695" = "1" /* INS/REPL DUAL PULSE GEN */
"8696" = "1" /* INSERT/REPL OTH NEUROST */
"8697" = "1" /* INS/REP 1 PUL GEN */
"8698" = "1" /* INS/REP 2 PUL GEN */
"8753" = "1" /* INTRAOPER CHOLANGIOGRAM */
"9227" = "1" /* RADIOACTIVE ELEM IMPLANT */
"9504" = "1" /* ANESTHETIZED EYE EXAM */
other  = "0"
;

value $LIVEB2D
'V301 ' = 1  /* SINGL LIVEBRN-BEFORE ADM */
'V302 ' = 1  /* SINGLE LIVEBORN-NONHOSP */
'V311 ' = 1  /* TWIN, MATE LB-BEFORE ADM */
'V312 ' = 1  /* TWIN, MATE LB-NONHOSP */
'V321 ' = 1  /* TWIN, MATE SB-BEFORE ADM */
'V322 ' = 1  /* TWIN, MATE SB-NONHOSP */
'V331 ' = 1  /* TWIN NOS-BEFORE ADMISSN */
'V332 ' = 1  /* TWIN NOS-NONHOSP */
'V341 ' = 1  /* OTH MULT NB-BEFORE ADM */
'V342 ' = 1  /* OTH MULTIPLE NB-NONHOSP */
'V351 ' = 1  /* OTH MULT SB-BEFORE ADM */
'V352 ' = 1  /* OTH MULTIPLE SB-NONHOSP */
'V361 ' = 1  /* MULT NB/SB-BEFORE ADM */
'V362 ' = 1  /* MULTIPLE NB/SB-NONHOSP */
'V371 ' = 1  /* MULT BRTH NOS-BEFORE ADM */
'V372 ' = 1  /* MULT BIRTH NOS-NONHOSP */
'V391 ' = 1  /* LIVEBORN NOS-BEFORE ADM */
'V392 ' = 1  /* LIVEBORN NOS-NONHOSP */
other   = 0;
/* ---------------------------------------------------------------- */
/* ADULT DRGS                                                       */
/* ---------------------------------------------------------------- */
/* DIAGNOSTIC RELATED GROUPS (DRGS):                                */
/* ---------------------------------------------------------------- */
/* MEDICAL DRGS (deleted Adult DRGs)                                */
/* ---------------------------------------------------------------- */
/* MEDICDR - DRG v24 and earlier removed in V6.0 */
/* MEDIC2R - DRG v25 and later */
value $MEDIC2R
'052' = '1' /* Spinal disorders & injuries w CC/MCC */
'053' = '1' /* Spinal disorders & injuries w/o CC/MCC */
'054' = '1' /* Nervous system neoplasms w MCC */
'055' = '1' /* Nervous system neoplasms w/o MCC */
'056' = '1' /* Degenerative nervous system disorders w MCC */
'057' = '1' /* Degenerative nervous system disorders w/o MCC */
'058' = '1' /* Multiple sclerosis & cerebellar ataxia w MCC */
'059' = '1' /* Multiple sclerosis & cerebellar ataxia w CC */
'060' = '1' /* Multiple sclerosis & cerebellar ataxia w/o CC/MCC */
'061' = '1' /* Acute ischemic stroke w use of thrombolytic agent w MCC */
'062' = '1' /* Acute ischemic stroke w use of thrombolytic agent w CC */
'063' = '1' /* Acute ischemic stroke w use of thrombolytic agent w/o CC/MCC */
'064' = '1' /* Intracranial hemorrhage or cerebral infarction w MCC */
'065' = '1' /* Intracranial hemorrhage or cerebral infarction w CC */
'066' = '1' /* Intracranial hemorrhage or cerebral infarction w/o CC/MCC */
'067' = '1' /* Nonspecific cva & precerebral occlusion w/o infarct w MCC */
'068' = '1' /* Nonspecific cva & precerebral occlusion w/o infarct w/o MCC */
'069' = '1' /* Transient ischemia */
'070' = '1' /* Nonspecific cerebrovascular disorders w MCC */
'071' = '1' /* Nonspecific cerebrovascular disorders w CC */
'072' = '1' /* Nonspecific cerebrovascular disorders w/o CC/MCC */
'073' = '1' /* Cranial & peripheral nerve disorders w MCC */
'074' = '1' /* Cranial & peripheral nerve disorders w/o MCC */
'075' = '1' /* Viral meningitis w CC/MCC */
'076' = '1' /* Viral meningitis w/o CC/MCC */
'077' = '1' /* Hypertensive encephalopathy w MCC */
'078' = '1' /* Hypertensive encephalopathy w CC */
'079' = '1' /* Hypertensive encephalopathy w/o CC/MCC */
'080' = '1' /* Nontraumatic stupor & coma w MCC */
'081' = '1' /* Nontraumatic stupor & coma w/o MCC */
'082' = '1' /* Traumatic stupor & coma, coma >1 hr w MCC */
'083' = '1' /* Traumatic stupor & coma, coma >1 hr w CC */
'084' = '1' /* Traumatic stupor & coma, coma >1 hr w/o CC/MCC */
'085' = '1' /* Traumatic stupor & coma, coma <1 hr w MCC */
'086' = '1' /* Traumatic stupor & coma, coma <1 hr w CC */
'087' = '1' /* Traumatic stupor & coma, coma <1 hr w/o CC/MCC */
'088' = '1' /* Concussion w MCC */
'089' = '1' /* Concussion w CC */
'090' = '1' /* Concussion w/o CC/MCC */
'091' = '1' /* Other disorders of nervous system w MCC */
'092' = '1' /* Other disorders of nervous system w CC */
'093' = '1' /* Other disorders of nervous system w/o CC/MCC */
'094' = '1' /* Bacterial & tuberculous infections of nervous system w MCC */
'095' = '1' /* Bacterial & tuberculous infections of nervous system w CC */
'096' = '1' /* Bacterial & tuberculous infections of nervous system w/o CC/MCC */
'097' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w MCC */
'098' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w CC */
'099' = '1' /* Non-bacterial infect of nervous sys exc viral meningitis w/o CC/MCC */
'100' = '1' /* Seizures w MCC */
'101' = '1' /* Seizures w/o MCC */
'102' = '1' /* Headaches w MCC */
'103' = '1' /* Headaches w/o MCC */
'121' = '1' /* Acute major eye infections w CC/MCC */
'122' = '1' /* Acute major eye infections w/o CC/MCC */
'123' = '1' /* Neurological eye disorders */
'124' = '1' /* Other disorders of the eye w MCC */
'125' = '1' /* Other disorders of the eye w/o MCC */
'146' = '1' /* Ear, nose, mouth & throat malignancy w MCC */
'147' = '1' /* Ear, nose, mouth & throat malignancy w CC */
'148' = '1' /* Ear, nose, mouth & throat malignancy w/o CC/MCC */
'149' = '1' /* Dysequilibrium */
'150' = '1' /* Epistaxis w MCC */
'151' = '1' /* Epistaxis w/o MCC */
'152' = '1' /* Otitis media & URI w MCC */
'153' = '1' /* Otitis media & URI w/o MCC */
'154' = '1' /* Nasal trauma & deformity w MCC */
'155' = '1' /* Nasal trauma & deformity w CC */
'156' = '1' /* Nasal trauma & deformity w/o CC/MCC */
'157' = '1' /* Dental & Oral Diseases w MCC */
'158' = '1' /* Dental & Oral Diseases w CC */
'159' = '1' /* Dental & Oral Diseases w/o CC/MCC */
'175' = '1' /* Pulmonary embolism w MCC */
'176' = '1' /* Pulmonary embolism w/o MCC */
'177' = '1' /* Respiratory infections & inflammations w MCC */
'178' = '1' /* Respiratory infections & inflammations w CC */
'179' = '1' /* Respiratory infections & inflammations w/o CC/MCC */
'180' = '1' /* Respiratory neoplasms w MCC */
'181' = '1' /* Respiratory neoplasms w CC */
'182' = '1' /* Respiratory neoplasms w/o CC/MCC */
'183' = '1' /* Major chest trauma w MCC */
'184' = '1' /* Major chest trauma w CC */
'185' = '1' /* Major chest trauma w/o CC/MCC */
'186' = '1' /* Pleural effusion w MCC */
'187' = '1' /* Pleural effusion w CC */
'188' = '1' /* Pleural effusion w/o CC/MCC */
'189' = '1' /* Pulmonary edema & respiratory failure */
'190' = '1' /* Chronic obstructive pulmonary disease w MCC */
'191' = '1' /* Chronic obstructive pulmonary disease w CC */
'192' = '1' /* Chronic obstructive pulmonary disease w/o CC/MCC */
'193' = '1' /* Simple pneumonia & pleurisy w MCC */
'194' = '1' /* Simple pneumonia & pleurisy w CC */
'195' = '1' /* Simple pneumonia & pleurisy w/o CC/MCC */
'196' = '1' /* Interstitial lung disease w MCC */
'197' = '1' /* Interstitial lung disease w CC */
'198' = '1' /* Interstitial lung disease w/o CC/MCC */
'199' = '1' /* Pneumothorax w MCC */
'200' = '1' /* Pneumothorax w CC */
'201' = '1' /* Pneumothorax w/o CC/MCC */
'202' = '1' /* Bronchitis & asthma w CC/MCC */
'203' = '1' /* Bronchitis & asthma w/o CC/MCC */
'204' = '1' /* Respiratory signs & symptoms */
'205' = '1' /* Other respiratory system diagnoses w MCC */
'206' = '1' /* Other respiratory system diagnoses w/o MCC */
'207' = '1' /* Respiratory system diagnosis w ventilator support 96+ hours */
'208' = '1' /* Respiratory system diagnosis w ventilator support <96 hours */
'280' = '1' /* Acute myocardial infarction, discharged alive w MCC */
'281' = '1' /* Acute myocardial infarction, discharged alive w CC */
'282' = '1' /* Acute myocardia infarction, discharged alive w/o CC/MCC */
'283' = '1' /* Acute myocardial infarction, expired w MCC */
'284' = '1' /* Acute myocardial infarction, expired w CC */
'285' = '1' /* Acute myocardial infarction, expired w/o CC/MCC */
'286' = '1' /* Circulatory disorders except AMI, w card cath w MCC */
'287' = '1' /* Circulatory disorders except AMI, w card cath w/o MCC */
'288' = '1' /* Acute & subacute endocarditis w MCC */
'289' = '1' /* Acute & subacute endocarditis w CC */
'290' = '1' /* Acute & subacute endocarditis w/o CC/MCC */
'291' = '1' /* Heart failure & shock w MCC */
'292' = '1' /* Heart failure & shock w CC */
'293' = '1' /* Heart failure & shock w/o CC/MCC */
'294' = '1' /* Deep vein thrombophlebitis w CC/MCC */
'295' = '1' /* Deep vein thrombophlebitis w/o CC/MCC */
'296' = '1' /* Cardiac arrest, unexplained w MCC */
'297' = '1' /* Cardiac arrest, unexplained w CC */
'298' = '1' /* Cardiac arrest, unexplained w/o CC/MCC */
'299' = '1' /* Peripheral vascular disorders w MCC */
'300' = '1' /* Peripheral vascular disorders w CC */
'301' = '1' /* Peripheral vascular disorders w/o CC/MCC */
'302' = '1' /* Atherosclerosis w MCC */
'303' = '1' /* Atherosclerosis w/o MCC */
'304' = '1' /* Hypertension w MCC */
'305' = '1' /* Hypertension w/o MCC */
'306' = '1' /* Cardiac congenital & valvular disorders w MCC */
'307' = '1' /* Cardiac congenital & valvular disorders w/o MCC */
'308' = '1' /* Cardiac arrhythmia & conduction disorders w MCC */
'309' = '1' /* Cardiac arrhythmia & conduction disorders w CC */
'310' = '1' /* Cardiac arrhythmia & conduction disorders w/o CC/MCC */
'311' = '1' /* Angina pectoris */
'312' = '1' /* Syncope & collapse */
'313' = '1' /* Chest pain */
'314' = '1' /* Other circulatory system diagnoses w MCC */
'315' = '1' /* Other circulatory system diagnoses w CC */
'316' = '1' /* Other circulatory system diagnoses w/o CC/MCC */
'368' = '1' /* Major esophageal disorders w MCC */
'369' = '1' /* Major esophageal disorders w CC */
'370' = '1' /* Major esophageal disorders w/o CC/MCC */
'371' = '1' /* Major gastrointestinal disorders & peritoneal infections w MCC */
'372' = '1' /* Major gastrointestinal disorders & peritoneal infections w CC */
'373' = '1' /* Major gastrointestinal disorders & peritoneal infections w/o CC/MCC */
'374' = '1' /* Digestive malignancy w MCC */
'375' = '1' /* Digestive malignancy w CC */
'376' = '1' /* Digestive malignancy w/o CC/MCC */
'377' = '1' /* G.I. hemorrhage w MCC */
'378' = '1' /* G.I. hemorrhage w CC */
'379' = '1' /* G.I. hemorrhage w/o CC/MCC */
'380' = '1' /* Complicated peptic ulcer w MCC */
'381' = '1' /* Complicated peptic ulcer w CC */
'382' = '1' /* Complicated peptic ulcer w/o CC/MCC */
'383' = '1' /* Uncomplicated peptic ulcer w MCC */
'384' = '1' /* Uncomplicated peptic ulcer w/o MCC */
'385' = '1' /* Inflammatory bowel disease w MCC */
'386' = '1' /* Inflammatory bowel disease w CC */
'387' = '1' /* Inflammatory bowel disease w/o CC/MCC */
'388' = '1' /* G.I. obstruction w MCC */
'389' = '1' /* G.I. obstruction w CC */
'390' = '1' /* G.I. obstruction w/o CC/MCC */
'391' = '1' /* Esophagitis, gastroent & misc digest disorders w MCC */
'392' = '1' /* Esophagitis, gastroent & misc digest disorders w/o MCC */
'393' = '1' /* Other digestive system diagnoses w MCC */
'394' = '1' /* Other digestive system diagnoses w CC */
'395' = '1' /* Other digestive system diagnoses w/o CC/MCC */
'432' = '1' /* Cirrhosis & alcoholic hepatitis w MCC */
'433' = '1' /* Cirrhosis & alcoholic hepatitis w CC */
'434' = '1' /* Cirrhosis & alcoholic hepatitis w/o CC/MCC */
'435' = '1' /* Malignancy of hepatobiliary system or pancreas w MCC */
'436' = '1' /* Malignancy of hepatobiliary system or pancreas w CC */
'437' = '1' /* Malignancy of hepatobiliary system or pancreas w/o CC/MCC */
'438' = '1' /* Disorders of pancreas except malignancy w MCC */
'439' = '1' /* Disorders of pancreas except malignancy w CC */
'440' = '1' /* Disorders of pancreas except malignancy w/o CC/MCC */
'441' = '1' /* Disorders of liver except malig,cirr,alc hepa w MCC */
'442' = '1' /* Disorders of liver except malig,cirr,alc hepa w CC */
'443' = '1' /* Disorders of liver except malig,cirr,alc hepa w/o CC/MCC */
'444' = '1' /* Disorders of the biliary tract w MCC */
'445' = '1' /* Disorders of the biliary tract w CC */
'446' = '1' /* Disorders of the biliary tract w/o CC/MCC */
'533' = '1' /* Fractures of femur w MCC */
'534' = '1' /* Fractures of femur w/o MCC */
'535' = '1' /* Fractures of hip & pelvis w MCC */
'536' = '1' /* Fractures of hip & pelvis w/o MCC */
'537' = '1' /* Sprains, strains, & dislocations of hip, pelvis & thigh w CC/MCC */
'538' = '1' /* Sprains, strains, & dislocations of hip, pelvis & thigh w/o CC/MCC */
'539' = '1' /* Osteomyelitis w MCC */
'540' = '1' /* Osteomyelitis w CC */
'541' = '1' /* Osteomyelitis w/o CC/MCC */
'542' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w MCC */
'543' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w CC */
'544' = '1' /* Pathological fractures & musculoskelet & conn tiss malig w/o CC/MCC */
'545' = '1' /* Connective tissue disorders w MCC */
'546' = '1' /* Connective tissue disorders w CC */
'547' = '1' /* Connective tissue disorders w/o CC/MCC */
'548' = '1' /* Septic arthritis w MCC */
'549' = '1' /* Septic arthritis w CC */
'550' = '1' /* Septic arthritis w/o CC/MCC */
'551' = '1' /* Medical back problems w MCC */
'552' = '1' /* Medical back problems w/o MCC */
'553' = '1' /* Bone diseases & arthropathies w MCC */
'554' = '1' /* Bone diseases & arthropathies w/o MCC */
'555' = '1' /* Signs & symptoms of musculoskeletal system & conn tissue w MCC */
'556' = '1' /* Signs & symptoms of musculoskeletal system & conn tissue w/o MCC */
'557' = '1' /* Tendonitis, myositis & bursitis w MCC */
'558' = '1' /* Tendonitis, myositis & bursitis w/o MCC */
'559' = '1' /* Aftercare, musculoskeletal system & connective tissue w MCC */
'560' = '1' /* Aftercare, musculoskeletal system & connective tissue w CC */
'561' = '1' /* Aftercare, musculoskeletal system & connective tissue w/o CC/MCC */
'562' = '1' /* Fx, sprn, strn & disl except femur, hip, pelvis & thigh w MCC */
'563' = '1' /* Fx, sprn, strn & disl except femur, hip, pelvis & thigh w/o MCC */
'564' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w MCC */
'565' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w CC */
'566' = '1' /* Other musculoskeletal sys & connective tissue diagnoses w/o CC/MCC */
'592' = '1' /* Skin ulcers w MCC */
'593' = '1' /* Skin ulcers w CC */
'594' = '1' /* Skin ulcers w/o CC/MCC */
'595' = '1' /* Major skin disorders w MCC */
'596' = '1' /* Major skin disorders w/o MCC */
'597' = '1' /* Malignant breast disorders w MCC */
'598' = '1' /* Malignant breast disorders w CC */
'599' = '1' /* Malignant breast disorders w/o CC/MCC */
'600' = '1' /* Non-malignant breast disorders w CC/MCC */
'601' = '1' /* Non-malignant breast disorders w/o CC/MCC */
'602' = '1' /* Cellulitis w MCC */
'603' = '1' /* Cellulitis w/o MCC */
'604' = '1' /* Trauma to the skin, subcut tiss & breast w MCC */
'605' = '1' /* Trauma to the skin, subcut tiss & breast w/o MCC */
'606' = '1' /* Minor skin disorders w MCC */
'607' = '1' /* Minor skin disorders w/o MCC */
'637' = '1' /* Diabetes w MCC */
'638' = '1' /* Diabetes w CC */
'639' = '1' /* Diabetes w/o CC/MCC */
'640' = '1' /* Nutritional & misc metabolic disorders w MCC */
'641' = '1' /* Nutritional & misc metabolic disorders w/o MCC */
'642' = '1' /* Inborn errors of metabolism */
'643' = '1' /* Endocrine disorders w MCC */
'644' = '1' /* Endocrine disorders w CC */
'645' = '1' /* Endocrine disorders w/o CC/MCC */
'682' = '1' /* Renal failure w MCC */
'683' = '1' /* Renal failure w CC */
'684' = '1' /* Renal failure w/o CC/MCC */
'685' = '1' /* Admit for renal dialysis */
'686' = '1' /* Kidney & urinary tract neoplasms w MCC */
'687' = '1' /* Kidney & urinary tract neoplasms w CC */
'688' = '1' /* Kidney & urinary tract neoplasms w/o CC/MCC */
'689' = '1' /* Kidney & urinary tract infections w MCC */
'690' = '1' /* Kidney & urinary tract infections w/o MCC */
'691' = '1' /* Urinary stones w esw lithotripsy w CC/MCC */
'692' = '1' /* Urinary stones w esw lithotripsy w/o CC/MCC */
'693' = '1' /* Urinary stones w/o esw lithotripsy w MCC */
'694' = '1' /* Urinary stones w/o esw lithotripsy w/o MCC */
'695' = '1' /* Kidney & urinary tract signs & symptoms w MCC */
'696' = '1' /* Kidney & urinary tract signs & symptoms w/o MCC */
'697' = '1' /* Urethral stricture */
'698' = '1' /* Other kidney & urinary tract diagnoses w MCC */
'699' = '1' /* Other kidney & urinary tract diagnoses w CC */
'700' = '1' /* Other kidney & urinary tract diagnoses w/o CC/MCC */
'722' = '1' /* Malignancy, male reproductive system w MCC */
'723' = '1' /* Malignancy, male reproductive system w CC */
'724' = '1' /* Malignancy, male reproductive system w/o CC/MCC */
'725' = '1' /* Benign prostatic hypertrophy w MCC */
'726' = '1' /* Benign prostatic hypertrophy w/o MCC */
'727' = '1' /* Inflammation of the male reproductive system w MCC */
'728' = '1' /* Inflammation of the male reproductive system w/o MCC */
'729' = '1' /* Other male reproductive system diagnoses w CC/MCC */
'730' = '1' /* Other male reproductive system diagnoses w/o CC/MCC */
'754' = '1' /* Malignancy, female reproductive system w MCC */
'755' = '1' /* Malignancy, female reproductive system w CC */
'756' = '1' /* Malignancy, female reproductive system w/o CC/MCC */
'757' = '1' /* Infections, female reproductive system w MCC */
'758' = '1' /* Infections, female reproductive system w CC */
'759' = '1' /* Infections, female reproductive system w/o CC/MCC */
'760' = '1' /* Menstrual & other female reproductive system disorders w CC/MCC */
'761' = '1' /* Menstrual & other female reproductive system disorders w/o CC/MCC */
'774' = '1' /* Vaginal delivery w complicating diagnoses */
'775' = '1' /* Vaginal delivery w/o complicating diagnoses */
'776' = '1' /* Postpartum & post abortion diagnoses w/o O.R. procedure */
'777' = '1' /* Ectopic pregnancy */
'778' = '1' /* Threatened abortion */
'779' = '1' /* Abortion w/o D&C */
'780' = '1' /* False labor */
'781' = '1' /* Other antepartum diagnoses w medical complications */
'782' = '1' /* Other antepartum diagnoses w/o medical complications */
'789' = '1' /* Neonates, died or transferred to another acute care facility */
'790' = '1' /* Extreme immaturity or respiratory distress syndrome, neonate */
'791' = '1' /* Prematurity w major problems */
'792' = '1' /* Prematurity w/o major problems */
'793' = '1' /* Full term neonate w major problems */
'794' = '1' /* Neonate w other significant problems */
'795' = '1' /* Normal newborn */
'808' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w MCC */
'809' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w CC */
'810' = '1' /* Major hematol/immun diag exc sickle cell crisis & coagul w/o CC/MCC */
'811' = '1' /* Red blood cell disorders w MCC */
'812' = '1' /* Red blood cell disorders w/o MCC */
'813' = '1' /* Coagulation disorders */
'814' = '1' /* Reticuloendothelial & immunity disorders w MCC */
'815' = '1' /* Reticuloendothelial & immunity disorders w CC */
'816' = '1' /* Reticuloendothelial & immunity disorders w/o CC/MCC */
'834' = '1' /* Acute leukemia w/o major O.R. procedure w MCC */
'835' = '1' /* Acute leukemia w/o major O.R. procedure w CC */
'836' = '1' /* Acute leukemia w/o major O.R. procedure w/o CC/MCC */
'837' = '1' /* Chemo w acute leukemia as sdx or w high dose chemo agent w MCC */
'838' = '1' /* Chemo w acute leukemia as sdx w CC or high dose chemo agent */
'839' = '1' /* Chemo w acute leukemia as sdx w/o CC/MCC */
'840' = '1' /* Lymphoma & non-acute leukemia w MCC */
'841' = '1' /* Lymphoma & non-acute leukemia w CC */
'842' = '1' /* Lymphoma & non-acute leukemia w/o CC/MCC */
'843' = '1' /* Other myeloprolif dis or poorly diff neopl diag w MCC */
'844' = '1' /* Other myeloprolif dis or poorly diff neopl diag w CC */
'845' = '1' /* Other myeloprolif dis or poorly diff neopl diag w/o CC/MCC */
'846' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w MCC */
'847' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w CC */
'848' = '1' /* Chemotherapy w/o acute leukemia as secondary diagnosis w/o CC/MCC */
'849' = '1' /* Radiotherapy */
'862' = '1' /* Postoperative & post-traumatic infections w MCC */
'863' = '1' /* Postoperative & post-traumatic infections w/o MCC */
'864' = '1' /* Fever of unknown origin */
'865' = '1' /* Viral illness w MCC */
'866' = '1' /* Viral illness w/o MCC */
'867' = '1' /* Other infectious & parasitic diseases diagnoses w MCC */
'868' = '1' /* Other infectious & parasitic diseases diagnoses w CC */
'869' = '1' /* Other infectious & parasitic diseases diagnoses w/o CC/MCC */
'870' = '1' /* Septicemia w MV 96+ hours */
'871' = '1' /* Septicemia w/o MV 96+ hours w MCC */
'872' = '1' /* Septicemia w/o MV 96+ hours w/o MCC */
'880' = '1' /* Acute adjustment reaction & psychosocial dysfunction */
'881' = '1' /* Depressive neuroses */
'882' = '1' /* Neuroses except depressive */
'883' = '1' /* Disorders of personality & impulse control */
'884' = '1' /* Organic disturbances & mental retardation */
'885' = '1' /* Psychoses */
'886' = '1' /* Behavioral & developmental disorders */
'887' = '1' /* Other mental disorder diagnoses */
'894' = '1' /* Alcohol/drug abuse or dependence, left ama */
'895' = '1' /* Alcohol/drug abuse or dependence w rehabilitation therapy */
'896' = '1' /* Alcohol/drug abuse or dependence w/o rehabilitation therapy w MCC */
'897' = '1' /* Alcohol/drug abuse or dependence w/o rehabilitation therapy w/o MCC */
'913' = '1' /* Traumatic injury w MCC */
'914' = '1' /* Traumatic injury w/o MCC */
'915' = '1' /* Allergic reactions w MCC */
'916' = '1' /* Allergic reactions w/o MCC */
'917' = '1' /* Poisoning & toxic effects of drugs w MCC */
'918' = '1' /* Poisoning & toxic effects of drugs w/o MCC */
'919' = '1' /* Complications of treatment w MCC */
'920' = '1' /* Complications of treatment w CC */
'921' = '1' /* Complications of treatment w/o CC/MCC */
'922' = '1' /* Other injury, poisoning & toxic effect diag w MCC */
'923' = '1' /* Other injury, poisoning & toxic effect diag w/o MCC */
'933' = '1' /* Extensive burns or full thickness burns w MV 96+ hrs w/o skin graft */
'934' = '1' /* Full thickness burn w/o skin grft or inhal inj */
'935' = '1' /* Non-extensive burns */
'945' = '1' /* Rehabilitation w CC/MCC */
'946' = '1' /* Rehabilitation w/o CC/MCC */
'947' = '1' /* Signs & symptoms w MCC */
'948' = '1' /* Signs & symptoms w/o MCC */
'949' = '1' /* Aftercare w CC/MCC */
'950' = '1' /* Aftercare w/o CC/MCC */
'951' = '1' /* Other factors influencing health status */
'963' = '1' /* Other multiple significant trauma w MCC */
'964' = '1' /* Other multiple significant trauma w CC */
'965' = '1' /* Other multiple significant trauma w/o CC/MCC */
'974' = '1' /* HIV w major related condition w MCC */
'975' = '1' /* HIV w major related condition w CC */
'976' = '1' /* HIV w major related condition w/o CC/MCC */
'977' = '1' /* HIV w or w/o other related condition */
other = '0';
/* ---------------------------------------------------------------- */
/* SURGICAL DRGS  (deleted Adult DRGs)                              */
/* ---------------------------------------------------------------- */
/* DIAGNOSTIC RELATED GROUPS (DRGS):  */
/* $SURGIDR (DRGs V24 or earlier) deleted in V6.0 */
/* $SURGI2R DRGs V25 or later */
value $SURGI2R
'001' = '1' /* Heart transplant or implant of heart assist system w MCC */
'002' = '1' /* Heart transplant or implant of heart assist system w/o MCC */
'003' = '1' /* ECMO or trach w MV 96+ hrs or PDX exc face, mouth & neck w maj O.R. */
'004' = '1' /* Trach w MV 96+ hrs or PDX exc face, mouth & neck w/o maj O.R. */
'005' = '1' /* Liver transplant w MCC or intestinal transplant */
'006' = '1' /* Liver transplant w/o MCC */
'007' = '1' /* Lung transplant */
'008' = '1' /* Simultaneous pancreas/kidney transplant */
'009' = '1' /* Bone marrow transplant */
'010' = '1' /* Pancreas transplant */
'011' = '1' /* Tracheostomy for face,mouth & neck diagnoses w MCC */
'012' = '1' /* Tracheostomy for face,mouth & neck diagnoses w CC */
'013' = '1' /* Tracheostomy for face,mouth & neck diagnoses w/o CC/MCC */
'014' = '1' /* ALLOGENEIC BONE MARROW TRANSPLANT */
'015' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT */
'016' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT W CC/MCC */
'017' = '1' /* AUTOLOGOUS BONE MARROW TRANSPLANT W/O CC/MCC */
'020' = '1' /* Intracranial vascular procedures w PDX hemorrhage w MCC */
'021' = '1' /* Intracranial vascular procedures w PDX hemorrhage w CC */
'022' = '1' /* Intracranial vascular procedures w PDX hemorrhage w/o CC/MCC */
'023' = '1' /* Cranio w major dev impl/acute complex CNS PDX w MCC or chemo implant */
'024' = '1' /* Cranio w major dev impl/acute complex CNS PDX w/o MCC */
'025' = '1' /* Craniotomy & endovascular intracranial procedures w MCC */
'026' = '1' /* Craniotomy & endovascular intracranial procedures w CC */
'027' = '1' /* Craniotomy & endovascular intracranial procedures w/o CC/MCC */
'028' = '1' /* Spinal procedures w MCC */
'029' = '1' /* Spinal procedures w CC or spinal neurostimulators */
'030' = '1' /* Spinal procedures w/o CC/MCC */
'031' = '1' /* Ventricular shunt procedures w MCC */
'032' = '1' /* Ventricular shunt procedures w CC */
'033' = '1' /* Ventricular shunt procedures w/o CC/MCC */
'034' = '1' /* Carotid artery stent procedure w MCC */
'035' = '1' /* Carotid artery stent procedure w CC */
'036' = '1' /* Carotid artery stent procedure w/o CC/MCC */
'037' = '1' /* Extracranial procedures w MCC */
'038' = '1' /* Extracranial procedures w CC */
'039' = '1' /* Extracranial procedures w/o CC/MCC */
'040' = '1' /* Periph/cranial nerve & other nerv syst proc w MCC */
'041' = '1' /* Periph/cranial nerve & other nerv syst proc w CC or periph neurostim */
'042' = '1' /* Periph/cranial nerve & other nerv syst proc w/o CC/MCC */
'113' = '1' /* Orbital procedures w CC/MCC */
'114' = '1' /* Orbital procedures w/o CC/MCC */
'115' = '1' /* Extraocular procedures except orbit */
'116' = '1' /* Intraocular procedures w CC/MCC */
'117' = '1' /* Intraocular procedures w/o CC/MCC */
'129' = '1' /* Major head & neck procedures w CC/MCC or major device */
'130' = '1' /* Major head & neck procedures w/o CC/MCC */
'131' = '1' /* Cranial/facial procedures w CC/MCC */
'132' = '1' /* Cranial/facial procedures w/o CC/MCC */
'133' = '1' /* Other ear, nose, mouth & throat O.R. procedures w CC/MCC */
'134' = '1' /* Other ear, nose, mouth & throat O.R. procedures w/o CC/MCC */
'135' = '1' /* Sinus & mastoid procedures w CC/MCC */
'136' = '1' /* Sinus & mastoid procedures w/o CC/MCC */
'137' = '1' /* Mouth procedures w CC/MCC */
'138' = '1' /* Mouth procedures w/o CC/MCC */
'139' = '1' /* Salivary gland procedures */
'163' = '1' /* Major chest procedures w MCC */
'164' = '1' /* Major chest procedures w CC */
'165' = '1' /* Major chest procedures w/o CC/MCC */
'166' = '1' /* Other resp system O.R. procedures w MCC */
'167' = '1' /* Other resp system O.R. procedures w CC */
'168' = '1' /* Other resp system O.R. procedures w/o CC/MCC */
'215' = '1' /* Other heart assist system implant */
'216' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w MCC */
'217' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w CC */
'218' = '1' /* Cardiac valve & oth maj cardiothoracic proc w card cath w/o CC/MCC */
'219' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w MCC */
'220' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w CC */
'221' = '1' /* Cardiac valve & oth maj cardiothoracic proc w/o card cath w/o CC/MCC */
'222' = '1' /* Cardiac defib implant w cardiac cath w AMI/HF/shock w MCC */
'223' = '1' /* Cardiac defib implant w cardiac cath w AMI/HF/shock w/o MCC */
'224' = '1' /* Cardiac defib implant w cardiac cath w/o AMI/HF/shock w MCC */
'225' = '1' /* Cardiac defib implant w cardiac cath w/o AMI/HF/shock w/o MCC */
'226' = '1' /* Cardiac defibrillator implant w/o cardiac cath w MCC */
'227' = '1' /* Cardiac defibrillator implant w/o cardiac cath w/o MCC */
'228' = '1' /* Other cardiothoracic procedures w MCC */
'229' = '1' /* Other cardiothoracic procedures w CC */
'230' = '1' /* Other cardiothoracic procedures w/o CC/MCC */
'231' = '1' /* Coronary bypass w PTCA w MCC */
'232' = '1' /* Coronary bypass w PTCA w/o MCC */
'233' = '1' /* Coronary bypass w cardiac cath w MCC */
'234' = '1' /* Coronary bypass w cardiac cath w/o MCC */
'235' = '1' /* Coronary bypass w/o cardiac cath w MCC */
'236' = '1' /* Coronary bypass w/o cardiac cath w/o MCC */
'239' = '1' /* Amputation for circ sys disorders exc upper limb & toe w MCC */
'240' = '1' /* Amputation for circ sys disorders exc upper limb & toe w CC */
'241' = '1' /* Amputation for circ sys disorders exc upper limb & toe w/o CC/MCC */
'242' = '1' /* Permanent cardiac pacemaker implant w MCC */
'243' = '1' /* Permanent cardiac pacemaker implant w CC */
'244' = '1' /* Permanent cardiac pacemaker implant w/o CC/MCC */
'245' = '1' /* AICD lead & generator procedures */
'246' = '1' /* Perc cardiovasc proc w drug-eluting stent w MCC or 4+ vessels/stents */
'247' = '1' /* Perc cardiovasc proc w drug-eluting stent w/o MCC */
'248' = '1' /* Perc cardiovasc proc w non-drug-eluting stent w MCC or 4+ ves/stents */
'249' = '1' /* Perc cardiovasc proc w non-drug-eluting stent w/o MCC */
'250' = '1' /* Perc cardiovasc proc w/o coronary artery stent or AMI w MCC */
'251' = '1' /* Perc cardiovasc proc w/o coronary artery stent or AMI w/o MCC */
'252' = '1' /* Other vascular procedures w MCC */
'253' = '1' /* Other vascular procedures w CC */
'254' = '1' /* Other vascular procedures w/o CC/MCC */
'255' = '1' /* Upper limb & toe amputation for circ system disorders w MCC */
'256' = '1' /* Upper limb & toe amputation for circ system disorders w CC */
'257' = '1' /* Upper limb & toe amputation for circ system disorders w/o CC/MCC */
'258' = '1' /* Cardiac pacemaker device replacement w MCC */
'259' = '1' /* Cardiac pacemaker device replacement w/o MCC */
'260' = '1' /* Cardiac pacemaker revision except device replacement w MCC */
'261' = '1' /* Cardiac pacemaker revision except device replacement w CC */
'262' = '1' /* Cardiac pacemaker revision except device replacement w/o CC/MCC */
'263' = '1' /* Vein ligation & stripping */
'264' = '1' /* Other circulatory system O.R. procedures */
'265' = '1' /* AICD LEAD PROCEDURES */
'266' = '1' /* Endovascular Cardiac Valve Replacement w MCC */
'267' = '1' /* Endovascular Cardiac Valve Replacement w/o MCC */
'268' = '1' /* Aortic and heart assist procedures except pulsation balloon w mcc */
'269' = '1' /* Aortic and heart assist procedures except pulsation balloon w/o mcc */
'270' = '1' /* Other major cardiovascular procedures w mcc */ 
'271' = '1' /* Other major cardiovascular procedures w cc */ 
'272' = '1' /* Other major cardiovascular procedures w/o cc/mcc */ 
'273' = '1' /* Percutaneous intracardiac procedures w mcc */
'274' = '1' /* Percutaneous intracardiac procedures w/o mcc */
'326' = '1' /* Stomach, esophageal & duodenal proc w MCC */
'327' = '1' /* Stomach, esophageal & duodenal proc w CC */
'328' = '1' /* Stomach, esophageal & duodenal proc w/o CC/MCC */
'329' = '1' /* Major small & large bowel procedures w MCC */
'330' = '1' /* Major small & large bowel procedures w CC */
'331' = '1' /* Major small & large bowel procedures w/o CC/MCC */
'332' = '1' /* Rectal resection w MCC */
'333' = '1' /* Rectal resection w CC */
'334' = '1' /* Rectal resection w/o CC/MCC */
'335' = '1' /* Peritoneal adhesiolysis w MCC */
'336' = '1' /* Peritoneal adhesiolysis w CC */
'337' = '1' /* Peritoneal adhesiolysis w/o CC/MCC */
'338' = '1' /* Appendectomy w complicated principal diag w MCC */
'339' = '1' /* Appendectomy w complicated principal diag w CC */
'340' = '1' /* Appendectomy w complicated principal diag w/o CC/MCC */
'341' = '1' /* Appendectomy w/o complicated principal diag w MCC */
'342' = '1' /* Appendectomy w/o complicated principal diag w CC */
'343' = '1' /* Appendectomy w/o complicated principal diag w/o CC/MCC */
'344' = '1' /* Minor small & large bowel procedures w MCC */
'345' = '1' /* Minor small & large bowel procedures w CC */
'346' = '1' /* Minor small & large bowel procedures w/o CC/MCC */
'347' = '1' /* Anal & stomal procedures w MCC */
'348' = '1' /* Anal & stomal procedures w CC */
'349' = '1' /* Anal & stomal procedures w/o CC/MCC */
'350' = '1' /* Inguinal & femoral hernia procedures w MCC */
'351' = '1' /* Inguinal & femoral hernia procedures w CC */
'352' = '1' /* Inguinal & femoral hernia procedures w/o CC/MCC */
'353' = '1' /* Hernia procedures except inguinal & femoral w MCC */
'354' = '1' /* Hernia procedures except inguinal & femoral w CC */
'355' = '1' /* Hernia procedures except inguinal & femoral w/o CC/MCC */
'356' = '1' /* Other digestive system O.R. procedures w MCC */
'357' = '1' /* Other digestive system O.R. procedures w CC */
'358' = '1' /* Other digestive system O.R. procedures w/o CC/MCC */
'405' = '1' /* Pancreas, liver & shunt procedures w MCC */
'406' = '1' /* Pancreas, liver & shunt procedures w CC */
'407' = '1' /* Pancreas, liver & shunt procedures w/o CC/MCC */
'408' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w MCC */
'409' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w CC */
'410' = '1' /* Biliary tract proc except only cholecyst w or w/o c.d.e. w/o CC/MCC */
'411' = '1' /* Cholecystectomy w c.d.e. w MCC */
'412' = '1' /* Cholecystectomy w c.d.e. w CC */
'413' = '1' /* Cholecystectomy w c.d.e. w/o CC/MCC */
'414' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w MCC */
'415' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w CC */
'416' = '1' /* Cholecystectomy except by laparoscope w/o c.d.e. w/o CC/MCC */
'417' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w MCC */
'418' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w CC */
'419' = '1' /* Laparoscopic cholecystectomy w/o c.d.e. w/o CC/MCC */
'420' = '1' /* Hepatobiliary diagnostic procedures w MCC */
'421' = '1' /* Hepatobiliary diagnostic procedures w CC */
'422' = '1' /* Hepatobiliary diagnostic procedures w/o CC/MCC */
'423' = '1' /* Other hepatobiliary or pancreas O.R. procedures w MCC */
'424' = '1' /* Other hepatobiliary or pancreas O.R. procedures w CC */
'425' = '1' /* Other hepatobiliary or pancreas O.R. procedures w/o CC/MCC */
'453' = '1' /* Combined anterior/posterior spinal fusion w MCC */
'454' = '1' /* Combined anterior/posterior spinal fusion w CC */
'455' = '1' /* Combined anterior/posterior spinal fusion w/o CC/MCC */
'456' = '1' /* Spinal Fusion Except Cervical with Spinal Curvature/Malignancy/Infection or Extensive Fusion with MCC */
'457' = '1' /* Spinal Fusion Except Cervical with Spinal Curvature/Malignancy/Infection or Extensive Fusion with CC */
'458' = '1' /* Spinal Fusion Except Cervical with Spinal Curvature/Malignancy/Infection or Extensive Fusion without CC/MCC */
'459' = '1' /* Spinal fusion except cervical w MCC */
'460' = '1' /* Spinal fusion except cervical w/o MCC */
'461' = '1' /* Bilateral or multiple major joint procs of lower extremity w MCC */
'462' = '1' /* Bilateral or multiple major joint procs of lower extremity w/o MCC */
'463' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w MCC */
'464' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w CC */
'465' = '1' /* Wnd debrid & skn grft exc hand, for musculo-conn tiss dis w/o CC/MCC */
'466' = '1' /* Revision of hip or knee replacement w MCC */
'467' = '1' /* Revision of hip or knee replacement w CC */
'468' = '1' /* Revision of hip or knee replacement w/o CC/MCC */
'469' = '1' /* Major joint replacement or reattachment of lower extremity w MCC */
'470' = '1' /* Major joint replacement or reattachment of lower extremity w/o MCC */
'471' = '1' /* Cervical spinal fusion w MCC */
'472' = '1' /* Cervical spinal fusion w CC */
'473' = '1' /* Cervical spinal fusion w/o CC/MCC */
'474' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w MCC */
'475' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w CC */
'476' = '1' /* Amputation for musculoskeletal sys & conn tissue dis w/o CC/MCC */
'477' = '1' /* Biopsies of musculoskeletal system & connective tissue w MCC */
'478' = '1' /* Biopsies of musculoskeletal system & connective tissue w CC */
'479' = '1' /* Biopsies of musculoskeletal system & connective tissue w/o CC/MCC */
'480' = '1' /* Hip & femur procedures except major joint w MCC */
'481' = '1' /* Hip & femur procedures except major joint w CC */
'482' = '1' /* Hip & femur procedures except major joint w/o CC/MCC */
'483' = '1' /* Major joint & limb reattachment proc of upper extremity w CC/MCC */
'484' = '1' /* Major joint & limb reattachment proc of upper extremity w/o CC/MCC */
'485' = '1' /* Knee procedures w pdx of infection w MCC */
'486' = '1' /* Knee procedures w pdx of infection w CC */
'487' = '1' /* Knee procedures w pdx of infection w/o CC/MCC */
'488' = '1' /* Knee procedures w/o pdx of infection w CC/MCC */
'489' = '1' /* Knee procedures w/o pdx of infection w/o CC/MCC */
'490' = '1' /* Back & neck proc exc spinal fusion w CC/MCC or disc device/neurostim */
'491' = '1' /* Back & neck proc exc spinal fusion w/o CC/MCC */
'492' = '1' /* Lower extrem & humer proc except hip,foot,femur w MCC */
'493' = '1' /* Lower extrem & humer proc except hip,foot,femur w CC */
'494' = '1' /* Lower extrem & humer proc except hip,foot,femur w/o CC/MCC */
'495' = '1' /* Local excision & removal int fix devices exc hip & femur w MCC */
'496' = '1' /* Local excision & removal int fix devices exc hip & femur w CC */
'497' = '1' /* Local excision & removal int fix devices exc hip & femur w/o CC/MCC */
'498' = '1' /* Local excision & removal int fix devices of hip & femur w CC/MCC */
'499' = '1' /* Local excision & removal int fix devices of hip & femur w/o CC/MCC */
'500' = '1' /* Soft tissue procedures w MCC */
'501' = '1' /* Soft tissue procedures w CC */
'502' = '1' /* Soft tissue procedures w/o CC/MCC */
'503' = '1' /* Foot procedures w MCC */
'504' = '1' /* Foot procedures w CC */
'505' = '1' /* Foot procedures w/o CC/MCC */
'506' = '1' /* Major thumb or joint procedures */
'507' = '1' /* Major shoulder or elbow joint procedures w CC/MCC */
'508' = '1' /* Major shoulder or elbow joint procedures w/o CC/MCC */
'509' = '1' /* Arthroscopy */
'510' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w MCC */
'511' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w CC */
'512' = '1' /* Shoulder,elbow or forearm proc,exc major joint proc w/o CC/MCC */
'513' = '1' /* Hand or wrist proc, except major thumb or joint proc w CC/MCC */
'514' = '1' /* Hand or wrist proc, except major thumb or joint proc w/o CC/MCC */
'515' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w MCC */
'516' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w CC */
'517' = '1' /* Other musculoskelet sys & conn tiss O.R. proc w/o CC/MCC */
'518' = '1' /* Back & Neck Procedure excluding spinal fusion w MCC or disc device/neurostimulator */
'519' = '1' /* Back & Neck Procedure excluding spinal fusion w CC */
'520' = '1' /* Back & Neck Procedure excluding spinal fusion w/o CC/MCC */
'570' = '1' /* SKIN DEBRIDEMENT W MCC */
'571' = '1' /* SKIN DEBRIDEMENT W CC */
'572' = '1' /* SKIN DEBRIDEMENT W/O CC/MCC */
'573' = '1' /* Skin graft for skn ulcer or cellulitis w MCC */
'574' = '1' /* Skin graft for skn ulcer or cellulitis w CC */
'575' = '1' /* Skin graft for skn ulcer or cellulitis w/o CC/MCC */
'576' = '1' /* Skin graft exc for skin ulcer or cellulitis w MCC */
'577' = '1' /* Skin graft exc for skin ulcer or cellulitis w CC */
'578' = '1' /* Skin graft exc for skin ulcer or cellulitis w/o CC/MCC */
'579' = '1' /* Other skin, subcut tiss & breast proc w MCC */
'580' = '1' /* Other skin, subcut tiss & breast proc w CC */
'581' = '1' /* Other skin, subcut tiss & breast proc w/o CC/MCC */
'582' = '1' /* Mastectomy for malignancy w CC/MCC */
'583' = '1' /* Mastectomy for malignancy w/o CC/MCC */
'584' = '1' /* Breast biopsy, local excision & other breast procedures w CC/MCC */
'585' = '1' /* Breast biopsy, local excision & other breast procedures w/o CC/MCC */
'614' = '1' /* Adrenal & pituitary procedures w CC/MCC */
'615' = '1' /* Adrenal & pituitary procedures w/o CC/MCC */
'616' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w MCC */
'617' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w CC */
'618' = '1' /* Amputat of lower limb for endocrine,nutrit,& metabol dis w/o CC/MCC */
'619' = '1' /* O.R. procedures for obesity w MCC */
'620' = '1' /* O.R. procedures for obesity w CC */
'621' = '1' /* O.R. procedures for obesity w/o CC/MCC */
'622' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w MCC */
'623' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w CC */
'624' = '1' /* Skin grafts & wound debrid for endoc, nutrit & metab dis w/o CC/MCC */
'625' = '1' /* Thyroid, parathyroid & thyroglossal procedures w MCC */
'626' = '1' /* Thyroid, parathyroid & thyroglossal procedures w CC */
'627' = '1' /* Thyroid, parathyroid & thyroglossal procedures w/o CC/MCC */
'628' = '1' /* Other endocrine, nutrit & metab O.R. proc w MCC */
'629' = '1' /* Other endocrine, nutrit & metab O.R. proc w CC */
'630' = '1' /* Other endocrine, nutrit & metab O.R. proc w/o CC/MCC */
'652' = '1' /* Kidney transplant */
'653' = '1' /* Major bladder procedures w MCC */
'654' = '1' /* Major bladder procedures w CC */
'655' = '1' /* Major bladder procedures w/o CC/MCC */
'656' = '1' /* Kidney & ureter procedures for neoplasm w MCC */
'657' = '1' /* Kidney & ureter procedures for neoplasm w CC */
'658' = '1' /* Kidney & ureter procedures for neoplasm w/o CC/MCC */
'659' = '1' /* Kidney & ureter procedures for non-neoplasm w MCC */
'660' = '1' /* Kidney & ureter procedures for non-neoplasm w CC */
'661' = '1' /* Kidney & ureter procedures for non-neoplasm w/o CC/MCC */
'662' = '1' /* Minor bladder procedures w MCC */
'663' = '1' /* Minor bladder procedures w CC */
'664' = '1' /* Minor bladder procedures w/o CC/MCC */
'665' = '1' /* Prostatectomy w MCC */
'666' = '1' /* Prostatectomy w CC */
'667' = '1' /* Prostatectomy w/o CC/MCC */
'668' = '1' /* Transurethral procedures w MCC */
'669' = '1' /* Transurethral procedures w CC */
'670' = '1' /* Transurethral procedures w/o CC/MCC */
'671' = '1' /* Urethral procedures w CC/MCC */
'672' = '1' /* Urethral procedures w/o CC/MCC */
'673' = '1' /* Other kidney & urinary tract procedures w MCC */
'674' = '1' /* Other kidney & urinary tract procedures w CC */
'675' = '1' /* Other kidney & urinary tract procedures w/o CC/MCC */
'707' = '1' /* Major male pelvic procedures w CC/MCC */
'708' = '1' /* Major male pelvic procedures w/o CC/MCC */
'709' = '1' /* Penis procedures w CC/MCC */
'710' = '1' /* Penis procedures w/o CC/MCC */
'711' = '1' /* Testes procedures w CC/MCC */
'712' = '1' /* Testes procedures w/o CC/MCC */
'713' = '1' /* Transurethral prostatectomy w CC/MCC */
'714' = '1' /* Transurethral prostatectomy w/o CC/MCC */
'715' = '1' /* Other male reproductive system O.R. proc for malignancy w CC/MCC */
'716' = '1' /* Other male reproductive system O.R. proc for malignancy w/o CC/MCC */
'717' = '1' /* Other male reproductive system O.R. proc exc malignancy w CC/MCC */
'718' = '1' /* Other male reproductive system O.R. proc exc malignancy w/o CC/MCC */
'734' = '1' /* Pelvic evisceration, rad hysterectomy & rad vulvectomy w CC/MCC */
'735' = '1' /* Pelvic evisceration, rad hysterectomy & rad vulvectomy w/o CC/MCC */
'736' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w MCC */
'737' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w CC */
'738' = '1' /* Uterine & adnexa proc for ovarian or adnexal malignancy w/o CC/MCC */
'739' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w MCC */
'740' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w CC */
'741' = '1' /* Uterine,adnexa proc for non-ovarian/adnexal malig w/o CC/MCC */
'742' = '1' /* Uterine & adnexa proc for non-malignancy w CC/MCC */
'743' = '1' /* Uterine & adnexa proc for non-malignancy w/o CC/MCC */
'744' = '1' /* D&C, conization, laparascopy & tubal interruption w CC/MCC */
'745' = '1' /* D&C, conization, laparascopy & tubal interruption w/o CC/MCC */
'746' = '1' /* Vagina, cervix & vulva procedures w CC/MCC */
'747' = '1' /* Vagina, cervix & vulva procedures w/o CC/MCC */
'748' = '1' /* Female reproductive system reconstructive procedures */
'749' = '1' /* Other female reproductive system O.R. procedures w CC/MCC */
'750' = '1' /* Other female reproductive system O.R. procedures w/o CC/MCC */
'765' = '1' /* Cesarean section w CC/MCC */
'766' = '1' /* Cesarean section w/o CC/MCC */
'767' = '1' /* Vaginal delivery w sterilization &/or D&C */
'768' = '1' /* Vaginal delivery w O.R. proc except steril &/or D&C */
'769' = '1' /* Postpartum & post abortion diagnoses w O.R. procedure */
'770' = '1' /* Abortion w D&C, aspiration curettage or hysterotomy */
'799' = '1' /* Splenectomy w MCC */
'800' = '1' /* Splenectomy w CC */
'801' = '1' /* Splenectomy w/o CC/MCC */
'802' = '1' /* Other O.R. proc of the blood & blood forming organs w MCC */
'803' = '1' /* Other O.R. proc of the blood & blood forming organs w CC */
'804' = '1' /* Other O.R. proc of the blood & blood forming organs w/o CC/MCC */
'820' = '1' /* Lymphoma & leukemia w major O.R. procedure w MCC */
'821' = '1' /* Lymphoma & leukemia w major O.R. procedure w CC */
'822' = '1' /* Lymphoma & leukemia w major O.R. procedure w/o CC/MCC */
'823' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w MCC */
'824' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w CC */
'825' = '1' /* Lymphoma & non-acute leukemia w other O.R. proc w/o CC/MCC */
'826' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w MCC */
'827' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w CC */
'828' = '1' /* Myeloprolif disord or poorly diff neopl w maj O.R. proc w/o CC/MCC */
'829' = '1' /* Myeloprolif disord or poorly diff neopl w other O.R. proc w CC/MCC */
'830' = '1' /* Myeloprolif disord or poorly diff neopl w other O.R. proc w/o CC/MCC */
'853' = '1' /* Infectious & parasitic diseases w O.R. procedure w MCC */
'854' = '1' /* Infectious & parasitic diseases w O.R. procedure w CC */
'855' = '1' /* Infectious & parasitic diseases w O.R. procedure w/o CC/MCC */
'856' = '1' /* Postoperative or post-traumatic infections w O.R. proc w MCC */
'857' = '1' /* Postoperative or post-traumatic infections w O.R. proc w CC */
'858' = '1' /* Postoperative or post-traumatic infections w O.R. proc w/o CC/MCC */
'876' = '1' /* O.R. procedure w principal diagnoses of mental illness */
'901' = '1' /* Wound debridements for injuries w MCC */
'902' = '1' /* Wound debridements for injuries w CC */
'903' = '1' /* Wound debridements for injuries w/o CC/MCC */
'904' = '1' /* Skin grafts for injuries w CC/MCC */
'905' = '1' /* Skin grafts for injuries w/o CC/MCC */
'906' = '1' /* Hand procedures for injuries */
'907' = '1' /* Other O.R. procedures for injuries w MCC */
'908' = '1' /* Other O.R. procedures for injuries w CC */
'909' = '1' /* Other O.R. procedures for injuries w/o CC/MCC */
'927' = '1' /* Extensive burns or full thickness burns w MV 96+ hrs w skin graft */
'928' = '1' /* Full thickness burn w skin graft or inhal inj w CC/MCC */
'929' = '1' /* Full thickness burn w skin graft or inhal inj w/o CC/MCC */
'939' = '1' /* O.R. proc w diagnoses of other contact w health services w MCC */
'940' = '1' /* O.R. proc w diagnoses of other contact w health services w CC */
'941' = '1' /* O.R. proc w diagnoses of other contact w health services w/o CC/MCC */
'955' = '1' /* Craniotomy for multiple significant trauma */
'956' = '1' /* Limb reattachment, hip & femur proc for multiple significant trauma */
'957' = '1' /* Other O.R. procedures for multiple significant trauma w MCC */
'958' = '1' /* Other O.R. procedures for multiple significant trauma w CC */
'959' = '1' /* Other O.R. procedures for multiple significant trauma w/o CC/MCC */
'969' = '1' /* HIV w extensive O.R. procedure w MCC */
'970' = '1' /* HIV w extensive O.R. procedure w/o MCC */
'981' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w MCC */
'982' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w CC */
'983' = '1' /* Extensive O.R. procedure unrelated to principal diagnosis w/o CC/MCC */
'984' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w MCC */
'985' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w CC */
'986' = '1' /* Prostatic O.R. procedure unrelated to principal diagnosis w/o CC/MCC */
'987' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w MCC */
'988' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w CC */
'989' = '1' /* Non-extensive O.R. proc unrelated to principal diagnosis w/o CC/MCC */
other = '0';
value $ORPROC
"0050" = "1" /* IMPL CRT PACEMAKER SYS */
"0051" = "1" /* IMPL CRT DEFIBRILLAT SYS */
"0052" = "1" /* IMP/REP LEAD LF VEN SYS */
"0053" = "1" /* IMP/REP CRT PACEMAKR GEN */
"0054" = "1" /* IMP/REP CRT DEFIB GENAT */
"0056" = "1" /* INS/REP IMPL SENSOR LEAD */
"0057" = "1" /* IMP/REP SUBCUE CARD DEV */
"0061" = "1" /* PERC ANGIO PRECEREB VESS */
"0062" = "1" /* PERC ANGIO INTRACRAN VES */
"0066" = "1" /* PTCA OR CORONARY ATHER */
"0070" = "1" /* REV HIP REPL-ACETAB/FEM */
"0071" = "1" /* REV HIP REPL-ACETAB COMP */
"0072" = "1" /* REV HIP REPL-FEM COMP */
"0073" = "1" /* REV HIP REPL-LINER/HEAD */
"0080" = "1" /* REV KNEE REPLACEMT-TOTAL */
"0081" = "1" /* REV KNEE REPL-TIBIA COMP */
"0082" = "1" /* REV KNEE REPL-FEMUR COMP */
"0083" = "1" /* REV KNEE REPLACE-PATELLA */
"0084" = "1" /* REV KNEE REPL-TIBIA LIN */
"0085" = "1" /* RESRF HIPTOTAL-ACET/FEM */
"0086" = "1" /* RESRF HIPPART-FEM HEAD */
"0087" = "1" /* RESRF HIPPART-ACETABLUM */
"0112" = "1" /* OPEN CEREB MENINGES BX */
"0114" = "1" /* OPEN BRAIN BIOPSY */
"0115" = "1" /* SKULL BIOPSY */
"0118" = "1" /* OTHER BRAIN DX PROCEDURE */
"0119" = "1" /* OTHER SKULL DX PROCEDURE */
"0120" = "1" /* IMP/REPL BRAIN PULSE GEN */
"0121" = "1" /* CRANIAL SINUS I & D */
"0122" = "1" /* REMOV INTRACRAN STIMULAT */
"0123" = "1" /* REOPEN CRANIOTOMY SITE */
"0124" = "1" /* OTHER CRANIOTOMY */
"0125" = "1" /* OTHER CRANIECTOMY */
"0128" = "1" /* INTRACEREB CTH-BURR HOLE */
"0129" = "1" /* REM BRAIN PULSE GENERATR */
"0131" = "1" /* INCISE CEREBRAL MENINGES */
"0132" = "1" /* LOBOTOMY & TRACTOTOMY */
"0139" = "1" /* OTHER BRAIN INCISION */
"0141" = "1" /* THALAMUS OPERATIONS */
"0142" = "1" /* GLOBUS PALLIDUS OPS */
"0151" = "1" /* EX CEREB MENINGEAL LES */
"0152" = "1" /* HEMISPHERECTOMY */
"0153" = "1" /* BRAIN LOBECTOMY */
"0159" = "1" /* OTHER BRAIN EXCISION */
"016 " = "1" /* EXCISE SKULL LESION */
"0201" = "1" /* LINEAR CRANIECTOMY */
"0202" = "1" /* ELEVATE SKULL FX FRAGMNT */
"0203" = "1" /* SKULL FLAP FORMATION */
"0204" = "1" /* BONE GRAFT TO SKULL */
"0205" = "1" /* SKULL PLATE INSERTION */
"0206" = "1" /* CRANIAL OSTEOPLASTY NEC */
"0207" = "1" /* SKULL PLATE REMOVAL */
"0211" = "1" /* SIMPLE SUTURE OF DURA */
"0212" = "1" /* BRAIN MENINGE REPAIR NEC */
"0213" = "1" /* MENINGE VESSEL LIGATION */
"0214" = "1" /* CHOROID PLEXECTOMY */
"022 " = "1" /* VENTRICULOSTOMY */
"0221" = "1" /*	INSERTION OR REPLACEMENT OF EXTERNAL VENTICULAR DRAIN [EVD] */
"0222" = "1" /*	INTRACRANIAL VENTICULAR SHUNT OR ANASTOMOSIS */
"0231" = "1" /* VENTRICL SHUNT-HEAD/NECK */
"0232" = "1" /* VENTRI SHUNT-CIRCULA SYS */
"0233" = "1" /* VENTRICL SHUNT-THORAX */
"0234" = "1" /* VENTRICL SHUNT-ABDOMEN */
"0235" = "1" /* VENTRI SHUNT-UNINARY SYS */
"0239" = "1" /* OTHER VENTRICULAR SHUNT */
"0242" = "1" /* REPLACE VENTRICLE SHUNT */
"0243" = "1" /* REMOVE VENTRICLE SHUNT */
"0291" = "1" /* LYSIS CORTICAL ADHESION */
"0292" = "1" /* BRAIN REPAIR */
"0293" = "1" /* IMPLANT BRAIN STIMULATOR */
"0294" = "1" /* INSERT/REPLAC SKULL TONG */
"0299" = "1" /* SKULL & BRAIN OP NEC */
"0301" = "1" /* REMOVAL FB SPINAL CANAL */
"0302" = "1" /* REOPEN LAMINECTOMY SITE */
"0309" = "1" /* SPINAL CANAL EXPLOR NEC */
"031 " = "1" /* INTRASPIN NERVE ROOT DIV */
"0321" = "1" /* PERCUTANEOUS CHORDOTOMY */
"0329" = "1" /* OTHER CHORDOTOMY */
"0332" = "1" /* SPINAL CORD/MENINGES BX */
"0339" = "1" /* OTHER SPINAL DX PROC */
"034 " = "1" /* EXCIS SPINAL CORD LESION */
"0351" = "1" /* SPINE MENINGOCELE REPAIR */
"0352" = "1" /* MYELOMENINGOCEL REPAIR */
"0353" = "1" /* VERTEBRAL FX REPAIR */
"0359" = "1" /* SPINAL STRUCT REPAIR NEC */
"036 " = "1" /* SPINAL CORD ADHESIOLYSIS */
"0371" = "1" /* SUBARACH-PERITON SHUNT */
"0372" = "1" /* SUBARACH-URETERAL SHUNT */
"0379" = "1" /* OTH SPINAL THECAL SHUNT */
"0393" = "1" /* INSERT SPINAL STIMULATOR */
"0394" = "1" /* REMOVE SPINAL STIMULATOR */
"0397" = "1" /* REVISE SPINE THECA SHUNT */
"0398" = "1" /* REMOVE SPINE THECA SHUNT */
"0399" = "1" /* SPINE CANAL STRUC OP NEC */
"0401" = "1" /* EXCISION ACOUSTC NEUROMA */
"0402" = "1" /* TRIGEMINAL NERV DIVISION */
"0403" = "1" /* PERIPH NERVE DIV NEC */
"0404" = "1" /* PERIPH NERVE INCIS NEC */
"0405" = "1" /* GASSERIAN GANGLIONECTOMY */
"0406" = "1" /* PERIPH GANGLIONECT NEC */
"0407" = "1" /* PERIPH NERV EXCISION NEC */
"0412" = "1" /* OPEN PERIPH NERVE BIOPSY */
"0419" = "1" /* PERIPH NERVE DX PROC NEC */
"043 " = "1" /* PERIPHERAL NERVE SUTURE */
"0441" = "1" /* DECOMPRESS TRIGEM ROOT */
"0442" = "1" /* CRAN NERV ROOT DECOM NEC */
"0443" = "1" /* CARPAL TUNNEL RELEASE */
"0444" = "1" /* TARSAL TUNNEL RELEASE */
"0449" = "1" /* PER NERVE ADHESIOLYS NEC */
"045 " = "1" /* PERIPHERAL NERVE GRAFT */
"046 " = "1" /* PERIPH NERVE TRANSPOSIT */
"0471" = "1" /* HYPOGLOSS-FACIAL ANASTOM */
"0472" = "1" /* ACCESSORY-FACIAL ANASTOM */
"0473" = "1" /* ACCESS-HYPOGLOSS ANASTOM */
"0474" = "1" /* PERIPH NERV ANASTOM NEC */
"0475" = "1" /* POSTOP REVIS PER NERV OP */
"0476" = "1" /* LATE REPAIR PER NERV INJ */
"0479" = "1" /* OTHER NEUROPLASTY */
"0491" = "1" /* NEURECTASIS */
"0492" = "1" /* IMPLANT PERIPH STIMULAT */
"0493" = "1" /* REMOVE PERIPH STIMULATOR */
"0499" = "1" /* PERIPHERAL NERVE OPS NEC */
"050 " = "1" /* SYMPATH NERVE DIVISION */
"0511" = "1" /* SYMPATHETIC NERVE BIOPSY */
"0519" = "1" /* SYMPATH NRV DX PROC NEC */
"0521" = "1" /* SPHENOPALATIN GANGLIONEC */
"0522" = "1" /* CERVICAL SYMPATHECTOMY */
"0523" = "1" /* LUMBAR SYMPATHECTOMY */
"0524" = "1" /* PRESACRAL SYMPATHECTOMY */
"0525" = "1" /* PERIART SYMPATHECTOMY */
"0529" = "1" /* OTHER SYMPATHECTOMY */
"0581" = "1" /* SYMPATHETIC NERVE REPAIR */
"0589" = "1" /* SYMPATHETIC NERVE OP NEC */
"059 " = "1" /* OTHER NERVOUS SYSTEM OPS */
"0602" = "1" /* REOPEN THYROID FIELD WND */
"0609" = "1" /* INCIS THYROID FIELD NEC */
"0612" = "1" /* OPEN THYROID GLAND BX */
"0613" = "1" /* PARATHYROID BIOPSY */
"0619" = "1" /* THYR/PARATHY DX PROC NEC */
"062 " = "1" /* UNILAT THYROID LOBECTOMY */
"0631" = "1" /* EXCISION THYROID LESION */
"0639" = "1" /* PART THYROIDECTOMY NEC */
"064 " = "1" /* COMPLETE THYROIDECTOMY */
"0650" = "1" /* SUBSTERN THYROIDECT NOS */
"0651" = "1" /* PART SUBSTERN THYROIDECT */
"0652" = "1" /* TOT SUBSTERN THYROIDECT */
"066 " = "1" /* LINGUAL THYROID EXCISION */
"067 " = "1" /* THYROGLOSS DUCT EXCISION */
"0681" = "1" /* TOTAL PARATHYROIDECTOMY */
"0689" = "1" /* OTHER PARATHYROIDECTOMY */
"0691" = "1" /* THYROID ISTHMUS DIVISION */
"0692" = "1" /* THYROID VESSEL LIGATION */
"0693" = "1" /* THYROID SUTURE */
"0694" = "1" /* THYROID REIMPLANTATION */
"0695" = "1" /* PARATHYROID REIMPLANT */
"0698" = "1" /* OTHER THYROID OPERATIONS */
"0699" = "1" /* OTHER PARATHYROID OPS */
"0700" = "1" /* ADRENAL EXPLORATION NOS */
"0701" = "1" /* UNILAT ADRENAL EXPLORAT */
"0702" = "1" /* BILAT ADRENAL EXPLORAT */
"0712" = "1" /* OPEN ADRENAL GLAND BX */
"0713" = "1" /* TRANSFRONT PITUITARY BX */
"0714" = "1" /* TRANSPHEN PITUITARY BX */
"0715" = "1" /* PITUITARY BIOPSY NOS */
"0716" = "1" /* THYMUS BIOPSY */
"0717" = "1" /* PINEAL BIOPSY */
"0719" = "1" /* ENDOCRINE DX PROC NEC */
"0721" = "1" /* ADRENAL LESION EXCISION */
"0722" = "1" /* UNILATERAL ADRENALECTOMY */
"0729" = "1" /* PART ADRENALECTOMY NEC */
"073 " = "1" /* BILATERAL ADRENALECTOMY */
"0741" = "1" /* ADRENAL INCISION */
"0742" = "1" /* ADRENAL NERVE DIVISION */
"0743" = "1" /* ADRENAL VESSEL LIGATION */
"0744" = "1" /* ADRENAL REPAIR */
"0745" = "1" /* ADRENAL REIMPLANTATION */
"0749" = "1" /* ADRENAL OPERATION NEC */
"0751" = "1" /* PINEAL FIELD EXPLORATION */
"0752" = "1" /* PINEAL GLAND INCISION */
"0753" = "1" /* PARTIAL PINEALECTOMY */
"0754" = "1" /* TOTAL PINEALECTOMY */
"0759" = "1" /* PINEAL OPERATION NEC */
"0761" = "1" /* EXC PITUIT LES-TRANSFRON */
"0762" = "1" /* EXC PITUIT LES-TRANSPHEN */
"0763" = "1" /* PART EXCIS PITUITARY NOS */
"0764" = "1" /* TOT EXC PITUIT-TRANSFRON */
"0765" = "1" /* TOT EXC PITUIT-TRANSPHEN */
"0768" = "1" /* TOTAL EXC PITUITARY NEC */
"0769" = "1" /* TOTAL EXC PITUITARY NOS */
"0771" = "1" /* PITUITARY FOSSA EXPLORAT */
"0772" = "1" /* PITUITARY GLAND INCISION */
"0779" = "1" /* PITUITARY OPERATION NEC */
"0780" = "1" /* THYMECTOMY NOS */
"0781" = "1" /* PART EXCISION OF THYMUS */
"0782" = "1" /* TOTAL EXCISION OF THYMUS */
"0783" = "1" /* THORAC PART EXISN THYMUS */
"0784" = "1" /* THORAC TOTAL EXC THYMUS */
"0791" = "1" /* THYMUS FIELD EXPLORATION */
"0792" = "1" /* INCISION OF THYMUS */
"0793" = "1" /* REPAIR OF THYMUS */
"0794" = "1" /* THYMUS TRANSPLANTATION */
"0795" = "1" /* THORAC INCISION THYMUS */
"0798" = "1" /* OTH THORAC OP THYMUS NOS */
"0799" = "1" /* THYMUS OPERATION NEC */
"0811" = "1" /* EYELID BIOPSY */
"0820" = "1" /* REMOVE EYELID LESION NOS */
"0821" = "1" /* CHALAZION EXCISION */
"0822" = "1" /* EXCISE MINOR LES LID NEC */
"0823" = "1" /* EXC MAJ LES LID PRT-THIC */
"0824" = "1" /* EXC MAJ LES LID FUL-THIC */
"0825" = "1" /* DESTRUCTION LID LESION */
"0831" = "1" /* PTOSIS REP-FRONT MUS SUT */
"0832" = "1" /* PTOSIS REP-FRON MUS SLNG */
"0833" = "1" /* PTOSIS REP-LEVAT MUS ADV */
"0834" = "1" /* PTOSIS REP-LEVAT MUS NEC */
"0835" = "1" /* PTOS REP-TARSAL TECHNIQ */
"0836" = "1" /* BLEPHAROPTOS REPAIR NEC */
"0837" = "1" /* REDUC OVERCORRECT PTOSIS */
"0838" = "1" /* CORRECT LID RETRACTION */
"0841" = "1" /* THERMOCAUT/ENTROPION REP */
"0842" = "1" /* SUTURE ENTROPION REPAIR */
"0843" = "1" /* WEDG RESEC ENTROPION REP */
"0844" = "1" /* LID RECONS ENTROPION REP */
"0849" = "1" /* ENTROPION/ECTROP REP NEC */
"0851" = "1" /* CANTHOTOMY */
"0852" = "1" /* BLEPHARORRHAPHY */
"0859" = "1" /* ADJUST LID POSITION NEC */
"0861" = "1" /* LID RECONST W SKIN GRAFT */
"0862" = "1" /* LID RECONST W MUC GRAFT */
"0863" = "1" /* LID RECONST W HAIR GRAFT */
"0864" = "1" /* LID RECON-TARSOCONJ FLAP */
"0869" = "1" /* LID RECONSTR W GRAFT NEC */
"0870" = "1" /* LID RECONSTRUCTION NOS */
"0871" = "1" /* LID MARG RECON-PART THIC */
"0872" = "1" /* LID RECONS-PART THIC NEC */
"0873" = "1" /* LID MARG RECONS FUL THIC */
"0874" = "1" /* LID RECONST-FUL THIC NEC */
"0891" = "1" /* ELECTROSURG LID EPILAT */
"0892" = "1" /* CRYOSURG LID EPILATION */
"0893" = "1" /* EYELID EPILATION NEC */
"0899" = "1" /* EYELID OPERATION NEC */
"090 " = "1" /* LACRIMAL GLAND INCISION */
"0911" = "1" /* LACRIMAL GLAND BIOPSY */
"0912" = "1" /* LACRIMAL SAC BIOPSY */
"0919" = "1" /* LACRIMAL SYS DX PROC NEC */
"0920" = "1" /* EXC LACRIMAL GLAND NOS */
"0921" = "1" /* EXCIS LES LACRIMAL GLAND */
"0922" = "1" /* PART DACRYOADENECT NEC */
"0923" = "1" /* TOTAL DACRYOADENECTOMY */
"093 " = "1" /* OTHER LACRIMAL GLAND OPS */
"0941" = "1" /* LACRIMAL PUNCTUM PROBE */
"0942" = "1" /* LAC CANALICULI PROBE */
"0943" = "1" /* NASOLACRIMAL DUCT PROBE */
"0944" = "1" /* NASOLAC DUCT INTUBAT */
"0949" = "1" /* LAC PASSAGE MANIP NEC */
"0951" = "1" /* LAC PUNCTUM INCISION */
"0952" = "1" /* LAC CANALICULI INCISION */
"0953" = "1" /* LACRIMAL SAC INCISION */
"0959" = "1" /* LACRIM PASSAGE INCIS NEC */
"096 " = "1" /* LACRIM SAC/PASSAGE EXCIS */
"0971" = "1" /* CORRECT EVERTED PUNCTUM */
"0972" = "1" /* PUNCTUM REPAIR NEC */
"0973" = "1" /* CANALICULUS REPAIR */
"0981" = "1" /* DACRYOCYSTORHINOSTOMY */
"0982" = "1" /* CONJUNCTIVOCYSTORHINOST */
"0983" = "1" /* CONJUNCTIVORHINOS W TUBE */
"0991" = "1" /* LAC PUNCTUM OBLITERATION */
"0999" = "1" /* LACRIMAL SYSTEM OP NEC */
"100 " = "1" /* INCISE/REMOV CONJUNCT FB */
"101 " = "1" /* CONJUNCTIVA INCISION NEC */
"1021" = "1" /* CONJUNCTIVAL BIOPSY */
"1029" = "1" /* CONJUNCTIVA DX PROC NEC */
"1031" = "1" /* EXCISE CONJUNCTIV LESION */
"1032" = "1" /* DESTRUCT CONJUNC LES NEC */
"1033" = "1" /* OTH CONJUNC DESTRUC PROC */
"1041" = "1" /* SYMBLEPH REP W FREE GRFT */
"1042" = "1" /* GRAFT CONJUNC CUL-DE-SAC */
"1043" = "1" /* CONJUN CUL-DE-SAC RX NEC */
"1044" = "1" /* CONJUNC FREE GRAFT NEC */
"1049" = "1" /* CONJUNCTIVOPLASTY NEC */
"105 " = "1" /* CONJUNC/LID ADHESIOLYSIS */
"106 " = "1" /* REPAIR CONJUNCT LACERAT */
"1091" = "1" /* SUBCONJUNCTIVAL INJECT */
"1099" = "1" /* CONJUNCTIVAL OP NEC */
"110 " = "1" /* MAGNET REMOVAL CORNEA FB */
"111 " = "1" /* CORNEAL INCISION */
"1121" = "1" /* CORNEAL SCRAPE FOR SMEAR */
"1122" = "1" /* CORNEAL BIOPSY */
"1129" = "1" /* CORNEAL DX PROC NEC */
"1131" = "1" /* PTERYGIUM TRANSPOSITION */
"1132" = "1" /* PTERYG EXC W CORNEA GRFT */
"1139" = "1" /* PTERYGIUM EXCISION NEC */
"1141" = "1" /* MECH REMOV CORNEA EPITH */
"1142" = "1" /* THERMOCAUT CORNEA LESION */
"1143" = "1" /* CRYOTHERAP CORNEA LESION */
"1149" = "1" /* DESTRUCT CORNEA LES NEC */
"1151" = "1" /* SUTURE CORNEA LACERATION */
"1152" = "1" /* REP CORNEA POSTOP DEHISC */
"1153" = "1" /* RX CORNEA LAC W CONJ FLP */
"1159" = "1" /* CORNEAL REPAIR NEC */
"1160" = "1" /* CORNEAL TRANSPLANT NOS */
"1161" = "1" /* LAM KERATPLAST W AUTGRFT */
"1162" = "1" /* LAMELLAR KERATOPLAST NEC */
"1163" = "1" /* PERF KERATOPL W AUTOGRFT */
"1164" = "1" /* PERFORAT KERATOPLAST NEC */
"1169" = "1" /* CORNEAL TRANSPLANT NEC */
"1171" = "1" /* KERATOMILEUSIS */
"1172" = "1" /* KERATOPHAKIA */
"1173" = "1" /* KERATOPROSTHESIS */
"1174" = "1" /* THERMOKERATOPLASTY */
"1175" = "1" /* RADIAL KERATOTOMY */
"1176" = "1" /* EPIKERATOPHAKIA */
"1179" = "1" /* CORNEA RECONSTRUCT NEC */
"1191" = "1" /* CORNEAL TATTOOING */
"1192" = "1" /* REMOVE CORNEAL IMPLANT */
"1199" = "1" /* CORNEAL OPERATION NEC */
"1200" = "1" /* REMOV ANT SEGMNT FB NOS */
"1201" = "1" /* MAGNET REMOV ANT SEG FB */
"1202" = "1" /* NONMAG REMOV ANT SEG FB */
"1211" = "1" /* IRIDOTOMY W TRANSFIXION */
"1212" = "1" /* IRIDOTOMY NEC */
"1213" = "1" /* PROLAPSED IRIS EXCISION */
"1214" = "1" /* IRIDECTOMY NEC */
"1221" = "1" /* DX ASPIRAT-ANT CHAMBER */
"1222" = "1" /* IRIS BIOPSY */
"1229" = "1" /* ANT SEGMENT DX PROC NEC */
"1231" = "1" /* GONIOSYNECHIAE LYSIS */
"1232" = "1" /* ANT SYNECHIA LYSIS NEC */
"1233" = "1" /* POST SYNECHIAE LYSIS */
"1234" = "1" /* CORNEOVITREAL ADHESIOLYS */
"1235" = "1" /* COREOPLASTY */
"1239" = "1" /* IRIDOPLASTY NEC */
"1240" = "1" /* REMOV ANT SEGMNT LES NOS */
"1241" = "1" /* NONEXC DESTRUC IRIS LES */
"1242" = "1" /* EXCISION OF IRIS LESION */
"1243" = "1" /* NONEXC DESTR CIL BOD LES */
"1244" = "1" /* EXCISE CILIARY BODY LES */
"1251" = "1" /* GONIOPUNCTURE */
"1252" = "1" /* GONIOTOMY */
"1253" = "1" /* GONIOTOMY W GONIOPUNCTUR */
"1254" = "1" /* TRABECULOTOMY AB EXTERNO */
"1255" = "1" /* CYCLODIALYSIS */
"1259" = "1" /* FACILIT INTRAOC CIRC NEC */
"1261" = "1" /* TREPHIN SCLERA W IRIDECT */
"1262" = "1" /* THERMCAUT SCLER W IRIDEC */
"1263" = "1" /* IRIDENCLEISIS/IRIDOTASIS */
"1264" = "1" /* TRABECULECTOM AB EXTERNO */
"1265" = "1" /* SCLER FISTULIZ W IRIDECT */
"1266" = "1" /* POSTOP REVIS SCL FISTUL */
"1267" = "1" /*	INSERTION OF AQUEOUS DRAINAGE DEVICE */
"1269" = "1" /* SCLER FISTULIZING OP NEC */
"1271" = "1" /* CYCLODIATHERMY */
"1272" = "1" /* CYCLOCRYOTHERAPY */
"1273" = "1" /* CYCLOPHOTOCOAGULATION */
"1274" = "1" /* CIL BODY DIMINUTION NOS */
"1279" = "1" /* GLAUCOMA PROCEDURE NEC */
"1281" = "1" /* SUTURE SCLERAL LACER */
"1282" = "1" /* SCLERAL FISTULA REPAIR */
"1283" = "1" /* REVIS ANT SEG OP WND NEC */
"1284" = "1" /* DESTRUCT SCLERAL LESION */
"1285" = "1" /* REPAIR STAPHYLOM W GRAFT */
"1286" = "1" /* REP SCLER STAPHYLOMA NEC */
"1287" = "1" /* GRAFT REINFORCE SCLERA */
"1288" = "1" /* SCLERA REINFORCEMENT NEC */
"1289" = "1" /* SCLERAL OPERATION NEC */
"1291" = "1" /* THERAPEUT EVAC ANT CHAMB */
"1292" = "1" /* ANTERIOR CHAMBER INJECT */
"1293" = "1" /* REMOV EPITHEL DOWNGROWTH */
"1297" = "1" /* IRIS OPERATION NEC */
"1298" = "1" /* CILIARY BODY OP NEC */
"1299" = "1" /* ANTERIOR CHAMBER OP NEC */
"1300" = "1" /* REMOVE FB LENS NOS */
"1301" = "1" /* MAGNET REMOVE FB LENS */
"1302" = "1" /* NONMAGNET REMOVE FB LENS */
"1311" = "1" /* TEMP-INF INTRCAP LENS EX */
"1319" = "1" /* INTRACAPSUL LENS EXT NEC */
"132 " = "1" /* LINEAR EXTRACAP LENS EXT */
"133 " = "1" /* SIMPL ASPIR LENS EXTRACT */
"1341" = "1" /* CATARAC PHACOEMULS/ASPIR */
"1342" = "1" /* POST CATARAC FRAG/ASPIR */
"1343" = "1" /* CATARACT FRAG/ASPIR NEC */
"1351" = "1" /* TEMP-INF XTRACAP LENS EX */
"1359" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1361" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1362" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1363" = "1" /* EXTRACAP LENS EXTRAC NEC */
"1364" = "1" /* AFTER-CATAR DISCISSION */
"1365" = "1" /* AFTER-CATARACT EXCISION */
"1366" = "1" /* AFTER CATAR FRAGMNTATION */
"1369" = "1" /* CATARACT EXTRACTION NEC */
"1370" = "1" /* INSERT PSEUDOPHAKOS NOS */
"1371" = "1" /* INSERT LENS AT CATAR EXT */
"1372" = "1" /* SECONDARY INSERT LENS */
"138 " = "1" /* IMPLANTED LENS REMOVAL */
"139 " = "1" /* OTHER OPERATIONS ON LENS */
"1390" = "1" /* OPERATION ON LENS NEC */
"1391" = "1" /* IMPL INTRAOC TELESC PROS */
"1400" = "1" /* REMOV POST SEGMNT FB NOS */
"1401" = "1" /* MAGNET REMOV POST SEG FB */
"1402" = "1" /* NONMAG REMOV POST SEG FB */
"1411" = "1" /* DIAGNOST VITREOUS ASPIR */
"1419" = "1" /* DX PROC POST SEG NEC */
"1421" = "1" /* CHORIORET LES DIATHERMY */
"1422" = "1" /* CHORIORETIN LES CRYOTHER */
"1426" = "1" /* CHORIORET LES RADIOTHER */
"1427" = "1" /* CHORIORET LES RAD IMPLAN */
"1429" = "1" /* CHORIORET LES DESTR NEC */
"1431" = "1" /* RETINAL TEAR DIATHERMY */
"1432" = "1" /* RETINAL TEAR CRYOTHERAPY */
"1439" = "1" /* RETINAL TEAR REPAIR NEC */
"1441" = "1" /* SCLERAL BUCKLE W IMPLANT */
"1449" = "1" /* SCLERAL BUCKLING NEC */
"1451" = "1" /* DETACH RETINA-DIATHERMY */
"1452" = "1" /* DETACH RETINA-CRYOTHERAP */
"1453" = "1" /* DETACH RETINA XENON COAG */
"1454" = "1" /* DETACH RETINA LASER COAG */
"1455" = "1" /* DETACH RET PHOTOCOAG NOS */
"1459" = "1" /* REPAIR RETINA DETACH NEC */
"146 " = "1" /* REMOV PROS MAT POST SEG */
"1471" = "1" /* ANTERIOR REMOV VITREOUS */
"1472" = "1" /* VITREOUS REMOVAL NEC */
"1473" = "1" /* ANTERIOR MECHAN VITRECT */
"1474" = "1" /* MECH VITRECTOMY NEC */
"1475" = "1" /* VITREOUS SUBSTITUT INJEC */
"1479" = "1" /* VITREOUS OPERATION NEC */
"1481" = "1" /* IMP EPIRETINAL PROSTH */
"1482" = "1" /* REM EPIRETINAL PROSTH */
"1483" = "1" /* REV/REPL EPIRETINAL PROSTH */
"149 " = "1" /* OTHER POST SEGMENT OPS */
"1501" = "1" /* EXTRAOC MUSC-TEND BIOPSY */
"1509" = "1" /* EXTRAOC MUSC DX PROC NEC */
"1511" = "1" /* ONE EXTRAOC MUS RECESS */
"1512" = "1" /* 1 EXTRAOC MUSCL ADVANCE */
"1513" = "1" /* 1 EXTRAOC MUSCL RESECT */
"1519" = "1" /* XTRAOC MUS OP/DETACH NEC */
"1521" = "1" /* LENGTHEN 1 EXTRAOC MUSC */
"1522" = "1" /* SHORTEN 1 EXTRAOC MUSC */
"1529" = "1" /* OP ON 1 EXTRAOC MUSC NEC */
"153 " = "1" /* TEMP DETACH >1 XTROC MUS */
"154 " = "1" /* OTH OP ON >L EXTRAOC MUS */
"155 " = "1" /* EXTRAOCUL MUS TRANSPOSIT */
"156 " = "1" /* REVIS EXTRAOC MUSC SURG */
"157 " = "1" /* EXTRAOC MUSC INJ REPAIR */
"159 " = "1" /* OTH EXTRAOC MUS-TEND OP */
"1601" = "1" /* ORBITOTOMY W BONE FLAP */
"1602" = "1" /* ORBITOTOMY W IMPLANT */
"1609" = "1" /* ORBITOTOMY NEC */
"161 " = "1" /* REMOVE PENETRAT FB EYE */
"1622" = "1" /* DIAGNOSTIC ASP OF ORBIT */
"1623" = "1" /* EYEBALL & ORBIT BIOPSY */
"1629" = "1" /* EYEBAL/ORBIT DX PROC NEC */
"1631" = "1" /* EYE EVISC W SYNCH IMPLAN */
"1639" = "1" /* EYEBALL EVISCERATION NEC */
"1641" = "1" /* EYE ENUC/IMPLAN/MUSC ATT */
"1642" = "1" /* EYE ENUC W IMPLANT NEC */
"1649" = "1" /* EYEBALL ENUCLEATION NEC */
"1651" = "1" /* RADICAL ORBITOMAXILLECT */
"1652" = "1" /* ORBIT EXENT W BONE REMOV */
"1659" = "1" /* ORBITAL EXENTERATION NEC */
"1661" = "1" /* 2NDRY OCULAR IMP INSERT */
"1662" = "1" /* REVIS/REINSERT OCUL IMP */
"1663" = "1" /* REVIS ENUC SOCKET W GRFT */
"1664" = "1" /* ENUC SOCKET REVIS NEC */
"1665" = "1" /* 2NDRY EXENT CAVITY GRAFT */
"1666" = "1" /* REVIS EXENTER CAVITY NEC */
"1669" = "1" /* 2ND OP POST EYE REM NEC */
"1671" = "1" /* REMOVE OCULAR IMPLANT */
"1672" = "1" /* REMOVE ORBITAL IMPLANT */
"1681" = "1" /* REPAIR OF ORBITAL WOUND */
"1682" = "1" /* REPAIR EYEBALL RUPTURE */
"1689" = "1" /* EYE/ORBIT INJ REPAIR NEC */
"1692" = "1" /* EXCISION ORBITAL LESION */
"1693" = "1" /* EXCISION EYE LESION NOS */
"1698" = "1" /* OPERATION ON ORBIT NEC */
"1699" = "1" /* OPERATION ON EYEBALL NEC */
"1711" = "1" /* LAP DIR ING HERN-GRAFT */
"1712" = "1" /* LAP INDIR ING HERN-GRAFT */
"1713" = "1" /* LAP ING HERN-GRAFT NOS */
"1721" = "1" /* LAP BIL DIR ING HRN-GRFT */
"1722" = "1" /* LAP BI INDIR ING HRN-GRF */
"1723" = "1" /* LAP BI DR/IND ING HRN-GR */
"1724" = "1" /* LAP BIL ING HERN-GRF NOS */
"1731" = "1" /* LAP MUL SEG RES LG INTES */
"1732" = "1" /* LAPAROSCOPIC CECECTOMY */
"1733" = "1" /* LAP RIGHT HEMICOLECTOMY */
"1734" = "1" /* LAP RES TRANSVERSE COLON */
"1735" = "1" /* LAP LEFT HEMICOLECTOMY */
"1736" = "1" /* LAP SIGMOIDECTOMY */
"1739" = "1" /* LAP PT EX LRG INTEST NEC */
"1751" = "1" /* IMPLANT CCM,TOTAL SYSTEM */
"1752" = "1" /* IMPLANT CCM PULSE GENRTR */
"1753" = "1" /*	PERCUTANEOUS ATHERECTOMY OF EXTRACRANIAL VESSEL(S) */
"1754" = "1" /*	PERCUTANEOUS ATHERECTOMY OF INTRACRANIAL VESSEL(S) */
"1755" = "1" /*	TRANSLUMINAL CORONARY ATHERECTOMY */
"1756" = "1" /*	ATHERECTOMY OF OTHER NON-CORONARY VESSEL(S) */
"1761" = "1" /* LITT LESN BRAIN,GUIDANCE */
"1762" = "1" /* LITT LES HD/NCK,GUIDANCE */
"1763" = "1" /* LITT LESN LIVER,GUIDANCE */
"1769" = "1" /* LITT LESN, GUIDE OTH/NOS */
"1821" = "1" /* PREAURICULAR SINUS EXCIS */
"1831" = "1" /* RAD EXCIS EXT EAR LES */
"1839" = "1" /* EXCIS EXTERNAL EAR NEC */
"185 " = "1" /* CORRECTION PROMINENT EAR */
"186 " = "1" /* EXT AUDIT CANAL RECONSTR */
"1871" = "1" /* CONSTRUCTION EAR AURICLE */
"1872" = "1" /* REATTACH AMPUTATED EAR */
"1879" = "1" /* PLASTIC REP EXT EAR NEC */
"189 " = "1" /* OTHER EXT EAR OPERATIONS */
"190 " = "1" /* STAPES MOBILIZATION */
"1911" = "1" /* STAPEDECT W REPLAC INCUS */
"1919" = "1" /* STAPEDECTOMY NEC */
"1921" = "1" /* REV STAPDEC W INCUS REPL */
"1929" = "1" /* STAPEDECTOMY REVIS NEC */
"193 " = "1" /* OSSICULAR CHAIN OP NEC */
"194 " = "1" /* MYRINGOPLASTY */
"1952" = "1" /* TYPE 2 TYMPANOPLASTY */
"1953" = "1" /* TYPE 3 TYMPANOPLASTY */
"1954" = "1" /* TYPE 4 TYMPANOPLASTY */
"1955" = "1" /* TYPE 5 TYMPANOPLASTY */
"196 " = "1" /* TYMPANOPLASTY REVISION */
"199 " = "1" /* MIDDLE EAR REPAIR NEC */
"2001" = "1" /* MYRINGOTOMY W INTUBATION */
"2021" = "1" /* MASTOID INCISION */
"2022" = "1" /* PETRUS PYRAM AIR CEL INC */
"2023" = "1" /* MIDDLE EAR INCISION */
"2032" = "1" /* MID & INNER EAR BIOPSY */
"2039" = "1" /* MID/IN EAR DX PROC NEC */
"2041" = "1" /* SIMPLE MASTOIDECTOMY */
"2042" = "1" /* RADICAL MASTOIDECTOMY */
"2049" = "1" /* MASTOIDECTOMY NEC */
"2051" = "1" /* EXCISE MIDDLE EAR LESION */
"2059" = "1" /* MIDDLE EAR EXCISION NEC */
"2061" = "1" /* INNER EAR FENESTRATION */
"2062" = "1" /* REVIS INNER EAR FENESTRA */
"2071" = "1" /* ENDOLYMPHATIC SHUNT */
"2072" = "1" /* INNER EAR INJECTION */
"2079" = "1" /* INC/EXC/DESTR IN EAR NEC */
"2091" = "1" /* TYMPANOSYMPATHECTOMY */
"2092" = "1" /* MASTOIDECTOMY REVISION */
"2093" = "1" /* REPAIR OVAL/ROUND WINDOW */
"2095" = "1" /* ELECMAG HEAR DEV IMPLANT */
"2096" = "1" /* IMPLT COCHLEAR PROST NOS */
"2097" = "1" /* IMP/REP SCHAN COCH PROS */
"2098" = "1" /* IMP/REP MCHAN COCHL PROS */
"2099" = "1" /* MID-INNER EAR OPS NEC */
"2104" = "1" /* ETHMOID ART LIGAT-EPIST */
"2105" = "1" /* MAX ART LIG FOR EPISTAX */
"2106" = "1" /* EXT CAROT ART LIG-EPIST */
"2107" = "1" /* NASAL SEPT GRFT-EPISTAX */
"2109" = "1" /* EPISTAXIS CONTROL NEC */
"214 " = "1" /* RESECTION OF NOSE */
"215 " = "1" /* SUBMUC NASAL SEPT RESECT */
"2161" = "1" /* DIATHER/CRYO TURBINECTOM */
"2162" = "1" /* TURBINATE FRACTURE */
"2169" = "1" /* TURBINECTOMY NEC */
"2172" = "1" /* OPEN REDUCTION NASAL FX */
"2182" = "1" /* NASAL FISTULA CLOSURE */
"2183" = "1" /* TOT NASAL RECONSTRUCTION */
"2184" = "1" /* REVISION RHINOPLASTY */
"2185" = "1" /* AUGMENTATION RHINOPLASTY */
"2186" = "1" /* LIMITED RHINOPLASTY */
"2187" = "1" /* RHINOPLASTY NEC */
"2188" = "1" /* SEPTOPLASTY NEC */
"2189" = "1" /* NASAL REPAIR NEC */
"2199" = "1" /* NASAL OPERATION NEC */
"2212" = "1" /* OPEN BIOPSY NASAL SINUS */
"2231" = "1" /* RADICAL MAXILLARY ANTROT */
"2239" = "1" /* EXT MAXILLARY ANTROT NEC */
"2241" = "1" /* FRONTAL SINUSOTOMY */
"2242" = "1" /* FRONTAL SINUSECTOMY */
"2250" = "1" /* SINUSOTOMY NOS */
"2251" = "1" /* ETHMOIDOTOMY */
"2252" = "1" /* SPHENOIDOTOMY */
"2253" = "1" /* MULTIPLE SINUS INCISION */
"2260" = "1" /* SINUSECTOMY NOS */
"2261" = "1" /* C-LUC EXC MAX SINUS LES */
"2262" = "1" /* EXC MAX SINUS LESION NEC */
"2263" = "1" /* ETHMOIDECTOMY */
"2264" = "1" /* SPHENOIDECTOMY */
"2271" = "1" /* NASAL SINUS FISTULA CLOS */
"2279" = "1" /* NASAL SINUS REPAIR NEC */
"229 " = "1" /* OTHER NASAL SINUS OPS */
"242 " = "1" /* GINGIVOPLASTY */
"244 " = "1" /* EXC OF DENTAL LES OF JAW */
"245 " = "1" /* ALVEOLOPLASTY */
"2502" = "1" /* OPEN BIOPSY OF TONGUE */
"251 " = "1" /* DESTRUCTION TONGUE LES */
"252 " = "1" /* PARTIAL GLOSSECTOMY */
"253 " = "1" /* COMPLETE GLOSSECTOMY */
"254 " = "1" /* RADICAL GLOSSECTOMY */
"2559" = "1" /* REPAIR OF TONGUE NEC */
"2594" = "1" /* OTHER GLOSSOTOMY */
"2599" = "1" /* TONGUE OPERATION NEC */
"2612" = "1" /* OPEN BX SALIV GLAND/DUCT */
"2621" = "1" /* SALIVARY CYST MARSUPIAL */
"2629" = "1" /* SALIV LESION EXCIS NEC */
"2630" = "1" /* SIALOADENECTOMY NOS */
"2631" = "1" /* PARTIAL SIALOADENECTOMY */
"2632" = "1" /* COMPLETE SIALOADENECTOMY */
"2641" = "1" /* SUTURE OF SALIV GLND LAC */
"2642" = "1" /* SALIVARY FISTULA CLOSURE */
"2649" = "1" /* SALIVARY REPAIR NEC */
"2699" = "1" /* SALIVARY OPERATION NEC */
"270 " = "1" /* DRAIN FACE & MOUTH FLOOR */
"271 " = "1" /* INCISION OF PALATE */
"2721" = "1" /* BONY PALATE BIOPSY */
"2722" = "1" /* UVULA AND SOFT PALATE BX */
"2731" = "1" /* LOC EXC BONY PALATE LES */
"2732" = "1" /* WIDE EXC BONY PALATE LES */
"2742" = "1" /* WIDE EXCISION OF LIP LES */
"2743" = "1" /* EXCISION OF LIP LES NEC */
"2749" = "1" /* EXCISION OF MOUTH NEC */
"2753" = "1" /* CLOSURE OF MOUTH FISTULA */
"2754" = "1" /* REPAIR OF CLEFT LIP */
"2755" = "1" /* FULL-THICK GRFT TO MOUTH */
"2756" = "1" /* SKIN GRAFT TO MOUTH NEC */
"2757" = "1" /* PEDICLE ATTACH TO MOUTH */
"2759" = "1" /* MOUTH REPAIR NEC */
"2761" = "1" /* SUTURE OF PALATE LACERAT */
"2762" = "1" /* CLEFT PALATE CORRECTION */
"2763" = "1" /* REVIS CLEFT PALAT REPAIR */
"2769" = "1" /* OTH PLASTIC REPAIR PALAT */
"2771" = "1" /* INCISION OF UVULA */
"2772" = "1" /* EXCISION OF UVULA */
"2773" = "1" /* REPAIR OF UVULA */
"2779" = "1" /* OTHER UVULA OPERATIONS */
"2792" = "1" /* MOUTH INCISION NOS */
"2799" = "1" /* ORAL CAVITY OPS NEC */
"280 " = "1" /* PERITONSILLAR I & D */
"2811" = "1" /* TONSIL&ADENOID BIOPSY */
"2819" = "1" /* TONSIL&ADENOID DX OP NEC */
"282 " = "1" /* TONSILLECTOMY */
"283 " = "1" /* TONSILLECTOMY/ADENOIDEC */
"284 " = "1" /* EXCISION OF TONSIL TAG */
"285 " = "1" /* EXCISION LINGUAL TONSIL */
"286 " = "1" /* ADENOIDECTOMY */
"287 " = "1" /* HEMORR CONTRL POST T & A */
"2891" = "1" /* INCIS TO REMOV TONSIL FB */
"2892" = "1" /* EXCIS TONSIL/ADENOID LES */
"2899" = "1" /* TONSIL/ADENOID OPS NEC */
"290 " = "1" /* PHARYNGOTOMY */
"292 " = "1" /* EXC BRANCHIAL CLEFT CYST */
"293 " = "1" /* EXC BRANCHIAL CLEFT CYST */
"2931" = "1" /* CRICOPHARYNGEAL MYOTOMY */
"2932" = "1" /* PHARYNGEAL DIVERTICULEC */
"2933" = "1" /* PHARYNGECTOMY */
"2939" = "1" /* EXCIS/DESTR LES PHAR NEC */
"294 " = "1" /* PLASTIC OP ON PHARYNX */
"2951" = "1" /* SUTURE OF PHARYNGEAL LAC */
"2952" = "1" /* CLOS BRANCH CLEFT FISTUL */
"2953" = "1" /* CLOS PHARYNX FISTULA NEC */
"2954" = "1" /* LYSIS PHARYNGEAL ADHES */
"2959" = "1" /* PHARYNGEAL REPAIR NEC */
"2992" = "1" /* DIVIS GLOSSOPHARYNG NERV */
"2999" = "1" /* PHARYNGEAL OPERATION NEC */
"3001" = "1" /* LARYNX CYST MARSUPIALIZ */
"3009" = "1" /* DESTRUCT LARYNX LES NEC */
"301 " = "1" /* HEMILARYNGECTOMY */
"3021" = "1" /* EPIGLOTTIDECTOMY */
"3022" = "1" /* VOCAL CORDECTOMY */
"3029" = "1" /* OTHER PART LARYNGECTOMY */
"303 " = "1" /* COMPLETE LARYNGECTOMY */
"304 " = "1" /* RADICAL LARYNGECTOMY */
"3121" = "1" /* MEDIASTINAL TRACHEOSTOMY */
"3129" = "1" /* OTHER PERM TRACHEOSTOMY */
"313 " = "1" /* INCIS LARYNX TRACHEA NEC */
"3145" = "1" /* OPN BX LARYNX OR TRACHEA */
"315 " = "1" /* LOCAL DESTRUC TRACH LES */
"3161" = "1" /* SUTURE OF LARYNGEAL LAC */
"3162" = "1" /* LARYNGEAL FISTULA CLOS */
"3163" = "1" /* LARYNGOSTOMY REVISION */
"3164" = "1" /* LARYNGEAL FX REPAIR */
"3169" = "1" /* OTHER LARYNGEAL REPAIR */
"3171" = "1" /* SUTURE OF TRACHEAL LACER */
"3172" = "1" /* CLOSURE OF TRACHEOSTOMY */
"3173" = "1" /* TRACHEA FISTULA CLOS NEC */
"3174" = "1" /* REVISION OF TRACHEOSTOMY */
"3175" = "1" /* TRACHEAL RECONSTRUCTION */
"3179" = "1" /* OTHER TRACHEAL REPAIR */
"3191" = "1" /* LARYNGEAL NERV DIVISION */
"3192" = "1" /* LYSIS TRACH/LARYNX ADHES */
"3198" = "1" /* OTH LARYNGEAL OPERATION */
"3199" = "1" /* OTHER TRACHEAL OPERATION */
"320 " = "1" /* OTHER TRACHEAL OPERATION */
"3209" = "1" /* OTHER DESTRUC BRONC LES */
"321 " = "1" /* OTHER BRONCHIAL EXCISION */
"3220" = "1" /* THORAC EXC LUNG LESION */
"3221" = "1" /* EMPHYSEMA BLEB PLICATION */
"3222" = "1" /* LUNG VOL REDUCTION SURG */
"3223" = "1" /* OPEN ABLTN LUNG LES/TISS */
"3224" = "1" /* PERC ABLTN LUNG LES/TISS */
"3225" = "1" /* THOR ABLTN LUNG LES/TISS */
"3226" = "1" /* ABLTN LUNG TISS NEC/NOS */
"3227" = "1" /* BRNC THRMPLSTYABLT MSCL	 */
"3229" = "1" /* DESTROY LOC LUNG LES NEC */
"323 " = "1" /* SEGMENTAL LUNG RESECTION */
"3230" = "1" /* THORAC SEG LUNG RESECT */
"3239" = "1" /* OTH SEG LUNG RESECT NOS */
"324 " = "1" /* LOBECTOMY OF LUNG */
"3241" = "1" /* THORAC LOBECTOMY LUNG */
"3249" = "1" /* LOBECTOMY OF LUNG NEC */
"325 " = "1" /* COMPLETE PNEUMONECTOMY */
"3250" = "1" /* THORACOSPC PNEUMONECTOMY */
"3259" = "1" /* OTHER PNEUMONECTOMY NOS */
"326 " = "1" /* RAD DISSEC THORAC STRUCT */
"329 " = "1" /* OTHER EXCISION OF LUNG */
"330 " = "1" /* INCISION OF BRONCHUS */
"331 " = "1" /* INCISION OF LUNG */
"3320" = "1" /* THORACOSCOPC LUNG BIOPSY */
"3325" = "1" /* OPEN BRONCHIAL BIOPSY */
"3327" = "1" /* CLOS ENDOSCOPIC LUNG BX */
"3328" = "1" /* OPEN LUNG BIOPSY */
"3329" = "1" /* BRONCH/LUNG DX PROC NEC */
"3334" = "1" /* THORACOPLASTY */
"3339" = "1" /* SURG COLLAPS OF LUNG NEC */
"3341" = "1" /* BRONCHIAL LACERAT SUTURE */
"3342" = "1" /* BRONCHIAL FISTULA CLOS */
"3343" = "1" /* LUNG LACERATION CLOSURE */
"3348" = "1" /* BRONCHIAL REPAIR NEC */
"3349" = "1" /* LUNG REPAIR NEC */
"335 " = "1" /* LUNG REPAIR NEC */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336 " = "1" /* COMB HEART/LUNG TRANSPLA */
"3392" = "1" /* BRONCHIAL LIGATION */
"3393" = "1" /* PUNCTURE OF LUNG */
"3398" = "1" /* BRONCHIAL OPERATION NEC */
"3399" = "1" /* LUNG OPERATION NEC */
"3402" = "1" /* EXPLORATORY THORACOTOMY */
"3403" = "1" /* REOPEN THORACOTOMY SITE */
"3406" = "1" /* THORAC DRAIN PLEURL CAV */
"341 " = "1" /* INCISION OF MEDIASTINUM */
"3420" = "1" /* THORACOSCOPIC PLEURAL BX */
"3421" = "1" /* TRANSPLEURA THORACOSCOPY */
"3422" = "1" /* MEDIASTINOSCOPY */
"3426" = "1" /* OPEN MEDIASTINAL BIOPSY */
"3427" = "1" /* BIOPSY OF DIAPHRAGM */
"3428" = "1" /* DX PROCEDURE THORAX NEC */
"3429" = "1" /* DX PROC MEDIASTINUM NEC */
"343 " = "1" /* DESTRUCT MEDIASTIN LES */
"344 " = "1" /* DESTRUCT CHEST WALL LES */
"3451" = "1" /* DECORTICATION OF LUNG */
"3452" = "1" /* THORACOSCOPC DECORT LUNG */
"3459" = "1" /* OTHER PLEURAL EXCISION */
"346 " = "1" /* SCARIFICATION OF PLEURA */
"3473" = "1" /* CLOS THORACIC FISTUL NEC */
"3474" = "1" /* PECTUS DEFORMITY REPAIR */
"3479" = "1" /* OTHER CHEST WALL REPAIR */
"3481" = "1" /* EXCISE DIAPHRAGM LESION */
"3482" = "1" /* SUTURE DIAPHRAGM LACERAT */
"3483" = "1" /* CLOSE DIAPHRAGM FISTULA */
"3484" = "1" /* OTHER DIAPHRAGM REPAIR */
"3485" = "1" /* IMPLANT DIAPHRA PACEMAKE */
"3489" = "1" /* DIAPHRAGM OPERATION NEC */
"3493" = "1" /* REPAIR OF PLEURA */
"3499" = "1" /* THORACIC OPERATION NEC */
"3500" = "1" /* CLOSED VALVOTOMY NOS */
"3501" = "1" /* CLOSED AORTIC VALVOTOMY */
"3502" = "1" /* CLOSED MITRAL VALVOTOMY */
"3503" = "1" /* CLOSED PULMON VALVOTOMY */
"3504" = "1" /* CLOSED TRICUSP VALVOTOMY */
"3505" = "1" /*	ENDOVASCULAR REPLACEMENT OF AORTIC VALVE */
"3506" = "1" /*	TRANSAPICAL REPLACEMENT OF AORTIC VALVE */
"3507" = "1" /*	ENDOVASCULAR REPLACEMENT OF PULMONARY  VALVE  */
"3508" = "1" /*	TRANSAPICAL REPLACEMENT OF PULMONARY VALVE  */
"3509" = "1" /*	ENDOVASCULAR REPLACEMENT OF UNSPECIFIED HEART VALVE */
"3510" = "1" /* OPEN VALVULOPLASTY NOS */
"3511" = "1" /* OPN AORTIC VALVULOPLASTY */
"3512" = "1" /* OPN MITRAL VALVULOPLASTY */
"3513" = "1" /* OPN PULMON VALVULOPLASTY */
"3514" = "1" /* OPN TRICUS VALVULOPLASTY */
"3520" = "1" /* REPLACE HEART VALVE NOS */
"3521" = "1" /* REPLACE AORT VALV-TISSUE */
"3522" = "1" /* REPLACE AORTIC VALVE NEC */
"3523" = "1" /* REPLACE MITR VALV-TISSUE */
"3524" = "1" /* REPLACE MITRAL VALVE NEC */
"3525" = "1" /* REPLACE PULM VALV-TISSUE */
"3526" = "1" /* REPLACE PULMON VALVE NEC */
"3527" = "1" /* REPLACE TRIC VALV-TISSUE */
"3528" = "1" /* REPLACE TRICUSP VALV NEC */
"3531" = "1" /* PAPILLARY MUSCLE OPS */
"3532" = "1" /* CHORDAE TENDINEAE OPS */
"3533" = "1" /* ANNULOPLASTY */
"3534" = "1" /* INFUNDIBULECTOMY */
"3535" = "1" /* TRABECUL CARNEAE CORD OP */
"3539" = "1" /* TISS ADJ TO VALV OPS NEC */
"3542" = "1" /* CREATE SEPTAL DEFECT */
"3550" = "1" /* PROSTH REP HRT SEPTA NOS */
"3551" = "1" /* PROS REP ATRIAL DEF-OPN */
"3552" = "1" /* PROS REPAIR ATRIA DEF-CL */
"3553" = "1" /* PROST REPAIR VENTRIC DEF */
"3554" = "1" /* PROS REP ENDOCAR CUSHION */
"3555" = "1" /* PROS REP VENTRC DEF-CLOS */
"3560" = "1" /* GRFT REPAIR HRT SEPT NOS */
"3561" = "1" /* GRAFT REPAIR ATRIAL DEF */
"3562" = "1" /* GRAFT REPAIR VENTRIC DEF */
"3563" = "1" /* GRFT REP ENDOCAR CUSHION */
"3570" = "1" /* HEART SEPTA REPAIR NOS */
"3571" = "1" /* ATRIA SEPTA DEF REP NEC */
"3572" = "1" /* VENTR SEPTA DEF REP NEC */
"3573" = "1" /* ENDOCAR CUSHION REP NEC */
"3581" = "1" /* TOT REPAIR TETRAL FALLOT */
"3582" = "1" /* TOTAL REPAIR OF TAPVC */
"3583" = "1" /* TOT REP TRUNCUS ARTERIOS */
"3584" = "1" /* TOT COR TRANSPOS GRT VES */
"3591" = "1" /* INTERAT VEN RETRN TRANSP */
"3592" = "1" /* CONDUIT RT VENT-PUL ART */
"3593" = "1" /* CONDUIT LEFT VENTR-AORTA */
"3594" = "1" /* CONDUIT ARTIUM-PULM ART */
"3595" = "1" /* HEART REPAIR REVISION */
"3596" = "1" /* PERC HEART VALVULOPLASTY */
"3597" = "1" /* PERC MTRL VLV REPR W IMP */	
"3598" = "1" /* OTHER HEART SEPTA OPS */
"3599" = "1" /* OTHER HEART VALVE OPS */
"3600" = "1" /* OTHER HEART VALVE OPS */
"3601" = "1" /* PTCA-1 VES/ATH W/O AGENT */
"3602" = "1" /* PTCA-1 VES/ATH W AGENT */
"3603" = "1" /* OPEN CORONRY ANGIOPLASTY */
"3605" = "1" /* PTCA-MULTIPLE VESSEL/ATH */
"3609" = "1" /* REM OF COR ART OBSTR NEC */
"3610" = "1" /* AORTOCORONARY BYPASS NOS */
"3611" = "1" /* AORTOCOR BYPAS-1 COR ART */
"3612" = "1" /* AORTOCOR BYPAS-2 COR ART */
"3613" = "1" /* AORTOCOR BYPAS-3 COR ART */
"3614" = "1" /* AORTCOR BYPAS-4+ COR ART */
"3615" = "1" /* 1 INT MAM-COR ART BYPASS */
"3616" = "1" /* 2 INT MAM-COR ART BYPASS */
"3617" = "1" /* ABD-CORON ARTERY BYPASS */
"3619" = "1" /* HRT REVAS BYPS ANAS NEC */
"362 " = "1" /* ARTERIAL IMPLANT REVASC */
"363 " = "1" /* ARTERIAL IMPLANT REVASC */
"3631" = "1" /* OPEN CHEST TRANS REVASC */
"3632" = "1" /* OTH TRANSMYO REVASCULAR */
"3633" = "1" /* ENDO TRANSMYO REVASCULAR */
"3634" = "1" /* PERC TRANSMYO REVASCULAR */
"3639" = "1" /* OTH HEART REVASCULAR */
"3691" = "1" /* CORON VESS ANEURYSM REP */
"3699" = "1" /* HEART VESSEL OP NEC */
"3710" = "1" /* INCISION OF HEART NOS */
"3711" = "1" /* CARDIOTOMY */
"3712" = "1" /* PERICARDIOTOMY */
"3724" = "1" /* PERICARDIAL BIOPSY */
"3731" = "1" /* PERICARDIECTOMY */
"3732" = "1" /* HEART ANEURYSM EXCISION */
"3733" = "1" /* EXC/DEST HRT LESION OPEN */
"3734" = "1" /* EXC/DEST HRT LES OTHER */
"3735" = "1" /* PARTIAL VENTRICULECTOMY */
"3737" = "1" /* EXC/DEST HRT LES THRSPC	 */
"374 " = "1" /* HEART & PERICARD REPAIR */
"3741" = "1" /* IMPL CARDIAC SUPPORT DEV */
"3749" = "1" /* HEART/PERICARD REPR NEC */
"375 " = "1" /* HEART & PERICARD REPAIR */
"3751" = "1" /* HEART TRANSPLANTATION */
"3752" = "1" /* IMPLANT TOT REP HRT SYS */
"3753" = "1" /* REPL/REP THORAC UNIT HRT */
"3754" = "1" /* REPL/REP OTH TOT HRT SYS */
"3755" = "1" /* REM INT BIVENT HRT SYS */
"3760" = "1" /* IMP BIVN EXT HRT AST SYS */
"3761" = "1" /* PULSATION BALLOON IMPLAN */
"3762" = "1" /* IMPLANT HRT ASST SYS NEC */
"3763" = "1" /* REPLACE HRT ASSIST SYST */
"3764" = "1" /* REMOVE HEART ASSIST SYS */
"3765" = "1" /* IMP EXT PUL HRT ASST SYS */
"3766" = "1" /* IMP IMP PUL HRT ASST SYS */
"3767" = "1" /* IMP CARDIOMYOSTIMUL SYS */
"3768" = "1" /* PERCUTAN HRT ASSIST SYST */
"3774" = "1" /* INT OR REPL LEAD EPICAR */
"3775" = "1" /* REVISION OF LEAD */
"3776" = "1" /* REPL TV ATRI-VENT LEAD */
"3777" = "1" /* REMOVAL OF LEAD W/O REPL */
"3779" = "1" /* REVIS OR RELOCATE POCKET */
"3780" = "1" /* INT OR REPL PERM PACEMKR */
"3785" = "1" /* REPL PACEM W 1-CHAM, NON */
"3786" = "1" /* REPL PACEM 1-CHAM, RATE */
"3787" = "1" /* REPL PACEM W DUAL-CHAM */
"3789" = "1" /* REVISE OR REMOVE PACEMAK */
"3791" = "1" /* OPN CHEST CARDIAC MASSAG */
"3794" = "1" /* IMPLT/REPL CARDDEFIB TOT */
"3795" = "1" /* IMPLT CARDIODEFIB LEADS */
"3796" = "1" /* IMPLT CARDIODEFIB GENATR */
"3797" = "1" /* REPL CARDIODEFIB LEADS */
"3798" = "1" /* REPL CARDIODEFIB GENRATR */
"3799" = "1" /* OTHER HEART/PERICARD OPS */
"3800" = "1" /* INCISION OF VESSEL NOS */
"3801" = "1" /* INTRACRAN VESSEL INCIS */
"3802" = "1" /* HEAD/NECK VES INCIS NEC */
"3803" = "1" /* UPPER LIMB VESSEL INCIS */
"3804" = "1" /* INCISION OF AORTA */
"3805" = "1" /* THORACIC VESSEL INC NEC */
"3806" = "1" /* ABDOMEN ARTERY INCISION */
"3807" = "1" /* ABDOMINAL VEIN INCISION */
"3808" = "1" /* LOWER LIMB ARTERY INCIS */
"3809" = "1" /* LOWER LIMB VEIN INCISION */
"3810" = "1" /* ENDARTERECTOMY NOS */
"3811" = "1" /* INTRACRAN ENDARTERECTOMY */
"3812" = "1" /* HEAD & NECK ENDARTER NEC */
"3813" = "1" /* UPPER LIMB ENDARTERECTOM */
"3814" = "1" /* ENDARTERECTOMY OF AORTA */
"3815" = "1" /* THORACIC ENDARTERECTOMY */
"3816" = "1" /* ABDOMINAL ENDARTERECTOMY */
"3818" = "1" /* LOWER LIMB ENDARTERECT */
"3821" = "1" /* BLOOD VESSEL BIOPSY */
"3826" = "1" /* INSERTION OF IMPLANTABLE PRESSURE SENSOR WITHOUT LEAD FOR INTRACARDIAC OR GREAT VESSEL HEMODYNAMIC MONITORING */
"3829" = "1" /* BLOOD VESSEL DX PROC NEC */
"3830" = "1" /* VESSEL RESECT/ANAST NOS */
"3831" = "1" /* INTRACRAN VES RESEC-ANAS */
"3832" = "1" /* HEAD/NECK VES RESEC-ANAS */
"3833" = "1" /* ARM VESSEL RESECT/ANAST */
"3834" = "1" /* AORTA RESECTION & ANAST */
"3835" = "1" /* THOR VESSEL RESECT/ANAST */
"3836" = "1" /* ABD VESSEL RESECT/ANAST */
"3837" = "1" /* ABD VEIN RESECT & ANAST */
"3838" = "1" /* LEG ARTERY RESECT/ANAST */
"3839" = "1" /* LEG VEIN RESECT/ANASTOM */
"3840" = "1" /* VESSEL RESECT/REPLAC NOS */
"3841" = "1" /* INTRACRAN VES RESEC-REPL */
"3842" = "1" /* HEAD/NECK VES RESEC-REPL */
"3843" = "1" /* ARM VES RESECT W REPLACE */
"3844" = "1" /* RESECT ABDM AORTA W REPL */
"3845" = "1" /* RESECT THORAC VES W REPL */
"3846" = "1" /* ABD ARTERY RESEC W REPLA */
"3847" = "1" /* ABD VEIN RESECT W REPLAC */
"3848" = "1" /* LEG ARTERY RESEC W REPLA */
"3849" = "1" /* LEG VEIN RESECT W REPLAC */
"3850" = "1" /* VARICOSE V LIG-STRIP NOS */
"3851" = "1" /* INTCRAN VAR V LIG-STRIP */
"3852" = "1" /* HEAD/NECK VAR V LIG-STR */
"3853" = "1" /* ARM VARICOSE V LIG-STRIP */
"3855" = "1" /* THORAC VAR V LIG-STRIP */
"3857" = "1" /* ABD VARICOS V LIGA-STRIP */
"3859" = "1" /* LEG VARICOS V LIGA-STRIP */
"3860" = "1" /* EXCISION OF VESSEL NOS */
"3861" = "1" /* INTRACRAN VESSEL EXCIS */
"3862" = "1" /* HEAD/NECK VESSEL EXCIS */
"3863" = "1" /* ARM VESSEL EXCISION */
"3864" = "1" /* EXCISION OF AORTA */
"3865" = "1" /* THORACIC VESSEL EXCISION */
"3866" = "1" /* ABDOMINAL ARTERY EXCIS */
"3867" = "1" /* ABDOMINAL VEIN EXCISION */
"3868" = "1" /* LEG ARTERY EXCISION */
"3869" = "1" /* LEG VEIN EXCISION */
"3880" = "1" /* SURG VESSEL OCCLUS NEC */
"3881" = "1" /* OCCLUS INTRACRAN VES NEC */
"3882" = "1" /* OCCLUS HEAD/NECK VES NEC */
"3883" = "1" /* OCCLUDE ARM VESSEL NEC */
"3884" = "1" /* OCCLUDE AORTA NEC */
"3885" = "1" /* OCCLUDE THORACIC VES NEC */
"3886" = "1" /* OCCLUDE ABD ARTERY NEC */
"3887" = "1" /* OCCLUDE ABD VEIN NEC */
"3888" = "1" /* OCCLUDE LEG ARTERY NEC */
"3889" = "1" /* OCCLUDE LEG VEIN NEC */
"390 " = "1" /* SYSTEMIC-PULM ART SHUNT */
"391 " = "1" /* INTRA-ABD VENOUS SHUNT */
"3921" = "1" /* CAVAL-PULMON ART ANASTOM */
"3922" = "1" /* AORTA-SUBCLV-CAROT BYPAS */
"3923" = "1" /* INTRATHORACIC SHUNT NEC */
"3924" = "1" /* AORTA-RENAL BYPASS */
"3925" = "1" /* AORTA-ILIAC-FEMOR BYPASS */
"3926" = "1" /* INTRA-ABDOMIN SHUNT NEC */
"3927" = "1" /* DIALYSIS ARTERIOVENOSTOM */
"3928" = "1" /* EXTRACRAN-INTRACR BYPASS */
"3929" = "1" /* VASC SHUNT & BYPASS NEC */
"3930" = "1" /* SUTURE OF VESSEL NOS */
"3931" = "1" /* SUTURE OF ARTERY */
"3932" = "1" /* SUTURE OF VEIN */
"3941" = "1" /* POSTOP VASC OP HEM CONTR */
"3942" = "1" /* REVIS REN DIALYSIS SHUNT */
"3943" = "1" /* REMOV REN DIALYSIS SHUNT */
"3949" = "1" /* VASC PROC REVISION NEC */
"3950" = "1" /* ANGIO/ATH NON-CORO VES */
"3951" = "1" /* CLIPPING OF ANEURYSM */
"3952" = "1" /* ANEURYSM REPAIR NEC */
"3953" = "1" /* ARTERIOVEN FISTULA REP */
"3954" = "1" /* RE-ENTRY OPERATION */
"3955" = "1" /* REIMPLAN ABERR RENAL VES */
"3956" = "1" /* REPAIR VESS W TIS PATCH */
"3957" = "1" /* REP VESS W SYNTH PATCH */
"3958" = "1" /* REPAIR VESS W PATCH NOS */
"3959" = "1" /* REPAIR OF VESSEL NEC */
"397 " = "1" /* PER CARDIOPULMON BYPASS */
"3971" = "1" /* ENDO IMPL GRFT ABD AORTA */
"3972" = "1" /* ENDOVASC REPAIR HEAD VES */
"3973" = "1" /* ENDO IMP GRFT THOR AORTA */
"3974" = "1" /* ENDO REM OBS HD/NECK VES */
"3975" = "1" /* ENDO EMB HD/NK,BARE COIL */
"3976" = "1" /* ENDO EM HD/NK,BIOAC COIL */
"3977" = "1" /*	TEMPORARY (PARTIAL) THERAPEUTIC ENDOVASCULAR OCCLUSION OF VESSEL */
"3978" = "1" /*	ENDOVASCULAR IMPLANTATION OF BRANCHING OR FENESTRATED GRAFT(S) IN AORTA*/
"3979" = "1" /* ENDO REPAIR OTHER VESSEL */
"398 " = "1" /* CARTD BODY/SINUS/VASC OP */
"3981" = "1" /* IMP CRTD SINUS STMTOTL	 */
"3982" = "1" /* IMP/REP CRTD SINUS LEAD	 */
"3983" = "1" /* IMP/REP CRTD SINUS GNRTR */	
"3984" = "1" /* REV CRTD SINUS STM LEADS */	
"3985" = "1" /* REV CRTD SINUS PULSE GEN */	
"3986" = "1" /* REM CRTD SINUS STM TOTL	 */
"3987" = "1" /* REM CRTD SINUS STM LEAD	 */
"3988" = "1" /* REM CRTD SINUS PULSE GEN */	
"3989" = "1" /* OTH CARTD BODY/SINUS OP	 */
"3991" = "1" /* FREEING OF VESSEL */
"3992" = "1" /* VEIN INJECT-SCLEROS AGNT */
"3993" = "1" /* INSERT VES-TO-VES CANNUL */
"3994" = "1" /* REPLAC VES-TO-VES CANNUL */
"3998" = "1" /* HEMORRHAGE CONTROL NOS */
"3999" = "1" /* VESSEL OPERATION NEC */
"400 " = "1" /* INCIS LYMPHATIC STRUCTUR */
"4011" = "1" /* LYMPHATIC STRUCT BIOPSY */
"4019" = "1" /* LYMPHATIC DIAG PROC NEC */
"4021" = "1" /* EXCIS DEEP CERVICAL NODE */
"4022" = "1" /* EXCISE INT MAMMARY NODE */
"4023" = "1" /* EXCISE AXILLARY NODE */
"4024" = "1" /* EXCISE INGUINAL NODE */
"4029" = "1" /* SIMP EXC LYMPH STRUC NEC */
"403 " = "1" /* REGIONAL LYMPH NODE EXC */
"4040" = "1" /* RAD NECK DISSECTION NOS */
"4041" = "1" /* UNILAT RAD NECK DISSECT */
"4042" = "1" /* BILAT RAD NECK DISSECT */
"4050" = "1" /* RAD NODE DISSECTION NOS */
"4051" = "1" /* RAD DISSEC AXILLARY NODE */
"4052" = "1" /* RAD DISSEC PERIAORT NODE */
"4053" = "1" /* RAD DISSECT ILIAC NODES */
"4054" = "1" /* RADICAL GROIN DISSECTION */
"4059" = "1" /* RAD NODE DISSECTION NEC */
"4061" = "1" /* THORAC DUCT CANNULATION */
"4062" = "1" /* THORACIC DUCT FISTULIZAT */
"4063" = "1" /* CLOSE THORACIC DUCT FIST */
"4064" = "1" /* LIGATE THORACIC DUCT */
"4069" = "1" /* THORACIC DUCT OP NEC */
"409 " = "1" /* LYMPH STRUCTURE OP NEC */
"412 " = "1" /* SPLENOTOMY */
"4133" = "1" /* OPEN SPLEEN BIOPSY */
"4141" = "1" /* SPLENIC CYST MARSUPIAL */
"4142" = "1" /* EXC SPLENIC LESION/TISS */
"4143" = "1" /* PARTIAL SPLENECTOMY */
"415 " = "1" /* TOTAL SPLENECTOMY */
"4193" = "1" /* EXC OF ACCESSORY SPLEEN */
"4194" = "1" /* SPLEEN TRANSPLANTATION */
"4195" = "1" /* REPAIR OF SPLEEN */
"4199" = "1" /* SPLEEN OPERATION NEC */
"4201" = "1" /* ESOPHAGEAL WEB INCISION */
"4209" = "1" /* ESOPHAGEAL INCISION NEC */
"4210" = "1" /* ESOPHAGOSTOMY NOS */
"4211" = "1" /* CERVICAL ESOPHAGOSTOMY */
"4212" = "1" /* ESOPH POUCH EXTERIORIZAT */
"4219" = "1" /* EXT FISTULIZAT ESOPH NEC */
"4221" = "1" /* ESOPHAGOSCOPY BY INCIS */
"4225" = "1" /* OPEN BIOPSY OF ESOPHAGUS */
"4231" = "1" /* LOC EXCIS ESOPH DIVERTIC */
"4232" = "1" /* LOCAL EXCIS ESOPHAG NEC */
"4239" = "1" /* DESTRUCT ESOPHAG LES NEC */
"4240" = "1" /* ESOPHAGECTOMY NOS */
"4241" = "1" /* PARTIAL ESOPHAGECTOMY */
"4242" = "1" /* TOTAL ESOPHAGECTOMY */
"4251" = "1" /* THORAC ESOPHAGOESOPHAGOS */
"4252" = "1" /* THORAC ESOPHAGOGASTROST */
"4253" = "1" /* THORAC SM BOWEL INTERPOS */
"4254" = "1" /* THORAC ESOPHAGOENTER NEC */
"4255" = "1" /* THORAC LG BOWEL INTERPOS */
"4256" = "1" /* THORAC ESOPHAGOCOLOS NEC */
"4258" = "1" /* THORAC INTERPOSITION NEC */
"4259" = "1" /* THORAC ESOPHAG ANAST NEC */
"4261" = "1" /* STERN ESOPHAGOESOPHAGOST */
"4262" = "1" /* STERN ESOPHAGOGASTROSTOM */
"4263" = "1" /* STERN SM BOWEL INTERPOS */
"4264" = "1" /* STERN ESOPHAGOENTER NEC */
"4265" = "1" /* STERN LG BOWEL INTERPOS */
"4266" = "1" /* STERN ESOPHAGOCOLOS NEC */
"4268" = "1" /* STERN INTERPOSITION NEC */
"4269" = "1" /* STERN ESOPHAG ANAST NEC */
"427 " = "1" /* ESOPHAGOMYOTOMY */
"4282" = "1" /* SUTURE ESOPHAGEAL LACER */
"4283" = "1" /* ESOPHAGOSTOMY CLOSURE */
"4284" = "1" /* ESOPH FISTULA REPAIR NEC */
"4285" = "1" /* ESOPHAG STRICTURE REPAIR */
"4286" = "1" /* PROD SUBQ TUNNEL NO ANAS */
"4287" = "1" /* ESOPHAGEAL GRAFT NEC */
"4289" = "1" /* ESOPHAGEAL REPAIR NEC */
"4291" = "1" /* LIGATION ESOPH VARIX */
"430 " = "1" /* GASTROTOMY */
"431 " = "1" /* GASTROTOMY */
"432 " = "1" /* OTHER GASTROSTOMY */
"433 " = "1" /* PYLOROMYOTOMY */
"4342" = "1" /* LOCAL GASTR EXCISION NEC */
"4349" = "1" /* LOCAL GASTR DESTRUCT NEC */
"435 " = "1" /* PROXIMAL GASTRECTOMY */
"436 " = "1" /* DISTAL GASTRECTOMY */
"437 " = "1" /* PART GASTREC W JEJ ANAST */
"4381" = "1" /* PART GAST W JEJ TRANSPOS */
"4382" = "1" /*	LAPAROSCOPIC VERTICAL (SLEEVE) GASTERECTOMY  */
"4389" = "1" /* PARTIAL GASTRECTOMY NEC */
"4391" = "1" /* TOT GAST W INTES INTERPO */
"4399" = "1" /* TOTAL GASTRECTOMY NEC */
"4400" = "1" /* VAGOTOMY NOS */
"4401" = "1" /* TRUNCAL VAGOTOMY */
"4402" = "1" /* HIGHLY SELECT VAGOTOMY */
"4403" = "1" /* SELECTIVE VAGOTOMY NEC */
"4411" = "1" /* TRANSABDOMIN GASTROSCOPY */
"4415" = "1" /* OPEN GASTRIC BIOPSY */
"442 " = "1" /* GASTRIC DIAGNOS PROC NEC */
"4421" = "1" /* DILATE PYLORUS, INCISION */
"4429" = "1" /* OTHER PYLOROPLASTY */
"4431" = "1" /* HIGH GASTRIC BYPASS */
"4432" = "1" /* PERCU GASTROJEJUNOSTOMY */
"4438" = "1" /* LAP GASTROENTEROSTOMY */
"4439" = "1" /* GASTROENTEROSTOMY NEC */
"4440" = "1" /* SUTURE PEPTIC ULCER NOS */
"4441" = "1" /* SUT GASTRIC ULCER SITE */
"4442" = "1" /* SUTURE DUODEN ULCER SITE */
"445 " = "1" /* REVISION GASTRIC ANASTOM */
"4461" = "1" /* SUTURE GASTRIC LACERAT */
"4463" = "1" /* CLOSE GASTRIC FISTUL NEC */
"4464" = "1" /* GASTROPEXY */
"4465" = "1" /* ESOPHAGOGASTROPLASTY */
"4466" = "1" /* CREAT ESOPHAGASTR SPHINC */
"4467" = "1" /* LAP CREAT ESOPH SPHINCT */
"4468" = "1" /* LAPAROSCOP GASTROPLASTY */
"4469" = "1" /* GASTRIC REPAIR NEC */
"4491" = "1" /* LIGATE GASTRIC VARICES */
"4492" = "1" /* INTRAOP GASTRIC MANIPUL */
"4495" = "1" /* LAP GASTRIC RESTRIC PROC */
"4496" = "1" /* LAP REV GAST RESTRI PROC */
"4497" = "1" /* LAP REM GAST RESTRIC DEV */
"4498" = "1" /* ADJUST GAST RESTRICT DEV */
"4499" = "1" /* GASTRIC OPERATION NEC */
"4500" = "1" /* INTESTINAL INCISION NOS */
"4501" = "1" /* DUODENAL INCISION */
"4502" = "1" /* SMALL BOWEL INCISION NEC */
"4503" = "1" /* LARGE BOWEL INCISION */
"4511" = "1" /* TRANSAB SM BOWEL ENDOSC */
"4515" = "1" /* OPEN SMALL BOWEL BIOPSY */
"4521" = "1" /* TRANSAB LG BOWEL ENDOSC */
"4526" = "1" /* OPEN LARGE BOWEL BIOPSY */
"4531" = "1" /* OTH EXCISE DUODENUM LES */
"4532" = "1" /* DESTRUCT DUODEN LES NEC */
"4533" = "1" /* LOCAL EXCIS SM BOWEL NEC */
"4534" = "1" /* DESTR SM BOWEL LES NEC */
"4541" = "1" /* EXCISE LG INTESTINE LES */
"4549" = "1" /* DESTRUC LG BOWEL LES NEC */
"4550" = "1" /* INTEST SEG ISOLAT NOS */
"4551" = "1" /* SM BOWEL SEGMENT ISOLAT */
"4552" = "1" /* LG BOWEL SEGMENT ISOLAT */
"4561" = "1" /* MULT SEG SM BOWEL EXCIS */
"4562" = "1" /* PART SM BOWEL RESECT NEC */
"4563" = "1" /* TOTAL REMOVAL SM BOWEL */
"4571" = "1" /* MULT SEG LG BOWEL EXCIS */
"4572" = "1" /* CECECTOMY */
"4573" = "1" /* RIGHT HEMICOLECTOMY */
"4574" = "1" /* TRANSVERSE COLON RESECT */
"4575" = "1" /* LEFT HEMICOLECTOMY */
"4576" = "1" /* SIGMOIDECTOMY */
"4579" = "1" /* PART LG BOWEL EXCIS NEC */
"458 " = "1" /* TOT INTRA-ABD COLECTOMY */
"4581" = "1" /* LAP TOT INTR-AB COLECTMY */
"4582" = "1" /* OP TOT INTR-ABD COLECTMY */
"4583" = "1" /* TOT ABD COLECTMY NEC/NOS */
"4590" = "1" /* INTESTINAL ANASTOM NOS */
"4591" = "1" /* SM-TO-SM BOWEL ANASTOM */
"4592" = "1" /* SM BOWEL-RECT STUMP ANAS */
"4593" = "1" /* SMALL-TO-LARGE BOWEL NEC */
"4594" = "1" /* LG-TO-LG BOWEL ANASTOM */
"4595" = "1" /* ANAL ANASTOMOSIS */
"4601" = "1" /* SM BOWEL EXTERIORIZATION */
"4602" = "1" /* RESECT EXT SEG SM BOWEL */
"4603" = "1" /* LG BOWEL EXTERIORIZATION */
"4604" = "1" /* RESECT EXT SEG LG BOWEL */
"4610" = "1" /* COLOSTOMY NOS */
"4611" = "1" /* TEMPORARY COLOSTOMY */
"4612" = "1" /* TEMPORARY COLOSTOMY */
"4613" = "1" /* PERMANENT COLOSTOMY */
"4620" = "1" /* ILEOSTOMY NOS */
"4621" = "1" /* TEMPORARY ILEOSTOMY */
"4622" = "1" /* CONTINENT ILEOSTOMY */
"4623" = "1" /* PERMANENT ILEOSTOMY NEC */
"4640" = "1" /* INTEST STOMA REVIS NOS */
"4641" = "1" /* SM BOWEL STOMA REVISION */
"4642" = "1" /* PERICOLOST HERNIA REPAIR */
"4643" = "1" /* LG BOWEL STOMA REVIS NEC */
"4650" = "1" /* INTEST STOMA CLOSURE NOS */
"4651" = "1" /* SM BOWEL STOMA CLOSURE */
"4652" = "1" /* LG BOWEL STOMA CLOSURE */
"4660" = "1" /* INTESTINAL FIXATION NOS */
"4661" = "1" /* SM BOWEL-ABD WALL FIXAT */
"4662" = "1" /* SMALL BOWEL FIXATION NEC */
"4663" = "1" /* LG BOWEL-ABD WALL FIXAT */
"4664" = "1" /* LARGE BOWEL FIXATION NEC */
"4671" = "1" /* DUODENAL LACERAT SUTURE */
"4672" = "1" /* DUODENAL FISTULA CLOSURE */
"4673" = "1" /* SMALL BOWEL SUTURE NEC */
"4674" = "1" /* CLOSE SM BOWEL FIST NEC */
"4675" = "1" /* SUTURE LG BOWEL LACERAT */
"4676" = "1" /* CLOSE LG BOWEL FISTULA */
"4679" = "1" /* REPAIR OF INTESTINE NEC */
"4680" = "1" /* INTRA-AB BOWEL MANIP NOS */
"4681" = "1" /* INTRA-ABD SM BOWEL MANIP */
"4682" = "1" /* INTRA-ABD LG BOWEL MANIP */
"4691" = "1" /* MYOTOMY OF SIGMOID COLON */
"4692" = "1" /* MYOTOMY OF COLON NEC */
"4693" = "1" /* REVISE SM BOWEL ANASTOM */
"4694" = "1" /* REVISE LG BOWEL ANASTOM */
"4697" = "1" /* TRANSPLANT OF INTESTINE */
"4699" = "1" /* INTESTINAL OP NEC */
"470 " = "1" /* INTESTINAL OP NEC */
"4701" = "1" /* LAP APPENDECTOMY */
"4709" = "1" /* OTHER APPENDECTOMY */
"471 " = "1" /* OTHER APPENDECTOMY */
"4711" = "1" /* LAP INCID APPENDECTOMY */
"4719" = "1" /* OTHER INCID APPENDECTOMY */
"472 " = "1" /* DRAIN APPENDICEAL ABSC */
"4791" = "1" /* APPENDICOSTOMY */
"4792" = "1" /* CLOSE APPENDICEAL FISTUL */
"4799" = "1" /* APPENDICEAL OPS NEC */
"480 " = "1" /* PROCTOTOMY */
"481 " = "1" /* PROCTOSTOMY */
"4821" = "1" /* TRANSAB PROCTOSIGMOIDOSC */
"4825" = "1" /* OPEN RECTAL BIOPSY */
"4835" = "1" /* LOCAL EXCIS RECTAL LES */
"4840" = "1" /* PULL-THRU RES RECTUM NOS */
"4841" = "1" /* SOAVE SUBMUC RECT RESECT */
"4842" = "1" /* LAP PULL-THRU RES RECTUM */
"4843" = "1" /* OPN PULL-THRU RES RECTUM */
"4849" = "1" /* PULL-THRU RECT RESEC NEC */
"485 " = "1" /* ABD-PERINEAL RECT RESECT */
"4850" = "1" /* ABDPERNEAL RES RECTM NOS */
"4851" = "1" /* LAP ABDPERNEAL RESC REC */
"4852" = "1" /* OPN ABDPERNEAL RESC REC */
"4859" = "1" /* ABDPERNEAL RESC RECT NEC */
"4861" = "1" /* TRANSSAC RECTOSIGMOIDECT */
"4862" = "1" /* ANT RECT RESECT W COLOST */
"4863" = "1" /* ANTERIOR RECT RESECT NEC */
"4864" = "1" /* POSTERIOR RECT RESECTION */
"4865" = "1" /* DUHAMEL RECTAL RESECTION */
"4866" = "1" /* DUHAMEL RECTAL RESECTION */
"4869" = "1" /* RECTAL RESECTION NEC */
"4871" = "1" /* SUTURE OF RECTAL LACER */
"4872" = "1" /* CLOSURE OF PROCTOSTOMY */
"4873" = "1" /* CLOSE RECTAL FIST NEC */
"4874" = "1" /* RECTORECTOSTOMY */
"4875" = "1" /* ABDOMINAL PROCTOPEXY */
"4876" = "1" /* PROCTOPEXY NEC */
"4879" = "1" /* REPAIR OF RECTUM NEC */
"4881" = "1" /* PERIRECTAL INCISION */
"4882" = "1" /* PERIRECTAL EXCISION */
"4891" = "1" /* INCIS RECTAL STRICTURE */
"4892" = "1" /* ANORECTAL MYOMECTOMY */
"4893" = "1" /* REPAIR PERIRECT FISTULA */
"4899" = "1" /* RECTAL PERIRECT OP NEC */
"4901" = "1" /* INCIS PERIANAL ABSCESS */
"4902" = "1" /* PERIANAL INCISION NEC */
"4904" = "1" /* PERIANAL EXCISION NEC */
"4911" = "1" /* ANAL FISTULOTOMY */
"4912" = "1" /* ANAL FISTULECTOMY */
"493 " = "1" /* ANAL/PERIAN DX PROC NEC */
"4939" = "1" /* OTHER DESTRUC ANUS LES */
"4944" = "1" /* HEMORRHOID CRYOTHERAPY */
"4945" = "1" /* HEMORRHOID LIGATION */
"4946" = "1" /* HEMORRHOIDECTOMY */
"4949" = "1" /* HEMORRHOID PROCEDURE NEC */
"4951" = "1" /* LEFT LAT SPHINCTEROTOMY */
"4952" = "1" /* POST SPHINCTEROTOMY */
"4959" = "1" /* ANAL SPHINCTEROTOMY NEC */
"496 " = "1" /* EXCISION OF ANUS */
"4971" = "1" /* SUTURE ANAL LACERATION */
"4972" = "1" /* ANAL CERCLAGE */
"4973" = "1" /* CLOSURE OF ANAL FISTULA */
"4974" = "1" /* GRACILIS MUSC TRANSPLAN */
"4975" = "1" /* IMPL OR REV ART ANAL SPH */
"4976" = "1" /* REMOV ART ANAL SPHINCTER */
"4979" = "1" /* ANAL SPHINCT REPAIR NEC */
"4991" = "1" /* INCISION OF ANAL SEPTUM */
"4992" = "1" /* INSERT SUBQ ANAL STIMUL */
"4993" = "1" /* ANAL INCISION NEC */
"4994" = "1" /* REDUCTION ANAL PROLAPSE */
"4995" = "1" /* CONTROL ANAL HEMORRHAGE */
"4999" = "1" /* ANAL OPERATION NEC */
"500 " = "1" /* HEPATOTOMY */
"5012" = "1" /* OPEN LIVER BIOPSY */
"5014" = "1" /* LAPAROSCOPIC LIVER BX */
"5019" = "1" /* HEPATIC DX PROC NEC */
"5021" = "1" /* MARSUPIALIZAT LIVER LES */
"5022" = "1" /* PARTIAL HEPATECTOMY */
"5023" = "1" /* OPN ABLTN LIVER LES/TISS */
"5024" = "1" /* PERC ABLTN LIVER LES/TIS */
"5025" = "1" /* LAP ABLTN LIVER LES/TISS */
"5026" = "1" /* ABLTN LIVER LES/TISS NEC */
"5029" = "1" /* DESTRUC HEPATIC LES NEC */
"503 " = "1" /* HEPATIC LOBECTOMY */
"504 " = "1" /* TOTAL HEPATECTOMY */
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5061" = "1" /* CLOSURE LIVER LACERAT */
"5069" = "1" /* LIVER REPAIR NEC */
"5102" = "1" /* TROCAR CHOLECYSTOSTOMY */
"5103" = "1" /* CHOLECYSTOSTOMY NEC */
"5104" = "1" /* CHOLECYSTOTOMY NEC */
"5113" = "1" /* OPEN BILIARY TRACT BX */
"5119" = "1" /* BILIARY TR DX PROC NEC */
"5121" = "1" /* OTH PART CHOLECYSTECTOMY */
"5122" = "1" /* CHOLECYSTECTOMY */
"5123" = "1" /* LAPAROSCOPIC CHOLECYSTEC */
"5124" = "1" /* LAP PART CHOLECYSTECTOMY */
"5131" = "1" /* GB-TO-HEPAT DUCT ANAST */
"5132" = "1" /* GB-TO-INTESTINE ANASTOM */
"5133" = "1" /* GB-TO-PANCREAS ANASTOM */
"5134" = "1" /* GB-TO-STOMACH ANASTOMOS */
"5135" = "1" /* GALLBLADDER ANASTOM NEC */
"5136" = "1" /* CHOLEDOCHOENTEROSTOMY */
"5137" = "1" /* HEPATIC DUCT-GI ANASTOM */
"5139" = "1" /* BILE DUCT ANASTOMOS NEC */
"5141" = "1" /* CDE FOR CALCULUS REMOV */
"5142" = "1" /* CDE FOR OBSTRUCTION NEC */
"5143" = "1" /* CHOLEDOCHOHEPAT INTUBAT */
"5149" = "1" /* INCIS OBSTR BILE DUC NEC */
"5151" = "1" /* COMMON DUCT EXPLORATION */
"5159" = "1" /* BILE DUCT INCISION NEC */
"5161" = "1" /* EXCIS CYST DUCT REMNANT */
"5162" = "1" /* EXCIS AMPULLA OF VATER */
"5163" = "1" /* COMMON DUCT EXCIS NEC */
"5169" = "1" /* BILE DUCT EXCISION NEC */
"5171" = "1" /* SIMPLE SUT-COMMON DUCT */
"5172" = "1" /* CHOLEDOCHOPLASTY */
"5179" = "1" /* BILE DUCT REPAIR NEC */
"5181" = "1" /* SPHINCTER OF ODDI DILAT */
"5182" = "1" /* PANCREAT SPHINCTEROTOM */
"5183" = "1" /* PANCREAT SPHINCTEROPLAS */
"5189" = "1" /* SPHINCT OF ODDI OP NEC */
"5191" = "1" /* REPAIR GB LACERATION */
"5192" = "1" /* CLOSURE CHOLECYSTOSTOMY */
"5193" = "1" /* CLOS BILIARY FISTUL NEC */
"5194" = "1" /* REVIS BILE TRACT ANASTOM */
"5195" = "1" /* REMOVE BILE DUCT PROSTH */
"5199" = "1" /* BILIARY TRACT OP NEC */
"5201" = "1" /* CATH DRAIN-PANCREAT CYST */
"5209" = "1" /* PANCREATOTOMY NEC */
"5212" = "1" /* OPEN PANCREATIC BIOPSY */
"5219" = "1" /* PANCREATIC DX PROC NEC */
"522 " = "1" /* PANCREATIC DX PROC NEC */
"5222" = "1" /* OTHER DESTRU PANCREA LES */
"523 " = "1" /* PANCREAT CYST MARSUPIALI */
"524 " = "1" /* INT DRAIN PANCREAT CYST */
"5251" = "1" /* PROXIMAL PANCREATECTOMY */
"5252" = "1" /* DISTAL PANCREATECTOMY */
"5253" = "1" /* RAD SUBTOT PANCREATECTOM */
"5259" = "1" /* PARTIAL PANCREATECT NEC */
"526 " = "1" /* TOTAL PANCREATECTOMY */
"527 " = "1" /* RAD PANCREATICODUODENECT */
"5280" = "1" /* PANCREAT TRANSPLANT NOS */
"5281" = "1" /* REIMPLANT PANCREATIC TIS */
"5282" = "1" /* PANCREATIC HOMOTRANSPLAN */
"5283" = "1" /* PANCREATIC HETEROTRANSPL */
"5291" = "1" /* TRNSPLNT ISLETS LANG NOS */
"5292" = "1" /* CANNULATION PANCREA DUC */
"5295" = "1" /* PANCREATIC REPAIR NEC */
"5296" = "1" /* PANCREATIC ANASTOMOSIS */
"5299" = "1" /* PANCREATIC OPERATION NEC */
"5300" = "1" /* UNILAT ING HERN REP NOS */
"5301" = "1" /* REPAIR DIRECT ING HERNIA */
"5302" = "1" /* REPAIR INDIR ING HERNIA */
"5303" = "1" /* DIR ING HERNIA REP-GRAFT */
"5304" = "1" /* IND ING HERNIA REP-GRAFT */
"5305" = "1" /* ING HERNIA REP-GRAFT NOS */
"5310" = "1" /* BILAT ING HERNIA REP NOS */
"5311" = "1" /* BILAT DIR ING HERN REP */
"5312" = "1" /* BILAT IND ING HERN REP */
"5313" = "1" /* BIL DIR/IND ING HRN REP */
"5314" = "1" /* BIL DIR ING HRN REP-GRFT */
"5315" = "1" /* BIL IND ING HRN REP-GRFT */
"5316" = "1" /* BIL DIR/IND ING HERN-PRO */
"5317" = "1" /* BIL ING HRN REP-GRFT NOS */
"5321" = "1" /* UNIL FEMOR HRN REP-GRFT */
"5329" = "1" /* UNIL FEMOR HERN REP NEC */
"5331" = "1" /* BIL FEM HERN REPAIR-GRFT */
"5339" = "1" /* BIL FEM HERN REPAIR NEC */
"5341" = "1" /* UMBIL HERNIA REPAIR-GRFT */
"5342" = "1" /* LAP UMBIL HERNIA-GRAFT */
"5343" = "1" /* LAP UMBILICAL HERNIA NEC */
"5349" = "1" /* UMBIL HERNIA REPAIR NEC */
"5351" = "1" /* INCISIONAL HERNIA REPAIR */
"5359" = "1" /* ABD WALL HERN REPAIR NEC */
"5361" = "1" /* INCIS HERNIA REPAIR-GRFT */
"5362" = "1" /* LAP INCIS HERN REPR-GRFT */
"5363" = "1" /* LAP HERN ANT ABD-GFT NEC */
"5369" = "1" /* ABD HERN REPAIR-GRFT NEC */
"537 " = "1" /* ABD REPAIR-DIAPHR HERNIA */
"5371" = "1" /* LAP ABD REP-DIAPHR HERN */
"5372" = "1" /* OPN ABD DIAPHRM HERN NEC */
"5375" = "1" /* ABD REP-DIAPHR HERN NOS */
"5380" = "1" /* THOR REP-DIAPH HERN NOS */
"5381" = "1" /* DIAPHRAGMATIC PLICATION */
"5382" = "1" /* PARASTERN HERNIA REPAIR */
"5383" = "1" /* LAP THORC APP-DIAPH HERN */
"5384" = "1" /* OPN THORC DIAPH HERN NEC */
"539 " = "1" /* OTHER HERNIA REPAIR */
"540 " = "1" /* ABDOMINAL WALL INCISION */
"5411" = "1" /* EXPLORATORY LAPAROTOMY */
"5412" = "1" /* REOPEN RECENT LAP SITE */
"5419" = "1" /* LAPAROTOMY NEC */
"5421" = "1" /* LAPAROSCOPY */
"5422" = "1" /* ABDOMINAL WALL BIOPSY */
"5423" = "1" /* PERITONEAL BIOPSY */
"5429" = "1" /* ABD REGION DX PROC NEC */
"543 " = "1" /* DESTRUCT ABD WALL LESION */
"544 " = "1" /* DESTRUCT PERITONEAL TISS */
"545 " = "1" /* DESTRUCT PERITONEAL TISS */
"5451" = "1" /* LAP PERITON ADHESIOLYSIS */
"5459" = "1" /* OTH PERITON ADHESIOLYSIS */
"5461" = "1" /* RECLOSE POST OP DISRUPT */
"5462" = "1" /* DELAYED CLOS ABD WOUND */
"5463" = "1" /* ABD WALL SUTURE NEC */
"5464" = "1" /* PERITONEAL SUTURE */
"5471" = "1" /* REPAIR OF GASTROSCHISIS */
"5472" = "1" /* ABDOMEN WALL REPAIR NEC */
"5473" = "1" /* PERITONEAL REPAIR NEC */
"5474" = "1" /* OMENTAL REPAIR NEC */
"5475" = "1" /* MESENTERIC REPAIR NEC */
"5492" = "1" /* REMOVE FB FROM PERITON */
"5493" = "1" /* CREATE CUTANPERITON FIST */
"5494" = "1" /* CREAT PERITONEOVAS SHUNT */
"5495" = "1" /* PERITONEAL INCISION */
"5501" = "1" /* NEPHROTOMY */
"5502" = "1" /* NEPHROSTOMY */
"5503" = "1" /* PERCU NEPHROSTM W/O FRAG */
"5504" = "1" /* PERCU NEPHROSTMY W FRAG */
"5511" = "1" /* PYELOTOMY */
"5512" = "1" /* PYELOSTOMY */
"5524" = "1" /* OPEN RENAL BIOPSY */
"5529" = "1" /* RENAL DIAGNOST PROC NEC */
"5531" = "1" /* RENAL LES MARSUPIALIZAT */
"5532" = "1" /* OPN ABLTN RENAL LES/TISS */
"5533" = "1" /* PERC ABLTN RENL LES/TISS */
"5534" = "1" /* LAP ABLTN RENAL LES/TISS */
"5535" = "1" /* ABLTN RENAL LES/TISS NEC */
"5539" = "1" /* LOC DESTR RENAL LES NEC */
"554 " = "1" /* PARTIAL NEPHRECTOMY */
"5551" = "1" /* NEPHROURETERECTOMY */
"5552" = "1" /* SOLITARY KIDNEY NEPHRECT */
"5553" = "1" /* REJECTED KIDNEY NEPHRECT */
"5554" = "1" /* BILATERAL NEPHRECTOMY */
"5561" = "1" /* RENAL AUTOTRANSPLANT */
"5569" = "1" /* KIDNEY TRANSPLANT NEC */
"557 " = "1" /* NEPHROPEXY */
"5581" = "1" /* SUTURE KIDNEY LACERATION */
"5582" = "1" /* CLOSE NEPHROST & PYELOST */
"5583" = "1" /* CLOSE RENAL FISTULA NEC */
"5584" = "1" /* REDUCE RENAL PEDICL TORS */
"5585" = "1" /* SYMPHYSIOTOMY */
"5586" = "1" /* RENAL ANASTOMOSIS */
"5587" = "1" /* CORRECT URETEROPELV JUNC */
"5589" = "1" /* RENAL REPAIR NEC */
"5591" = "1" /* RENAL DECAPSULATION */
"5597" = "1" /* IMPLANT MECHANIC KIDNEY */
"5598" = "1" /* REMOV MECHANICAL KIDNEY */
"5599" = "1" /* RENAL OPERATION NEC */
"560 " = "1" /* TU REMOV URETER OBSTRUCT */
"561 " = "1" /* URETERAL MEATOTOMY */
"562 " = "1" /* URETEROTOMY */
"5634" = "1" /* OPEN URETERAL BIOPSY */
"5639" = "1" /* URETERAL DX PROCEDUR NEC */
"5640" = "1" /* URETERECTOMY NOS */
"5641" = "1" /* PARTIAL URETERECTOMY */
"5642" = "1" /* TOTAL URETERECTOMY */
"5651" = "1" /* FORM CUTAN ILEOURETEROST */
"5652" = "1" /* REVIS CUTAN ILEOURETEROS */
"5661" = "1" /* FORM CUTAN URETEROSTOMY */
"5662" = "1" /* REVIS CUTAN URETEROS NEC */
"5671" = "1" /* URIN DIVERSION TO BOWEL */
"5672" = "1" /* REVIS URETEROENTEROSTOMY */
"5673" = "1" /* NEPHROCYSTANASTOMOSI NOS */
"5674" = "1" /* URETERONEOCYSTOSTOMY */
"5675" = "1" /* TRANSURETEROURETEROSTOMY */
"5679" = "1" /* URETERAL ANASTOMOSIS NEC */
"5681" = "1" /* INTRALUM URETE ADHESIOLY */
"5682" = "1" /* SUTURE URETERAL LACERAT */
"5683" = "1" /* URETEROSTOMY CLOSURE */
"5684" = "1" /* CLOSE URETER FISTULA NEC */
"5685" = "1" /* URETEROPEXY */
"5686" = "1" /* REMOVE URETERAL LIGATURE */
"5689" = "1" /* REPAIR OF URETER NEC */
"5692" = "1" /* IMPLANT URETERAL STIMUL */
"5693" = "1" /* REPLACE URETERAL STIMUL */
"5694" = "1" /* REMOVE URETERAL STIMULAT */
"5695" = "1" /* LIGATION OF URETER */
"5699" = "1" /* URETERAL OPERATION NEC */
"5712" = "1" /* CYSTOTOMY & ADHESIOLYSIS */
"5718" = "1" /* OTHER SUPRAPU CYSTOSTOMY */
"5719" = "1" /* CYSTOTOMY NEC */
"5721" = "1" /* VESICOSTOMY */
"5722" = "1" /* REVISE CLO VESICOSTOMY */
"5733" = "1" /* CLOS TRANSURETH BLADD BX */
"5734" = "1" /* OPEN BLADDER BIOPSY */
"5739" = "1" /* BLADDER DIAGNOS PROC NEC */
"5741" = "1" /* TU ADHESIOLYSIS BLADDER */
"5749" = "1" /* TU DESTRUC BLADD LES NEC */
"5751" = "1" /* EXCISION OF URACHUS */
"5759" = "1" /* BLADDER LES DESTRUCT NEC */
"576 " = "1" /* PARTIAL CYSTECTOMY */
"5771" = "1" /* RADICAL CYSTECTOMY */
"5779" = "1" /* TOTAL CYSTECTOMY NEC */
"5781" = "1" /* SUTURE BLADDER LACERAT */
"5782" = "1" /* CYSTOSTOMY CLOSURE */
"5783" = "1" /* ENTEROVESICO FIST REPAIR */
"5784" = "1" /* VESIC FISTULA REPAIR NEC */
"5785" = "1" /* CYSTOURETHROPLASTY */
"5786" = "1" /* BLADDER EXSTROPHY REPAIR */
"5787" = "1" /* BLADDER RECONSTRUCTION */
"5788" = "1" /* BLADDER ANASTOMOSIS NEC */
"5789" = "1" /* BLADDER REPAIR NEC */
"5791" = "1" /* BLADDER SPHINCTEROTOMY */
"5793" = "1" /* CONTROL BLADD HEMORRHAGE */
"5796" = "1" /* IMPLANT BLADDER STIMULAT */
"5797" = "1" /* REPLACE BLADDER STIMULAT */
"5798" = "1" /* REMOVE BLADDER STIMULAT */
"5799" = "1" /* BLADDER OPERATION NEC */
"580 " = "1" /* URETHROTOMY */
"581 " = "1" /* URETHRAL MEATOTOMY */
"5841" = "1" /* SUTURE URETHRAL LACERAT */
"5842" = "1" /* URETHROSTOMY CLOSURE */
"5843" = "1" /* CLOSE URETH FISTULA NEC */
"5844" = "1" /* URETHRAL REANASTOMOSIS */
"5845" = "1" /* HYPO-EPISPADIUS REPAIR */
"5846" = "1" /* URETH RECONSTRUCTION NEC */
"5847" = "1" /* URETHRAL MEATOPLASTY */
"5849" = "1" /* URETHRAL REPAIR NEC */
"585 " = "1" /* URETH STRICTURE RELEASE */
"5891" = "1" /* PERIURETHRAL INCISION */
"5892" = "1" /* PERIURETHRAL EXCISION */
"5893" = "1" /* IMPLT ARTF URIN SPHINCT */
"5899" = "1" /* URETH/PERIURETH OP NEC */
"5900" = "1" /* RETROPERIT DISSECT NOS */
"5901" = "1" /* RETROPERIT DISSECT NOS */
"5902" = "1" /* PERIREN ADHESIOLYS NEC */
"5903" = "1" /* LAP LYS PERIREN/URET ADH */
"5909" = "1" /* PERIREN/URETER INCIS NEC */
"5911" = "1" /* OTH LYS PERIVES ADHESIO */
"5912" = "1" /* LAP LYS PERIVESURETH ADH */
"5919" = "1" /* PERIVESICAL INCISION NEC */
"5921" = "1" /* PERIREN/URETERAL BIOPSY */
"5929" = "1" /* PERIREN/URET DX PROC NEC */
"593 " = "1" /* URETHROVES JUNCT PLICAT */
"594 " = "1" /* SUPRAPUBIC SLING OP */
"595 " = "1" /* RETROPUBIC URETH SUSPENS */
"596 " = "1" /* PARAURETHRAL SUSPENSION */
"5971" = "1" /* LEVATOR MUSC SUSPENSION */
"5979" = "1" /* URIN INCONTIN REPAIR NEC */
"5991" = "1" /* PERIREN/VESICLE EXCISION */
"5992" = "1" /* PERIREN/VESICLE OP NEC */
"600 " = "1" /* INCISION OF PROSTATE */
"6012" = "1" /* OPEN PROSTATIC BIOPSY */
"6014" = "1" /* OPEN SEMINAL VESICLES BX */
"6015" = "1" /* PERIPROSTATIC BIOPSY */
"6018" = "1" /* PROSTATIC DX PROCED NEC */
"6019" = "1" /* SEMIN VES DX PROCED NEC */
"602 " = "1" /* SEMIN VES DX PROCED NEC */
"6021" = "1" /* TRANSURETH PROSTATECTOMY */
"6029" = "1" /* OTH TRANSURETH PROSTATEC */
"603 " = "1" /* SUPRAPUBIC PROSTATECTOMY */
"604 " = "1" /* RETROPUBIC PROSTATECTOMY */
"605 " = "1" /* RADICAL PROSTATECTOMY */
"6061" = "1" /* LOS EXCIS PROSTATIC LES */
"6062" = "1" /* PERINEAL PROSTATECTOMY */
"6069" = "1" /* PROSTATECTOMY NEC */
"6072" = "1" /* SEMINAL VESICLE INCISION */
"6073" = "1" /* SEMINAL VESICLE EXCISION */
"6079" = "1" /* SEMINAL VESICLE OP NEC */
"6081" = "1" /* PERIPROSTATIC INCISION */
"6082" = "1" /* PERIPROSTATIC EXCISION */
"6093" = "1" /* REPAIR OF PROSTATE */
"6094" = "1" /* CONTROL PROSTATE HEMORR */
"6095" = "1" /* TRANS BAL DIL PROS URETH */
"6096" = "1" /* TU DESTR PROSTATE BY MT */
"6097" = "1" /* OTH TU DESTR PROS - RT */
"6099" = "1" /* PROSTATIC OPERATION NEC */
"612 " = "1" /* EXCISION OF HYDROCELE */
"6142" = "1" /* SCROTAL FISTULA REPAIR */
"6149" = "1" /* SCROTUM/TUNIC REPAIR NEC */
"6192" = "1" /* EXCISION TUNICA LES NEC */
"6199" = "1" /* SCROTUM & TUNICA OP NEC */
"620 " = "1" /* INCISION OF TESTES */
"6212" = "1" /* OPEN TESTICULAR BIOPSY */
"6219" = "1" /* TESTES DX PROCEDURE NEC */
"622 " = "1" /* TESTICULAR LES DESTRUCT */
"623 " = "1" /* UNILATERAL ORCHIECTOMY */
"6241" = "1" /* REMOVE BOTH TESTES */
"6242" = "1" /* REMOVE SOLITARY TESTIS */
"625 " = "1" /* ORCHIOPEXY */
"6261" = "1" /* SUTURE TESTICULAR LACER */
"6269" = "1" /* TESTICULAR REPAIR NEC */
"627 " = "1" /* INSERT TESTICULAR PROSTH */
"6299" = "1" /* TESTICULAR OPERATION NEC */
"6309" = "1" /* SPERMAT CORD/VAS DX NEC */
"631 " = "1" /* EXC SPERMATIC VARICOCELE */
"632 " = "1" /* EXCISE EPIDIDYMIS CYST */
"633 " = "1" /* EXCISE CORD/EPID LES NEC */
"634 " = "1" /* EPIDIDYMECTOMY */
"6351" = "1" /* SUTURE CORD & EPID LACER */
"6353" = "1" /* TRANSPLANT SPERMAT CORD */
"6359" = "1" /* CORD & EPIDID REPAIR NEC */
"6381" = "1" /* SUTURE VAS & EPIDID LAC */
"6382" = "1" /* POSTOP VAS RECONSTRUCT */
"6383" = "1" /* EPIDIDYMOVASOSTOMY */
"6385" = "1" /* REMOV VAS DEFERENS VALVE */
"6389" = "1" /* VAS & EPIDIDY REPAIR NEC */
"6392" = "1" /* EPIDIDYMOTOMY */
"6393" = "1" /* SPERMATIC CORD INCISION */
"6394" = "1" /* SPERM CORD ADHESIOLYSIS */
"6395" = "1" /* INSERT VALVE IN VAS DEF */
"6399" = "1" /* CORD/EPID/VAS OPS NEC */
"6411" = "1" /* PENILE BIOPSY */
"642 " = "1" /* LOCAL EXCIS PENILE LES */
"643 " = "1" /* AMPUTATION OF PENIS */
"6441" = "1" /* SUTURE PENILE LACERATION */
"6442" = "1" /* RELEASE OF CHORDEE */
"6443" = "1" /* CONSTRUCTION OF PENIS */
"6444" = "1" /* RECONSTRUCTION OF PENIS */
"6445" = "1" /* REPLANTATION OF PENIS */
"6449" = "1" /* PENILE REPAIR NEC */
"645 " = "1" /* SEX TRANSFORMAT OP NEC */
"6492" = "1" /* INCISION OF PENIS */
"6493" = "1" /* DIVISION OF PENILE ADHES */
"6495" = "1" /* INS NONINFL PENIS PROSTH */
"6496" = "1" /* REMOVE INT PENILE PROSTH */
"6497" = "1" /* INS INFLATE PENIS PROSTH */
"6498" = "1" /* PENILE OPERATION NEC */
"6499" = "1" /* MALE GENITAL OP NEC */
"650 " = "1" /* MALE GENITAL OP NEC */
"6501" = "1" /* LAPAROSCOPIC OOPHOROTOMY */
"6509" = "1" /* OTHER OOPHOROTOMY */
"6511" = "1" /* OVARIAN ASPIRAT BIOPSY */
"6512" = "1" /* OVARIAN BIOPSY NEC */
"6513" = "1" /* LAP BIOPSY OF OVARY */
"6514" = "1" /* OTH LAP DX PROC OVARIES */
"6519" = "1" /* OVARIAN DX PROCEDURE NEC */
"6521" = "1" /* OVARIAN CYST MARSUPIALIZ */
"6522" = "1" /* OVARIAN WEDGE RESECTION */
"6523" = "1" /* LAP MARSUP OVARIAN CYST */
"6524" = "1" /* LAP WEDGE RESECT OVARY */
"6525" = "1" /* OTH LAP LOC EXC DEST OVA */
"6529" = "1" /* LOCAL DESTR OVA LES NEC */
"653 " = "1" /* LOCAL DESTR OVA LES NEC */
"6531" = "1" /* LAP UNILAT OOPHORECTOMY */
"6539" = "1" /* OTH UNILAT OOPHORECTOMY */
"654 " = "1" /* OTH UNILAT OOPHORECTOMY */
"6541" = "1" /* LAP UNI SALPINGO-OOPHOR */
"6549" = "1" /* OTH UNI SALPINGO-OOPHOR */
"6551" = "1" /* OTH REMOVE BOTH OVARIES */
"6552" = "1" /* OTH REMOVE REMAIN OVARY */
"6553" = "1" /* LAP REMOVE BOTH OVARIES */
"6554" = "1" /* LAP REMOVE REMAIN OVARY */
"6561" = "1" /* OTH REMOVE OVARIES/TUBES */
"6562" = "1" /* OTH REMOVE REM OVA/TUBE */
"6563" = "1" /* LAP REMOVE OVARIES/TUBES */
"6564" = "1" /* LAP REMOVE REM OVA/TUBE */
"6571" = "1" /* OTH SIMPLE SUTURE OVARY */
"6572" = "1" /* OTH REIMPLANT OF OVARY */
"6573" = "1" /* OTH SALPINGO-OOPHOROPLAS */
"6574" = "1" /* LAP SIMPLE SUTURE OVARY */
"6575" = "1" /* LAP REIMPLANT OF OVARY */
"6576" = "1" /* LAP SALPINGO-OOPHOROPLAS */
"6579" = "1" /* REPAIR OF OVARY NEC */
"658 " = "1" /* REPAIR OF OVARY NEC */
"6581" = "1" /* LAP ADHESIOLYS OVA/TUBE */
"6589" = "1" /* ADHESIOLYSIS OVARY/TUBE */
"6591" = "1" /* ASPIRATION OF OVARY */
"6592" = "1" /* TRANSPLANTATION OF OVARY */
"6593" = "1" /* MANUAL RUPT OVARIAN CYST */
"6594" = "1" /* OVARIAN DENERVATION */
"6595" = "1" /* OVARIAN TORSION RELEASE */
"6599" = "1" /* OVARIAN OPERATION NEC */
"660 " = "1" /* OVARIAN OPERATION NEC */
"6601" = "1" /* SALPINGOTOMY */
"6602" = "1" /* SALPINGOSTOMY */
"6611" = "1" /* FALLOPIAN TUBE BIOPSY */
"6619" = "1" /* FALLOP TUBE DX PROC NEC */
"6621" = "1" /* BILAT ENDOSC CRUSH TUBE */
"6622" = "1" /* BILAT ENDOSC DIVIS TUBE */
"6629" = "1" /* BILAT ENDOS OCC TUBE NEC */
"6631" = "1" /* BILAT TUBAL CRUSHING NEC */
"6632" = "1" /* BILAT TUBAL DIVISION NEC */
"6639" = "1" /* BILAT TUBAL DESTRUCT NEC */
"664 " = "1" /* TOTAL UNILAT SALPINGECT */
"6651" = "1" /* REMOVE BOTH FALLOP TUBES */
"6652" = "1" /* REMOVE SOLITARY FAL TUBE */
"6661" = "1" /* DESTROY FALLOP TUBE LES */
"6662" = "1" /* REMOV TUBE & ECTOP PREG */
"6663" = "1" /* BILAT PART SALPINGEC NOS */
"6669" = "1" /* PARTIAL SALPINGECTOM NEC */
"6671" = "1" /* SIMPL SUTURE FALLOP TUBE */
"6672" = "1" /* SALPINGO-OOPHOROSTOMY */
"6673" = "1" /* SALPINGO-SALPINGOSTOMY */
"6674" = "1" /* SALPINGO-UTEROSTOMY */
"6679" = "1" /* FALLOP TUBE REPAIR NEC */
"6692" = "1" /* UNILAT FALLOP TUBE DESTR */
"6693" = "1" /* IMPL FALLOP TUBE PROSTH */
"6694" = "1" /* REMOV FALLOP TUBE PROSTH */
"6695" = "1" /* BLOW THERAPEUT INTO TUBE */
"6696" = "1" /* FALLOPIAN TUBE DILATION */
"6697" = "1" /* BURY FIMBRIAE IN UTERUS */
"6699" = "1" /* FALLOPIAN TUBE OP NEC */
"6711" = "1" /* ENDOCERVICAL BIOPSY */
"6712" = "1" /* CERVICAL BIOPSY NEC */
"6719" = "1" /* CERVICAL DX PROCEDUR NEC */
"672 " = "1" /* CONIZATION OF CERVIX */
"6731" = "1" /* CERVICAL CYST MARSUPIAL */
"6732" = "1" /* CERVICAL LES CAUTERIZAT */
"6733" = "1" /* CERVICAL LES CRYOTHERAPY */
"6739" = "1" /* CERVICAL LES DESTRUC NEC */
"674 " = "1" /* AMPUTATION OF CERVIX */
"675 " = "1" /* AMPUTATION OF CERVIX */
"6751" = "1" /* TRANSAB CERCLAGE CERVIX */
"6759" = "1" /* OTH REP INT CERVICAL OS */
"6761" = "1" /* SUTURE CERVICAL LACERAT */
"6762" = "1" /* CERVICAL FISTULA REPAIR */
"6769" = "1" /* CERVICAL REPAIR NEC */
"680 " = "1" /* HYSTEROTOMY */
"6813" = "1" /* OPEN UTERINE BIOPSY */
"6814" = "1" /* OPEN UTERINE LIGAMENT BX */
"6815" = "1" /* CLOS UTERINE LIGAMENT BX */
"6816" = "1" /* CLOSED UTERINE BIOPSY */
"6819" = "1" /* UTERUS/ADNEX DX PROC NEC */
"6821" = "1" /* ENDOMET SYNECHIAE DIVIS */
"6822" = "1" /* INCISION UTERINE SEPTUM */
"6823" = "1" /* ENDOMETRIAL ABLATION */
"6824" = "1" /*	UTERINE ARTERY EMBOLIZATION [UAE] WITH COILS */
"6825" = "1" /*	UTERINE ARTERY EMBOLIZATION [UAE] WITHOUT COILS  */
"6829" = "1" /* UTERINE LES DESTRUCT NEC */
"683 " = "1" /* UTERINE LES DESTRUCT NEC */
"6831" = "1" /* LAP SCERVIC HYSTERECTOMY */
"6839" = "1" /* OTH SUBTOT ABD HYSTERECT */
"684 " = "1" /* TOTAL ABD HYSTERECTOMY */
"6841" = "1" /* LAP TOTAL ABDOMINAL HYST */
"6849" = "1" /* TOTAL ABD HYST NEC/NOS */
"685 " = "1" /* TOTAL ABD HYSTERECTOMY */
"6851" = "1" /* LAP AST VAG HYSTERECTOMY */
"6859" = "1" /* OTHER VAG HYSTERECTOMY */
"686 " = "1" /* RADICAL ABD HYSTERECTOMY */
"6861" = "1" /* LAP RADICAL ABDOMNL HYST */
"6869" = "1" /* RADICAL ABD HYST NEC/NOS */
"687 " = "1" /* RADICAL VAG HYSTERECTOMY */
"6871" = "1" /* LAP RADICAL VAGINAL HYST */
"6879" = "1" /* RADICAL VAG HYST NEC/NOS */
"688 " = "1" /* PELVIC EVISCERATION */
"689 " = "1" /* HYSTERECTOMY NEC/NOS */
"6901" = "1" /* D & C FOR PREG TERMINAT */
"6902" = "1" /* D & C POST DELIVERY */
"6909" = "1" /* D & C NEC */
"6911" = "1" /* D & C NEC */
"6919" = "1" /* DESTRUC UTER SUPPORT NEC */
"6921" = "1" /* INTERPOSIT OP UTERIN LIG */
"6922" = "1" /* UTERINE SUSPENSION NEC */
"6923" = "1" /* VAG REPAIR INVERS UTERUS */
"6929" = "1" /* UTERUS/ADNEXA REPAIR NEC */
"693 " = "1" /* PARACERV UTERINE DENERV */
"6941" = "1" /* SUTURE UTERINE LACERAT */
"6942" = "1" /* CLOSURE UTERINE FISTULA */
"6949" = "1" /* UTERINE REPAIR NEC */
"6951" = "1" /* ASPIRAT CURET-PREG TERMI */
"6952" = "1" /* ASPIRAT CURET-POST DELIV */
"6995" = "1" /* INCISION OF CERVIX */
"6997" = "1" /* REMOVE PENETRAT CERV FB */
"6998" = "1" /* UTERINE SUPPORT OP NEC */
"6999" = "1" /* UTERINE OPERATION NEC */
"7012" = "1" /* CULDOTOMY */
"7013" = "1" /* INTRALUM VAG ADHESIOLYS */
"7014" = "1" /* VAGINOTOMY NEC */
"7023" = "1" /* CUL-DE-SAC BIOPSY */
"7024" = "1" /* VAGINAL BIOPSY */
"7029" = "1" /* VAGIN/CUL-DE-SAC DX NEC */
"7031" = "1" /* HYMENECTOMY */
"7032" = "1" /* EXCIS CUL-DE-SAC LESION */
"7033" = "1" /* EXCISION VAGINAL LESION */
"704 " = "1" /* VAGINAL OBLITERATION */
"7050" = "1" /* CYSTOCEL/RECTOCEL REPAIR */
"7051" = "1" /* CYSTOCELE REPAIR */
"7052" = "1" /* RECTOCELE REPAIR */
"7053" = "1" /* CYSTO & RECTO W GRF/PROS */
"7054" = "1" /* REP CYSTOCEL W GRFT/PROS */
"7055" = "1" /* REP RECTOCELE W GRF/PROS */
"7061" = "1" /* VAGINAL CONSTRUCTION */
"7062" = "1" /* VAGINAL RECONSTRUCTION */
"7063" = "1" /* VAGINAL CONST W GRF/PROS */
"7064" = "1" /* VAG RECONST W GRFT/PROS */
"7071" = "1" /* SUTURE VAGINA LACERATION */
"7072" = "1" /* REPAIR COLOVAGIN FISTULA */
"7073" = "1" /* REPAIR RECTOVAG FISTULA */
"7074" = "1" /* REP VAGINOENT FISTUL NEC */
"7075" = "1" /* REPAIR VAG FISTULA NEC */
"7076" = "1" /* HYMENORRHAPHY */
"7077" = "1" /* VAGINAL SUSPENS & FIXAT */
"7078" = "1" /* VAG SUSP/FIX W GRFT/PROS */
"7079" = "1" /* VAGINAL REPAIR NEC */
"708 " = "1" /* VAGINAL VAULT OBLITERAT */
"7091" = "1" /* VAGINAL OPERATION NEC */
"7092" = "1" /* CUL-DE-SAC OPERATION NEC */
"7093" = "1" /* CUL-DE-SAC GRF/PROS NEC */
"7101" = "1" /* VULVAR ADHESIOLYSIS */
"7109" = "1" /* INCIS VULVA/PERINEUM NEC */
"7111" = "1" /* VULVAR BIOPSY */
"7119" = "1" /* VULVAR DIAGNOS PROC NEC */
"7122" = "1" /* INCISE BARTHOLIN"S GLAND */
"7123" = "1" /* BARTHOLIN GLAND MARSUP */
"7124" = "1" /* DESTRUC BARTHOLIN GLAND */
"7129" = "1" /* BARTHOLIN"S GLAND OP NEC */
"713 " = "1" /* LOCAL VULVAR EXCIS NEC */
"714 " = "1" /* OPERATIONS ON CLITORIS */
"715 " = "1" /* RADICAL VULVECTOMY */
"7161" = "1" /* UNILATERAL VULVECTOMY */
"7162" = "1" /* BILATERAL VULVECTOMY */
"7171" = "1" /* SUTURE VULVAR LACERATION */
"7172" = "1" /* REPAIR VULVAR FISTULA */
"7179" = "1" /* VULVAR/PERIN REPAIR NEC */
"718 " = "1" /* OTHER VULVAR OPERATIONS */
"719 " = "1" /* OTHER FEMALE GENITAL OPS */
"7394" = "1" /* PUBIOTOMY TO ASSIST DEL */
"7399" = "1" /* OPS ASSISTING DELIV NEC */
"740 " = "1" /* CLASSICAL C-SECTION */
"741 " = "1" /* LOW CERVICAL C-SECTION */
"742 " = "1" /* EXTRAPERITONEAL C-SECT */
"743 " = "1" /* REM EXTRATUB ECTOP PREG */
"744 " = "1" /* CESAREAN SECTION NEC */
"7491" = "1" /* HYSTEROTOMY TO TERMIN PG */
"7499" = "1" /* CESAREAN SECTION NOS */
"7536" = "1" /* CORRECTION FETAL DEFECT */
"7550" = "1" /* REPAIR OB LAC UTERUS NOS */
"7551" = "1" /* REPAIR OB LACERAT CERVIX */
"7552" = "1" /* REPAIR OB LAC CORP UTERI */
"7561" = "1" /* REPAIR OB LAC BLAD/URETH */
"7593" = "1" /* SURG CORR INVERT UTERUS */
"7599" = "1" /* OBSTETRIC OPERATION NEC */
"7601" = "1" /* FACIAL BONE SEQUESTRECT */
"7609" = "1" /* FACIAL BONE INCISION NEC */
"7611" = "1" /* FACIAL BONE BIOPSY */
"7619" = "1" /* FACIAL BONE DX PROC NEC */
"762 " = "1" /* DESTRUCT FACIAL BONE LES */
"7631" = "1" /* PARTIAL MANDIBULECTOMY */
"7639" = "1" /* PART FACIAL OSTECTOM NEC */
"7641" = "1" /* TOT MANDIBULEC W RECONST */
"7642" = "1" /* TOTAL MANDIBULECTOMY NEC */
"7643" = "1" /* MANDIBULAR RECONST NEC */
"7644" = "1" /* TOT FACE OSTECT W RECONS */
"7645" = "1" /* TOT FACE BONE OSTECT NEC */
"7646" = "1" /* FACIAL BONE RECONSTR NEC */
"765 " = "1" /* TEMPOROMAND ARTHROPLASTY */
"7661" = "1" /* CL OSTEOPLASTY MAND RAMI */
"7662" = "1" /* OPEN OSTEOPLAS MAND RAMI */
"7663" = "1" /* OSTEOPLASTY MANDIBLE BDY */
"7664" = "1" /* MAND ORTHOGNATHIC OP NEC */
"7665" = "1" /* SEG OSTEOPLASTY MAXILLA */
"7666" = "1" /* TOT OSTEOPLASTY MAXILLA */
"7667" = "1" /* REDUCTION GENIOPLASTY */
"7668" = "1" /* AUGMENTATION GENIOPLASTY */
"7669" = "1" /* FACIAL BONE REPAIR NEC */
"7670" = "1" /* REDUCTION FACIAL FX NOS */
"7672" = "1" /* OPN REDUCT MALAR/ZYGO FX */
"7674" = "1" /* OPEN REDUCT MAXILLARY FX */
"7676" = "1" /* OPEN REDUCT MANDIBLE FX */
"7677" = "1" /* OPEN REDUCT ALVEOLAR FX */
"7679" = "1" /* OPEN REDUCT FACE FX NEC */
"7691" = "1" /* BONE GRAFT TO FACE BONE */
"7692" = "1" /* SYN IMPLANT TO FACE BONE */
"7694" = "1" /* OPEN REDUCT TM DISLOCAT */
"7697" = "1" /* REMOVE INT FIX FACE BONE */
"7699" = "1" /* FACIAL BONE/JNT OP NEC */
"7700" = "1" /* SEQUESTRECTOMY NOS */
"7701" = "1" /* CHEST CAGE SEQUESTREC */
"7702" = "1" /* HUMERUS SEQUESTRECTOMY */
"7703" = "1" /* RADIUS & ULNA SEQUESTREC */
"7704" = "1" /* METACARP/CARP SEQUESTREC */
"7705" = "1" /* FEMORAL SEQUESTRECTOMY */
"7706" = "1" /* PATELLAR SEQUESTRECTOMY */
"7707" = "1" /* TIBIA/FIBULA SEQUESTREC */
"7708" = "1" /* METATAR/TAR SEQUESTREC */
"7709" = "1" /* SEQUESTRECTOMY NEC */
"7710" = "1" /* OTHER BONE INCISION NOS */
"7711" = "1" /* OTHER CHEST CAGE INCIS */
"7712" = "1" /* OTHER HUMERUS INCISION */
"7713" = "1" /* OTHER RADIUS/ULNA INCIS */
"7714" = "1" /* OTH METACARP/CARP INCIS */
"7715" = "1" /* OTHER FEMORAL INCISION */
"7716" = "1" /* OTHER PATELLAR INCISION */
"7717" = "1" /* OTHER TIBIA/FIBULA INCIS */
"7718" = "1" /* OTH METATARS/TARS INCIS */
"7719" = "1" /* BONE INCIS W/O DIV NEC */
"7720" = "1" /* WEDGE OSTEOTOMY NOS */
"7721" = "1" /* CHEST CAGE WEDG OSTEOTOM */
"7722" = "1" /* HUMERUS WEDGE OSTEOTOMY */
"7723" = "1" /* RADIUS/ULNA WEDG OSTEOTO */
"7724" = "1" /* METACAR/CAR WEDG OSTEOTO */
"7725" = "1" /* FEMORAL WEDGE OSTEOTOMY */
"7726" = "1" /* PATELLAR WEDGE OSTEOTOMY */
"7727" = "1" /* TIBIA/FIBUL WEDG OSTEOT */
"7728" = "1" /* METATAR/TAR WEDG OSTEOT */
"7729" = "1" /* WEDGE OSTEOTOMY NEC */
"7730" = "1" /* OTHER BONE DIVISION NOS */
"7731" = "1" /* CHEST CAGE BONE DIV NEC */
"7732" = "1" /* HUMERUS DIVISION NEC */
"7733" = "1" /* RADIUS/ULNA DIVISION NEC */
"7734" = "1" /* METACAR/CAR DIVISION NEC */
"7735" = "1" /* FEMORAL DIVISION NEC */
"7736" = "1" /* PATELLAR DIVISION NEC */
"7737" = "1" /* TIBIA/FIBULA DIV NEC */
"7738" = "1" /* METATAR/TAR DIVISION NEC */
"7739" = "1" /* BONE DIVISION NEC */
"7740" = "1" /* BONE BIOPSY NOS */
"7741" = "1" /* CHEST CAGE BONE BIOPSY */
"7742" = "1" /* HUMERUS BIOPSY */
"7743" = "1" /* RADIUS & ULNA BIOPSY */
"7744" = "1" /* METACARPAL/CARPAL BIOPSY */
"7745" = "1" /* FEMORAL BIOPSY */
"7746" = "1" /* PATELLAR BIOPSY */
"7747" = "1" /* TIBIA & FIBULA BIOPSY */
"7748" = "1" /* METATARSAL/TARSAL BIOPSY */
"7749" = "1" /* BONE BIOPSY NEC */
"7751" = "1" /* BUNIONECT/SFT/OSTEOTOMY */
"7752" = "1" /* BUNIONECT/SFT/ARTHRODES */
"7753" = "1" /* OTH BUNIONECT W SFT CORR */
"7754" = "1" /* EXC CORRECT BUNIONETTE */
"7756" = "1" /* REPAIR OF HAMMER TOE */
"7757" = "1" /* REPAIR OF CLAW TOE */
"7758" = "1" /* OTH EXC, FUS, REPAIR TOE */
"7759" = "1" /* BUNIONECTOMY NEC */
"7760" = "1" /* LOC EXC BONE LESION NOS */
"7761" = "1" /* EXC CHEST CAGE BONE LES */
"7762" = "1" /* LOC EXC BONE LES HUMERUS */
"7763" = "1" /* LOC EXC LES RADIUS/ULNA */
"7764" = "1" /* LOC EXC LES METACAR/CAR */
"7765" = "1" /* LOC EXC BONE LES FEMUR */
"7766" = "1" /* LOC EXC BONE LES PATELLA */
"7767" = "1" /* LOC EXC LES TIBIA/FIBULA */
"7768" = "1" /* LOC EXC LES METATAR/TAR */
"7769" = "1" /* LOC EXC BONE LESION NEC */
"7770" = "1" /* EXCISE BONE FOR GRFT NOS */
"7771" = "1" /* EX CHEST CAGE BONE-GFT */
"7772" = "1" /* EXCISE HUMERUS FOR GRAFT */
"7773" = "1" /* EXCIS RADIUS/ULNA-GRAFT */
"7774" = "1" /* EXCIS METACAR/CAR-GRAFT */
"7775" = "1" /* EXCISE FEMUR FOR GRAFT */
"7776" = "1" /* EXCISE PATELLA FOR GRAFT */
"7777" = "1" /* EXCISE TIB/FIB FOR GRAFT */
"7778" = "1" /* EXCIS METATAR/TAR-GRAFT */
"7779" = "1" /* EXCISE BONE FOR GFT NEC */
"7780" = "1" /* OTH PART OSTECTOMY NOS */
"7781" = "1" /* OTH CHEST CAGE OSTECTOMY */
"7782" = "1" /* PARTIAL HUMERECTOMY NEC */
"7783" = "1" /* PART OSTECT-RADIUS/ULNA */
"7784" = "1" /* PART OSTECT-METACAR/CAR */
"7785" = "1" /* PART OSTECTOMY-FEMUR */
"7786" = "1" /* PARTIAL PATELLECTOMY */
"7787" = "1" /* PART OSTECT-TIBIA/FIBULA */
"7788" = "1" /* PART OSTECT-METATAR/TAR */
"7789" = "1" /* PARTIAL OSTECTOMY NEC */
"7790" = "1" /* TOTAL OSTECTOMY NOS */
"7791" = "1" /* TOT CHEST CAGE OSTECTOMY */
"7792" = "1" /* TOTAL OSTECTOMY-HUMERUS */
"7793" = "1" /* TOT OSTECT-RADIUS/ULNA */
"7794" = "1" /* TOT OSTECT-METACARP/CARP */
"7795" = "1" /* TOT OSTECTOMY-FEMUR */
"7796" = "1" /* TOTAL PATELLECTOMY */
"7797" = "1" /* TOT OSTECT-TIBIA/FIBULA */
"7798" = "1" /* TOT OSTECT-METATARS/TARS */
"7799" = "1" /* TOTAL OSTECTOMY NEC */
"7800" = "1" /* BONE GRAFT NOS */
"7801" = "1" /* BONE GRAFT TO CHEST CAGE */
"7802" = "1" /* BONE GRAFT TO HUMERUS */
"7803" = "1" /* BONE GRAFT-RADIUS/ULNA */
"7804" = "1" /* BONE GRFT TO METACAR/CAR */
"7805" = "1" /* BONE GRAFT TO FEMUR */
"7806" = "1" /* BONE GRAFT TO PATELLA */
"7807" = "1" /* BONE GRAFT-TIBIA/FIBULA */
"7808" = "1" /* BONE GRAFT-METATAR/TAR */
"7809" = "1" /* BONE GRAFT NEC */
"7810" = "1" /* APPLIC EXT FIX DEV NOS */
"7811" = "1" /* APPL EXT FIX-CHEST CAGE */
"7812" = "1" /* APPLIC EXT FIX-HUMERUS */
"7813" = "1" /* APPL EXT FIX-RADIUS/ULNA */
"7814" = "1" /* APPL EXT FIX-METACAR/CAR */
"7815" = "1" /* APPLIC EXT FIX DEV-FEMUR */
"7816" = "1" /* APPL EXT FIX DEV-PATELLA */
"7817" = "1" /* APPL EXT FIX-TIB/FIBULA */
"7818" = "1" /* APPL EXT FIX-METATAR/TAR */
"7819" = "1" /* APPLIC EXT FIX DEV NEC */
"7820" = "1" /* LIMB SHORTEN PROC NOS */
"7822" = "1" /* LIMB SHORT PROC-HUMERUS */
"7823" = "1" /* LIMB SHORTEN-RADIUS/ULNA */
"7824" = "1" /* LIMB SHORTEN-METACAR/CAR */
"7825" = "1" /* LIMB SHORT PROC-FEMUR */
"7827" = "1" /* LIMB SHORTEN-TIB/FIBULA */
"7828" = "1" /* LIMB SHORTEN-METATAR/TAR */
"7829" = "1" /* LIMB SHORTEN PROC NEC */
"7830" = "1" /* LIMB LENGTHEN PROC NOS */
"7831" = "1" /* LIMB LENGTHEN PROC NOS */
"7832" = "1" /* LIMB LENGTH PROC-HUMERUS */
"7833" = "1" /* LIMB LENGTH-RADIUS/ULNA */
"7834" = "1" /* LIMB LENGTH-METACAR/CAR */
"7835" = "1" /* LIMB LENGTH PROC-FEMUR */
"7837" = "1" /* LIMB LENGTHEN-TIB/FIBULA */
"7838" = "1" /* LIMB LENGTHN-METATAR/TAR */
"7839" = "1" /* LIMB LENGTHEN PROC NEC */
"7840" = "1" /* OTH BONE REPAIR/PLAST OP */
"7841" = "1" /* OTH CHEST CAGE REP/PLAST */
"7842" = "1" /* OTH HUMERUS REPAIR/PLAST */
"7843" = "1" /* OTH RAD/ULN REPAIR/PLAST */
"7844" = "1" /* OTH METAC/CARP REP/PLAST */
"7845" = "1" /* OTH FEMUR REPAIR/PLASTIC */
"7846" = "1" /* OTH PATELLA REPAIR/PLAST */
"7847" = "1" /* OTH TIB/FIB REPAIR/PLAST */
"7848" = "1" /* OTH META/TAR REPA/PLAST */
"7849" = "1" /* OTH BONE REPA/PLAST NEC */
"7850" = "1" /* INT FIX W/O FX REDUC NOS */
"7851" = "1" /* INT FIXATION-CHEST CAGE */
"7852" = "1" /* INT FIXATION-HUMERUS */
"7853" = "1" /* INT FIXATION-RADIUS/ULNA */
"7854" = "1" /* INT FIXATION-METACAR/CAR */
"7855" = "1" /* INTERNAL FIXATION-FEMUR */
"7856" = "1" /* INTERNAL FIX-PATELLA */
"7857" = "1" /* INT FIXATION-TIBIA/FIBUL */
"7858" = "1" /* INT FIXATION-METATAR/TAR */
"7859" = "1" /* INT FIX-NO FX REDUCT NEC */
"7860" = "1" /* REMOVE IMP DEVICE NOS */
"7861" = "1" /* REMOV IMP DEV-CHEST CAGE */
"7862" = "1" /* REMOVE IMPL DEV-HUMERUS */
"7863" = "1" /* REMOV IMP DEV-RADIUS/ULN */
"7864" = "1" /* REMOV IMP DEV-METAC/CARP */
"7865" = "1" /* REMOVE IMP DEVICE-FEMUR */
"7866" = "1" /* REMOV IMP DEVICE-PATELLA */
"7867" = "1" /* REMOV IMP DEV-TIB/FIBULA */
"7868" = "1" /* REMOVE IMP DEV-METAT/TAR */
"7869" = "1" /* REMOVE IMPL DEVICE NEC */
"7870" = "1" /* OSTEOCLASIS NOS */
"7871" = "1" /* OSTEOCLASIS-CHEST CAGE */
"7872" = "1" /* OSTEOCLASIS-HUMERUS */
"7873" = "1" /* OSTEOCLASIS-RADIUS/ULNA */
"7874" = "1" /* OSTEOCLASIS-METACAR/CAR */
"7875" = "1" /* OSTEOCLASIS-FEMUR */
"7876" = "1" /* OSTEOCLASIS-PATELLA */
"7877" = "1" /* OSTEOCLASIS-TIBIA/FIBULA */
"7878" = "1" /* OSTEOCLASIS-METATAR/TAR */
"7879" = "1" /* OSTEOCLASIS NEC */
"7880" = "1" /* OTHER BONE DX PROC NOS */
"7881" = "1" /* OTH DX PROCED-CHEST CAGE */
"7882" = "1" /* OTH DX PROCED-HUMERUS */
"7883" = "1" /* OTH DX PROC-RADIUS/ULNA */
"7884" = "1" /* OTH DX PROC-METACAR/CAR */
"7885" = "1" /* OTH DX PROCED-FEMUR */
"7886" = "1" /* OTH DX PROCED-PATELLA */
"7887" = "1" /* OTH DX PROC-TIBIA/FIBULA */
"7888" = "1" /* OTH DX PROC-METATAR/TAR */
"7889" = "1" /* OTHER BONE DX PROC NEC */
"7890" = "1" /* INSERT BONE STIMUL NOS */
"7891" = "1" /* INSERT BONE STIMUL-CHEST */
"7892" = "1" /* INSERT BONE STIM-HUMERUS */
"7893" = "1" /* INSER BONE STIM-RAD/ULNA */
"7894" = "1" /* INSER BONE STIM-META/CAR */
"7895" = "1" /* INSERT BONE STIM-FEMUR */
"7896" = "1" /* INSERT BONE STIM-PATELLA */
"7897" = "1" /* INSER BONE STIM-TIB/FIB */
"7898" = "1" /* INSER BONE STIM-META/TAR */
"7899" = "1" /* INSERT BONE STIMUL NEC */
"7910" = "1" /* CL FX REDUC-INT FIX NOS */
"7911" = "1" /* CLOS RED-INT FIX HUMERUS */
"7912" = "1" /* CL RED-INT FIX RAD/ULNA */
"7913" = "1" /* CL RED-INT FIX METAC/CAR */
"7914" = "1" /* CLOSE RED-INT FIX FINGER */
"7915" = "1" /* CLOSED RED-INT FIX FEMUR */
"7916" = "1" /* CL RED-INT FIX TIB/FIBU */
"7917" = "1" /* CL RED-INT FIX METAT/TAR */
"7918" = "1" /* CLOSE RED-INT FIX TOE FX */
"7919" = "1" /* CL FX REDUC-INT FIX NEC */
"7920" = "1" /* OPEN FX REDUCTION NOS */
"7921" = "1" /* OPEN REDUC-HUMERUS FX */
"7922" = "1" /* OPEN REDUC-RADIUS/ULN FX */
"7923" = "1" /* OPEN REDUC-METAC/CAR FX */
"7924" = "1" /* OPEN REDUCTION-FINGER FX */
"7925" = "1" /* OPEN REDUCTION-FEMUR FX */
"7926" = "1" /* OPEN REDUC-TIBIA/FIB FX */
"7927" = "1" /* OPEN REDUC-METAT/TARS FX */
"7928" = "1" /* OPEN REDUCTION-TOE FX */
"7929" = "1" /* OPEN FX REDUCTION NEC */
"7930" = "1" /* OPN FX RED W INT FIX NOS */
"7931" = "1" /* OPEN RED-INT FIX HUMERUS */
"7932" = "1" /* OP RED-INT FIX RAD/ULNA */
"7933" = "1" /* OP RED-INT FIX METAC/CAR */
"7934" = "1" /* OPEN RED-INT FIX FINGER */
"7935" = "1" /* OPEN REDUC-INT FIX FEMUR */
"7936" = "1" /* OP RED-INT FIX TIB/FIBUL */
"7937" = "1" /* OP RED-INT FIX METAT/TAR */
"7938" = "1" /* OPEN REDUCT-INT FIX TOE */
"7939" = "1" /* OPN FX RED W INT FIX NEC */
"7940" = "1" /* CLS REDUC-SEP EPIPHY NOS */
"7941" = "1" /* CLOSE RED-HUMERUS EPIPHY */
"7942" = "1" /* CLS RED-RADIUS/UL EPIPHY */
"7945" = "1" /* CLOSE REDUC-FEMUR EPIPHY */
"7946" = "1" /* CLS RED-TIBIA/FIB EPIPHY */
"7949" = "1" /* CLS REDUC-SEP EPIPHY NEC */
"7950" = "1" /* OPEN RED-SEP EPIPHY NOS */
"7951" = "1" /* OPN RED-SEP EPIPHY-HUMER */
"7952" = "1" /* OP RED-RADIUS/ULN EPIPHY */
"7955" = "1" /* OPN RED-SEP EPIPHY-FEMUR */
"7956" = "1" /* OP RED-TIBIA/FIB EPIPHYS */
"7959" = "1" /* OPEN RED-SEP EPIPHY NEC */
"7960" = "1" /* OPEN FX SITE DEBRIDE NOS */
"7961" = "1" /* DEBRID OPEN FX-HUMERUS */
"7962" = "1" /* DEBRID OPN FX-RADIUS/ULN */
"7963" = "1" /* DEBRID OPN FX-METAC/CAR */
"7964" = "1" /* DEBRID OPN FX-FINGER */
"7965" = "1" /* DEBRID OPN FX-FEMUR */
"7966" = "1" /* DEBRID OPN FX-TIBIA/FIB */
"7967" = "1" /* DEBRID OPN FX-METAT/TAR */
"7968" = "1" /* DEBRID OPN FX-TOE */
"7969" = "1" /* OPEN FX SITE DEBRIDE NEC */
"7980" = "1" /* OPEN REDUC-DISLOCAT NOS */
"7981" = "1" /* OPN REDUC DISLOC-SHOULDR */
"7982" = "1" /* OPEN REDUC-ELBOW DISLOC */
"7983" = "1" /* OPEN REDUC-WRIST DISLOC */
"7984" = "1" /* OPN REDUC DISLOC-HAND */
"7985" = "1" /* OPEN REDUC-HIP DISLOCAT */
"7986" = "1" /* OPEN REDUC-KNEE DISLOCAT */
"7987" = "1" /* OPEN REDUC-ANKLE DISLOC */
"7988" = "1" /* OPN REDUC DISLOC-FT/TOE */
"7989" = "1" /* OPEN REDUC-DISLOCAT NEC */
"7990" = "1" /* UNSPEC OP BONE INJ NOS */
"7991" = "1" /* HUMERUS INJURY OP NOS */
"7992" = "1" /* RADIUS/ULNA INJ OP NOS */
"7993" = "1" /* METACARP/CARP INJ OP NOS */
"7994" = "1" /* FINGER INJURY OP NOS */
"7995" = "1" /* FEMUR INJURY OP NOS */
"7996" = "1" /* TIBIA/FIBULA INJ OP NOS */
"7997" = "1" /* METATARS/TARS INJ OP NOS */
"7998" = "1" /* TOE INJURY OPERATION NOS */
"7999" = "1" /* UNSPEC OP-BONE INJ NEC */
"8000" = "1" /* ARTHROT & PROS REMOV NOS */
"8001" = "1" /* ARTHROT/PROS REMOV-SHLDR */
"8002" = "1" /* ARTHROT/PROS REMOV-ELBOW */
"8003" = "1" /* ARTHROT/PROS REMOV-WRIST */
"8004" = "1" /* ARTHROT/PROS REMOV-HAND */
"8005" = "1" /* ARTHROT/PROS REMOV-HIP */
"8006" = "1" /* ARTHROT/PROS REMOV-KNEE */
"8007" = "1" /* ARTHROT/PROS REMOV-ANKLE */
"8008" = "1" /* ARTHROT/PROS REMOV-FOOT */
"8009" = "1" /* ARTHROT & PROS REMOV NEC */
"8010" = "1" /* OTHER ARTHROTOMY NOS */
"8011" = "1" /* OTH ARTHROTOMY-SHOULDER */
"8012" = "1" /* OTH ARTHROTOMY-ELBOW */
"8013" = "1" /* OTH ARTHROTOMY-WRIST */
"8014" = "1" /* OTH ARTHROTOMY-HAND/FNGR */
"8015" = "1" /* OTH ARTHROTOMY-HIP */
"8016" = "1" /* OTH ARTHROTOMY-KNEE */
"8017" = "1" /* OTH ARTHROTOMY-ANKLE */
"8018" = "1" /* OTH ARTHROTOMY-FOOT/TOE */
"8019" = "1" /* OTHER ARTHROTOMY NEC */
"8020" = "1" /* ARTHROSCOPY NOS */
"8021" = "1" /* SHOULDER ARTHROSCOPY */
"8022" = "1" /* ELBOW ARTHROSCOPY */
"8023" = "1" /* WRIST ARTHROSCOPY */
"8024" = "1" /* HAND & FINGER ARTHROSCOP */
"8025" = "1" /* HIP ARTHROSCOPY */
"8026" = "1" /* KNEE ARTHROSCOPY */
"8027" = "1" /* ANKLE ARTHROSCOPY */
"8028" = "1" /* FOOT & TOE ARTHROSCOPY */
"8029" = "1" /* ARTHROSCOPY NEC */
"8040" = "1" /* JT STRUCTUR DIVISION NOS */
"8041" = "1" /* SHOULDER STRUCT DIVISION */
"8042" = "1" /* ELBOW STRUCTURE DIVISION */
"8043" = "1" /* WRIST STRUCTURE DIVISION */
"8044" = "1" /* HAND JOINT STRUCT DIVIS */
"8045" = "1" /* HIP STRUCTURE DIVISION */
"8046" = "1" /* KNEE STRUCTURE DIVISION */
"8047" = "1" /* ANKLE STRUCTURE DIVISION */
"8048" = "1" /* FOOT JOINT STRUCT DIVIS */
"8049" = "1" /* JT STRUCTUR DIVISION NEC */
"805 " = "1" /* JT STRUCTUR DIVISION NEC */
"8050" = "1" /* EXC/DEST INTVRT DISC NOS */
"8051" = "1" /* EXCISION INTERVERT DISC */
"8053" = "1" /* REP ANULUS FIBROSUS-GRFT */
"8054" = "1" /* REP ANULS FIBROS NEC/NOS */
"8059" = "1" /* OTH EXC/DEST INTVRT DISC */
"806 " = "1" /* EXCIS KNEE SEMILUN CARTL */
"8070" = "1" /* SYNOVECTOMY-SITE NOS */
"8071" = "1" /* SHOULDER SYNOVECTOMY */
"8072" = "1" /* ELBOW SYNOVECTOMY */
"8073" = "1" /* WRIST SYNOVECTOMY */
"8074" = "1" /* HAND SYNOVECTOMY */
"8075" = "1" /* HIP SYNOVECTOMY */
"8076" = "1" /* KNEE SYNOVECTOMY */
"8077" = "1" /* ANKLE SYNOVECTOMY */
"8078" = "1" /* FOOT SYNOVECTOMY */
"8079" = "1" /* SYNOVECTOMY-SITE NEC */
"8080" = "1" /* DESTRUCT JOINT LES NOS */
"8081" = "1" /* DESTRUC-SHOULDER LES NEC */
"8082" = "1" /* DESTRUC-ELBOW LESION NEC */
"8083" = "1" /* DESTRUC-WRIST LESION NEC */
"8084" = "1" /* DESTRUC-HAND JT LES NEC */
"8085" = "1" /* DESTRUCT-HIP LESION NEC */
"8086" = "1" /* DESTRUCT-KNEE LESION NEC */
"8087" = "1" /* DESTRUC-ANKLE LESION NEC */
"8088" = "1" /* DESTRUC-FOOT JT LES NEC */
"8089" = "1" /* DESTRUCT JOINT LES NEC */
"8090" = "1" /* EXCISION OF JOINT NOS */
"8091" = "1" /* EXCISION OF SHOULDER NEC */
"8092" = "1" /* EXCISION OF ELBOW NEC */
"8093" = "1" /* EXCISION OF WRIST NEC */
"8094" = "1" /* EXCISION HAND JOINT NEC */
"8095" = "1" /* EXCISION OF HIP NEC */
"8096" = "1" /* EXCISION OF KNEE NEC */
"8097" = "1" /* EXCISION OF ANKLE NEC */
"8098" = "1" /* EXCISION FOOT JOINT NEC */
"8099" = "1" /* EXCISION OF JOINT NEC */
"8100" = "1" /* SPINAL FUSION NOS */
"8101" = "1" /* ATLAS-AXIS FUSION */
"8102" = "1" /* OTHER CERVICAL FUS ANT */
"8103" = "1" /* OTHER CERVICAL FUS POST */
"8104" = "1" /* DORSAL/DORSOLUM FUS ANT */
"8105" = "1" /* DORSAL/DORSOLUM FUS POST */
"8106" = "1" /* LUMBAR/LUMBOSAC FUS ANT */
"8107" = "1" /* LUMBAR/LUMBOSAC FUS LAT */
"8108" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8109" = "1" /* LUMBAR/LUMBOSAC FUS POST */
"8111" = "1" /* ANKLE FUSION */
"8112" = "1" /* TRIPLE ARTHRODESIS */
"8113" = "1" /* SUBTALAR FUSION */
"8114" = "1" /* MIDTARSAL FUSION */
"8115" = "1" /* TARSOMETATARSAL FUSION */
"8116" = "1" /* METATARSOPHALANGEAL FUS */
"8117" = "1" /* OTHER FUSION OF FOOT */
"8118" = "1" /* OTHER FUSION OF FOOT */
"8120" = "1" /* ARTHRODESIS NOS */
"8121" = "1" /* ARTHRODESIS OF HIP */
"8122" = "1" /* ARTHRODESIS OF KNEE */
"8123" = "1" /* ARTHRODESIS OF SHOULDER */
"8124" = "1" /* ARTHRODESIS OF ELBOW */
"8125" = "1" /* CARPORADIAL FUSION */
"8126" = "1" /* METACARPOCARPAL FUSION */
"8127" = "1" /* METACARPOPHALANGEAL FUS */
"8128" = "1" /* INTERPHALANGEAL FUSION */
"8129" = "1" /* ARTHRODESIS NEC */
"8130" = "1" /* SPINAL REFUSION NOS */
"8131" = "1" /* REFUSION OF ATLAS-AXIS */
"8132" = "1" /* REFUSION OF OTH CERV ANT */
"8133" = "1" /* REFUS OF OTH CERV POST */
"8134" = "1" /* REFUSION OF DORSAL ANT */
"8135" = "1" /* REFUSION OF DORSAL POST */
"8136" = "1" /* REFUSION OF LUMBAR ANT */
"8137" = "1" /* REFUSION OF LUMBAR LAT */
"8138" = "1" /* REFUSION OF LUMBAR POST */
"8139" = "1" /* REFUSION OF SPINE NEC */
"8140" = "1" /* REPAIR OF HIP, NEC */
"8141" = "1" /* REPAIR OF HIP, NEC */
"8142" = "1" /* FIVE-IN-ONE KNEE REPAIR */
"8143" = "1" /* TRIAD KNEE REPAIR */
"8144" = "1" /* PATELLAR STABILIZATION */
"8145" = "1" /* CRUCIATE LIG REPAIR NEC */
"8146" = "1" /* COLLATERL LIG REPAIR NEC */
"8147" = "1" /* OTHER REPAIR OF KNEE */
"8148" = "1" /* OTHER REPAIR OF KNEE */
"8149" = "1" /* OTHER REPAIR OF ANKLE */
"8151" = "1" /* TOTAL HIP REPLACEMENT */
"8152" = "1" /* PARTIAL HIP REPLACEMENT */
"8153" = "1" /* REVISE HIP REPLACEMENT */
"8154" = "1" /* TOTAL KNEE REPLACEMENT */
"8155" = "1" /* REVISE KNEE REPLACEMENT */
"8156" = "1" /* TOTAL ANKLE REPLACEMENT */
"8157" = "1" /* REPL JOINT OF FOOT, TOE */
"8159" = "1" /* REV JT REPL LOW EXT NEC */
"8161" = "1" /* 360 SPINAL FUSION */
"8162" = "1" /* FUS/REFUS 2-3 VERTEBRAE */
"8163" = "1" /* FUS/REFUS 4-8 VERTEBRAE */
"8164" = "1" /* FUS/REFUS 9 VERTEBRAE */
"8165" = "1" /* VERTEBROPLASTY */
"8166" = "1" /* KYPHOPLASTY */
"8169" = "1" /* OTH HIP REPAIR  JAN80--SEP89 */
"8171" = "1" /* ARTHROPLAS METACARP WIT */
"8172" = "1" /* ARTHROPLASTY METACAR W/O */
"8173" = "1" /* TOTAL WRIST REPLACEMENT */
"8174" = "1" /* ARTHROPLASTY CARPAL WIT */
"8175" = "1" /* ARTHROPLASTY CARPAL W/O */
"8179" = "1" /* OTH REPAIR HAN/FIN/WRIS */
"8180" = "1" /* TOTAL SHOULDER REPLACE */
"8181" = "1" /* PARTIAL SHOULDER REPLACE */
"8182" = "1" /* REP RECUR SHLDER DISLOC */
"8183" = "1" /* SHOULDER ARTHROPLAST NEC */
"8184" = "1" /* TOTAL ELBOW REPLACEMENT */
"8185" = "1" /* ELBOW ARTHROPLASTY NEC */
"8186" = "1" /* ELBOW ARTHROPLASTY NEC */
"8187" = "1" /* ELBOW ARTHROPLASTY NEC */
"8188" = "1" /* RVRS TOTL SHLDR REPLACMT */	
"8193" = "1" /* SUTUR CAPSUL/LIGAMEN ARM */
"8194" = "1" /* SUTURE CAPSUL/LIG ANK/FT */
"8195" = "1" /* SUTUR CAPSUL/LIG LEG NEC */
"8196" = "1" /* OTHER REPAIR OF JOINT */
"8197" = "1" /* REV JT REPL UPPER EXTREM */
"8198" = "1" /* OTHER JOINT DX PROCEDURE */
"8199" = "1" /* JOINT STRUCTURE OP NEC */
"8201" = "1" /* EXPLOR TEND SHEATH-HAND */
"8202" = "1" /* MYOTOMY OF HAND */
"8203" = "1" /* BURSOTOMY OF HAND */
"8209" = "1" /* INC SOFT TISSUE HAND NEC */
"8211" = "1" /* TENOTOMY OF HAND */
"8212" = "1" /* FASCIOTOMY OF HAND */
"8219" = "1" /* DIV SOFT TISSUE HAND NEC */
"8221" = "1" /* EXC LES TEND SHEATH HAND */
"8222" = "1" /* EXCISION HAND MUSCLE LES */
"8229" = "1" /* EXC LES SFT TISS HND NEC */
"8231" = "1" /* BURSECTOMY OF HAND */
"8232" = "1" /* EXCIS HAND TEND FOR GRFT */
"8233" = "1" /* HAND TENONECTOMY NEC */
"8234" = "1" /* EXC HND MUS/FAS FOR GRFT */
"8235" = "1" /* HAND FASCIECTOMY NEC */
"8236" = "1" /* OTHER MYECTOMY OF HAND */
"8239" = "1" /* HAND SOFT TISSUE EXC NEC */
"8241" = "1" /* SUTURE TENDN SHEATH HAND */
"8242" = "1" /* DELAY SUT FLEX TEND HAND */
"8243" = "1" /* DELAY SUT HAND TEND NEC */
"8244" = "1" /* SUTUR FLEX TEND HAND NEC */
"8245" = "1" /* SUTURE HAND TENDON NEC */
"8246" = "1" /* SUTURE HAND MUSCLE/FASC */
"8251" = "1" /* HAND TENDON ADVANCEMENT */
"8252" = "1" /* HAND TENDON RECESSION */
"8253" = "1" /* HAND TENDON REATTACHMENT */
"8254" = "1" /* HAND MUSCLE REATTACHMENT */
"8255" = "1" /* CHNG HND MUS/TEN LNG NEC */
"8256" = "1" /* TRANSPLANT HAND TEND NEC */
"8257" = "1" /* TRANSPOSIT HAND TEND NEC */
"8258" = "1" /* TRANSPLANT HAND MUSC NEC */
"8259" = "1" /* TRANSPOSIT HAND MUSC NEC */
"8261" = "1" /* POLLICIZATION OPERATION */
"8269" = "1" /* THUMB RECONSTRUCTION NEC */
"8271" = "1" /* HAND TEND PULLEY RECONST */
"8272" = "1" /* PLAST OP HND-MUS/FAS GRF */
"8279" = "1" /* PLAST OP HAND W GRFT NEC */
"8281" = "1" /* TRANSFER OF FINGER */
"8282" = "1" /* REPAIR OF CLEFT HAND */
"8283" = "1" /* REPAIR OF MACRODACTYLY */
"8284" = "1" /* REPAIR OF MALLET FINGER */
"8285" = "1" /* OTHER TENODESIS OF HAND */
"8286" = "1" /* OTHER TENOPLASTY OF HAND */
"8289" = "1" /* HAND PLASTIC OP NEC */
"8291" = "1" /* LYSIS OF HAND ADHESIONS */
"8299" = "1" /* HAND MUS/TEN/FAS/OPS NEC */
"8301" = "1" /* TENDON SHEATH EXPLORAT */
"8302" = "1" /* MYOTOMY */
"8303" = "1" /* BURSOTOMY */
"8309" = "1" /* SOFT TISSUE INCISION NEC */
"8311" = "1" /* ACHILLOTENOTOMY */
"8312" = "1" /* ADDUCTOR TENOTOMY OF HIP */
"8313" = "1" /* OTHER TENOTOMY */
"8314" = "1" /* FASCIOTOMY */
"8319" = "1" /* SOFT TISSUE DIVISION NEC */
"8321" = "1" /* SOFT TISSUE BIOPSY */
"8329" = "1" /* SOFT TISSUE DX PROC NEC */
"8331" = "1" /* EXCIS LES TENDON SHEATH */
"8332" = "1" /* EXCIS LESION OF MUSCLE */
"8339" = "1" /* EXC LES SOFT TISSUE NEC */
"8341" = "1" /* TENDON EXCISION FOR GRFT */
"8342" = "1" /* OTHER TENONECTOMY */
"8343" = "1" /* MUSC/FASC EXCIS FOR GRFT */
"8344" = "1" /* OTHER FASCIECTOMY */
"8345" = "1" /* OTHER MYECTOMY */
"8349" = "1" /* OTHER SOFT TISSUE EXCIS */
"835 " = "1" /* BURSECTOMY */
"8361" = "1" /* TENDON SHEATH SUTURE */
"8362" = "1" /* DELAYED TENDON SUTURE */
"8363" = "1" /* ROTATOR CUFF REPAIR */
"8364" = "1" /* OTHER SUTURE OF TENDON */
"8365" = "1" /* OTHER MUSCLE/FASC SUTURE */
"8371" = "1" /* TENDON ADVANCEMENT */
"8372" = "1" /* TENDON RECESSION */
"8373" = "1" /* TENDON REATTACHMENT */
"8374" = "1" /* MUSCLE REATTACHMENT */
"8375" = "1" /* TENDON TRNSFR/TRANSPLANT */
"8376" = "1" /* OTHER TENDON TRANSPOSIT */
"8377" = "1" /* MUSCLE TRNSFR/TRANSPLANT */
"8379" = "1" /* OTHER MUSCLE TRANSPOSIT */
"8381" = "1" /* TENDON GRAFT */
"8382" = "1" /* MUSCLE OR FASCIA GRAFT */
"8383" = "1" /* TENDON PULLEY RECONSTRUC */
"8384" = "1" /* CLUBFOOT RELEASE NEC */
"8385" = "1" /* MUSC/TEND LNG CHANGE NEC */
"8386" = "1" /* QUADRICEPSPLASTY */
"8387" = "1" /* OTHER PLASTIC OPS MUSCLE */
"8388" = "1" /* OTHER PLASTIC OPS TENDON */
"8389" = "1" /* OTHER PLASTIC OPS FASCIA */
"8391" = "1" /* ADHESIOLYSIS MUS/TEN/FAS */
"8392" = "1" /* INSERT SKEL MUSC STIMULA */
"8393" = "1" /* REMOV SKEL MUSC STIMULAT */
"8399" = "1" /* MUS/TEN/FAS/BUR OP NEC */
"8400" = "1" /* UPPER LIMB AMPUTAT NOS */
"8401" = "1" /* FINGER AMPUTATION */
"8402" = "1" /* THUMB AMPUTATION */
"8403" = "1" /* AMPUTATION THROUGH HAND */
"8404" = "1" /* DISARTICULATION OF WRIST */
"8405" = "1" /* AMPUTATION THRU FOREARM */
"8406" = "1" /* DISARTICULATION OF ELBOW */
"8407" = "1" /* AMPUTATION THRU HUMERUS */
"8408" = "1" /* SHOULDER DISARTICULATION */
"8409" = "1" /* FOREQUARTER AMPUTATION */
"8410" = "1" /* LOWER LIMB AMPUTAT NOS */
"8411" = "1" /* TOE AMPUTATION */
"8412" = "1" /* AMPUTATION THROUGH FOOT */
"8413" = "1" /* DISARTICULATION OF ANKLE */
"8414" = "1" /* AMPUTAT THROUGH MALLEOLI */
"8415" = "1" /* BELOW KNEE AMPUTAT NEC */
"8416" = "1" /* DISARTICULATION OF KNEE */
"8417" = "1" /* ABOVE KNEE AMPUTATION */
"8418" = "1" /* DISARTICULATION OF HIP */
"8419" = "1" /* HINDQUARTER AMPUTATION */
"8421" = "1" /* THUMB REATTACHMENT */
"8422" = "1" /* FINGER REATTACHMENT */
"8423" = "1" /* FOREARM/WRIST/HAND REATT */
"8424" = "1" /* UPPER ARM REATTACHMENT */
"8425" = "1" /* TOE REATTACHMENT */
"8426" = "1" /* FOOT REATTACHMENT */
"8427" = "1" /* LOWER LEG/ANKLE REATTACH */
"8428" = "1" /* THIGH REATTACHMENT */
"8429" = "1" /* REATTACHMENT NEC */
"843 " = "1" /* AMPUTATION STUMP REVIS */
"8440" = "1" /* IMPLNT/FIT PROS LIMB NOS */
"8444" = "1" /* IMPLANT ARM PROSTHESIS */
"8448" = "1" /* IMPLANT LEG PROSTHESIS */
"8458" = "1" /* IMP INTRSPINE DECOMP DEV */
"8459" = "1" /* INSERT OTHR SPIN DEVICE */
"8460" = "1" /* INSERT DISC PROS NOS */
"8461" = "1" /* INS PART DISC PROS CERV */
"8462" = "1" /* INS TOT DISC PROST CERV */
"8463" = "1" /* INS SPIN DISC PROS THOR */
"8464" = "1" /* INS PART DISC PROS LUMB */
"8465" = "1" /* INS TOTL DISC PROS LUMB */
"8466" = "1" /* REVISE DISC PROST CERV */
"8467" = "1" /* REVISE DISC PROST THORA */
"8468" = "1" /* REVISE DISC PROSTH LUMB */
"8469" = "1" /* REVISE DISC PROSTH NOS */
"8480" = "1" /* INS/REPL INTERSPINE DEV */
"8481" = "1" /* REV INTERSPINE DEVICE */
"8482" = "1" /* INS/REPL PDCL STABIL DEV */
"8483" = "1" /* REV PEDCL DYN STABIL DEV */
"8484" = "1" /* INS/REPL FACET REPLC DEV */
"8485" = "1" /* REV FACET REPLACE DEVICE */
"8491" = "1" /* AMPUTATION NOS */
"8492" = "1" /* SEPARAT EQUAL JOIN TWIN */
"8493" = "1" /* SEPARAT UNEQUL JOIN TWIN */
"8494" = "1" /* INS STRN FIX W RGD PLATE */	
"8499" = "1" /* MUSCULOSKELETAL OP NEC */
"8512" = "1" /* OPEN BREAST BIOPSY */
"8520" = "1" /* BREAST TISSU DESTRUC NOS */
"8521" = "1" /* LOCAL EXCIS BREAST LES */
"8522" = "1" /* QUADRANT RESECT BREAST */
"8523" = "1" /* SUBTOTAL MASTECTOMY */
"8524" = "1" /* EXC ECTOPIC BREAST TISSU */
"8525" = "1" /* EXCISION OF NIPPLE */
"8531" = "1" /* UNILAT REDUCT MAMMOPLAST */
"8532" = "1" /* BILAT REDUCT MAMMOPLASTY */
"8533" = "1" /* UNIL SUBQ MAMMECT-IMPLNT */
"8534" = "1" /* UNILAT SUBQ MAMMECT NEC */
"8535" = "1" /* BIL SUBQ MAMMECT-IMPLANT */
"8536" = "1" /* BILAT SUBQ MAMMECTOM NEC */
"8541" = "1" /* UNILAT SIMPLE MASTECTOMY */
"8542" = "1" /* BILAT SIMPLE MASTECTOMY */
"8543" = "1" /* UNILAT EXTEN SIMP MASTEC */
"8544" = "1" /* BILAT EXTEND SIMP MASTEC */
"8545" = "1" /* UNILAT RADICAL MASTECTOM */
"8546" = "1" /* BILAT RADICAL MASTECTOMY */
"8547" = "1" /* UNIL EXT RAD MASTECTOMY */
"8548" = "1" /* BIL EXTEN RAD MASTECTOMY */
"8550" = "1" /* AUGMENT MAMMOPLASTY NOS */
"8553" = "1" /* UNILAT BREAST IMPLANT */
"8554" = "1" /* BILATERAL BREAST IMPLANT */
"8555" = "1" /* FAT GRAFT TO BREAST	  	 */
"856 " = "1" /* MASTOPEXY */
"857 " = "1" /* TOTAL BREAST RECONSTRUCT */
"8570" = "1" /* TOTL RECONSTC BREAST NOS */
"8571" = "1" /* LATISS DORSI MYOCUT FLAP */
"8572" = "1" /* TRAM FLAP, PEDICLED */
"8573" = "1" /* TRAM FLAP, FREE */
"8574" = "1" /* DIEP FLAP, FREE */
"8575" = "1" /* SIEA FLAP, FREE */
"8576" = "1" /* GAP FLAP, FREE */
"8579" = "1" /* TOTL RECONST BREAST NEC */
"8582" = "1" /* BREAST SPLIT-THICK GRAFT */
"8583" = "1" /* BREAST FULL-THICK GRAFT */
"8584" = "1" /* BREAST PEDICLE GRAFT */
"8585" = "1" /* BREAST MUSCLE FLAP GRAFT */
"8586" = "1" /* TRANSPOSITION OF NIPPLE */
"8587" = "1" /* NIPPLE REPAIR NEC */
"8589" = "1" /* MAMMOPLASTY NEC */
"8593" = "1" /* BREAST IMPLANT REVISION */
"8594" = "1" /* BREAST IMPLANT REMOVAL */
"8595" = "1" /* INSER BREAST TISSU EXPAN */
"8596" = "1" /* REMOV BREAST TISSU EXPAN */
"8599" = "1" /* BREAST OPERATION NEC */
"8606" = "1" /* INSERT INFUSION PUMP */
"8621" = "1" /* EXCISION OF PILONID CYST */
"8622" = "1" /* EXC WOUND DEBRIDEMENT */
"8625" = "1" /* DERMABRASION */
"864 " = "1" /* RADICAL EXCIS SKIN LES */
"8660" = "1" /* FREE SKIN GRAFT NOS */
"8661" = "1" /* FULL-THICK HAND SKIN GRF */
"8662" = "1" /* HAND SKIN GRAFT NEC */
"8663" = "1" /* FULL-THICK SKIN GRFT NEC */
"8665" = "1" /* HETEROGRAFT TO SKIN */
"8666" = "1" /* HOMOGRAFT TO SKIN */
"8667" = "1" /* DERMAL REGENER GRAFT */
"8669" = "1" /* FREE SKIN GRAFT NEC */
"8670" = "1" /* PEDICLE GRAFT/FLAP NOS */
"8671" = "1" /* CUT & PREP PEDICLE GRAFT */
"8672" = "1" /* PEDICLE GRAFT ADVANCEMEN */
"8673" = "1" /* ATTACH PEDICLE TO HAND */
"8674" = "1" /* ATTACH PEDICLE GRAFT NEC */
"8675" = "1" /* REVISION OF PEDICLE GRFT */
"8681" = "1" /* REPAIR FACIAL WEAKNESS */
"8682" = "1" /* FACIAL RHYTIDECTOMY */
"8683" = "1" /* SIZE REDUCT PLASTIC OP */
"8684" = "1" /* RELAXATION OF SCAR */
"8685" = "1" /* SYNDACTYLY CORRECTION */
"8686" = "1" /* ONYCHOPLASTY */
"8687" = "1" /* FAT GRFT SKIN/SUBQ TISS	 */
"8689" = "1" /* SKIN REPAIR & PLASTY NEC */
"8690" = "1" /* EXT FAT FOR GRFT/BANKING */
"8691" = "1" /* SKIN EXCISION FOR GRAFT */
"8693" = "1" /* INSERT TISSUE EXPANDER */
"8694" = "1" /* INS/REPL SINGLE PUL GEN */
"8695" = "1" /* INS/REPL DUAL PULSE GEN */
"8696" = "1" /* INSERT/REPL OTH NEUROST */
"8697" = "1" /* INS/REP 1 PUL GEN */
"8698" = "1" /* INS/REP 2 PUL GEN */
"8753" = "1" /* INTRAOPER CHOLANGIOGRAM */
"9227" = "1" /* RADIOACTIVE ELEM IMPLANT */
"9504" = "1" /* ANESTHETIZED EYE EXAM */
other  = "0"
;

/* ---------------------------------------------------------------- */
/* LOW BIRTH WEIGHT                                                 */
/* ---------------------------------------------------------------- */
/* ICD-9-CM DIAGNOSIS CODES: */
value $LW500G
"76401" = "1"
"76411" = "1"
"76421" = "1"
"76491" = "1"
"76501" = "1"
"76511" = "1"
"V2131" = "1"
other = "0";
value $LW750G
"76402" = "1"
"76412" = "1"
"76422" = "1"
"76492" = "1"
"76502" = "1"
"76512" = "1"
"V2132" = "1"
other   = "0";
value $LW1000G
"76403" = "1"
"76413" = "1"
"76423" = "1"
"76493" = "1"
"76503" = "1"
"76513" = "1"
"V2132" = "1"
other   = "0";
value $LW1250G
"76404" = "1"
"76414" = "1"
"76424" = "1"
"76494" = "1"
"76504" = "1"
"76514" = "1"
"V2133" = "1"
other   = "0";
value $LW1500G
"76405" = "1"
"76415" = "1"
"76425" = "1"
"76495" = "1"
"76505" = "1"
"76515" = "1"
"V2133" = "1"
other   = "0";
value $LW1750G
"76406" = "1"
"76416" = "1"
"76426" = "1"
"76496" = "1"
"76506" = "1"
"76516" = "1"
"V2134" = "1"
other   = "0";
value $LW2000G
"76407" = "1"
"76417" = "1"
"76427" = "1"
"76497" = "1"
"76507" = "1"
"76517" = "1"
"V2134" = "1"
other   = "0";
value $LW2500G
"76408" = "1" /* LT-FOR-DATES 2000-2499G */
"76418" = "1" /* LT-DATE W/MAL 2000-2499G */
"76428" = "1" /* FETAL MALNUTR 2000-2499G */
"76498" = "1" /* FET GRWTH RET 2000-2499G */
"76508" = "1" /* EXTREME IMMAT 2000-2499G */
"76518" = "1" /* OTHER PRETERM INFANTS 2000-2499G */
"V2135" = "1"
other   = "0";
value $LW2500P
"76409" = "1" /* LT-FOR-DATES 2000-2499G */
"76419" = "1" /* LT-DATE W/MAL 2000-2499G */
"76429" = "1" /* FETAL MALNUTR 2000-2499G */
"76499" = "1" /* FET GRWTH RET 2000-2499G */
"76509" = "1" /* EXTREME IMMAT 2000-2499G */
"76519" = "1" /* OTHER PRETERM INFANTS 2000-2499G */
other   = "0";

   VALUE $pr
   '80000' = '1'
   '80001' = '1'
   '80002' = '1'
   '80003' = '1'
   '80004' = '1'
   '80005' = '1'
   '80006' = '1'
   '80009' = '1'
   '80010' = '1'
   '80011' = '1'
   '80012' = '1'
   '80013' = '1'
   '80014' = '1'
   '80015' = '1'
   '80016' = '1'
   '80019' = '1'
   '80020' = '1'
   '80021' = '1'
   '80022' = '1'
   '80023' = '1'
   '80024' = '1'
   '80025' = '1'
   '80026' = '1'
   '80029' = '1'
   '80030' = '1'
   '80031' = '1'
   '80032' = '1'
   '80033' = '1'
   '80034' = '1'
   '80035' = '1'
   '80036' = '1'
   '80039' = '1'
   '80040' = '1'
   '80041' = '1'
   '80042' = '1'
   '80043' = '1'
   '80044' = '1'
   '80045' = '1'
   '80046' = '1'
   '80049' = '1'
   '80050' = '1'
   '80051' = '1'
   '80052' = '1'
   '80053' = '1'
   '80054' = '1'
   '80055' = '1'
   '80056' = '1'
   '80059' = '1'
   '80060' = '1'
   '80061' = '1'
   '80062' = '1'
   '80063' = '1'
   '80064' = '1'
   '80132' = '1'
   '80133' = '1'
   '80134' = '1'
   '80135' = '1'
   '80136' = '1'
   '80139' = '1'
   '80140' = '1'
   '80141' = '1'
   '80142' = '1'
   '80143' = '1'
   '80144' = '1'
   '80145' = '1'
   '80146' = '1'
   '80149' = '1'
   '80150' = '1'
   '80151' = '1'
   '80152' = '1'
   '80153' = '1'
   '80154' = '1'
   '80155' = '1'
   '80156' = '1'
   '80159' = '1'
   '80160' = '1'
   '80161' = '1'
   '80162' = '1'
   '80163' = '1'
   '80164' = '1'
   '80165' = '1'
   '80166' = '1'
   '80169' = '1'
   '80170' = '1'
   '80171' = '1'
   '80172' = '1'
   '80173' = '1'
   '80174' = '1'
   '80175' = '1'
   '80176' = '1'
   '80179' = '1'
   '80180' = '1'
   '80181' = '1'
   '80182' = '1'
   '80183' = '1'
   '80184' = '1'
   '80185' = '1'
   '80186' = '1'
   '80189' = '1'
   '80190' = '1'
   '80191' = '1'
   '80192' = '1'
   '80193' = '1'
   '80194' = '1'
   '80195' = '1'
   '80196' = '1'
   '80199' = '1'
   '8020'  = '1'
   '8021'  = '1'
   '80220' = '1'
   '80221' = '1'
   '80222' = '1'
   '80223' = '1'
   '80224' = '1'
   '80225' = '1'
   '80226' = '1'
   '80227' = '1'
   '80228' = '1'
   '80360' = '1'
   '80361' = '1'
   '80362' = '1'
   '80363' = '1'
   '80364' = '1'
   '80365' = '1'
   '80366' = '1'
   '80369' = '1'
   '80370' = '1'
   '80371' = '1'
   '80372' = '1'
   '80373' = '1'
   '80374' = '1'
   '80375' = '1'
   '80376' = '1'
   '80379' = '1'
   '80380' = '1'
   '80381' = '1'
   '80382' = '1'
   '80383' = '1'
   '80384' = '1'
   '80385' = '1'
   '80386' = '1'
   '80389' = '1'
   '80390' = '1'
   '80391' = '1'
   '80392' = '1'
   '80393' = '1'
   '80394' = '1'
   '80395' = '1'
   '80396' = '1'
   '80399' = '1'
   '80400' = '1'
   '80401' = '1'
   '80402' = '1'
   '80403' = '1'
   '80404' = '1'
   '80405' = '1'
   '80406' = '1'
   '80409' = '1'
   '80410' = '1'
   '80411' = '1'
   '80412' = '1'
   '80413' = '1'
   '80414' = '1'
   '80415' = '1'
   '80416' = '1'
   '80419' = '1'
   '80420' = '1'
   '80421' = '1'
   '80422' = '1'
   '80423' = '1'
   '80424' = '1'
   '80425' = '1'
   '80426' = '1'
   '80429' = '1'
   '80430' = '1'
   '80431' = '1'
   '80432' = '1'
   '80433' = '1'
   '80434' = '1'
   '80435' = '1'
   '80436' = '1'
   '80439' = '1'
   '80440' = '1'
   '8052'  = '1'
   '8053'  = '1'
   '8054'  = '1'
   '8055'  = '1'
   '8056'  = '1'
   '8057'  = '1'
   '8058'  = '1'
   '8059'  = '1'
   '80600' = '1'
   '80601' = '1'
   '80602' = '1'
   '80603' = '1'
   '80604' = '1'
   '80605' = '1'
   '80606' = '1'
   '80607' = '1'
   '80608' = '1'
   '80609' = '1'
   '80610' = '1'
   '80611' = '1'
   '80612' = '1'
   '80613' = '1'
   '80614' = '1'
   '80615' = '1'
   '80616' = '1'
   '80617' = '1'
   '80618' = '1'
   '80619' = '1'
   '80620' = '1'
   '80621' = '1'
   '80622' = '1'
   '80623' = '1'
   '80624' = '1'
   '80625' = '1'
   '80626' = '1'
   '80627' = '1'
   '80628' = '1'
   '80629' = '1'
   '80630' = '1'
   '80631' = '1'
   '80632' = '1'
   '80633' = '1'
   '80634' = '1'
   '80635' = '1'
   '80636' = '1'
   '80637' = '1'
   '80638' = '1'
   '80639' = '1'
   '8064'  = '1'
   '8065'  = '1'
   '80660' = '1'
   '80661' = '1'
   '80662' = '1'
   '80669' = '1'
   '80670' = '1'
   '80671' = '1'
   '80672' = '1'
   '80679' = '1'
   '8068'  = '1'
   '8069'  = '1'
   '80700' = '1'
   '80701' = '1'
   '80702' = '1'
   '80703' = '1'
   '80704' = '1'
   '81221' = '1'
   '81230' = '1'
   '81231' = '1'
   '81240' = '1'
   '81241' = '1'
   '81242' = '1'
   '81243' = '1'
   '81244' = '1'
   '81249' = '1'
   '81250' = '1'
   '81251' = '1'
   '81252' = '1'
   '81253' = '1'
   '81254' = '1'
   '81259' = '1'
   '81300' = '1'
   '81301' = '1'
   '81302' = '1'
   '81303' = '1'
   '81304' = '1'
   '81305' = '1'
   '81306' = '1'
   '81307' = '1'
   '81308' = '1'
   '81310' = '1'
   '81311' = '1'
   '81312' = '1'
   '81313' = '1'
   '81314' = '1'
   '81315' = '1'
   '81316' = '1'
   '81317' = '1'
   '81318' = '1'
   '81320' = '1'
   '81321' = '1'
   '81322' = '1'
   '81323' = '1'
   '81330' = '1'
   '81331' = '1'
   '81332' = '1'
   '81333' = '1'
   '81340' = '1'
   '81341' = '1'
   '81342' = '1'
   '81343' = '1'
   '81344' = '1'
   '81345' = '1'
   '81350' = '1'
   '81351' = '1'
   '81352' = '1'
   '81353' = '1'
   '81354' = '1'
   '81380' = '1'
   '81381' = '1'
   '81382' = '1'
   '81383' = '1'
   '81390' = '1'
   '81391' = '1'
   '81392' = '1'
   '81393' = '1'
   '81400' = '1'
   '81401' = '1'
   '81402' = '1'
   '81403' = '1'
   '81404' = '1'
   '82122' = '1'
   '82123' = '1'
   '82129' = '1'
   '82130' = '1'
   '82131' = '1'
   '82132' = '1'
   '82133' = '1'
   '82139' = '1'
   '8220'  = '1'
   '8221'  = '1'
   '82300' = '1'
   '82301' = '1'
   '82302' = '1'
   '82310' = '1'
   '82311' = '1'
   '82312' = '1'
   '82320' = '1'
   '82321' = '1'
   '82322' = '1'
   '82330' = '1'
   '82331' = '1'
   '82332' = '1'
   '82340' = '1'
   '82341' = '1'
   '82342' = '1'
   '82380' = '1'
   '82381' = '1'
   '82382' = '1'
   '82390' = '1'
   '82391' = '1'
   '82392' = '1'
   '8240'  = '1'
   '8241'  = '1'
   '8242'  = '1'
   '8243'  = '1'
   '8244'  = '1'
   '8245'  = '1'
   '8246'  = '1'
   '8247'  = '1'
   '8248'  = '1'
   '8249'  = '1'
   '8250'  = '1'
   '8251'  = '1'
   '82520' = '1'
   '82521' = '1'
   '82522' = '1'
   '82523' = '1'
   '82524' = '1'
   '82525' = '1'
   '82529' = '1'
   '82530' = '1'
   '82531' = '1'
   '82532' = '1'
   '82533' = '1'
   '82534' = '1'
   '82535' = '1'
   '82539' = '1'
   '8260'  = '1'
   '8261'  = '1'
   '8270'  = '1'
   '8271'  = '1'
   '8280'  = '1'
   '8281'  = '1'
   '8290'  = '1'
   '8291'  = '1'
   '83660' = '1'
   '83661' = '1'
   '83662' = '1'
   '83663' = '1'
   '83664' = '1'
   '83669' = '1'
   '8370'  = '1'
   '8371'  = '1'
   '83800' = '1'
   '83801' = '1'
   '83802' = '1'
   '83803' = '1'
   '83804' = '1'
   '83805' = '1'
   '83806' = '1'
   '83809' = '1'
   '83810' = '1'
   '83811' = '1'
   '83812' = '1'
   '83813' = '1'
   '83814' = '1'
   '83815' = '1'
   '83816' = '1'
   '83819' = '1'
   '83900' = '1'
   '83901' = '1'
   '83902' = '1'
   '83903' = '1'
   '83904' = '1'
   '83905' = '1'
   '83906' = '1'
   '83907' = '1'
   '83908' = '1'
   '83910' = '1'
   '83911' = '1'
   '83912' = '1'
   '83913' = '1'
   '83914' = '1'
   '83915' = '1'
   '83916' = '1'
   '83917' = '1'
   '83918' = '1'
   '83920' = '1'
   '83921' = '1'
   '83930' = '1'
   '83931' = '1'
   '83940' = '1'
   '83941' = '1'
   '83942' = '1'
   '83949' = '1'
   '83950' = '1'
   '83951' = '1'
   '83952' = '1'
   '83959' = '1'
   '83961' = '1'
   '83969' = '1'
   '83971' = '1'
   '83979' = '1'
   '8398'  = '1'
   '8399'  = '1'
   '8400'  = '1'
   '8401'  = '1'
   '8402'  = '1'
   '8403'  = '1'
   '8404'  = '1'
   '85012' = '1'
   '8502'  = '1'
   '8503'  = '1'
   '8504'  = '1'
   '8505'  = '1'
   '8509'  = '1'
   '85100' = '1'
   '85101' = '1'
   '85102' = '1'
   '85103' = '1'
   '85104' = '1'
   '85105' = '1'
   '85106' = '1'
   '85109' = '1'
   '85110' = '1'
   '85111' = '1'
   '85112' = '1'
   '85113' = '1'
   '85114' = '1'
   '85115' = '1'
   '85116' = '1'
   '85119' = '1'
   '85120' = '1'
   '85121' = '1'
   '85122' = '1'
   '85123' = '1'
   '85124' = '1'
   '85125' = '1'
   '85126' = '1'
   '85129' = '1'
   '85130' = '1'
   '85131' = '1'
   '85132' = '1'
   '85133' = '1'
   '85134' = '1'
   '85135' = '1'
   '85136' = '1'
   '85139' = '1'
   '85140' = '1'
   '85141' = '1'
   '85142' = '1'
   '85143' = '1'
   '85144' = '1'
   '85145' = '1'
   '85146' = '1'
   '85149' = '1'
   '85150' = '1'
   '85151' = '1'
   '85152' = '1'
   '85153' = '1'
   '85154' = '1'
   '85155' = '1'
   '85156' = '1'
   '85159' = '1'
   '85160' = '1'
   '85161' = '1'
   '85162' = '1'
   '85163' = '1'
   '85164' = '1'
   '85165' = '1'
   '85166' = '1'
   '85169' = '1'
   '85170' = '1'
   '85171' = '1'
   '85172' = '1'
   '85254' = '1'
   '85255' = '1'
   '85256' = '1'
   '85259' = '1'
   '85300' = '1'
   '85301' = '1'
   '85302' = '1'
   '85303' = '1'
   '85304' = '1'
   '85305' = '1'
   '85306' = '1'
   '85309' = '1'
   '85310' = '1'
   '85311' = '1'
   '85312' = '1'
   '85313' = '1'
   '85314' = '1'
   '85315' = '1'
   '85316' = '1'
   '85319' = '1'
   '85400' = '1'
   '85401' = '1'
   '85402' = '1'
   '85403' = '1'
   '85404' = '1'
   '85405' = '1'
   '85406' = '1'
   '85409' = '1'
   '85410' = '1'
   '85411' = '1'
   '85412' = '1'
   '85413' = '1'
   '85414' = '1'
   '85415' = '1'
   '85416' = '1'
   '85419' = '1'
   '8600'  = '1'
   '8601'  = '1'
   '8602'  = '1'
   '8603'  = '1'
   '8604'  = '1'
   '8605'  = '1'
   '86100' = '1'
   '86101' = '1'
   '86102' = '1'
   '86103' = '1'
   '86110' = '1'
   '86111' = '1'
   '86112' = '1'
   '86113' = '1'
   '86120' = '1'
   '86121' = '1'
   '86122' = '1'
   '86130' = '1'
   '86131' = '1'
   '86132' = '1'
   '8620'  = '1'
   '8621'  = '1'
   '86221' = '1'
   '86222' = '1'
   '86229' = '1'
   '86231' = '1'
   '86232' = '1'
   '86239' = '1'
   '8628'  = '1'
   '86600' = '1'
   '86601' = '1'
   '86602' = '1'
   '86603' = '1'
   '86610' = '1'
   '86611' = '1'
   '86612' = '1'
   '86613' = '1'
   '8670'  = '1'
   '8671'  = '1'
   '8672'  = '1'
   '8673'  = '1'
   '8674'  = '1'
   '8675'  = '1'
   '8676'  = '1'
   '8677'  = '1'
   '8678'  = '1'
   '8679'  = '1'
   '86800' = '1'
   '86801' = '1'
   '86802' = '1'
   '86803' = '1'
   '86804' = '1'
   '86809' = '1'
   '86810' = '1'
   '86811' = '1'
   '86812' = '1'
   '86813' = '1'
   '86814' = '1'
   '86819' = '1'
   '8690'  = '1'
   '8691'  = '1'
   '8700'  = '1'
   '8701'  = '1'
   '8702'  = '1'
   '8703'  = '1'
   '8704'  = '1'
   '8708'  = '1'
   '8709'  = '1'
   '8710'  = '1'
   '8711'  = '1'
   '8712'  = '1'
   '8713'  = '1'
   '8714'  = '1'
   '8715'  = '1'
   '8716'  = '1'
   '8717'  = '1'
   '8719'  = '1'
   '87200' = '1'
   '87201' = '1'
   '87202' = '1'
   '87210' = '1'
   '87211' = '1'
   '87212' = '1'
   '87261' = '1'
   '87262' = '1'
   '87263' = '1'
   '87264' = '1'
   '87269' = '1'
   '87271' = '1'
   '87272' = '1'
   '87273' = '1'
   '87274' = '1'
   '87279' = '1'
   '8728'  = '1'
   '8786'  = '1'
   '8787'  = '1'
   '8788'  = '1'
   '8789'  = '1'
   '8790'  = '1'
   '8791'  = '1'
   '8792'  = '1'
   '8793'  = '1'
   '8794'  = '1'
   '8795'  = '1'
   '8796'  = '1'
   '8797'  = '1'
   '8798'  = '1'
   '8799'  = '1'
   '88000' = '1'
   '88001' = '1'
   '88002' = '1'
   '88003' = '1'
   '88009' = '1'
   '88010' = '1'
   '88011' = '1'
   '88012' = '1'
   '88013' = '1'
   '88019' = '1'
   '88020' = '1'
   '88021' = '1'
   '88022' = '1'
   '88023' = '1'
   '88029' = '1'
   '88100' = '1'
   '88101' = '1'
   '88102' = '1'
   '88110' = '1'
   '88111' = '1'
   '88112' = '1'
   '88120' = '1'
   '88121' = '1'
   '88122' = '1'
   '8820'  = '1'
   '8821'  = '1'
   '8822'  = '1'
   '8830'  = '1'
   '8831'  = '1'
   '8832'  = '1'
   '8840'  = '1'
   '8841'  = '1'
   '8842'  = '1'
   '8850'  = '1'
   '8851'  = '1'
   '8860'  = '1'
   '8861'  = '1'
   '8870'  = '1'
   '8871'  = '1'
   '8872'  = '1'
   '8873'  = '1'
   '8874'  = '1'
   '8875'  = '1'
   '8876'  = '1'
   '8877'  = '1'
   '8900'  = '1'
   '8901'  = '1'
   '8902'  = '1'
   '8910'  = '1'
   '8911'  = '1'
   '8912'  = '1'
   '90249' = '1'
   '90250' = '1'
   '90251' = '1'
   '90252' = '1'
   '90253' = '1'
   '90254' = '1'
   '90255' = '1'
   '90256' = '1'
   '90259' = '1'
   '90281' = '1'
   '90282' = '1'
   '90287' = '1'
   '90289' = '1'
   '9029'  = '1'
   '90300' = '1'
   '90301' = '1'
   '90302' = '1'
   '9031'  = '1'
   '9032'  = '1'
   '9033'  = '1'
   '9034'  = '1'
   '9035'  = '1'
   '9038'  = '1'
   '9039'  = '1'
   '9040'  = '1'
   '9041'  = '1'
   '9042'  = '1'
   '9043'  = '1'
   '90440' = '1'
   '90441' = '1'
   '90442' = '1'
   '90450' = '1'
   '90451' = '1'
   '90452' = '1'
   '90453' = '1'
   '90454' = '1'
   '9046'  = '1'
   '9047'  = '1'
   '9048'  = '1'
   '9049'  = '1'
   '9100'  = '1'
   '9101'  = '1'
   '9102'  = '1'
   '9103'  = '1'
   '9104'  = '1'
   '9105'  = '1'
   '9106'  = '1'
   '9107'  = '1'
   '9108'  = '1'
   '9109'  = '1'
   '9110'  = '1'
   '9111'  = '1'
   '9112'  = '1'
   '9113'  = '1'
   '9114'  = '1'
   '9115'  = '1'
   '9116'  = '1'
   '9117'  = '1'
   '9118'  = '1'
   '9119'  = '1'
   '9120'  = '1'
   '9121'  = '1'
   '9122'  = '1'
   '9123'  = '1'
   '9124'  = '1'
   '9196'  = '1'
   '9197'  = '1'
   '9198'  = '1'
   '9199'  = '1'
   '920'   = '1'
   '9210'  = '1'
   '9211'  = '1'
   '9212'  = '1'
   '9213'  = '1'
   '9219'  = '1'
   '9220'  = '1'
   '9221'  = '1'
   '9222'  = '1'
   '92231' = '1'
   '92232' = '1'
   '92233' = '1'
   '9224'  = '1'
   '9228'  = '1'
   '9229'  = '1'
   '92300' = '1'
   '92301' = '1'
   '92302' = '1'
   '92303' = '1'
   '92309' = '1'
   '92310' = '1'
   '92311' = '1'
   '92320' = '1'
   '92321' = '1'
   '9233'  = '1'
   '9238'  = '1'
   '9239'  = '1'
   '92400' = '1'
   '92401' = '1'
   '92410' = '1'
   '92411' = '1'
   '92420' = '1'
   '92421' = '1'
   '9243'  = '1'
   '9244'  = '1'
   '9245'  = '1'
   '9248'  = '1'
   '9249'  = '1'
   '9251'  = '1'
   '9252'  = '1'
   '9260'  = '1'
   '92611' = '1'
   '92612' = '1'
   '92619' = '1'
   '9268'  = '1'
   '9269'  = '1'
   '92700' = '1'
   '92701' = '1'
   '92702' = '1'
   '92703' = '1'
   '92709' = '1'
   '92710' = '1'
   '92711' = '1'
   '92720' = '1'
   '92721' = '1'
   '9273'  = '1'
   '9278'  = '1'
   '9279'  = '1'
   '92800' = '1'
   '92801' = '1'
   '92810' = '1'
   '9555'  = '1'
   '9556'  = '1'
   '9557'  = '1'
   '9558'  = '1'
   '9559'  = '1'
   '9560'  = '1'
   '9561'  = '1'
   '9562'  = '1'
   '9563'  = '1'
   '9564'  = '1'
   '9565'  = '1'
   '9568'  = '1'
   '9569'  = '1'
   '9570'  = '1'
   '9571'  = '1'
   '9578'  = '1'
   '9579'  = '1'
   '9580'  = '1'
   '9581'  = '1'
   '9582'  = '1'
   '9583'  = '1'
   '80065' = '1'
   '80066' = '1'
   '80069' = '1'
   '80070' = '1'
   '80071' = '1'
   '80072' = '1'
   '80073' = '1'
   '80074' = '1'
   '80075' = '1'
   '80076' = '1'
   '80079' = '1'
   '80080' = '1'
   '80081' = '1'
   '80082' = '1'
   '80083' = '1'
   '80084' = '1'
   '80085' = '1'
   '80086' = '1'
   '80089' = '1'
   '80090' = '1'
   '80091' = '1'
   '80092' = '1'
   '80093' = '1'
   '80094' = '1'
   '80095' = '1'
   '80096' = '1'
   '80099' = '1'
   '80100' = '1'
   '80101' = '1'
   '80102' = '1'
   '80103' = '1'
   '80104' = '1'
   '80105' = '1'
   '80106' = '1'
   '80109' = '1'
   '80110' = '1'
   '80111' = '1'
   '80112' = '1'
   '80113' = '1'
   '80114' = '1'
   '80115' = '1'
   '80116' = '1'
   '80119' = '1'
   '80120' = '1'
   '80121' = '1'
   '80122' = '1'
   '80123' = '1'
   '80124' = '1'
   '80125' = '1'
   '80126' = '1'
   '80129' = '1'
   '80130' = '1'
   '80131' = '1'
   '80229' = '1'
   '80230' = '1'
   '80231' = '1'
   '80232' = '1'
   '80233' = '1'
   '80234' = '1'
   '80235' = '1'
   '80236' = '1'
   '80237' = '1'
   '80238' = '1'
   '80239' = '1'
   '8024'  = '1'
   '8025'  = '1'
   '8026'  = '1'
   '8027'  = '1'
   '8028'  = '1'
   '8029'  = '1'
   '80300' = '1'
   '80301' = '1'
   '80302' = '1'
   '80303' = '1'
   '80304' = '1'
   '80305' = '1'
   '80306' = '1'
   '80309' = '1'
   '80310' = '1'
   '80311' = '1'
   '80312' = '1'
   '80313' = '1'
   '80314' = '1'
   '80315' = '1'
   '80316' = '1'
   '80319' = '1'
   '80320' = '1'
   '80321' = '1'
   '80322' = '1'
   '80323' = '1'
   '80324' = '1'
   '80325' = '1'
   '80326' = '1'
   '80329' = '1'
   '80330' = '1'
   '80331' = '1'
   '80332' = '1'
   '80333' = '1'
   '80334' = '1'
   '80335' = '1'
   '80336' = '1'
   '80339' = '1'
   '80340' = '1'
   '80341' = '1'
   '80342' = '1'
   '80343' = '1'
   '80344' = '1'
   '80345' = '1'
   '80346' = '1'
   '80349' = '1'
   '80350' = '1'
   '80351' = '1'
   '80352' = '1'
   '80353' = '1'
   '80354' = '1'
   '80355' = '1'
   '80356' = '1'
   '80359' = '1'
   '80441' = '1'
   '80442' = '1'
   '80443' = '1'
   '80444' = '1'
   '80445' = '1'
   '80446' = '1'
   '80449' = '1'
   '80450' = '1'
   '80451' = '1'
   '80452' = '1'
   '80453' = '1'
   '80454' = '1'
   '80455' = '1'
   '80456' = '1'
   '80459' = '1'
   '80460' = '1'
   '80461' = '1'
   '80462' = '1'
   '80463' = '1'
   '80464' = '1'
   '80465' = '1'
   '80466' = '1'
   '80469' = '1'
   '80470' = '1'
   '80471' = '1'
   '80472' = '1'
   '80473' = '1'
   '80474' = '1'
   '80475' = '1'
   '80476' = '1'
   '80479' = '1'
   '80480' = '1'
   '80481' = '1'
   '80482' = '1'
   '80483' = '1'
   '80484' = '1'
   '80485' = '1'
   '80486' = '1'
   '80489' = '1'
   '80490' = '1'
   '80491' = '1'
   '80492' = '1'
   '80493' = '1'
   '80494' = '1'
   '80495' = '1'
   '80496' = '1'
   '80499' = '1'
   '80500' = '1'
   '80501' = '1'
   '80502' = '1'
   '80503' = '1'
   '80504' = '1'
   '80505' = '1'
   '80506' = '1'
   '80507' = '1'
   '80508' = '1'
   '80510' = '1'
   '80511' = '1'
   '80512' = '1'
   '80513' = '1'
   '80514' = '1'
   '80515' = '1'
   '80516' = '1'
   '80517' = '1'
   '80518' = '1'
   '80705' = '1'
   '80706' = '1'
   '80707' = '1'
   '80708' = '1'
   '80709' = '1'
   '80710' = '1'
   '80711' = '1'
   '80712' = '1'
   '80713' = '1'
   '80714' = '1'
   '80715' = '1'
   '80716' = '1'
   '80717' = '1'
   '80718' = '1'
   '80719' = '1'
   '8072'  = '1'
   '8073'  = '1'
   '8074'  = '1'
   '8075'  = '1'
   '8076'  = '1'
   '8080'  = '1'
   '8081'  = '1'
   '8082'  = '1'
   '8083'  = '1'
   '80841' = '1'
   '80842' = '1'
   '80843' = '1'
   '80849' = '1'
   '80851' = '1'
   '80852' = '1'
   '80853' = '1'
   '80859' = '1'
   '8088'  = '1'
   '8089'  = '1'
   '8090'  = '1'
   '8091'  = '1'
   '81000' = '1'
   '81001' = '1'
   '81002' = '1'
   '81003' = '1'
   '81010' = '1'
   '81011' = '1'
   '81012' = '1'
   '81013' = '1'
   '81100' = '1'
   '81101' = '1'
   '81102' = '1'
   '81103' = '1'
   '81109' = '1'
   '81110' = '1'
   '81111' = '1'
   '81112' = '1'
   '81113' = '1'
   '81119' = '1'
   '81200' = '1'
   '81201' = '1'
   '81202' = '1'
   '81203' = '1'
   '81209' = '1'
   '81210' = '1'
   '81211' = '1'
   '81212' = '1'
   '81213' = '1'
   '81219' = '1'
   '81220' = '1'
   '81405' = '1'
   '81406' = '1'
   '81407' = '1'
   '81408' = '1'
   '81409' = '1'
   '81410' = '1'
   '81411' = '1'
   '81412' = '1'
   '81413' = '1'
   '81414' = '1'
   '81415' = '1'
   '81416' = '1'
   '81417' = '1'
   '81418' = '1'
   '81419' = '1'
   '81500' = '1'
   '81501' = '1'
   '81502' = '1'
   '81503' = '1'
   '81504' = '1'
   '81509' = '1'
   '81510' = '1'
   '81511' = '1'
   '81512' = '1'
   '81513' = '1'
   '81514' = '1'
   '81519' = '1'
   '81600' = '1'
   '81601' = '1'
   '81602' = '1'
   '81603' = '1'
   '81610' = '1'
   '81611' = '1'
   '81612' = '1'
   '81613' = '1'
   '8170'  = '1'
   '8171'  = '1'
   '8180'  = '1'
   '8181'  = '1'
   '8190'  = '1'
   '8191'  = '1'
   '82000' = '1'
   '82001' = '1'
   '82002' = '1'
   '82003' = '1'
   '82009' = '1'
   '82010' = '1'
   '82011' = '1'
   '82012' = '1'
   '82013' = '1'
   '82019' = '1'
   '82020' = '1'
   '82021' = '1'
   '82022' = '1'
   '82030' = '1'
   '82031' = '1'
   '82032' = '1'
   '8208'  = '1'
   '8209'  = '1'
   '82100' = '1'
   '82101' = '1'
   '82110' = '1'
   '82111' = '1'
   '82120' = '1'
   '82121' = '1'
   '8300'  = '1'
   '8301'  = '1'
   '83100' = '1'
   '83101' = '1'
   '83102' = '1'
   '83103' = '1'
   '83104' = '1'
   '83109' = '1'
   '83110' = '1'
   '83111' = '1'
   '83112' = '1'
   '83113' = '1'
   '83114' = '1'
   '83119' = '1'
   '83200' = '1'
   '83201' = '1'
   '83202' = '1'
   '83203' = '1'
   '83204' = '1'
   '83209' = '1'
   '83210' = '1'
   '83211' = '1'
   '83212' = '1'
   '83213' = '1'
   '83214' = '1'
   '83219' = '1'
   '83300' = '1'
   '83301' = '1'
   '83302' = '1'
   '83303' = '1'
   '83304' = '1'
   '83305' = '1'
   '83309' = '1'
   '83310' = '1'
   '83311' = '1'
   '83312' = '1'
   '83313' = '1'
   '83314' = '1'
   '83315' = '1'
   '83319' = '1'
   '83400' = '1'
   '83401' = '1'
   '83402' = '1'
   '83410' = '1'
   '83411' = '1'
   '83412' = '1'
   '83500' = '1'
   '83501' = '1'
   '83502' = '1'
   '83503' = '1'
   '83510' = '1'
   '83511' = '1'
   '83512' = '1'
   '83513' = '1'
   '8360'  = '1'
   '8361'  = '1'
   '8362'  = '1'
   '8363'  = '1'
   '8364'  = '1'
   '83650' = '1'
   '83651' = '1'
   '83652' = '1'
   '83653' = '1'
   '83654' = '1'
   '83659' = '1'
   '8405'  = '1'
   '8406'  = '1'
   '8407'  = '1'
   '8408'  = '1'
   '8409'  = '1'
   '8410'  = '1'
   '8411'  = '1'
   '8412'  = '1'
   '8413'  = '1'
   '8418'  = '1'
   '8419'  = '1'
   '84200' = '1'
   '84201' = '1'
   '84202' = '1'
   '84209' = '1'
   '84210' = '1'
   '84211' = '1'
   '84212' = '1'
   '84213' = '1'
   '84219' = '1'
   '8430'  = '1'
   '8431'  = '1'
   '8438'  = '1'
   '8439'  = '1'
   '8440'  = '1'
   '8441'  = '1'
   '8442'  = '1'
   '8443'  = '1'
   '8448'  = '1'
   '8449'  = '1'
   '84500' = '1'
   '84501' = '1'
   '84502' = '1'
   '84503' = '1'
   '84509' = '1'
   '84510' = '1'
   '84511' = '1'
   '84512' = '1'
   '84513' = '1'
   '84519' = '1'
   '8460'  = '1'
   '8461'  = '1'
   '8462'  = '1'
   '8463'  = '1'
   '8468'  = '1'
   '8469'  = '1'
   '8470'  = '1'
   '8471'  = '1'
   '8472'  = '1'
   '8473'  = '1'
   '8474'  = '1'
   '8479'  = '1'
   '8480'  = '1'
   '8481'  = '1'
   '8482'  = '1'
   '8483'  = '1'
   '84840' = '1'
   '84841' = '1'
   '84842' = '1'
   '84849' = '1'
   '8485'  = '1'
   '8488'  = '1'
   '8489'  = '1'
   '8500'  = '1'
   '85011' = '1'
   '85173' = '1'
   '85174' = '1'
   '85175' = '1'
   '85176' = '1'
   '85179' = '1'
   '85180' = '1'
   '85181' = '1'
   '85182' = '1'
   '85183' = '1'
   '85184' = '1'
   '85185' = '1'
   '85186' = '1'
   '85189' = '1'
   '85190' = '1'
   '85191' = '1'
   '85192' = '1'
   '85193' = '1'
   '85194' = '1'
   '85195' = '1'
   '85196' = '1'
   '85199' = '1'
   '85200' = '1'
   '85201' = '1'
   '85202' = '1'
   '85203' = '1'
   '85204' = '1'
   '85205' = '1'
   '85206' = '1'
   '85209' = '1'
   '85210' = '1'
   '85211' = '1'
   '85212' = '1'
   '85213' = '1'
   '85214' = '1'
   '85215' = '1'
   '85216' = '1'
   '85219' = '1'
   '85220' = '1'
   '85221' = '1'
   '85222' = '1'
   '85223' = '1'
   '85224' = '1'
   '85225' = '1'
   '85226' = '1'
   '85229' = '1'
   '85230' = '1'
   '85231' = '1'
   '85232' = '1'
   '85233' = '1'
   '85234' = '1'
   '85235' = '1'
   '85236' = '1'
   '85239' = '1'
   '85240' = '1'
   '85241' = '1'
   '85242' = '1'
   '85243' = '1'
   '85244' = '1'
   '85245' = '1'
   '85246' = '1'
   '85249' = '1'
   '85250' = '1'
   '85251' = '1'
   '85252' = '1'
   '85253' = '1'
   '8629'  = '1'
   '8630'  = '1'
   '8631'  = '1'
   '86320' = '1'
   '86321' = '1'
   '86329' = '1'
   '86330' = '1'
   '86331' = '1'
   '86339' = '1'
   '86340' = '1'
   '86341' = '1'
   '86342' = '1'
   '86343' = '1'
   '86344' = '1'
   '86345' = '1'
   '86346' = '1'
   '86349' = '1'
   '86350' = '1'
   '86351' = '1'
   '86352' = '1'
   '86353' = '1'
   '86354' = '1'
   '86355' = '1'
   '86356' = '1'
   '86359' = '1'
   '86380' = '1'
   '86381' = '1'
   '86382' = '1'
   '86383' = '1'
   '86384' = '1'
   '86385' = '1'
   '86389' = '1'
   '86390' = '1'
   '86391' = '1'
   '86392' = '1'
   '86393' = '1'
   '86394' = '1'
   '86395' = '1'
   '86399' = '1'
   '86400' = '1'
   '86401' = '1'
   '86402' = '1'
   '86403' = '1'
   '86404' = '1'
   '86405' = '1'
   '86409' = '1'
   '86410' = '1'
   '86411' = '1'
   '86412' = '1'
   '86413' = '1'
   '86414' = '1'
   '86415' = '1'
   '86419' = '1'
   '86500' = '1'
   '86501' = '1'
   '86502' = '1'
   '86503' = '1'
   '86504' = '1'
   '86509' = '1'
   '86510' = '1'
   '86511' = '1'
   '86512' = '1'
   '86513' = '1'
   '86514' = '1'
   '86519' = '1'
   '8729'  = '1'
   '8730'  = '1'
   '8731'  = '1'
   '87320' = '1'
   '87321' = '1'
   '87322' = '1'
   '87323' = '1'
   '87329' = '1'
   '87330' = '1'
   '87331' = '1'
   '87332' = '1'
   '87333' = '1'
   '87339' = '1'
   '87340' = '1'
   '87341' = '1'
   '87342' = '1'
   '87343' = '1'
   '87344' = '1'
   '87349' = '1'
   '87350' = '1'
   '87351' = '1'
   '87352' = '1'
   '87353' = '1'
   '87354' = '1'
   '87359' = '1'
   '87360' = '1'
   '87361' = '1'
   '87362' = '1'
   '87363' = '1'
   '87364' = '1'
   '87365' = '1'
   '87369' = '1'
   '87370' = '1'
   '87371' = '1'
   '87372' = '1'
   '87373' = '1'
   '87374' = '1'
   '87375' = '1'
   '87379' = '1'
   '8738'  = '1'
   '8739'  = '1'
   '87400' = '1'
   '87401' = '1'
   '87402' = '1'
   '87410' = '1'
   '87411' = '1'
   '87412' = '1'
   '8742'  = '1'
   '8743'  = '1'
   '8744'  = '1'
   '8745'  = '1'
   '8748'  = '1'
   '8749'  = '1'
   '8750'  = '1'
   '8751'  = '1'
   '8760'  = '1'
   '8761'  = '1'
   '8770'  = '1'
   '8771'  = '1'
   '8780'  = '1'
   '8781'  = '1'
   '8782'  = '1'
   '8783'  = '1'
   '8784'  = '1'
   '8785'  = '1'
   '8920'  = '1'
   '8921'  = '1'
   '8922'  = '1'
   '8930'  = '1'
   '8931'  = '1'
   '8932'  = '1'
   '8940'  = '1'
   '8941'  = '1'
   '8942'  = '1'
   '8950'  = '1'
   '8951'  = '1'
   '8960'  = '1'
   '8961'  = '1'
   '8962'  = '1'
   '8963'  = '1'
   '8970'  = '1'
   '8971'  = '1'
   '8972'  = '1'
   '8973'  = '1'
   '8974'  = '1'
   '8975'  = '1'
   '8976'  = '1'
   '8977'  = '1'
   '90000' = '1'
   '90001' = '1'
   '90002' = '1'
   '90003' = '1'
   '9001'  = '1'
   '90081' = '1'
   '90082' = '1'
   '90089' = '1'
   '9009'  = '1'
   '9010'  = '1'
   '9011'  = '1'
   '9012'  = '1'
   '9013'  = '1'
   '90140' = '1'
   '90141' = '1'
   '90142' = '1'
   '90181' = '1'
   '90182' = '1'
   '90183' = '1'
   '90189' = '1'
   '9019'  = '1'
   '9020'  = '1'
   '90210' = '1'
   '90211' = '1'
   '90219' = '1'
   '90220' = '1'
   '90221' = '1'
   '90222' = '1'
   '90223' = '1'
   '90224' = '1'
   '90225' = '1'
   '90226' = '1'
   '90227' = '1'
   '90229' = '1'
   '90231' = '1'
   '90232' = '1'
   '90233' = '1'
   '90234' = '1'
   '90239' = '1'
   '90240' = '1'
   '90241' = '1'
   '90242' = '1'
   '9125'  = '1'
   '9126'  = '1'
   '9127'  = '1'
   '9128'  = '1'
   '9129'  = '1'
   '9130'  = '1'
   '9131'  = '1'
   '9132'  = '1'
   '9133'  = '1'
   '9134'  = '1'
   '9135'  = '1'
   '9136'  = '1'
   '9137'  = '1'
   '9138'  = '1'
   '9139'  = '1'
   '9140'  = '1'
   '9141'  = '1'
   '9142'  = '1'
   '9143'  = '1'
   '9144'  = '1'
   '9145'  = '1'
   '9146'  = '1'
   '9147'  = '1'
   '9148'  = '1'
   '9149'  = '1'
   '9150'  = '1'
   '9151'  = '1'
   '9152'  = '1'
   '9153'  = '1'
   '9154'  = '1'
   '9155'  = '1'
   '9156'  = '1'
   '9157'  = '1'
   '9158'  = '1'
   '9159'  = '1'
   '9160'  = '1'
   '9161'  = '1'
   '9162'  = '1'
   '9163'  = '1'
   '9164'  = '1'
   '9165'  = '1'
   '9166'  = '1'
   '9167'  = '1'
   '9168'  = '1'
   '9169'  = '1'
   '9170'  = '1'
   '9171'  = '1'
   '9172'  = '1'
   '9173'  = '1'
   '9174'  = '1'
   '9175'  = '1'
   '9176'  = '1'
   '9177'  = '1'
   '9178'  = '1'
   '9179'  = '1'
   '9180'  = '1'
   '9181'  = '1'
   '9182'  = '1'
   '9189'  = '1'
   '9190'  = '1'
   '9191'  = '1'
   '9192'  = '1'
   '9193'  = '1'
   '9194'  = '1'
   '9195'  = '1'
   '92811' = '1'
   '92820' = '1'
   '92821' = '1'
   '9283'  = '1'
   '9288'  = '1'
   '9289'  = '1'
   '9290'  = '1'
   '9299'  = '1'
   '9500'  = '1'
   '9501'  = '1'
   '9502'  = '1'
   '9503'  = '1'
   '9509'  = '1'
   '9510'  = '1'
   '9511'  = '1'
   '9512'  = '1'
   '9513'  = '1'
   '9514'  = '1'
   '9515'  = '1'
   '9516'  = '1'
   '9517'  = '1'
   '9518'  = '1'
   '9519'  = '1'
   '95200' = '1'
   '95201' = '1'
   '95202' = '1'
   '95203' = '1'
   '95204' = '1'
   '95205' = '1'
   '95206' = '1'
   '95207' = '1'
   '95208' = '1'
   '95209' = '1'
   '95210' = '1'
   '95211' = '1'
   '95212' = '1'
   '95213' = '1'
   '95214' = '1'
   '95215' = '1'
   '95216' = '1'
   '95217' = '1'
   '95218' = '1'
   '95219' = '1'
   '9522'  = '1'
   '9523'  = '1'
   '9524'  = '1'
   '9528'  = '1'
   '9529'  = '1'
   '9530'  = '1'
   '9531'  = '1'
   '9532'  = '1'
   '9533'  = '1'
   '9534'  = '1'
   '9535'  = '1'
   '9538'  = '1'
   '9539'  = '1'
   '9540'  = '1'
   '9541'  = '1'
   '9548'  = '1'
   '9549'  = '1'
   '9550'  = '1'
   '9551'  = '1'
   '9552'  = '1'
   '9553'  = '1'
   '9554'  = '1'
   '9584'  = '1'
   '9585'  = '1'
   '9586'  = '1'
   '9587'  = '1'
   '9588'  = '1'
   '95901' = '1'
   '95909' = '1'
   '95911' = '1'
   '95912' = '1'
   '95913' = '1'
   '95914' = '1'
   '95919' = '1'
   '9592'  = '1'
   '9593'  = '1'
   '9594'  = '1'
   '9595'  = '1'
   '9596'  = '1'
   '9597'  = '1'
   '9598'  = '1'
   '9599'  = '1'
   OTHER   = '0';


   /*Format for Medical_Head*/ 
   VALUE $s1fmt
   '80002' = '1'
   '80003' = '1'
   '80004' = '1'
   '80005' = '1'
   '80010' = '1'
   '80012' = '1'
   '80013' = '1'
   '80014' = '1'
   '80015' = '1'
   '80016' = '1'
   '80019' = '1'
   '80020' = '1'
   '80022' = '1'
   '80023' = '1'
   '80024' = '1'
   '80025' = '1'
   '80026' = '1'
   '80029' = '1'
   '80030' = '1'
   '80032' = '1'
   '80033' = '1'
   '80034' = '1'
   '80035' = '1'
   '80036' = '1'
   '80039' = '1'
   '80040' = '1'
   '80042' = '1'
   '80043' = '1'
   '80044' = '1'
   '80045' = '1'
   '80046' = '1'
   '80049' = '1'
   '80052' = '1'
   '80053' = '1'
   '80054' = '1'
   '80055' = '1'
   '80060' = '1'
   '80061' = '1'
   '80062' = '1'
   '80116' = '1'
   '80119' = '1'
   '80120' = '1'
   '80121' = '1'
   '80122' = '1'
   '80123' = '1'
   '80124' = '1'
   '80125' = '1'
   '80126' = '1'
   '80129' = '1'
   '80130' = '1'
   '80131' = '1'
   '80132' = '1'
   '80133' = '1'
   '80134' = '1'
   '80135' = '1'
   '80136' = '1'
   '80139' = '1'
   '80140' = '1'
   '80141' = '1'
   '80142' = '1'
   '80143' = '1'
   '80144' = '1'
   '80145' = '1'
   '80146' = '1'
   '80149' = '1'
   '80152' = '1'
   '80153' = '1'
   '80154' = '1'
   '80155' = '1'
   '80160' = '1'
   '80161' = '1'
   '80162' = '1'
   '80163' = '1'
   '80164' = '1'
   '80165' = '1'
   '80166' = '1'
   '80169' = '1'
   '80170' = '1'
   '80171' = '1'
   '80172' = '1'
   '80173' = '1'
   '80174' = '1'
   '80175' = '1'
   '80176' = '1'
   '80179' = '1'
   '80180' = '1'
   '80181' = '1'
   '80182' = '1'
   '80183' = '1'
   '80184' = '1'
   '80185' = '1'
   '80186' = '1'
   '80189' = '1'
   '80190' = '1'
   '80191' = '1'
   '80192' = '1'
   '80193' = '1'
   '80194' = '1'
   '80195' = '1'
   '80196' = '1'
   '80199' = '1'
   '80302' = '1'
   '80303' = '1'
   '80304' = '1'
   '80394' = '1'
   '80395' = '1'
   '80396' = '1'
   '80399' = '1'
   '80402' = '1'
   '80403' = '1'
   '80404' = '1'
   '80405' = '1'
   '80406' = '1'
   '80410' = '1'
   '80411' = '1'
   '80412' = '1'
   '80413' = '1'
   '80414' = '1'
   '80415' = '1'
   '80416' = '1'
   '80419' = '1'
   '80420' = '1'
   '80421' = '1'
   '80422' = '1'
   '80423' = '1'
   '80424' = '1'
   '80425' = '1'
   '80426' = '1'
   '80429' = '1'
   '80430' = '1'
   '80431' = '1'
   '80432' = '1'
   '80433' = '1'
   '80434' = '1'
   '80435' = '1'
   '80436' = '1'
   '80439' = '1'
   '80440' = '1'
   '80441' = '1'
   '80442' = '1'
   '80443' = '1'
   '80444' = '1'
   '80445' = '1'
   '80446' = '1'
   '80452' = '1'
   '80453' = '1'
   '80454' = '1'
   '80455' = '1'
   '80460' = '1'
   '80461' = '1'
   '80462' = '1'
   '80463' = '1'
   '80464' = '1'
   '80465' = '1'
   '80466' = '1'
   '80470' = '1'
   '80471' = '1'
   '80472' = '1'
   '80473' = '1'
   '80474' = '1'
   '80475' = '1'
   '80476' = '1'
   '80479' = '1'
   '80480' = '1'
   '80481' = '1'
   '80482' = '1'
   '80483' = '1'
   '80484' = '1'
   '80485' = '1'
   '85164' = '1'
   '85165' = '1'
   '85166' = '1'
   '85169' = '1'
   '85170' = '1'
   '85171' = '1'
   '85172' = '1'
   '85173' = '1'
   '85174' = '1'
   '85175' = '1'
   '85176' = '1'
   '85179' = '1'
   '85180' = '1'
   '85181' = '1'
   '85182' = '1'
   '85183' = '1'
   '85184' = '1'
   '85185' = '1'
   '85186' = '1'
   '85189' = '1'
   '85190' = '1'
   '85191' = '1'
   '85192' = '1'
   '85193' = '1'
   '85194' = '1'
   '85195' = '1'
   '85196' = '1'
   '85199' = '1'
   '85200' = '1'
   '85201' = '1'
   '85202' = '1'
   '85203' = '1'
   '85204' = '1'
   '85205' = '1'
   '85206' = '1'
   '85209' = '1'
   '85210' = '1'
   '85211' = '1'
   '85212' = '1'
   '85213' = '1'
   '85214' = '1'
   '85215' = '1'
   '85216' = '1'
   '85219' = '1'
   '85220' = '1'
   '85221' = '1'
   '85222' = '1'
   '85223' = '1'
   '85224' = '1'
   '85225' = '1'
   '85226' = '1'
   '85229' = '1'
   '85230' = '1'
   '85231' = '1'
   '85232' = '1'
   '85233' = '1'
   '85234' = '1'
   '85235' = '1'
   '80063' = '1'
   '80064' = '1'
   '80065' = '1'
   '80066' = '1'
   '80069' = '1'
   '80070' = '1'
   '80071' = '1'
   '80072' = '1'
   '80073' = '1'
   '80074' = '1'
   '80075' = '1'
   '80076' = '1'
   '80079' = '1'
   '80080' = '1'
   '80081' = '1'
   '80082' = '1'
   '80083' = '1'
   '80084' = '1'
   '80085' = '1'
   '80086' = '1'
   '80089' = '1'
   '80090' = '1'
   '80091' = '1'
   '80092' = '1'
   '80093' = '1'
   '80094' = '1'
   '80095' = '1'
   '80096' = '1'
   '80099' = '1'
   '80102' = '1'
   '80103' = '1'
   '80104' = '1'
   '80105' = '1'
   '80110' = '1'
   '80111' = '1'
   '80112' = '1'
   '80113' = '1'
   '80114' = '1'
   '80115' = '1'
   '80305' = '1'
   '80310' = '1'
   '80311' = '1'
   '80312' = '1'
   '80313' = '1'
   '80314' = '1'
   '80315' = '1'
   '80316' = '1'
   '80319' = '1'
   '80320' = '1'
   '80321' = '1'
   '80322' = '1'
   '80323' = '1'
   '80324' = '1'
   '80325' = '1'
   '80326' = '1'
   '80329' = '1'
   '80330' = '1'
   '80331' = '1'
   '80332' = '1'
   '80333' = '1'
   '80334' = '1'
   '80335' = '1'
   '80336' = '1'
   '80339' = '1'
   '80340' = '1'
   '80341' = '1'
   '80342' = '1'
   '80343' = '1'
   '80344' = '1'
   '80345' = '1'
   '80346' = '1'
   '80349' = '1'
   '80352' = '1'
   '80353' = '1'
   '80354' = '1'
   '80355' = '1'
   '80360' = '1'
   '80361' = '1'
   '80362' = '1'
   '80363' = '1'
   '80364' = '1'
   '80365' = '1'
   '80366' = '1'
   '80369' = '1'
   '80370' = '1'
   '80371' = '1'
   '80372' = '1'
   '80373' = '1'
   '80374' = '1'
   '80375' = '1'
   '80376' = '1'
   '80379' = '1'
   '80380' = '1'
   '80381' = '1'
   '80382' = '1'
   '80383' = '1'
   '80384' = '1'
   '80385' = '1'
   '80386' = '1'
   '80389' = '1'
   '80390' = '1'
   '80391' = '1'
   '80392' = '1'
   '80393' = '1'
   '80486' = '1'
   '80489' = '1'
   '80490' = '1'
   '80491' = '1'
   '80492' = '1'
   '80493' = '1'
   '80494' = '1'
   '80495' = '1'
   '80496' = '1'
   '80499' = '1'
   '8502'  = '1'
   '8503'  = '1'
   '8504'  = '1'
   '85100' = '1'
   '85101' = '1'
   '85102' = '1'
   '85103' = '1'
   '85104' = '1'
   '85105' = '1'
   '85106' = '1'
   '85109' = '1'
   '85110' = '1'
   '85111' = '1'
   '85112' = '1'
   '85113' = '1'
   '85114' = '1'
   '85115' = '1'
   '85116' = '1'
   '85119' = '1'
   '85120' = '1'
   '85121' = '1'
   '85122' = '1'
   '85123' = '1'
   '85124' = '1'
   '85125' = '1'
   '85126' = '1'
   '85129' = '1'
   '85130' = '1'
   '85131' = '1'
   '85132' = '1'
   '85133' = '1'
   '85134' = '1'
   '85135' = '1'
   '85136' = '1'
   '85139' = '1'
   '85140' = '1'
   '85141' = '1'
   '85142' = '1'
   '85143' = '1'
   '85144' = '1'
   '85145' = '1'
   '85146' = '1'
   '85149' = '1'
   '85150' = '1'
   '85151' = '1'
   '85152' = '1'
   '85153' = '1'
   '85154' = '1'
   '85155' = '1'
   '85156' = '1'
   '85159' = '1'
   '85160' = '1'
   '85161' = '1'
   '85162' = '1'
   '85163' = '1'
   '85236' = '1'
   '85239' = '1'
   '85240' = '1'
   '85241' = '1'
   '85242' = '1'
   '85243' = '1'
   '85244' = '1'
   '85245' = '1'
   '85246' = '1'
   '85249' = '1'
   '85250' = '1'
   '85251' = '1'
   '85252' = '1'
   '85253' = '1'
   '85254' = '1'
   '85255' = '1'
   '85256' = '1'
   '85259' = '1'
   '85300' = '1'
   '85301' = '1'
   '85302' = '1'
   '85303' = '1'
   '85304' = '1'
   '85305' = '1'
   '85306' = '1'
   '85309' = '1'
   '85310' = '1'
   '85311' = '1'
   '85312' = '1'
   '85313' = '1'
   '85314' = '1'
   '85315' = '1'
   '85316' = '1'
   '85319' = '1'
   '85400' = '1'
   '85401' = '1'
   '85402' = '1'
   '85403' = '1'
   '85404' = '1'
   '85405' = '1'
   '85406' = '1'
   '85409' = '1'
   '85410' = '1'
   '85411' = '1'
   '85412' = '1'
   '85413' = '1'
   '85414' = '1'
   '85415' = '1'
   '85416' = '1'
   '85419' = '1'
   '90001' = '1'
   '90002' = '1'
   '90003' = '1'
   '9001'  = '1'
   '90081' = '1'
   '90082' = '1'
   '9251'  = '1'
   '9252'  = '1'
   OTHER   = '0';
   /*Format for Medical_Chest*/ 
   VALUE $s2fmt
   '80707' = '1'
   '80708' = '1'
   '80716' = '1'
   '80717' = '1'
   '80718' = '1'
   '80719' = '1'
   '8073'  = '1'
   '8074'  = '1'
   '8075'  = '1'
   '8076'  = '1'
   '8191'  = '1'
   '83971' = '1'
   '8600'  = '1'
   '8601'  = '1'
   '8602'  = '1'
   '8603'  = '1'
   '8604'  = '1'
   '8605'  = '1'
   '86100' = '1'
   '86101' = '1'
   '86102' = '1'
   '86103' = '1'
   '86110' = '1'
   '86111' = '1'
   '86112' = '1'
   '86113' = '1'
   '86120' = '1'
   '86121' = '1'
   '86122' = '1'
   '86130' = '1'
   '80714' = '1'
   '80715' = '1'
   '86131' = '1'
   '86132' = '1'
   '8620'  = '1'
   '8621'  = '1'
   '86221' = '1'
   '86222' = '1'
   '86229' = '1'
   '86231' = '1'
   '86232' = '1'
   '86239' = '1'
   '8628'  = '1'
   '8629'  = '1'
   '87410' = '1'
   '87411' = '1'
   '87412' = '1'
   '9010'  = '1'
   '9011'  = '1'
   '9012'  = '1'
   '9013'  = '1'
   '90140' = '1'
   '90141' = '1'
   '90142' = '1'
   '90183' = '1'
   '90189' = '1'
   '9019'  = '1'
   '92701' = '1'
   '9580'  = '1'
   '9581'  = '1'
   OTHER   = '0';
   /*Format for Medical_Abdominal*/ 
   VALUE $s3fmt
   '8630'  = '1'
   '8631'  = '1'
   '86320' = '1'
   '86321' = '1'
   '86329' = '1'
   '86330' = '1'
   '86331' = '1'
   '86339' = '1'
   '86340' = '1'
   '86341' = '1'
   '86342' = '1'
   '86343' = '1'
   '86344' = '1'
   '86345' = '1'
   '86346' = '1'
   '86349' = '1'
   '86350' = '1'
   '86351' = '1'
   '86352' = '1'
   '86353' = '1'
   '86354' = '1'
   '86355' = '1'
   '86356' = '1'
   '86359' = '1'
   '86381' = '1'
   '86382' = '1'
   '86383' = '1'
   '86384' = '1'
   '86385' = '1'
   '86389' = '1'
   '86390' = '1'
   '86391' = '1'
   '86809' = '1'
   '86812' = '1'
   '86813' = '1'
   '86814' = '1'
   '86819' = '1'
   '9020'  = '1'
   '90210' = '1'
   '90211' = '1'
   '90219' = '1'
   '90220' = '1'
   '90221' = '1'
   '90222' = '1'
   '90223' = '1'
   '90224' = '1'
   '90225' = '1'
   '90226' = '1'
   '90227' = '1'
   '90229' = '1'
   '90231' = '1'
   '90232' = '1'
   '86392' = '1'
   '86393' = '1'
   '86394' = '1'
   '86395' = '1'
   '86399' = '1'
   '86400' = '1'
   '86401' = '1'
   '86402' = '1'
   '86403' = '1'
   '86404' = '1'
   '86405' = '1'
   '86409' = '1'
   '86410' = '1'
   '86411' = '1'
   '86412' = '1'
   '86413' = '1'
   '86414' = '1'
   '86415' = '1'
   '86419' = '1'
   '86500' = '1'
   '86501' = '1'
   '86502' = '1'
   '86503' = '1'
   '86504' = '1'
   '86509' = '1'
   '86510' = '1'
   '86511' = '1'
   '86512' = '1'
   '86513' = '1'
   '86514' = '1'
   '86519' = '1'
   '86802' = '1'
   '90233' = '1'
   '90234' = '1'
   '90239' = '1'
   '90240' = '1'
   '90241' = '1'
   '90242' = '1'
   '90249' = '1'
   '90250' = '1'
   '90251' = '1'
   '90252' = '1'
   '90253' = '1'
   '90254' = '1'
   '90255' = '1'
   '90256' = '1'
   '90259' = '1'
   '90281' = '1'
   '90282' = '1'
   '90287' = '1'
   '90289' = '1'
   '9029'  = '1'
   OTHER   = '0';
   /*Format for Medical_Kidney*/ 
   VALUE $s4fmt
   '86600' = '1'
   '86601' = '1'
   '86602' = '1'
   '86603' = '1'
   '86610' = '1'
   '86611' = '1'
   '86612' = '1'
   '86613' = '1'
   '86801' = '1'
   '86811' = '1'
   OTHER   = '0';
   /*Format for Medical_Urinary*/ 
   VALUE $s5fmt
   '8670'  = '1'
   '8671'  = '1'
   '8672'  = '1'
   '8673'  = '1'
   '8674'  = '1'
   '8675'  = '1'
   '8676'  = '1'
   '8677'  = '1'
   '8678'  = '1'
   '8679'  = '1'
   OTHER   = '0';
   /*Format for Medical_Pelvis_Spine*/ 
   VALUE $s6fmt
   '8056'  = '1'
   '8057'  = '1'
   '80600' = '1'
   '80601' = '1'
   '80602' = '1'
   '80603' = '1'
   '80604' = '1'
   '80605' = '1'
   '80606' = '1'
   '80607' = '1'
   '80608' = '1'
   '80609' = '1'
   '80610' = '1'
   '80611' = '1'
   '80612' = '1'
   '80613' = '1'
   '80614' = '1'
   '80615' = '1'
   '80616' = '1'
   '80617' = '1'
   '80618' = '1'
   '80619' = '1'
   '80660' = '1'
   '80670' = '1'
   '80671' = '1'
   '80672' = '1'
   '80679' = '1'
   '8068'  = '1'
   '8069'  = '1'
   '8080'  = '1'
   '8081'  = '1'
   '8082'  = '1'
   '8083'  = '1'
   '80841' = '1'
   '80842' = '1'
   '80843' = '1'
   '80849' = '1'
   '80851' = '1'
   '80852' = '1'
   '80853' = '1'
   '80859' = '1'
   '8088'  = '1'
   '8089'  = '1'
   '8091'  = '1'
   '83900' = '1'
   '83901' = '1'
   '83902' = '1'
   '83903' = '1'
   '83904' = '1'
   '83905' = '1'
   '83906' = '1'
   '83907' = '1'
   '83908' = '1'
   '83910' = '1'
   '83911' = '1'
   '83912' = '1'
   '83913' = '1'
   '83914' = '1'
   '83915' = '1'
   '83916' = '1'
   '83917' = '1'
   '80620' = '1'
   '80621' = '1'
   '80622' = '1'
   '80623' = '1'
   '80624' = '1'
   '80625' = '1'
   '80626' = '1'
   '80627' = '1'
   '80628' = '1'
   '80629' = '1'
   '80630' = '1'
   '80631' = '1'
   '80632' = '1'
   '80633' = '1'
   '80634' = '1'
   '80635' = '1'
   '80636' = '1'
   '80637' = '1'
   '80638' = '1'
   '80639' = '1'
   '8064'  = '1'
   '8065'  = '1'
   '83918' = '1'
   '83952' = '1'
   '83959' = '1'
   '86803' = '1'
   '86804' = '1'
   '92611' = '1'
   '92619' = '1'
   '9268'  = '1'
   '9269'  = '1'
   '95200' = '1'
   '95201' = '1'
   '95202' = '1'
   '95203' = '1'
   '95204' = '1'
   '95205' = '1'
   '95206' = '1'
   '95207' = '1'
   '95208' = '1'
   '95209' = '1'
   '95210' = '1'
   '95211' = '1'
   '95212' = '1'
   '95213' = '1'
   '95214' = '1'
   '95215' = '1'
   '95216' = '1'
   '95217' = '1'
   '95218' = '1'
   '95219' = '1'
   '9522'  = '1'
   '9523'  = '1'
   '9524'  = '1'
   '9528'  = '1'
   '9529'  = '1'
   '9535'  = '1'
   '9538'  = '1'
   '9548'  = '1'
   '9549'  = '1'
   OTHER   = '0';
   /*Format for Medical_UpperLimb*/ 
   VALUE $s7fmt
   '81210' = '1'
   '81211' = '1'
   '81212' = '1'
   '81213' = '1'
   '81219' = '1'
   '81230' = '1'
   '81231' = '1'
   '81250' = '1'
   '81251' = '1'
   '81252' = '1'
   '81253' = '1'
   '81254' = '1'
   '81259' = '1'
   '81310' = '1'
   '81311' = '1'
   '81312' = '1'
   '81313' = '1'
   '81314' = '1'
   '81315' = '1'
   '81316' = '1'
   '81317' = '1'
   '83210' = '1'
   '83211' = '1'
   '83212' = '1'
   '83213' = '1'
   '83214' = '1'
   '83219' = '1'
   '8870'  = '1'
   '8871'  = '1'
   '8872'  = '1'
   '8873'  = '1'
   '8874'  = '1'
   '8875'  = '1'
   '8876'  = '1'
   '8877'  = '1'
   '90300' = '1'
   '90301' = '1'
   '90302' = '1'
   '9031'  = '1'
   '9032'  = '1'
   '81318' = '1'
   '81330' = '1'
   '81331' = '1'
   '81332' = '1'
   '81333' = '1'
   '81350' = '1'
   '81351' = '1'
   '81352' = '1'
   '81353' = '1'
   '81354' = '1'
   '81390' = '1'
   '81391' = '1'
   '81392' = '1'
   '81393' = '1'
   '8181'  = '1'
   '83110' = '1'
   '83111' = '1'
   '83112' = '1'
   '83113' = '1'
   '83114' = '1'
   '83119' = '1'
   '9033'  = '1'
   '9038'  = '1'
   '9039'  = '1'
   '92700' = '1'
   '92702' = '1'
   '92703' = '1'
   '92709' = '1'
   '92710' = '1'
   '92711' = '1'
   '9278'  = '1'
   '9279'  = '1'
   '9534'  = '1'
   '9550'  = '1'
   '9551'  = '1'
   '9552'  = '1'
   '9553'  = '1'
   '9558'  = '1'
   '9586'  = '1'
   OTHER   = '0';
   /*Format for Medical_LowerLimb*/ 
   VALUE $s8fmt
   '82000' = '1'
   '82001' = '1'
   '82002' = '1'
   '82003' = '1'
   '82009' = '1'
   '82010' = '1'
   '82011' = '1'
   '82012' = '1'
   '82013' = '1'
   '82019' = '1'
   '82020' = '1'
   '82021' = '1'
   '82022' = '1'
   '82030' = '1'
   '82031' = '1'
   '82032' = '1'
   '8208'  = '1'
   '8209'  = '1'
   '82100' = '1'
   '82101' = '1'
   '82110' = '1'
   '82111' = '1'
   '82120' = '1'
   '82121' = '1'
   '82122' = '1'
   '82123' = '1'
   '82129' = '1'
   '82130' = '1'
   '82131' = '1'
   '82132' = '1'
   '82133' = '1'
   '82139' = '1'
   '82310' = '1'
   '82311' = '1'
   '82312' = '1'
   '82330' = '1'
   '82331' = '1'
   '82332' = '1'
   '82340' = '1'
   '82341' = '1'
   '82342' = '1'
   '92800' = '1'
   '92801' = '1'
   '92810' = '1'
   '92811' = '1'
   '9288'  = '1'
   '9289'  = '1'
   '82390' = '1'
   '82391' = '1'
   '82392' = '1'
   '8280'  = '1'
   '8281'  = '1'
   '83510' = '1'
   '83511' = '1'
   '83512' = '1'
   '83513' = '1'
   '83660' = '1'
   '83661' = '1'
   '83662' = '1'
   '83663' = '1'
   '83664' = '1'
   '83669' = '1'
   '8371'  = '1'
   '8960'  = '1'
   '8961'  = '1'
   '8962'  = '1'
   '8963'  = '1'
   '8970'  = '1'
   '8971'  = '1'
   '8972'  = '1'
   '8973'  = '1'
   '8974'  = '1'
   '8975'  = '1'
   '8976'  = '1'
   '8977'  = '1'
   '9040'  = '1'
   '9041'  = '1'
   '9042'  = '1'
   '90440' = '1'
   '90441' = '1'
   '90442' = '1'
   '90450' = '1'
   '90451' = '1'
   '90452' = '1'
   '90453' = '1'
   '90454' = '1'
   '9047'  = '1'
   '92612' = '1'
   '9560'  = '1'
   '9561'  = '1'
   '9562'  = '1'
   '9563'  = '1'
   '9568'  = '1'
   '9569'  = '1'
   OTHER   = '0';



/* -------------------------------------------------------------- */
/* --- FORMATS FOR MDC using principal diagnosis for MEDICARE data*/
/* -------------------------------------------------------------- */

   VALUE $DX1MDC
   '0010'  = 06
   '0011'  = 06
   '0019'  = 06
   '0020'  = 18
   '0021'  = 18
   '0022'  = 18
   '0023'  = 18
   '0029'  = 18
   '0030'  = 06
   '0031'  = 18
   '00320' = 18
   '00321' = 01
   '00322' = 04
   '00323' = 08
   '00324' = 08
   '00329' = 18
   '0038'  = 18
   '0039'  = 18
   '0040'  = 06
   '0041'  = 06
   '0042'  = 06
   '0043'  = 06
   '0048'  = 06
   '0049'  = 06
   '0050'  = 06
   '0051'  = 18
   '0052'  = 06
   '0053'  = 06
   '0054'  = 06
   '00581' = 06
   '00589' = 06
   '0059'  = 06
   '0060'  = 06
   '0061'  = 06
   '0062'  = 06
   '0063'  = 07
   '0064'  = 04
   '0065'  = 01
   '0066'  = 09
   '0068'  = 18
   '0069'  = 18
   '0070'  = 06
   '0071'  = 06
   '0072'  = 06
   '0073'  = 06
   '0074'  = 06
   '0075'  = 06
   '0078'  = 06
   '0079'  = 06
   '00800' = 06
   '00801' = 06
   '00802' = 06
   '00803' = 06
   '00804' = 06
   '00809' = 06
   '0081'  = 06
   '0082'  = 06
   '0083'  = 06
   '00841' = 06
   '00842' = 06
   '00843' = 06
   '00844' = 06
   '00845' = 06
   '00846' = 06
   '00847' = 06
   '00849' = 06
   '0085'  = 06
   '00861' = 06
   '00862' = 06
   '00863' = 06
   '00864' = 06
   '00865' = 06
   '00866' = 06
   '00867' = 06
   '00869' = 06
   '0088'  = 06
   '0090'  = 06
   '0091'  = 06
   '0092'  = 06
   '0093'  = 06
   '01000' = 04
   '01001' = 04
   '01002' = 04
   '01003' = 04
   '01004' = 04
   '01005' = 04
   '01006' = 04
   '01010' = 04
   '01011' = 04
   '01012' = 04
   '01013' = 04
   '01014' = 04
   '01015' = 04
   '01016' = 04
   '01080' = 04
   '01081' = 04
   '01082' = 04
   '01083' = 04
   '01084' = 04
   '01085' = 04
   '01086' = 04
   '01090' = 04
   '01091' = 04
   '01092' = 04
   '01093' = 04
   '01094' = 04
   '01095' = 04
   '01096' = 04
   '01100' = 04
   '01101' = 04
   '01102' = 04
   '01103' = 04
   '01104' = 04
   '01105' = 04
   '01106' = 04
   '01110' = 04
   '01111' = 04
   '01112' = 04
   '01113' = 04
   '01114' = 04
   '01115' = 04
   '01116' = 04
   '01120' = 04
   '01121' = 04
   '01122' = 04
   '01123' = 04
   '01124' = 04
   '01125' = 04
   '01126' = 04
   '01130' = 04
   '01131' = 04
   '01132' = 04
   '01133' = 04
   '01134' = 04
   '01135' = 04
   '01136' = 04
   '01140' = 04
   '01141' = 04
   '01142' = 04
   '01143' = 04
   '01144' = 04
   '01145' = 04
   '01146' = 04
   '01150' = 04
   '01151' = 04
   '01152' = 04
   '01153' = 04
   '01154' = 04
   '01155' = 04
   '01156' = 04
   '01160' = 04
   '01161' = 04
   '01162' = 04
   '01163' = 04
   '01164' = 04
   '01165' = 04
   '01166' = 04
   '01170' = 04
   '01171' = 04
   '01172' = 04
   '01173' = 04
   '01174' = 04
   '01175' = 04
   '01176' = 04
   '01180' = 04
   '01181' = 04
   '01182' = 04
   '01183' = 04
   '01184' = 04
   '01185' = 04
   '01186' = 04
   '01190' = 04
   '01191' = 04
   '01192' = 04
   '01193' = 04
   '01194' = 04
   '01195' = 04
   '01196' = 04
   '01200' = 04
   '01201' = 04
   '01202' = 04
   '01203' = 04
   '01204' = 04
   '01205' = 04
   '01206' = 04
   '01210' = 04
   '01211' = 04
   '01212' = 04
   '01213' = 04
   '01214' = 04
   '01215' = 04
   '01216' = 04
   '01220' = 04
   '01221' = 04
   '01222' = 04
   '01223' = 04
   '01224' = 04
   '01225' = 04
   '01226' = 04
   '01230' = 03
   '01231' = 03
   '01232' = 03
   '01233' = 03
   '01234' = 03
   '01235' = 03
   '01236' = 03
   '01280' = 04
   '01281' = 04
   '01282' = 04
   '01283' = 04
   '01284' = 04
   '01285' = 04
   '01286' = 04
   '01300' = 01
   '01301' = 01
   '01302' = 01
   '01303' = 01
   '01304' = 01
   '01305' = 01
   '01306' = 01
   '01310' = 01
   '01311' = 01
   '01312' = 01
   '01313' = 01
   '01314' = 01
   '01315' = 01
   '01316' = 01
   '01320' = 01
   '01321' = 01
   '01322' = 01
   '01323' = 01
   '01324' = 01
   '01325' = 01
   '01326' = 01
   '01330' = 01
   '01331' = 01
   '01332' = 01
   '01333' = 01
   '01334' = 01
   '01335' = 01
   '01336' = 01
   '01340' = 01
   '01341' = 01
   '01342' = 01
   '01343' = 01
   '01344' = 01
   '01345' = 01
   '01346' = 01
   '01350' = 01
   '01351' = 01
   '01352' = 01
   '01353' = 01
   '01354' = 01
   '01355' = 01
   '01356' = 01
   '01360' = 01
   '01361' = 01
   '01362' = 01
   '01363' = 01
   '01364' = 01
   '01365' = 01
   '01366' = 01
   '01380' = 01
   '01381' = 01
   '01382' = 01
   '01383' = 01
   '01384' = 01
   '01385' = 01
   '01386' = 01
   '01390' = 01
   '01391' = 01
   '01392' = 01
   '01393' = 01
   '01394' = 01
   '01395' = 01
   '01396' = 01
   '01400' = 06
   '01401' = 06
   '01402' = 06
   '01403' = 06
   '01404' = 06
   '01405' = 06
   '01406' = 06
   '01480' = 06
   '01481' = 06
   '01482' = 06
   '01483' = 06
   '01484' = 06
   '01485' = 06
   '01486' = 06
   '01500' = 08
   '01501' = 08
   '01502' = 08
   '01503' = 08
   '01504' = 08
   '01505' = 08
   '01506' = 08
   '01510' = 08
   '01511' = 08
   '01512' = 08
   '01513' = 08
   '01514' = 08
   '01515' = 08
   '01516' = 08
   '01520' = 08
   '01521' = 08
   '01522' = 08
   '01523' = 08
   '01524' = 08
   '01525' = 08
   '01526' = 08
   '01550' = 08
   '01551' = 08
   '01552' = 08
   '01553' = 08
   '01554' = 08
   '01555' = 08
   '01556' = 08
   '01560' = 03
   '01561' = 03
   '01562' = 03
   '01563' = 03
   '01564' = 03
   '01565' = 03
   '01566' = 03
   '01570' = 08
   '01571' = 08
   '01572' = 08
   '01573' = 08
   '01574' = 08
   '01575' = 08
   '01576' = 08
   '01580' = 08
   '01581' = 08
   '01582' = 08
   '01583' = 08
   '01584' = 08
   '01585' = 08
   '01586' = 08
   '01590' = 08
   '01591' = 08
   '01592' = 08
   '01593' = 08
   '01594' = 08
   '01595' = 08
   '01596' = 08
   '01600' = 11
   '01601' = 11
   '01602' = 11
   '01603' = 11
   '01604' = 11
   '01605' = 11
   '01606' = 11
   '01610' = 11
   '01611' = 11
   '01612' = 11
   '01613' = 11
   '01614' = 11
   '01615' = 11
   '01616' = 11
   '01620' = 11
   '01621' = 11
   '01622' = 11
   '01623' = 11
   '01624' = 11
   '01625' = 11
   '01626' = 11
   '01630' = 11
   '01631' = 11
   '01632' = 11
   '01633' = 11
   '01634' = 11
   '01635' = 11
   '01636' = 11
   '01640' = 12
   '01641' = 12
   '01642' = 12
   '01643' = 12
   '01644' = 12
   '01645' = 12
   '01646' = 12
   '01650' = 12
   '01651' = 12
   '01652' = 12
   '01653' = 12
   '01654' = 12
   '01655' = 12
   '01656' = 12
   '01660' = 13
   '01661' = 13
   '01662' = 13
   '01663' = 13
   '01664' = 13
   '01665' = 13
   '01666' = 13
   '01670' = 13
   '01671' = 13
   '01672' = 13
   '01673' = 13
   '01674' = 13
   '01675' = 13
   '01676' = 13
   '01690' = 11
   '01691' = 11
   '01692' = 11
   '01693' = 11
   '01694' = 11
   '01695' = 11
   '01696' = 11
   '01700' = 09
   '01701' = 09
   '01702' = 09
   '01703' = 09
   '01704' = 09
   '01705' = 09
   '01706' = 09
   '01710' = 09
   '01711' = 09
   '01712' = 09
   '01713' = 09
   '01714' = 09
   '01715' = 09
   '01716' = 09
   '01720' = 16
   '01721' = 16
   '01722' = 16
   '01723' = 16
   '01724' = 16
   '01725' = 16
   '01726' = 16
   '01730' = 02
   '01731' = 02
   '01732' = 02
   '01733' = 02
   '01734' = 02
   '01735' = 02
   '01736' = 02
   '01740' = 03
   '01741' = 03
   '01742' = 03
   '01743' = 03
   '01744' = 03
   '01745' = 03
   '01746' = 03
   '01750' = 10
   '01751' = 10
   '01752' = 10
   '01753' = 10
   '01754' = 10
   '01755' = 10
   '01756' = 10
   '01760' = 10
   '01761' = 10
   '01762' = 10
   '01763' = 10
   '01764' = 10
   '01765' = 10
   '01766' = 10
   '01770' = 16
   '01771' = 16
   '01772' = 16
   '01773' = 16
   '01774' = 16
   '01775' = 16
   '01776' = 16
   '01780' = 06
   '01781' = 06
   '01782' = 06
   '01783' = 06
   '01784' = 06
   '01785' = 06
   '01786' = 06
   '01790' = 18
   '01791' = 18
   '01792' = 18
   '01793' = 18
   '01794' = 18
   '01795' = 18
   '01796' = 18
   '01800' = 18
   '01801' = 18
   '01802' = 18
   '01803' = 18
   '01804' = 18
   '01805' = 18
   '01806' = 18
   '01880' = 18
   '01881' = 18
   '01882' = 18
   '01883' = 18
   '01884' = 18
   '01885' = 18
   '01886' = 18
   '01890' = 18
   '01891' = 18
   '01892' = 18
   '01893' = 18
   '01894' = 18
   '01895' = 18
   '01896' = 18
   '0200'  = 18
   '0201'  = 18
   '0202'  = 18
   '0203'  = 04
   '0204'  = 04
   '0205'  = 04
   '0208'  = 18
   '0209'  = 18
   '0210'  = 18
   '0211'  = 06
   '0212'  = 04
   '0213'  = 18
   '0218'  = 18
   '0219'  = 18
   '0220'  = 09
   '0221'  = 04
   '0222'  = 06
   '0223'  = 18
   '0228'  = 18
   '0229'  = 18
   '0230'  = 18
   '0231'  = 18
   '0232'  = 18
   '0233'  = 18
   '0238'  = 18
   '0239'  = 18
   '024'   = 18
   '025'   = 18
   '0260'  = 18
   '0261'  = 18
   '0269'  = 18
   '0270'  = 18
   '0271'  = 18
   '0272'  = 18
   '0278'  = 18
   '0279'  = 18
   '0300'  = 18
   '0301'  = 18
   '0302'  = 18
   '0303'  = 18
   '0308'  = 18
   '0309'  = 18
   '0310'  = 04
   '0311'  = 09
   '0312'  = 18
   '0318'  = 18
   '0319'  = 18
   '0320'  = 03
   '0321'  = 03
   '0322'  = 03
   '0323'  = 03
   '03281' = 02
   '03282' = 05
   '03283' = 06
   '03284' = 11
   '03285' = 09
   '03289' = 18
   '0329'  = 18
   '0330'  = 04
   '0331'  = 04
   '0338'  = 04
   '0339'  = 04
   '0340'  = 03
   '0341'  = 18
   '035'   = 09
   '0360'  = 01
   '0361'  = 01
   '0362'  = 18
   '0363'  = 18
   '03640' = 05
   '03641' = 05
   '03642' = 05
   '03643' = 05
   '03681' = 02
   '03682' = 08
   '03689' = 18
   '0369'  = 18
   '037'   = 18
   '0380'  = 18
   '03810' = 18
   '03811' = 18
   '03812' = 18
   '03819' = 18
   '0382'  = 18
   '0383'  = 18
   '03840' = 18
   '03841' = 18
   '03842' = 18
   '03843' = 18
   '03844' = 18
   '03849' = 18
   '0388'  = 18
   '0389'  = 18
   '0390'  = 09
   '0391'  = 04
   '0392'  = 06
   '0393'  = 09
   '0394'  = 09
   '0398'  = 18
   '0399'  = 18
   '0400'  = 18
   '0401'  = 18
   '0402'  = 06
   '0403'  = 18
   '04041' = 18
   '04042' = 18
   '04081' = 08
   '04082' = 18
   '04089' = 18
   '04100' = 18
   '04101' = 18
   '04102' = 18
   '04103' = 18
   '04104' = 18
   '04105' = 18
   '04109' = 18
   '04110' = 18
   '04111' = 18
   '04112' = 18
   '04119' = 18
   '0412'  = 18
   '0413'  = 18
   '04141' = 18
   '04142' = 18
   '04143' = 18
   '04149' = 18
   '0415'  = 18
   '0416'  = 18
   '0417'  = 18
   '04181' = 18
   '04182' = 18
   '04183' = 18
   '04184' = 18
   '04185' = 18
   '04186' = 18
   '04189' = 18
   '0419'  = 18
   '042'   = 25
   '04500' = 01
   '04501' = 01
   '04502' = 01
   '04503' = 01
   '04510' = 01
   '04511' = 01
   '04512' = 01
   '04513' = 01
   '04520' = 18
   '04521' = 18
   '04522' = 18
   '04523' = 18
   '04590' = 01
   '04591' = 01
   '04592' = 01
   '04593' = 01
   '0460'  = 01
   '04611' = 01
   '04619' = 01
   '0462'  = 01
   '0463'  = 01
   '04671' = 01
   '04672' = 01
   '04679' = 01
   '0468'  = 01
   '0469'  = 01
   '0470'  = 01
   '0471'  = 01
   '0478'  = 01
   '0479'  = 01
   '048'   = 01
   '0490'  = 01
   '0491'  = 01
   '0498'  = 01
   '0499'  = 01
   '0500'  = 18
   '0501'  = 18
   '0502'  = 18
   '0509'  = 18
   '05101' = 18
   '05102' = 18
   '0511'  = 09
   '0512'  = 09
   '0519'  = 18
   '0520'  = 01
   '0521'  = 04
   '0522'  = 01
   '0527'  = 18
   '0528'  = 18
   '0529'  = 18
   '0530'  = 01
   '05310' = 01
   '05311' = 01
   '05312' = 01
   '05313' = 01
   '05314' = 01
   '05319' = 01
   '05320' = 02
   '05321' = 02
   '05322' = 02
   '05329' = 02
   '05371' = 03
   '05379' = 18
   '0538'  = 18
   '0539'  = 09
   '0540'  = 09
   '05410' = 12
   '05411' = 13
   '05412' = 13
   '05413' = 12
   '05419' = 12
   '0542'  = 03
   '0543'  = 01
   '05440' = 02
   '05441' = 02
   '05442' = 02
   '05443' = 02
   '05444' = 02
   '05449' = 02
   '0545'  = 18
   '0546'  = 09
   '05471' = 06
   '05472' = 01
   '05473' = 03
   '05474' = 01
   '05479' = 18
   '0548'  = 18
   '0549'  = 09
   '0550'  = 01
   '0551'  = 04
   '0552'  = 03
   '05571' = 02
   '05579' = 18
   '0558'  = 18
   '0559'  = 18
   '05600' = 01
   '05601' = 01
   '05609' = 01
   '05671' = 08
   '05679' = 18
   '0568'  = 18
   '0569'  = 18
   '0570'  = 18
   '0578'  = 18
   '0579'  = 18
   '05810' = 18
   '05811' = 18
   '05812' = 18
   '05821' = 01
   '05829' = 01
   '05881' = 09
   '05882' = 09
   '05889' = 09
   '05900' = 18
   '05901' = 18
   '05909' = 18
   '05910' = 18
   '05911' = 18
   '05912' = 18
   '05919' = 18
   '05920' = 18
   '05921' = 18
   '05922' = 18
   '0598'  = 18
   '0599'  = 18
   '0600'  = 18
   '0601'  = 18
   '0609'  = 18
   '061'   = 18
   '0620'  = 01
   '0621'  = 01
   '0622'  = 01
   '0623'  = 01
   '0624'  = 01
   '0625'  = 01
   '0628'  = 01
   '0629'  = 01
   '0630'  = 01
   '0631'  = 01
   '0632'  = 01
   '0638'  = 01
   '0639'  = 01
   '064'   = 01
   '0650'  = 18
   '0651'  = 18
   '0652'  = 18
   '0653'  = 18
   '0654'  = 18
   '0658'  = 18
   '0659'  = 18
   '0660'  = 18
   '0661'  = 18
   '0662'  = 01
   '0663'  = 18
   '06640' = 18
   '06641' = 18
   '06642' = 18
   '06649' = 18
   '0668'  = 18
   '0669'  = 18
   '0700'  = 07
   '0701'  = 07
   '07020' = 07
   '07021' = 07
   '07022' = 07
   '07023' = 07
   '07030' = 07
   '07031' = 07
   '07032' = 07
   '07033' = 07
   '07041' = 07
   '07042' = 07
   '07043' = 07
   '07044' = 07
   '07049' = 07
   '07051' = 07
   '07052' = 07
   '07053' = 07
   '07054' = 07
   '07059' = 07
   '0706'  = 07
   '07070' = 07
   '07071' = 07
   '0709'  = 07
   '071'   = 01
   '0720'  = 12
   '0721'  = 01
   '0722'  = 01
   '0723'  = 07
   '07271' = 07
   '07272' = 01
   '07279' = 18
   '0728'  = 18
   '0729'  = 18
   '0730'  = 04
   '0737'  = 18
   '0738'  = 18
   '0739'  = 18
   '0740'  = 03
   '0741'  = 04
   '07420' = 05
   '07421' = 05
   '07422' = 05
   '07423' = 05
   '0743'  = 18
   '0748'  = 18
   '075'   = 18
   '0760'  = 02
   '0761'  = 02
   '0769'  = 02
   '0770'  = 02
   '0771'  = 02
   '0772'  = 02
   '0773'  = 02
   '0774'  = 02
   '0778'  = 02
   '07798' = 02
   '07799' = 02
   '0780'  = 09
   '07810' = 09
   '07811' = 09
   '07812' = 09
   '07819' = 09
   '0782'  = 18
   '0783'  = 16
   '0784'  = 18
   '0785'  = 18
   '0786'  = 11
   '0787'  = 18
   '07881' = 01
   '07882' = 06
   '07888' = 18
   '07889' = 18
   '0790'  = 18
   '0791'  = 18
   '0792'  = 18
   '0793'  = 18
   '0794'  = 18
   '07950' = 18
   '07951' = 18
   '07952' = 18
   '07953' = 18
   '07959' = 18
   '0796'  = 18
   '07981' = 18
   '07982' = 18
   '07983' = 18
   '07988' = 18
   '07989' = 18
   '07998' = 18
   '07999' = 18
   '080'   = 18
   '0810'  = 18
   '0811'  = 18
   '0812'  = 18
   '0819'  = 18
   '0820'  = 18
   '0821'  = 18
   '0822'  = 18
   '0823'  = 18
   '08240' = 18
   '08241' = 18
   '08249' = 18
   '0828'  = 18
   '0829'  = 18
   '0830'  = 18
   '0831'  = 18
   '0832'  = 18
   '0838'  = 18
   '0839'  = 18
   '0840'  = 18
   '0841'  = 18
   '0842'  = 18
   '0843'  = 18
   '0844'  = 18
   '0845'  = 18
   '0846'  = 18
   '0847'  = 18
   '0848'  = 18
   '0849'  = 18
   '0850'  = 18
   '0851'  = 09
   '0852'  = 09
   '0853'  = 09
   '0854'  = 09
   '0855'  = 09
   '0859'  = 18
   '0860'  = 05
   '0861'  = 18
   '0862'  = 18
   '0863'  = 18
   '0864'  = 18
   '0865'  = 18
   '0869'  = 18
   '0870'  = 18
   '0871'  = 18
   '0879'  = 18
   '0880'  = 18
   '08881' = 18
   '08882' = 18
   '08889' = 18
   '0889'  = 18
   '0900'  = 18
   '0901'  = 18
   '0902'  = 18
   '0903'  = 02
   '09040' = 01
   '09041' = 01
   '09042' = 01
   '09049' = 01
   '0905'  = 18
   '0906'  = 18
   '0907'  = 18
   '0909'  = 18
   '0910'  = 12
   '0911'  = 06
   '0912'  = 18
   '0913'  = 09
   '0914'  = 16
   '09150' = 02
   '09151' = 02
   '09152' = 02
   '09161' = 08
   '09162' = 07
   '09169' = 06
   '0917'  = 18
   '09181' = 01
   '09182' = 09
   '09189' = 18
   '0919'  = 18
   '0920'  = 18
   '0929'  = 18
   '0930'  = 05
   '0931'  = 05
   '09320' = 05
   '09321' = 05
   '09322' = 05
   '09323' = 05
   '09324' = 05
   '09381' = 05
   '09382' = 05
   '09389' = 05
   '0939'  = 05
   '0940'  = 01
   '0941'  = 01
   '0942'  = 01
   '0943'  = 01
   '09481' = 01
   '09482' = 01
   '09483' = 02
   '09484' = 02
   '09485' = 01
   '09486' = 03
   '09487' = 01
   '09489' = 01
   '0949'  = 01
   '0950'  = 02
   '0951'  = 04
   '0952'  = 06
   '0953'  = 07
   '0954'  = 11
   '0955'  = 08
   '0956'  = 08
   '0957'  = 08
   '0958'  = 18
   '0959'  = 18
   '096'   = 18
   '0970'  = 18
   '0971'  = 18
   '0979'  = 18
   '0980'  = 12
   '09810' = 12
   '09811' = 11
   '09812' = 12
   '09813' = 12
   '09814' = 12
   '09815' = 13
   '09816' = 13
   '09817' = 13
   '09819' = 12
   '0982'  = 12
   '09830' = 11
   '09831' = 11
   '09832' = 12
   '09833' = 12
   '09834' = 12
   '09835' = 13
   '09836' = 13
   '09837' = 13
   '09839' = 12
   '09840' = 02
   '09841' = 02
   '09842' = 02
   '09843' = 02
   '09849' = 02
   '09850' = 08
   '09851' = 08
   '09852' = 08
   '09853' = 08
   '09859' = 08
   '0986'  = 03
   '0987'  = 06
   '09881' = 02
   '09882' = 01
   '09883' = 05
   '09884' = 05
   '09885' = 05
   '09886' = 06
   '09889' = 18
   '0990'  = 12
   '0991'  = 12
   '0992'  = 12
   '0993'  = 08
   '09940' = 12
   '09941' = 12
   '09949' = 12
   '09950' = 12
   '09951' = 03
   '09952' = 06
   '09953' = 12
   '09954' = 11
   '09955' = 12
   '09956' = 06
   '09959' = 12
   '0998'  = 12
   '0999'  = 12
   '1000'  = 18
   '10081' = 01
   '10089' = 01
   '1009'  = 18
   '101'   = 03
   '1020'  = 09
   '1021'  = 09
   '1022'  = 09
   '1023'  = 09
   '1024'  = 09
   '1025'  = 03
   '1026'  = 08
   '1027'  = 18
   '1028'  = 18
   '1029'  = 18
   '1030'  = 09
   '1031'  = 09
   '1032'  = 18
   '1033'  = 09
   '1039'  = 18
   '1040'  = 18
   '1048'  = 18
   '1049'  = 18
   '1100'  = 09
   '1101'  = 09
   '1102'  = 09
   '1103'  = 09
   '1104'  = 09
   '1105'  = 09
   '1106'  = 09
   '1108'  = 09
   '1109'  = 09
   '1110'  = 09
   '1111'  = 09
   '1112'  = 09
   '1113'  = 09
   '1118'  = 09
   '1119'  = 09
   '1120'  = 03
   '1121'  = 13
   '1122'  = 12
   '1123'  = 09
   '1124'  = 04
   '1125'  = 18
   '11281' = 05
   '11282' = 03
   '11283' = 01
   '11284' = 06
   '11285' = 06
   '11289' = 18
   '1129'  = 18
   '1140'  = 04
   '1141'  = 09
   '1142'  = 01
   '1143'  = 18
   '1144'  = 04
   '1145'  = 04
   '1149'  = 18
   '11500' = 18
   '11501' = 01
   '11502' = 02
   '11503' = 05
   '11504' = 05
   '11505' = 04
   '11509' = 18
   '11510' = 18
   '11511' = 01
   '11512' = 02
   '11513' = 05
   '11514' = 05
   '11515' = 04
   '11519' = 18
   '11590' = 18
   '11591' = 01
   '11592' = 02
   '11593' = 05
   '11594' = 05
   '11595' = 04
   '11599' = 18
   '1160'  = 18
   '1161'  = 18
   '1162'  = 18
   '1170'  = 18
   '1171'  = 18
   '1172'  = 18
   '1173'  = 18
   '1174'  = 18
   '1175'  = 18
   '1176'  = 18
   '1177'  = 18
   '1178'  = 18
   '1179'  = 18
   '118'   = 18
   '1200'  = 11
   '1201'  = 07
   '1202'  = 18
   '1203'  = 09
   '1208'  = 18
   '1209'  = 18
   '1210'  = 07
   '1211'  = 07
   '1212'  = 04
   '1213'  = 07
   '1214'  = 07
   '1215'  = 18
   '1216'  = 18
   '1218'  = 18
   '1219'  = 18
   '1220'  = 07
   '1221'  = 04
   '1222'  = 10
   '1223'  = 18
   '1224'  = 18
   '1225'  = 07
   '1226'  = 18
   '1227'  = 18
   '1228'  = 07
   '1229'  = 18
   '1230'  = 06
   '1231'  = 06
   '1232'  = 06
   '1233'  = 06
   '1234'  = 06
   '1235'  = 06
   '1236'  = 06
   '1238'  = 06
   '1239'  = 06
   '124'   = 18
   '1250'  = 18
   '1251'  = 18
   '1252'  = 18
   '1253'  = 18
   '1254'  = 18
   '1255'  = 18
   '1256'  = 18
   '1257'  = 18
   '1259'  = 18
   '1260'  = 06
   '1261'  = 06
   '1262'  = 06
   '1263'  = 06
   '1268'  = 06
   '1269'  = 06
   '1270'  = 06
   '1271'  = 06
   '1272'  = 06
   '1273'  = 06
   '1274'  = 06
   '1275'  = 06
   '1276'  = 06
   '1277'  = 06
   '1278'  = 18
   '1279'  = 06
   '1280'  = 18
   '1281'  = 18
   '1288'  = 18
   '1289'  = 18
   '129'   = 06
   '1300'  = 01
   '1301'  = 02
   '1302'  = 02
   '1303'  = 05
   '1304'  = 04
   '1305'  = 07
   '1307'  = 18
   '1308'  = 18
   '1309'  = 18
   '13100' = 12
   '13101' = 13
   '13102' = 12
   '13103' = 12
   '13109' = 12
   '1318'  = 18
   '1319'  = 18
   '1320'  = 09
   '1321'  = 09
   '1322'  = 09
   '1323'  = 09
   '1329'  = 09
   '1330'  = 09
   '1338'  = 09
   '1339'  = 09
   '1340'  = 09
   '1341'  = 09
   '1342'  = 09
   '1348'  = 09
   '1349'  = 09
   '135'   = 04
   '1360'  = 18
   '1361'  = 08
   '13621' = 18
   '13629' = 18
   '1363'  = 04
   '1364'  = 18
   '1365'  = 18
   '1368'  = 18
   '1369'  = 18
   '1370'  = 04
   '1371'  = 01
   '1372'  = 11
   '1373'  = 08
   '1374'  = 18
   '138'   = 01
   '1390'  = 01
   '1391'  = 02
   '1398'  = 18
   '1400'  = 03
   '1401'  = 03
   '1403'  = 03
   '1404'  = 03
   '1405'  = 03
   '1406'  = 03
   '1408'  = 03
   '1409'  = 03
   '1410'  = 03
   '1411'  = 03
   '1412'  = 03
   '1413'  = 03
   '1414'  = 03
   '1415'  = 03
   '1416'  = 03
   '1418'  = 03
   '1419'  = 03
   '1420'  = 03
   '1421'  = 03
   '1422'  = 03
   '1428'  = 03
   '1429'  = 03
   '1430'  = 03
   '1431'  = 03
   '1438'  = 03
   '1439'  = 03
   '1440'  = 03
   '1441'  = 03
   '1448'  = 03
   '1449'  = 03
   '1450'  = 03
   '1451'  = 03
   '1452'  = 03
   '1453'  = 03
   '1454'  = 03
   '1455'  = 03
   '1456'  = 03
   '1458'  = 03
   '1459'  = 03
   '1460'  = 03
   '1461'  = 03
   '1462'  = 03
   '1463'  = 03
   '1464'  = 03
   '1465'  = 03
   '1466'  = 03
   '1467'  = 03
   '1468'  = 03
   '1469'  = 03
   '1470'  = 03
   '1471'  = 03
   '1472'  = 03
   '1473'  = 03
   '1478'  = 03
   '1479'  = 03
   '1480'  = 03
   '1481'  = 03
   '1482'  = 03
   '1483'  = 03
   '1488'  = 03
   '1489'  = 03
   '1490'  = 03
   '1491'  = 03
   '1498'  = 03
   '1499'  = 03
   '1500'  = 06
   '1501'  = 06
   '1502'  = 06
   '1503'  = 06
   '1504'  = 06
   '1505'  = 06
   '1508'  = 06
   '1509'  = 06
   '1510'  = 06
   '1511'  = 06
   '1512'  = 06
   '1513'  = 06
   '1514'  = 06
   '1515'  = 06
   '1516'  = 06
   '1518'  = 06
   '1519'  = 06
   '1520'  = 06
   '1521'  = 06
   '1522'  = 06
   '1523'  = 06
   '1528'  = 06
   '1529'  = 06
   '1530'  = 06
   '1531'  = 06
   '1532'  = 06
   '1533'  = 06
   '1534'  = 06
   '1535'  = 06
   '1536'  = 06
   '1537'  = 06
   '1538'  = 06
   '1539'  = 06
   '1540'  = 06
   '1541'  = 06
   '1542'  = 06
   '1543'  = 06
   '1548'  = 06
   '1550'  = 07
   '1551'  = 07
   '1552'  = 07
   '1560'  = 07
   '1561'  = 07
   '1562'  = 07
   '1568'  = 07
   '1569'  = 07
   '1570'  = 07
   '1571'  = 07
   '1572'  = 07
   '1573'  = 07
   '1574'  = 07
   '1578'  = 07
   '1579'  = 07
   '1580'  = 17
   '1588'  = 06
   '1589'  = 06
   '1590'  = 06
   '1591'  = 17
   '1598'  = 06
   '1599'  = 06
   '1600'  = 03
   '1601'  = 03
   '1602'  = 03
   '1603'  = 03
   '1604'  = 03
   '1605'  = 03
   '1608'  = 03
   '1609'  = 03
   '1610'  = 03
   '1611'  = 03
   '1612'  = 03
   '1613'  = 03
   '1618'  = 03
   '1619'  = 03
   '1620'  = 04
   '1622'  = 04
   '1623'  = 04
   '1624'  = 04
   '1625'  = 04
   '1628'  = 04
   '1629'  = 04
   '1630'  = 04
   '1631'  = 04
   '1638'  = 04
   '1639'  = 04
   '1640'  = 17
   '1641'  = 05
   '1642'  = 04
   '1643'  = 04
   '1648'  = 04
   '1649'  = 04
   '1650'  = 03
   '1658'  = 04
   '1659'  = 04
   '1700'  = 08
   '1701'  = 08
   '1702'  = 08
   '1703'  = 08
   '1704'  = 08
   '1705'  = 08
   '1706'  = 08
   '1707'  = 08
   '1708'  = 08
   '1709'  = 08
   '1710'  = 08
   '1712'  = 08
   '1713'  = 08
   '1714'  = 08
   '1715'  = 08
   '1716'  = 08
   '1717'  = 08
   '1718'  = 08
   '1719'  = 08
   '1720'  = 09
   '1721'  = 02
   '1722'  = 09
   '1723'  = 09
   '1724'  = 09
   '1725'  = 09
   '1726'  = 09
   '1727'  = 09
   '1728'  = 09
   '1729'  = 09
   '17300' = 09
   '17301' = 09
   '17302' = 09
   '17309' = 09
   '17310' = 02
   '17311' = 02
   '17312' = 02
   '17319' = 02
   '17320' = 09
   '17321' = 09
   '17322' = 09
   '17329' = 09
   '17330' = 09
   '17331' = 09
   '17332' = 09
   '17339' = 09
   '17340' = 09
   '17341' = 09
   '17342' = 09
   '17349' = 09
   '17350' = 09
   '17351' = 09
   '17352' = 09
   '17359' = 09
   '17360' = 09
   '17361' = 09
   '17362' = 09
   '17369' = 09
   '17370' = 09
   '17371' = 09
   '17372' = 09
   '17379' = 09
   '17380' = 09
   '17381' = 09
   '17382' = 09
   '17389' = 09
   '17390' = 09
   '17391' = 09
   '17392' = 09
   '17399' = 09
   '1740'  = 09
   '1741'  = 09
   '1742'  = 09
   '1743'  = 09
   '1744'  = 09
   '1745'  = 09
   '1746'  = 09
   '1748'  = 09
   '1749'  = 09
   '1750'  = 09
   '1759'  = 09
   '1760'  = 09
   '1761'  = 09
   '1762'  = 03
   '1763'  = 06
   '1764'  = 04
   '1765'  = 17
   '1768'  = 09
   '1769'  = 09
   '179'   = 13
   '1800'  = 13
   '1801'  = 13
   '1808'  = 13
   '1809'  = 13
   '181'   = 13
   '1820'  = 13
   '1821'  = 13
   '1828'  = 13
   '1830'  = 13
   '1832'  = 13
   '1833'  = 13
   '1834'  = 13
   '1835'  = 13
   '1838'  = 13
   '1839'  = 13
   '1840'  = 13
   '1841'  = 13
   '1842'  = 13
   '1843'  = 13
   '1844'  = 13
   '1848'  = 13
   '1849'  = 13
   '185'   = 12
   '1860'  = 12
   '1869'  = 12
   '1871'  = 12
   '1872'  = 12
   '1873'  = 12
   '1874'  = 12
   '1875'  = 12
   '1876'  = 12
   '1877'  = 12
   '1878'  = 12
   '1879'  = 12
   '1880'  = 11
   '1881'  = 11
   '1882'  = 11
   '1883'  = 11
   '1884'  = 11
   '1885'  = 11
   '1886'  = 11
   '1887'  = 11
   '1888'  = 11
   '1889'  = 11
   '1890'  = 11
   '1891'  = 11
   '1892'  = 11
   '1893'  = 11
   '1894'  = 11
   '1898'  = 11
   '1899'  = 11
   '1900'  = 02
   '1901'  = 02
   '1902'  = 02
   '1903'  = 02
   '1904'  = 02
   '1905'  = 02
   '1906'  = 02
   '1907'  = 02
   '1908'  = 02
   '1909'  = 02
   '1910'  = 01
   '1911'  = 01
   '1912'  = 01
   '1913'  = 01
   '1914'  = 01
   '1915'  = 01
   '1916'  = 01
   '1917'  = 01
   '1918'  = 01
   '1919'  = 01
   '1920'  = 01
   '1921'  = 01
   '1922'  = 01
   '1923'  = 01
   '1928'  = 01
   '1929'  = 01
   '193'   = 10
   '1940'  = 10
   '1941'  = 10
   '1943'  = 10
   '1944'  = 01
   '1945'  = 01
   '1946'  = 01
   '1948'  = 10
   '1949'  = 10
   '1950'  = 03
   '1951'  = 04
   '1952'  = 06
   '1953'  = 12
   '1954'  = 17
   '1955'  = 17
   '1958'  = 17
   '1960'  = 17
   '1961'  = 17
   '1962'  = 17
   '1963'  = 17
   '1965'  = 17
   '1966'  = 17
   '1968'  = 17
   '1969'  = 17
   '1970'  = 04
   '1971'  = 04
   '1972'  = 04
   '1973'  = 04
   '1974'  = 06
   '1975'  = 06
   '1976'  = 06
   '1977'  = 07
   '1978'  = 06
   '1980'  = 11
   '1981'  = 11
   '1982'  = 09
   '1983'  = 01
   '1984'  = 01
   '1985'  = 08
   '1986'  = 13
   '1987'  = 10
   '19881' = 09
   '19882' = 12
   '19889' = 17
   '1990'  = 17
   '1991'  = 17
   '1992'  = 17
   '20000' = 17
   '20001' = 17
   '20002' = 17
   '20003' = 17
   '20004' = 17
   '20005' = 17
   '20006' = 17
   '20007' = 17
   '20008' = 17
   '20010' = 17
   '20011' = 17
   '20012' = 17
   '20013' = 17
   '20014' = 17
   '20015' = 17
   '20016' = 17
   '20017' = 17
   '20018' = 17
   '20020' = 17
   '20021' = 17
   '20022' = 17
   '20023' = 17
   '20024' = 17
   '20025' = 17
   '20026' = 17
   '20027' = 17
   '20028' = 17
   '20030' = 17
   '20031' = 17
   '20032' = 17
   '20033' = 17
   '20034' = 17
   '20035' = 17
   '20036' = 17
   '20037' = 17
   '20038' = 17
   '20040' = 17
   '20041' = 17
   '20042' = 17
   '20043' = 17
   '20044' = 17
   '20045' = 17
   '20046' = 17
   '20047' = 17
   '20048' = 17
   '20050' = 17
   '20051' = 17
   '20052' = 17
   '20053' = 17
   '20054' = 17
   '20055' = 17
   '20056' = 17
   '20057' = 17
   '20058' = 17
   '20060' = 17
   '20061' = 17
   '20062' = 17
   '20063' = 17
   '20064' = 17
   '20065' = 17
   '20066' = 17
   '20067' = 17
   '20068' = 17
   '20070' = 17
   '20071' = 17
   '20072' = 17
   '20073' = 17
   '20074' = 17
   '20075' = 17
   '20076' = 17
   '20077' = 17
   '20078' = 17
   '20080' = 17
   '20081' = 17
   '20082' = 17
   '20083' = 17
   '20084' = 17
   '20085' = 17
   '20086' = 17
   '20087' = 17
   '20088' = 17
   '20100' = 17
   '20101' = 17
   '20102' = 17
   '20103' = 17
   '20104' = 17
   '20105' = 17
   '20106' = 17
   '20107' = 17
   '20108' = 17
   '20110' = 17
   '20111' = 17
   '20112' = 17
   '20113' = 17
   '20114' = 17
   '20115' = 17
   '20116' = 17
   '20117' = 17
   '20118' = 17
   '20120' = 17
   '20121' = 17
   '20122' = 17
   '20123' = 17
   '20124' = 17
   '20125' = 17
   '20126' = 17
   '20127' = 17
   '20128' = 17
   '20140' = 17
   '20141' = 17
   '20142' = 17
   '20143' = 17
   '20144' = 17
   '20145' = 17
   '20146' = 17
   '20147' = 17
   '20148' = 17
   '20150' = 17
   '20151' = 17
   '20152' = 17
   '20153' = 17
   '20154' = 17
   '20155' = 17
   '20156' = 17
   '20157' = 17
   '20158' = 17
   '20160' = 17
   '20161' = 17
   '20162' = 17
   '20163' = 17
   '20164' = 17
   '20165' = 17
   '20166' = 17
   '20167' = 17
   '20168' = 17
   '20170' = 17
   '20171' = 17
   '20172' = 17
   '20173' = 17
   '20174' = 17
   '20175' = 17
   '20176' = 17
   '20177' = 17
   '20178' = 17
   '20190' = 17
   '20191' = 17
   '20192' = 17
   '20193' = 17
   '20194' = 17
   '20195' = 17
   '20196' = 17
   '20197' = 17
   '20198' = 17
   '20200' = 17
   '20201' = 17
   '20202' = 17
   '20203' = 17
   '20204' = 17
   '20205' = 17
   '20206' = 17
   '20207' = 17
   '20208' = 17
   '20210' = 17
   '20211' = 17
   '20212' = 17
   '20213' = 17
   '20214' = 17
   '20215' = 17
   '20216' = 17
   '20217' = 17
   '20218' = 17
   '20220' = 17
   '20221' = 17
   '20222' = 17
   '20223' = 17
   '20224' = 17
   '20225' = 17
   '20226' = 17
   '20227' = 17
   '20228' = 17
   '20230' = 17
   '20231' = 17
   '20232' = 17
   '20233' = 17
   '20234' = 17
   '20235' = 17
   '20236' = 17
   '20237' = 17
   '20238' = 17
   '20240' = 17
   '20241' = 17
   '20242' = 17
   '20243' = 17
   '20244' = 17
   '20245' = 17
   '20246' = 17
   '20247' = 17
   '20248' = 17
   '20250' = 17
   '20251' = 17
   '20252' = 17
   '20253' = 17
   '20254' = 17
   '20255' = 17
   '20256' = 17
   '20257' = 17
   '20258' = 17
   '20260' = 17
   '20261' = 17
   '20262' = 17
   '20263' = 17
   '20264' = 17
   '20265' = 17
   '20266' = 17
   '20267' = 17
   '20268' = 17
   '20270' = 17
   '20271' = 17
   '20272' = 17
   '20273' = 17
   '20274' = 17
   '20275' = 17
   '20276' = 17
   '20277' = 17
   '20278' = 17
   '20280' = 17
   '20281' = 17
   '20282' = 17
   '20283' = 17
   '20284' = 17
   '20285' = 17
   '20286' = 17
   '20287' = 17
   '20288' = 17
   '20290' = 17
   '20291' = 17
   '20292' = 17
   '20293' = 17
   '20294' = 17
   '20295' = 17
   '20296' = 17
   '20297' = 17
   '20298' = 17
   '20300' = 17
   '20301' = 17
   '20302' = 17
   '20310' = 17
   '20311' = 17
   '20312' = 17
   '20380' = 17
   '20381' = 17
   '20382' = 17
   '20400' = 17
   '20401' = 17
   '20402' = 17
   '20410' = 17
   '20411' = 17
   '20412' = 17
   '20420' = 17
   '20421' = 17
   '20422' = 17
   '20480' = 17
   '20481' = 17
   '20482' = 17
   '20490' = 17
   '20491' = 17
   '20492' = 17
   '20500' = 17
   '20501' = 17
   '20502' = 17
   '20510' = 17
   '20511' = 17
   '20512' = 17
   '20520' = 17
   '20521' = 17
   '20522' = 17
   '20530' = 17
   '20531' = 17
   '20532' = 17
   '20580' = 17
   '20581' = 17
   '20582' = 17
   '20590' = 17
   '20591' = 17
   '20592' = 17
   '20600' = 17
   '20601' = 17
   '20602' = 17
   '20610' = 17
   '20611' = 17
   '20612' = 17
   '20620' = 17
   '20621' = 17
   '20622' = 17
   '20680' = 17
   '20681' = 17
   '20682' = 17
   '20690' = 17
   '20691' = 17
   '20692' = 17
   '20700' = 17
   '20701' = 17
   '20702' = 17
   '20710' = 17
   '20711' = 17
   '20712' = 17
   '20720' = 17
   '20721' = 17
   '20722' = 17
   '20780' = 17
   '20781' = 17
   '20782' = 17
   '20800' = 17
   '20801' = 17
   '20802' = 17
   '20810' = 17
   '20811' = 17
   '20812' = 17
   '20820' = 17
   '20821' = 17
   '20822' = 17
   '20880' = 17
   '20881' = 17
   '20882' = 17
   '20890' = 17
   '20891' = 17
   '20892' = 17
   '20900' = 06
   '20901' = 06
   '20902' = 06
   '20903' = 06
   '20910' = 06
   '20911' = 06
   '20912' = 06
   '20913' = 06
   '20914' = 06
   '20915' = 06
   '20916' = 06
   '20917' = 06
   '20920' = 17
   '20921' = 04
   '20922' = 17
   '20923' = 06
   '20924' = 11
   '20925' = 06
   '20926' = 06
   '20927' = 06
   '20929' = 17
   '20930' = 17
   '20931' = 09
   '20932' = 09
   '20933' = 09
   '20934' = 09
   '20935' = 09
   '20936' = 09
   '20940' = 06
   '20941' = 06
   '20942' = 06
   '20943' = 06
   '20950' = 06
   '20951' = 06
   '20952' = 06
   '20953' = 06
   '20954' = 06
   '20955' = 06
   '20956' = 06
   '20957' = 06
   '20960' = 17
   '20961' = 04
   '20962' = 16
   '20963' = 06
   '20964' = 11
   '20965' = 06
   '20966' = 06
   '20967' = 06
   '20969' = 17
   '20970' = 17
   '20971' = 17
   '20972' = 07
   '20973' = 08
   '20974' = 06
   '20975' = 17
   '20979' = 17
   '2100'  = 03
   '2101'  = 03
   '2102'  = 03
   '2103'  = 03
   '2104'  = 03
   '2105'  = 03
   '2106'  = 03
   '2107'  = 03
   '2108'  = 03
   '2109'  = 03
   '2110'  = 06
   '2111'  = 06
   '2112'  = 06
   '2113'  = 06
   '2114'  = 06
   '2115'  = 07
   '2116'  = 07
   '2117'  = 10
   '2118'  = 06
   '2119'  = 06
   '2120'  = 03
   '2121'  = 03
   '2122'  = 04
   '2123'  = 04
   '2124'  = 04
   '2125'  = 04
   '2126'  = 16
   '2127'  = 05
   '2128'  = 04
   '2129'  = 04
   '2130'  = 08
   '2131'  = 03
   '2132'  = 08
   '2133'  = 04
   '2134'  = 08
   '2135'  = 08
   '2136'  = 08
   '2137'  = 08
   '2138'  = 08
   '2139'  = 08
   '2140'  = 09
   '2141'  = 09
   '2142'  = 04
   '2143'  = 06
   '2144'  = 12
   '2148'  = 09
   '2149'  = 09
   '2150'  = 08
   '2152'  = 08
   '2153'  = 08
   '2154'  = 08
   '2155'  = 08
   '2156'  = 08
   '2157'  = 08
   '2158'  = 08
   '2159'  = 08
   '2160'  = 09
   '2161'  = 02
   '2162'  = 09
   '2163'  = 09
   '2164'  = 09
   '2165'  = 09
   '2166'  = 09
   '2167'  = 09
   '2168'  = 09
   '2169'  = 09
   '217'   = 09
   '2180'  = 13
   '2181'  = 13
   '2182'  = 13
   '2189'  = 13
   '2190'  = 13
   '2191'  = 13
   '2198'  = 13
   '2199'  = 13
   '220'   = 13
   '2210'  = 13
   '2211'  = 13
   '2212'  = 13
   '2218'  = 13
   '2219'  = 13
   '2220'  = 12
   '2221'  = 12
   '2222'  = 12
   '2223'  = 12
   '2224'  = 12
   '2228'  = 12
   '2229'  = 12
   '2230'  = 11
   '2231'  = 11
   '2232'  = 11
   '2233'  = 11
   '22381' = 11
   '22389' = 11
   '2239'  = 11
   '2240'  = 02
   '2241'  = 02
   '2242'  = 02
   '2243'  = 02
   '2244'  = 02
   '2245'  = 02
   '2246'  = 02
   '2247'  = 02
   '2248'  = 02
   '2249'  = 02
   '2250'  = 01
   '2251'  = 01
   '2252'  = 01
   '2253'  = 01
   '2254'  = 01
   '2258'  = 01
   '2259'  = 01
   '226'   = 10
   '2270'  = 10
   '2271'  = 10
   '2273'  = 10
   '2274'  = 01
   '2275'  = 01
   '2276'  = 01
   '2278'  = 10
   '2279'  = 10
   '22800' = 05
   '22801' = 09
   '22802' = 01
   '22803' = 02
   '22804' = 06
   '22809' = 05
   '2281'  = 16
   '2290'  = 16
   '2298'  = 17
   '2299'  = 17
   '2300'  = 03
   '2301'  = 06
   '2302'  = 06
   '2303'  = 06
   '2304'  = 06
   '2305'  = 06
   '2306'  = 06
   '2307'  = 06
   '2308'  = 07
   '2309'  = 06
   '2310'  = 03
   '2311'  = 04
   '2312'  = 04
   '2318'  = 04
   '2319'  = 04
   '2320'  = 09
   '2321'  = 02
   '2322'  = 09
   '2323'  = 09
   '2324'  = 09
   '2325'  = 09
   '2326'  = 09
   '2327'  = 09
   '2328'  = 09
   '2329'  = 09
   '2330'  = 09
   '2331'  = 13
   '2332'  = 13
   '23330' = 13
   '23331' = 13
   '23332' = 13
   '23339' = 13
   '2334'  = 12
   '2335'  = 12
   '2336'  = 12
   '2337'  = 11
   '2339'  = 11
   '2340'  = 02
   '2348'  = 17
   '2349'  = 17
   '2350'  = 03
   '2351'  = 03
   '2352'  = 06
   '2353'  = 07
   '2354'  = 06
   '2355'  = 06
   '2356'  = 03
   '2357'  = 04
   '2358'  = 04
   '2359'  = 04
   '2360'  = 13
   '2361'  = 13
   '2362'  = 13
   '2363'  = 13
   '2364'  = 12
   '2365'  = 12
   '2366'  = 12
   '2367'  = 11
   '23690' = 11
   '23691' = 11
   '23699' = 11
   '2370'  = 10
   '2371'  = 01
   '2372'  = 10
   '2373'  = 01
   '2374'  = 10
   '2375'  = 01
   '2376'  = 01
   '23770' = 01
   '23771' = 01
   '23772' = 01
   '23773' = 01
   '23779' = 01
   '2379'  = 01
   '2380'  = 08
   '2381'  = 08
   '2382'  = 09
   '2383'  = 09
   '2384'  = 17
   '2385'  = 17
   '2386'  = 17
   '23871' = 16
   '23872' = 16
   '23873' = 16
   '23874' = 16
   '23875' = 16
   '23876' = 17
   '23877' = 21
   '23879' = 17
   '2388'  = 17
   '2389'  = 17
   '2390'  = 06
   '2391'  = 04
   '2392'  = 08
   '2393'  = 09
   '2394'  = 11
   '2395'  = 11
   '2396'  = 01
   '2397'  = 10
   '23981' = 17
   '23989' = 17
   '2399'  = 17
   '2400'  = 10
   '2409'  = 10
   '2410'  = 10
   '2411'  = 10
   '2419'  = 10
   '24200' = 10
   '24201' = 10
   '24210' = 10
   '24211' = 10
   '24220' = 10
   '24221' = 10
   '24230' = 10
   '24231' = 10
   '24240' = 10
   '24241' = 10
   '24280' = 10
   '24281' = 10
   '24290' = 10
   '24291' = 10
   '243'   = 10
   '2440'  = 10
   '2441'  = 10
   '2442'  = 10
   '2443'  = 10
   '2448'  = 10
   '2449'  = 10
   '2450'  = 10
   '2451'  = 10
   '2452'  = 10
   '2453'  = 10
   '2454'  = 10
   '2458'  = 10
   '2459'  = 10
   '2460'  = 10
   '2461'  = 10
   '2462'  = 10
   '2463'  = 10
   '2468'  = 10
   '2469'  = 10
   '24900' = 10
   '24901' = 10
   '24910' = 10
   '24911' = 10
   '24920' = 10
   '24921' = 10
   '24930' = 10
   '24931' = 10
   '24940' = 11
   '24941' = 11
   '24950' = 02
   '24951' = 02
   '24960' = 01
   '24961' = 01
   '24970' = 05
   '24971' = 05
   '24980' = 10
   '24981' = 10
   '24990' = 10
   '24991' = 10
   '25000' = 10
   '25001' = 10
   '25002' = 10
   '25003' = 10
   '25010' = 10
   '25011' = 10
   '25012' = 10
   '25013' = 10
   '25020' = 10
   '25021' = 10
   '25022' = 10
   '25023' = 10
   '25030' = 10
   '25031' = 10
   '25032' = 10
   '25033' = 10
   '25040' = 11
   '25041' = 11
   '25042' = 11
   '25043' = 11
   '25050' = 02
   '25051' = 02
   '25052' = 02
   '25053' = 02
   '25060' = 01
   '25061' = 01
   '25062' = 01
   '25063' = 01
   '25070' = 05
   '25071' = 05
   '25072' = 05
   '25073' = 05
   '25080' = 10
   '25081' = 10
   '25082' = 10
   '25083' = 10
   '25090' = 10
   '25091' = 10
   '25092' = 10
   '25093' = 10
   '2510'  = 10
   '2511'  = 10
   '2512'  = 10
   '2513'  = 10
   '2514'  = 10
   '2515'  = 06
   '2518'  = 10
   '2519'  = 10
   '25200' = 10
   '25201' = 10
   '25202' = 10
   '25208' = 10
   '2521'  = 10
   '2528'  = 10
   '2529'  = 10
   '2530'  = 10
   '2531'  = 10
   '2532'  = 10
   '2533'  = 10
   '2534'  = 10
   '2535'  = 10
   '2536'  = 10
   '2537'  = 10
   '2538'  = 10
   '2539'  = 10
   '2540'  = 16
   '2541'  = 16
   '2548'  = 16
   '2549'  = 16
   '2550'  = 10
   '25510' = 10
   '25511' = 10
   '25512' = 10
   '25513' = 10
   '25514' = 10
   '2552'  = 10
   '2553'  = 10
   '25541' = 10
   '25542' = 10
   '2555'  = 10
   '2556'  = 10
   '2558'  = 10
   '2559'  = 10
   '2560'  = 13
   '2561'  = 13
   '2562'  = 13
   '25631' = 13
   '25639' = 13
   '2564'  = 13
   '2568'  = 13
   '2569'  = 13
   '2570'  = 10
   '2571'  = 10
   '2572'  = 10
   '2578'  = 10
   '2579'  = 10
   '25801' = 10
   '25802' = 10
   '25803' = 10
   '2581'  = 10
   '2588'  = 10
   '2589'  = 10
   '2590'  = 10
   '2591'  = 10
   '2592'  = 10
   '2593'  = 10
   '2594'  = 10
   '25950' = 10
   '25951' = 10
   '25952' = 10
   '2598'  = 10
   '2599'  = 10
   '260'   = 10
   '261'   = 10
   '262'   = 10
   '2630'  = 10
   '2631'  = 10
   '2632'  = 10
   '2638'  = 10
   '2639'  = 10
   '2640'  = 02
   '2641'  = 02
   '2642'  = 02
   '2643'  = 02
   '2644'  = 02
   '2645'  = 02
   '2646'  = 02
   '2647'  = 02
   '2648'  = 10
   '2649'  = 10
   '2650'  = 10
   '2651'  = 10
   '2652'  = 10
   '2660'  = 10
   '2661'  = 10
   '2662'  = 10
   '2669'  = 10
   '267'   = 10
   '2680'  = 08
   '2681'  = 08
   '2682'  = 08
   '2689'  = 10
   '2690'  = 10
   '2691'  = 10
   '2692'  = 10
   '2693'  = 10
   '2698'  = 10
   '2699'  = 10
   '2700'  = 10
   '2701'  = 10
   '2702'  = 10
   '2703'  = 10
   '2704'  = 10
   '2705'  = 10
   '2706'  = 10
   '2707'  = 10
   '2708'  = 10
   '2709'  = 10
   '2710'  = 10
   '2711'  = 10
   '2712'  = 06
   '2713'  = 06
   '2714'  = 10
   '2718'  = 10
   '2719'  = 10
   '2720'  = 10
   '2721'  = 10
   '2722'  = 10
   '2723'  = 10
   '2724'  = 10
   '2725'  = 10
   '2726'  = 10
   '2727'  = 10
   '2728'  = 10
   '2729'  = 10
   '2730'  = 16
   '2731'  = 16
   '2732'  = 17
   '2733'  = 17
   '2734'  = 10
   '2738'  = 17
   '2739'  = 17
   '27400' = 08
   '27401' = 08
   '27402' = 08
   '27403' = 08
   '27410' = 11
   '27411' = 11
   '27419' = 11
   '27481' = 08
   '27482' = 08
   '27489' = 08
   '2749'  = 08
   '27501' = 10
   '27502' = 10
   '27503' = 10
   '27509' = 10
   '2751'  = 10
   '2752'  = 10
   '2753'  = 10
   '27540' = 10
   '27541' = 10
   '27542' = 10
   '27549' = 10
   '2755'  = 10
   '2758'  = 10
   '2759'  = 10
   '2760'  = 10
   '2761'  = 10
   '2762'  = 10
   '2763'  = 10
   '2764'  = 10
   '27650' = 10
   '27651' = 10
   '27652' = 10
   '27661' = 10
   '27669' = 10
   '2767'  = 10
   '2768'  = 10
   '2769'  = 10
   '27700' = 10
   '27701' = 15
   '27702' = 04
   '27703' = 06
   '27709' = 10
   '2771'  = 10
   '2772'  = 10
   '27730' = 08
   '27731' = 08
   '27739' = 08
   '2774'  = 07
   '2775'  = 10
   '2776'  = 10
   '2777'  = 10
   '27781' = 10
   '27782' = 10
   '27783' = 10
   '27784' = 10
   '27785' = 10
   '27786' = 10
   '27787' = 10
   '27788' = 11
   '27789' = 10
   '2779'  = 10
   '27800' = 10
   '27801' = 10
   '27802' = 10
   '27803' = 04
   '2781'  = 10
   '2782'  = 10
   '2783'  = 10
   '2784'  = 10
   '2788'  = 10
   '27900' = 16
   '27901' = 16
   '27902' = 16
   '27903' = 16
   '27904' = 16
   '27905' = 16
   '27906' = 16
   '27909' = 16
   '27910' = 16
   '27911' = 16
   '27912' = 16
   '27913' = 16
   '27919' = 16
   '2792'  = 16
   '2793'  = 16
   '27941' = 08
   '27949' = 08
   '27950' = 16
   '27951' = 16
   '27952' = 16
   '27953' = 16
   '2798'  = 16
   '2799'  = 16
   '2800'  = 16
   '2801'  = 16
   '2808'  = 16
   '2809'  = 16
   '2810'  = 16
   '2811'  = 16
   '2812'  = 16
   '2813'  = 16
   '2814'  = 16
   '2818'  = 16
   '2819'  = 16
   '2820'  = 16
   '2821'  = 16
   '2822'  = 16
   '2823'  = 16
   '28240' = 16
   '28241' = 16
   '28242' = 16
   '28243' = 16
   '28244' = 16
   '28245' = 16
   '28246' = 16
   '28247' = 16
   '28249' = 16
   '2825'  = 16
   '28260' = 16
   '28261' = 16
   '28262' = 16
   '28263' = 16
   '28264' = 16
   '28268' = 16
   '28269' = 16
   '2827'  = 16
   '2828'  = 16
   '2829'  = 16
   '2830'  = 16
   '28310' = 16
   '28311' = 16
   '28319' = 16
   '2832'  = 16
   '2839'  = 16
   '28401' = 16
   '28409' = 16
   '28411' = 16
   '28412' = 16
   '28419' = 16
   '2842'  = 17
   '28481' = 16
   '28489' = 16
   '2849'  = 16
   '2850'  = 16
   '2851'  = 16
   '28521' = 16
   '28522' = 16
   '28529' = 16
   '2853'  = 16
   '2858'  = 16
   '2859'  = 16
   '2860'  = 16
   '2861'  = 16
   '2862'  = 16
   '2863'  = 16
   '2864'  = 16
   '28652' = 16
   '28653' = 16
   '28659' = 16
   '2866'  = 16
   '2867'  = 16
   '2869'  = 16
   '2870'  = 16
   '2871'  = 16
   '2872'  = 16
   '28730' = 16
   '28731' = 16
   '28732' = 16
   '28733' = 16
   '28739' = 16
   '28741' = 16
   '28749' = 16
   '2875'  = 16
   '2878'  = 16
   '2879'  = 16
   '28800' = 16
   '28801' = 16
   '28802' = 16
   '28803' = 16
   '28804' = 16
   '28809' = 16
   '2881'  = 16
   '2882'  = 16
   '2883'  = 16
   '2884'  = 16
   '28850' = 16
   '28851' = 16
   '28859' = 16
   '28860' = 16
   '28861' = 16
   '28862' = 16
   '28863' = 16
   '28864' = 16
   '28865' = 16
   '28866' = 16
   '28869' = 16
   '2888'  = 16
   '2889'  = 16
   '2890'  = 16
   '2891'  = 16
   '2892'  = 06
   '2893'  = 16
   '2894'  = 16
   '28950' = 16
   '28951' = 16
   '28952' = 16
   '28953' = 16
   '28959' = 16
   '2896'  = 16
   '2897'  = 16
   '28981' = 16
   '28982' = 16
   '28983' = 17
   '28984' = 16
   '28989' = 16
   '2899'  = 16
   '2900'  = 19
   '29010' = 19
   '29011' = 19
   '29012' = 19
   '29013' = 19
   '29020' = 19
   '29021' = 19
   '2903'  = 19
   '29040' = 19
   '29041' = 19
   '29042' = 19
   '29043' = 19
   '2908'  = 19
   '2909'  = 19
   '2910'  = 20
   '2911'  = 20
   '2912'  = 20
   '2913'  = 20
   '2914'  = 20
   '2915'  = 20
   '29181' = 20
   '29182' = 20
   '29189' = 20
   '2919'  = 20
   '2920'  = 20
   '29211' = 20
   '29212' = 20
   '2922'  = 20
   '29281' = 20
   '29282' = 20
   '29283' = 20
   '29284' = 20
   '29285' = 20
   '29289' = 20
   '2929'  = 20
   '2930'  = 19
   '2931'  = 19
   '29381' = 19
   '29382' = 19
   '29383' = 19
   '29384' = 19
   '29389' = 19
   '2939'  = 19
   '2940'  = 19
   '29410' = 19
   '29411' = 19
   '29420' = 19
   '29421' = 19
   '2948'  = 19
   '2949'  = 19
   '29500' = 19
   '29501' = 19
   '29502' = 19
   '29503' = 19
   '29504' = 19
   '29505' = 19
   '29510' = 19
   '29511' = 19
   '29512' = 19
   '29513' = 19
   '29514' = 19
   '29515' = 19
   '29520' = 19
   '29521' = 19
   '29522' = 19
   '29523' = 19
   '29524' = 19
   '29525' = 19
   '29530' = 19
   '29531' = 19
   '29532' = 19
   '29533' = 19
   '29534' = 19
   '29535' = 19
   '29540' = 19
   '29541' = 19
   '29542' = 19
   '29543' = 19
   '29544' = 19
   '29545' = 19
   '29550' = 19
   '29551' = 19
   '29552' = 19
   '29553' = 19
   '29554' = 19
   '29555' = 19
   '29560' = 19
   '29561' = 19
   '29562' = 19
   '29563' = 19
   '29564' = 19
   '29565' = 19
   '29570' = 19
   '29571' = 19
   '29572' = 19
   '29573' = 19
   '29574' = 19
   '29575' = 19
   '29580' = 19
   '29581' = 19
   '29582' = 19
   '29583' = 19
   '29584' = 19
   '29585' = 19
   '29590' = 19
   '29591' = 19
   '29592' = 19
   '29593' = 19
   '29594' = 19
   '29595' = 19
   '29600' = 19
   '29601' = 19
   '29602' = 19
   '29603' = 19
   '29604' = 19
   '29605' = 19
   '29606' = 19
   '29610' = 19
   '29611' = 19
   '29612' = 19
   '29613' = 19
   '29614' = 19
   '29615' = 19
   '29616' = 19
   '29620' = 19
   '29621' = 19
   '29622' = 19
   '29623' = 19
   '29624' = 19
   '29625' = 19
   '29626' = 19
   '29630' = 19
   '29631' = 19
   '29632' = 19
   '29633' = 19
   '29634' = 19
   '29635' = 19
   '29636' = 19
   '29640' = 19
   '29641' = 19
   '29642' = 19
   '29643' = 19
   '29644' = 19
   '29645' = 19
   '29646' = 19
   '29650' = 19
   '29651' = 19
   '29652' = 19
   '29653' = 19
   '29654' = 19
   '29655' = 19
   '29656' = 19
   '29660' = 19
   '29661' = 19
   '29662' = 19
   '29663' = 19
   '29664' = 19
   '29665' = 19
   '29666' = 19
   '2967'  = 19
   '29680' = 19
   '29681' = 19
   '29682' = 19
   '29689' = 19
   '29690' = 19
   '29699' = 19
   '2970'  = 19
   '2971'  = 19
   '2972'  = 19
   '2973'  = 19
   '2978'  = 19
   '2979'  = 19
   '2980'  = 19
   '2981'  = 19
   '2982'  = 19
   '2983'  = 19
   '2984'  = 19
   '2988'  = 19
   '2989'  = 19
   '29900' = 19
   '29901' = 19
   '29910' = 19
   '29911' = 19
   '29980' = 19
   '29981' = 19
   '29990' = 19
   '29991' = 19
   '30000' = 19
   '30001' = 19
   '30002' = 19
   '30009' = 19
   '30010' = 19
   '30011' = 19
   '30012' = 19
   '30013' = 19
   '30014' = 19
   '30015' = 19
   '30016' = 19
   '30019' = 19
   '30020' = 19
   '30021' = 19
   '30022' = 19
   '30023' = 19
   '30029' = 19
   '3003'  = 19
   '3004'  = 19
   '3005'  = 19
   '3006'  = 19
   '3007'  = 19
   '30081' = 19
   '30082' = 19
   '30089' = 19
   '3009'  = 19
   '3010'  = 19
   '30110' = 19
   '30111' = 19
   '30112' = 19
   '30113' = 19
   '30120' = 19
   '30121' = 19
   '30122' = 19
   '3013'  = 19
   '3014'  = 19
   '30150' = 19
   '30151' = 19
   '30159' = 19
   '3016'  = 19
   '3017'  = 19
   '30181' = 19
   '30182' = 19
   '30183' = 19
   '30184' = 19
   '30189' = 19
   '3019'  = 19
   '3020'  = 19
   '3021'  = 19
   '3022'  = 19
   '3023'  = 19
   '3024'  = 19
   '30250' = 19
   '30251' = 19
   '30252' = 19
   '30253' = 19
   '3026'  = 19
   '30270' = 19
   '30271' = 19
   '30272' = 19
   '30273' = 19
   '30274' = 19
   '30275' = 19
   '30276' = 19
   '30279' = 19
   '30281' = 19
   '30282' = 19
   '30283' = 19
   '30284' = 19
   '30285' = 19
   '30289' = 19
   '3029'  = 19
   '30300' = 20
   '30301' = 20
   '30302' = 20
   '30303' = 20
   '30390' = 20
   '30391' = 20
   '30392' = 20
   '30393' = 20
   '30400' = 20
   '30401' = 20
   '30402' = 20
   '30403' = 20
   '30410' = 20
   '30411' = 20
   '30412' = 20
   '30413' = 20
   '30420' = 20
   '30421' = 20
   '30422' = 20
   '30423' = 20
   '30430' = 20
   '30431' = 20
   '30432' = 20
   '30433' = 20
   '30440' = 20
   '30441' = 20
   '30442' = 20
   '30443' = 20
   '30450' = 20
   '30451' = 20
   '30452' = 20
   '30453' = 20
   '30460' = 20
   '30461' = 20
   '30462' = 20
   '30463' = 20
   '30470' = 20
   '30471' = 20
   '30472' = 20
   '30473' = 20
   '30480' = 20
   '30481' = 20
   '30482' = 20
   '30483' = 20
   '30490' = 20
   '30491' = 20
   '30492' = 20
   '30493' = 20
   '30500' = 20
   '30501' = 20
   '30502' = 20
   '30503' = 20
   '3051'  = 23
   '30520' = 20
   '30521' = 20
   '30522' = 20
   '30523' = 20
   '30530' = 20
   '30531' = 20
   '30532' = 20
   '30533' = 20
   '30540' = 20
   '30541' = 20
   '30542' = 20
   '30543' = 20
   '30550' = 20
   '30551' = 20
   '30552' = 20
   '30553' = 20
   '30560' = 20
   '30561' = 20
   '30562' = 20
   '30563' = 20
   '30570' = 20
   '30571' = 20
   '30572' = 20
   '30573' = 20
   '30580' = 20
   '30581' = 20
   '30582' = 20
   '30583' = 20
   '30590' = 20
   '30591' = 20
   '30592' = 20
   '30593' = 20
   '3060'  = 08
   '3061'  = 04
   '3062'  = 05
   '3063'  = 09
   '3064'  = 06
   '30650' = 11
   '30651' = 13
   '30652' = 13
   '30653' = 11
   '30659' = 11
   '3066'  = 10
   '3067'  = 19
   '3068'  = 19
   '3069'  = 19
   '3070'  = 19
   '3071'  = 19
   '30720' = 01
   '30721' = 01
   '30722' = 01
   '30723' = 01
   '3073'  = 19
   '30740' = 19
   '30741' = 19
   '30742' = 19
   '30743' = 19
   '30744' = 19
   '30745' = 19
   '30746' = 19
   '30747' = 19
   '30748' = 19
   '30749' = 19
   '30750' = 19
   '30751' = 19
   '30752' = 19
   '30753' = 19
   '30754' = 19
   '30759' = 19
   '3076'  = 19
   '3077'  = 19
   '30780' = 19
   '30781' = 01
   '30789' = 19
   '3079'  = 19
   '3080'  = 19
   '3081'  = 19
   '3082'  = 19
   '3083'  = 19
   '3084'  = 19
   '3089'  = 19
   '3090'  = 19
   '3091'  = 19
   '30921' = 19
   '30922' = 19
   '30923' = 19
   '30924' = 19
   '30928' = 19
   '30929' = 19
   '3093'  = 19
   '3094'  = 19
   '30981' = 19
   '30982' = 19
   '30983' = 19
   '30989' = 19
   '3099'  = 19
   '3100'  = 19
   '3101'  = 19
   '3102'  = 01
   '31081' = 01
   '31089' = 01
   '3109'  = 19
   '311'   = 19
   '31200' = 19
   '31201' = 19
   '31202' = 19
   '31203' = 19
   '31210' = 19
   '31211' = 19
   '31212' = 19
   '31213' = 19
   '31220' = 19
   '31221' = 19
   '31222' = 19
   '31223' = 19
   '31230' = 19
   '31231' = 19
   '31232' = 19
   '31233' = 19
   '31234' = 19
   '31235' = 19
   '31239' = 19
   '3124'  = 19
   '31281' = 19
   '31282' = 19
   '31289' = 19
   '3129'  = 19
   '3130'  = 19
   '3131'  = 19
   '31321' = 19
   '31322' = 19
   '31323' = 19
   '3133'  = 19
   '31381' = 19
   '31382' = 19
   '31383' = 19
   '31389' = 19
   '3139'  = 19
   '31400' = 19
   '31401' = 19
   '3141'  = 19
   '3142'  = 19
   '3148'  = 19
   '3149'  = 19
   '31500' = 19
   '31501' = 19
   '31502' = 19
   '31509' = 19
   '3151'  = 19
   '3152'  = 19
   '31531' = 19
   '31532' = 19
   '31534' = 19
   '31535' = 01
   '31539' = 19
   '3154'  = 19
   '3155'  = 19
   '3158'  = 19
   '3159'  = 19
   '316'   = 19
   '317'   = 19
   '3180'  = 19
   '3181'  = 19
   '3182'  = 19
   '319'   = 19
   '3200'  = 01
   '3201'  = 01
   '3202'  = 01
   '3203'  = 01
   '3207'  = 01
   '32081' = 01
   '32082' = 01
   '32089' = 01
   '3209'  = 01
   '3210'  = 01
   '3211'  = 01
   '3212'  = 01
   '3213'  = 01
   '3214'  = 01
   '3218'  = 01
   '3220'  = 01
   '3221'  = 01
   '3222'  = 01
   '3229'  = 01
   '32301' = 01
   '32302' = 01
   '3231'  = 01
   '3232'  = 01
   '32341' = 01
   '32342' = 01
   '32351' = 01
   '32352' = 01
   '32361' = 01
   '32362' = 01
   '32363' = 01
   '32371' = 01
   '32372' = 01
   '32381' = 01
   '32382' = 01
   '3239'  = 01
   '3240'  = 01
   '3241'  = 01
   '3249'  = 01
   '325'   = 01
   '326'   = 01
   '32700' = 19
   '32701' = 19
   '32702' = 19
   '32709' = 19
   '32710' = 19
   '32711' = 19
   '32712' = 19
   '32713' = 19
   '32714' = 19
   '32715' = 19
   '32719' = 19
   '32720' = 03
   '32721' = 01
   '32722' = 04
   '32723' = 03
   '32724' = 03
   '32725' = 01
   '32726' = 03
   '32727' = 01
   '32729' = 03
   '32730' = 01
   '32731' = 01
   '32732' = 01
   '32733' = 01
   '32734' = 01
   '32735' = 01
   '32736' = 01
   '32737' = 01
   '32739' = 01
   '32740' = 03
   '32741' = 01
   '32742' = 03
   '32743' = 01
   '32744' = 03
   '32749' = 03
   '32751' = 01
   '32752' = 01
   '32753' = 03
   '32759' = 03
   '3278'  = 03
   '3300'  = 01
   '3301'  = 01
   '3302'  = 01
   '3303'  = 01
   '3308'  = 01
   '3309'  = 01
   '3310'  = 01
   '33111' = 01
   '33119' = 01
   '3312'  = 01
   '3313'  = 01
   '3314'  = 01
   '3315'  = 01
   '3316'  = 01
   '3317'  = 01
   '33181' = 01
   '33182' = 01
   '33183' = 01
   '33189' = 01
   '3319'  = 01
   '3320'  = 01
   '3321'  = 01
   '3330'  = 01
   '3331'  = 01
   '3332'  = 01
   '3333'  = 01
   '3334'  = 01
   '3335'  = 01
   '3336'  = 01
   '33371' = 01
   '33372' = 01
   '33379' = 01
   '33381' = 02
   '33382' = 01
   '33383' = 01
   '33384' = 01
   '33385' = 01
   '33389' = 01
   '33390' = 01
   '33391' = 01
   '33392' = 01
   '33393' = 01
   '33394' = 01
   '33399' = 01
   '3340'  = 01
   '3341'  = 01
   '3342'  = 01
   '3343'  = 01
   '3344'  = 01
   '3348'  = 01
   '3349'  = 01
   '3350'  = 01
   '33510' = 01
   '33511' = 01
   '33519' = 01
   '33520' = 01
   '33521' = 01
   '33522' = 01
   '33523' = 01
   '33524' = 01
   '33529' = 01
   '3358'  = 01
   '3359'  = 01
   '3360'  = 01
   '3361'  = 01
   '3362'  = 01
   '3363'  = 01
   '3368'  = 01
   '3369'  = 01
   '33700' = 01
   '33701' = 01
   '33709' = 01
   '3371'  = 01
   '33720' = 01
   '33721' = 01
   '33722' = 01
   '33729' = 01
   '3373'  = 01
   '3379'  = 01
   '3380'  = 01
   '33811' = 23
   '33812' = 23
   '33818' = 23
   '33819' = 23
   '33821' = 01
   '33822' = 01
   '33828' = 01
   '33829' = 01
   '3383'  = 23
   '3384'  = 01
   '33900' = 01
   '33901' = 01
   '33902' = 01
   '33903' = 01
   '33904' = 01
   '33905' = 01
   '33909' = 01
   '33910' = 01
   '33911' = 01
   '33912' = 01
   '33920' = 01
   '33921' = 01
   '33922' = 01
   '3393'  = 01
   '33941' = 01
   '33942' = 01
   '33943' = 01
   '33944' = 01
   '33981' = 01
   '33982' = 01
   '33983' = 01
   '33984' = 01
   '33985' = 01
   '33989' = 01
   '340'   = 01
   '3410'  = 01
   '3411'  = 01
   '34120' = 01
   '34121' = 01
   '34122' = 01
   '3418'  = 01
   '3419'  = 01
   '34200' = 01
   '34201' = 01
   '34202' = 01
   '34210' = 01
   '34211' = 01
   '34212' = 01
   '34280' = 01
   '34281' = 01
   '34282' = 01
   '34290' = 01
   '34291' = 01
   '34292' = 01
   '3430'  = 01
   '3431'  = 01
   '3432'  = 01
   '3433'  = 01
   '3434'  = 01
   '3438'  = 01
   '3439'  = 01
   '34400' = 01
   '34401' = 01
   '34402' = 01
   '34403' = 01
   '34404' = 01
   '34409' = 01
   '3441'  = 01
   '3442'  = 01
   '34430' = 01
   '34431' = 01
   '34432' = 01
   '34440' = 01
   '34441' = 01
   '34442' = 01
   '3445'  = 01
   '34460' = 01
   '34461' = 11
   '34481' = 01
   '34489' = 01
   '3449'  = 01
   '34500' = 01
   '34501' = 01
   '34510' = 01
   '34511' = 01
   '3452'  = 01
   '3453'  = 01
   '34540' = 01
   '34541' = 01
   '34550' = 01
   '34551' = 01
   '34560' = 01
   '34561' = 01
   '34570' = 01
   '34571' = 01
   '34580' = 01
   '34581' = 01
   '34590' = 01
   '34591' = 01
   '34600' = 01
   '34601' = 01
   '34602' = 01
   '34603' = 01
   '34610' = 01
   '34611' = 01
   '34612' = 01
   '34613' = 01
   '34620' = 01
   '34621' = 01
   '34622' = 01
   '34623' = 01
   '34630' = 01
   '34631' = 01
   '34632' = 01
   '34633' = 01
   '34640' = 01
   '34641' = 01
   '34642' = 01
   '34643' = 01
   '34650' = 01
   '34651' = 01
   '34652' = 01
   '34653' = 01
   '34660' = 01
   '34661' = 01
   '34662' = 01
   '34663' = 01
   '34670' = 01
   '34671' = 01
   '34672' = 01
   '34673' = 01
   '34680' = 01
   '34681' = 01
   '34682' = 01
   '34683' = 01
   '34690' = 01
   '34691' = 01
   '34692' = 01
   '34693' = 01
   '34700' = 01
   '34701' = 01
   '34710' = 01
   '34711' = 01
   '3480'  = 01
   '3481'  = 01
   '3482'  = 01
   '34830' = 01
   '34831' = 01
   '34839' = 01
   '3484'  = 01
   '3485'  = 01
   '34881' = 01
   '34882' = 01
   '34889' = 01
   '3489'  = 01
   '3490'  = 01
   '3491'  = 01
   '3492'  = 01
   '34931' = 21
   '34939' = 21
   '34981' = 01
   '34982' = 01
   '34989' = 01
   '3499'  = 01
   '3501'  = 01
   '3502'  = 01
   '3508'  = 01
   '3509'  = 01
   '3510'  = 01
   '3511'  = 01
   '3518'  = 01
   '3519'  = 01
   '3520'  = 01
   '3521'  = 01
   '3522'  = 01
   '3523'  = 01
   '3524'  = 01
   '3525'  = 01
   '3526'  = 01
   '3529'  = 01
   '3530'  = 01
   '3531'  = 01
   '3532'  = 01
   '3533'  = 01
   '3534'  = 01
   '3535'  = 01
   '3536'  = 01
   '3538'  = 01
   '3539'  = 01
   '3540'  = 01
   '3541'  = 01
   '3542'  = 01
   '3543'  = 01
   '3544'  = 01
   '3545'  = 01
   '3548'  = 01
   '3549'  = 01
   '3550'  = 01
   '3551'  = 01
   '3552'  = 01
   '3553'  = 01
   '3554'  = 01
   '3555'  = 01
   '3556'  = 01
   '35571' = 01
   '35579' = 01
   '3558'  = 01
   '3559'  = 01
   '3560'  = 01
   '3561'  = 01
   '3562'  = 01
   '3563'  = 01
   '3564'  = 01
   '3568'  = 01
   '3569'  = 01
   '3570'  = 01
   '3571'  = 01
   '3572'  = 01
   '3573'  = 01
   '3574'  = 01
   '3575'  = 01
   '3576'  = 01
   '3577'  = 01
   '35781' = 01
   '35782' = 01
   '35789' = 01
   '3579'  = 01
   '35800' = 01
   '35801' = 01
   '3581'  = 01
   '3582'  = 01
   '35830' = 01
   '35831' = 01
   '35839' = 01
   '3588'  = 01
   '3589'  = 01
   '3590'  = 01
   '3591'  = 01
   '35921' = 01
   '35922' = 01
   '35923' = 01
   '35924' = 01
   '35929' = 01
   '3593'  = 01
   '3594'  = 01
   '3595'  = 01
   '3596'  = 01
   '35971' = 08
   '35979' = 08
   '35981' = 01
   '35989' = 01
   '3599'  = 01
   '36000' = 02
   '36001' = 02
   '36002' = 02
   '36003' = 02
   '36004' = 02
   '36011' = 02
   '36012' = 02
   '36013' = 02
   '36014' = 02
   '36019' = 02
   '36020' = 02
   '36021' = 02
   '36023' = 02
   '36024' = 02
   '36029' = 02
   '36030' = 02
   '36031' = 02
   '36032' = 02
   '36033' = 02
   '36034' = 02
   '36040' = 02
   '36041' = 02
   '36042' = 02
   '36043' = 02
   '36044' = 02
   '36050' = 02
   '36051' = 02
   '36052' = 02
   '36053' = 02
   '36054' = 02
   '36055' = 02
   '36059' = 02
   '36060' = 02
   '36061' = 02
   '36062' = 02
   '36063' = 02
   '36064' = 02
   '36065' = 02
   '36069' = 02
   '36081' = 02
   '36089' = 02
   '3609'  = 02
   '36100' = 02
   '36101' = 02
   '36102' = 02
   '36103' = 02
   '36104' = 02
   '36105' = 02
   '36106' = 02
   '36107' = 02
   '36110' = 02
   '36111' = 02
   '36112' = 02
   '36113' = 02
   '36114' = 02
   '36119' = 02
   '3612'  = 02
   '36130' = 02
   '36131' = 02
   '36132' = 02
   '36133' = 02
   '36181' = 02
   '36189' = 02
   '3619'  = 02
   '36201' = 02
   '36202' = 02
   '36203' = 02
   '36204' = 02
   '36205' = 02
   '36206' = 02
   '36207' = 02
   '36210' = 02
   '36211' = 02
   '36212' = 02
   '36213' = 02
   '36214' = 02
   '36215' = 02
   '36216' = 02
   '36217' = 02
   '36218' = 02
   '36220' = 02
   '36221' = 02
   '36222' = 02
   '36223' = 02
   '36224' = 02
   '36225' = 02
   '36226' = 02
   '36227' = 02
   '36229' = 02
   '36230' = 02
   '36231' = 02
   '36232' = 02
   '36233' = 02
   '36234' = 02
   '36235' = 02
   '36236' = 02
   '36237' = 02
   '36240' = 02
   '36241' = 02
   '36242' = 02
   '36243' = 02
   '36250' = 02
   '36251' = 02
   '36252' = 02
   '36253' = 02
   '36254' = 02
   '36255' = 02
   '36256' = 02
   '36257' = 02
   '36260' = 02
   '36261' = 02
   '36262' = 02
   '36263' = 02
   '36264' = 02
   '36265' = 02
   '36266' = 02
   '36270' = 02
   '36271' = 02
   '36272' = 02
   '36273' = 02
   '36274' = 02
   '36275' = 02
   '36276' = 02
   '36277' = 02
   '36281' = 02
   '36282' = 02
   '36283' = 02
   '36284' = 02
   '36285' = 02
   '36289' = 02
   '3629'  = 02
   '36300' = 02
   '36301' = 02
   '36303' = 02
   '36304' = 02
   '36305' = 02
   '36306' = 02
   '36307' = 02
   '36308' = 02
   '36310' = 02
   '36311' = 02
   '36312' = 02
   '36313' = 02
   '36314' = 02
   '36315' = 02
   '36320' = 02
   '36321' = 02
   '36322' = 02
   '36330' = 02
   '36331' = 02
   '36332' = 02
   '36333' = 02
   '36334' = 02
   '36335' = 02
   '36340' = 02
   '36341' = 02
   '36342' = 02
   '36343' = 02
   '36350' = 02
   '36351' = 02
   '36352' = 02
   '36353' = 02
   '36354' = 02
   '36355' = 02
   '36356' = 02
   '36357' = 02
   '36361' = 02
   '36362' = 02
   '36363' = 02
   '36370' = 02
   '36371' = 02
   '36372' = 02
   '3638'  = 02
   '3639'  = 02
   '36400' = 02
   '36401' = 02
   '36402' = 02
   '36403' = 02
   '36404' = 02
   '36405' = 02
   '36410' = 02
   '36411' = 02
   '36421' = 02
   '36422' = 02
   '36423' = 02
   '36424' = 02
   '3643'  = 02
   '36441' = 02
   '36442' = 02
   '36451' = 02
   '36452' = 02
   '36453' = 02
   '36454' = 02
   '36455' = 02
   '36456' = 02
   '36457' = 02
   '36459' = 02
   '36460' = 02
   '36461' = 02
   '36462' = 02
   '36463' = 02
   '36464' = 02
   '36470' = 02
   '36471' = 02
   '36472' = 02
   '36473' = 02
   '36474' = 02
   '36475' = 02
   '36476' = 02
   '36477' = 02
   '36481' = 02
   '36482' = 02
   '36489' = 02
   '3649'  = 02
   '36500' = 02
   '36501' = 02
   '36502' = 02
   '36503' = 02
   '36504' = 02
   '36505' = 02
   '36506' = 02
   '36510' = 02
   '36511' = 02
   '36512' = 02
   '36513' = 02
   '36514' = 02
   '36515' = 02
   '36520' = 02
   '36521' = 02
   '36522' = 02
   '36523' = 02
   '36524' = 02
   '36531' = 02
   '36532' = 02
   '36541' = 02
   '36542' = 02
   '36543' = 02
   '36544' = 02
   '36551' = 02
   '36552' = 02
   '36559' = 02
   '36560' = 02
   '36561' = 02
   '36562' = 02
   '36563' = 02
   '36564' = 02
   '36565' = 02
   '36570' = 02
   '36571' = 02
   '36572' = 02
   '36573' = 02
   '36574' = 02
   '36581' = 02
   '36582' = 02
   '36583' = 02
   '36589' = 02
   '3659'  = 02
   '36600' = 02
   '36601' = 02
   '36602' = 02
   '36603' = 02
   '36604' = 02
   '36609' = 02
   '36610' = 02
   '36611' = 02
   '36612' = 02
   '36613' = 02
   '36614' = 02
   '36615' = 02
   '36616' = 02
   '36617' = 02
   '36618' = 02
   '36619' = 02
   '36620' = 02
   '36621' = 02
   '36622' = 02
   '36623' = 02
   '36630' = 02
   '36631' = 02
   '36632' = 02
   '36633' = 02
   '36634' = 02
   '36641' = 02
   '36642' = 02
   '36643' = 02
   '36644' = 02
   '36645' = 02
   '36646' = 02
   '36650' = 02
   '36651' = 02
   '36652' = 02
   '36653' = 02
   '3668'  = 02
   '3669'  = 02
   '3670'  = 02
   '3671'  = 02
   '36720' = 02
   '36721' = 02
   '36722' = 02
   '36731' = 02
   '36732' = 02
   '3674'  = 02
   '36751' = 02
   '36752' = 02
   '36753' = 02
   '36781' = 02
   '36789' = 02
   '3679'  = 02
   '36800' = 02
   '36801' = 02
   '36802' = 02
   '36803' = 02
   '36810' = 02
   '36811' = 02
   '36812' = 02
   '36813' = 02
   '36814' = 02
   '36815' = 02
   '36816' = 02
   '3682'  = 02
   '36830' = 02
   '36831' = 02
   '36832' = 02
   '36833' = 02
   '36834' = 02
   '36840' = 02
   '36841' = 02
   '36842' = 02
   '36843' = 02
   '36844' = 02
   '36845' = 02
   '36846' = 02
   '36847' = 02
   '36851' = 02
   '36852' = 02
   '36853' = 02
   '36854' = 02
   '36855' = 02
   '36859' = 02
   '36860' = 02
   '36861' = 02
   '36862' = 02
   '36863' = 02
   '36869' = 02
   '3688'  = 02
   '3689'  = 02
   '36900' = 02
   '36901' = 02
   '36902' = 02
   '36903' = 02
   '36904' = 02
   '36905' = 02
   '36906' = 02
   '36907' = 02
   '36908' = 02
   '36910' = 02
   '36911' = 02
   '36912' = 02
   '36913' = 02
   '36914' = 02
   '36915' = 02
   '36916' = 02
   '36917' = 02
   '36918' = 02
   '36920' = 02
   '36921' = 02
   '36922' = 02
   '36923' = 02
   '36924' = 02
   '36925' = 02
   '3693'  = 02
   '3694'  = 02
   '36960' = 02
   '36961' = 02
   '36962' = 02
   '36963' = 02
   '36964' = 02
   '36965' = 02
   '36966' = 02
   '36967' = 02
   '36968' = 02
   '36969' = 02
   '36970' = 02
   '36971' = 02
   '36972' = 02
   '36973' = 02
   '36974' = 02
   '36975' = 02
   '36976' = 02
   '3698'  = 02
   '3699'  = 02
   '37000' = 02
   '37001' = 02
   '37002' = 02
   '37003' = 02
   '37004' = 02
   '37005' = 02
   '37006' = 02
   '37007' = 02
   '37020' = 02
   '37021' = 02
   '37022' = 02
   '37023' = 02
   '37024' = 02
   '37031' = 02
   '37032' = 02
   '37033' = 02
   '37034' = 02
   '37035' = 02
   '37040' = 02
   '37044' = 02
   '37049' = 02
   '37050' = 02
   '37052' = 02
   '37054' = 02
   '37055' = 02
   '37059' = 02
   '37060' = 02
   '37061' = 02
   '37062' = 02
   '37063' = 02
   '37064' = 02
   '3708'  = 02
   '3709'  = 02
   '37100' = 02
   '37101' = 02
   '37102' = 02
   '37103' = 02
   '37104' = 02
   '37105' = 02
   '37110' = 02
   '37111' = 02
   '37112' = 02
   '37113' = 02
   '37114' = 02
   '37115' = 02
   '37116' = 02
   '37120' = 02
   '37121' = 02
   '37122' = 02
   '37123' = 02
   '37124' = 02
   '37130' = 02
   '37131' = 02
   '37132' = 02
   '37133' = 02
   '37140' = 02
   '37141' = 02
   '37142' = 02
   '37143' = 02
   '37144' = 02
   '37145' = 02
   '37146' = 02
   '37148' = 02
   '37149' = 02
   '37150' = 02
   '37151' = 02
   '37152' = 02
   '37153' = 02
   '37154' = 02
   '37155' = 02
   '37156' = 02
   '37157' = 02
   '37158' = 02
   '37160' = 02
   '37161' = 02
   '37162' = 02
   '37170' = 02
   '37171' = 02
   '37172' = 02
   '37173' = 02
   '37181' = 02
   '37182' = 02
   '37189' = 02
   '3719'  = 02
   '37200' = 02
   '37201' = 02
   '37202' = 02
   '37203' = 02
   '37204' = 02
   '37205' = 02
   '37206' = 02
   '37210' = 02
   '37211' = 02
   '37212' = 02
   '37213' = 02
   '37214' = 02
   '37215' = 02
   '37220' = 02
   '37221' = 02
   '37222' = 02
   '37230' = 02
   '37231' = 02
   '37233' = 02
   '37234' = 02
   '37239' = 02
   '37240' = 02
   '37241' = 02
   '37242' = 02
   '37243' = 02
   '37244' = 02
   '37245' = 02
   '37250' = 02
   '37251' = 02
   '37252' = 02
   '37253' = 02
   '37254' = 02
   '37255' = 02
   '37256' = 02
   '37261' = 02
   '37262' = 02
   '37263' = 02
   '37264' = 02
   '37271' = 02
   '37272' = 02
   '37273' = 02
   '37274' = 02
   '37275' = 02
   '37281' = 02
   '37289' = 02
   '3729'  = 02
   '37300' = 02
   '37301' = 02
   '37302' = 02
   '37311' = 02
   '37312' = 02
   '37313' = 02
   '3732'  = 02
   '37331' = 02
   '37332' = 02
   '37333' = 02
   '37334' = 02
   '3734'  = 02
   '3735'  = 02
   '3736'  = 02
   '3738'  = 02
   '3739'  = 02
   '37400' = 02
   '37401' = 02
   '37402' = 02
   '37403' = 02
   '37404' = 02
   '37405' = 02
   '37410' = 02
   '37411' = 02
   '37412' = 02
   '37413' = 02
   '37414' = 02
   '37420' = 02
   '37421' = 02
   '37422' = 02
   '37423' = 02
   '37430' = 02
   '37431' = 02
   '37432' = 02
   '37433' = 02
   '37434' = 02
   '37441' = 02
   '37443' = 02
   '37444' = 02
   '37445' = 02
   '37446' = 02
   '37450' = 02
   '37451' = 09
   '37452' = 02
   '37453' = 02
   '37454' = 02
   '37455' = 02
   '37456' = 02
   '37481' = 02
   '37482' = 02
   '37483' = 02
   '37484' = 02
   '37485' = 02
   '37486' = 02
   '37487' = 02
   '37489' = 02
   '3749'  = 02
   '37500' = 02
   '37501' = 02
   '37502' = 02
   '37503' = 02
   '37511' = 02
   '37512' = 02
   '37513' = 02
   '37514' = 02
   '37515' = 02
   '37516' = 02
   '37520' = 02
   '37521' = 02
   '37522' = 02
   '37530' = 02
   '37531' = 02
   '37532' = 02
   '37533' = 02
   '37541' = 02
   '37542' = 02
   '37543' = 02
   '37551' = 02
   '37552' = 02
   '37553' = 02
   '37554' = 02
   '37555' = 02
   '37556' = 02
   '37557' = 02
   '37561' = 02
   '37569' = 02
   '37581' = 02
   '37589' = 02
   '3759'  = 02
   '37600' = 02
   '37601' = 02
   '37602' = 02
   '37603' = 02
   '37604' = 02
   '37610' = 02
   '37611' = 02
   '37612' = 02
   '37613' = 02
   '37621' = 02
   '37622' = 02
   '37630' = 02
   '37631' = 02
   '37632' = 02
   '37633' = 02
   '37634' = 02
   '37635' = 02
   '37636' = 02
   '37640' = 02
   '37641' = 02
   '37642' = 02
   '37643' = 02
   '37644' = 02
   '37645' = 02
   '37646' = 02
   '37647' = 02
   '37650' = 02
   '37651' = 02
   '37652' = 02
   '3766'  = 02
   '37681' = 02
   '37682' = 02
   '37689' = 02
   '3769'  = 02
   '37700' = 01
   '37701' = 01
   '37702' = 02
   '37703' = 02
   '37704' = 01
   '37710' = 02
   '37711' = 02
   '37712' = 02
   '37713' = 02
   '37714' = 02
   '37715' = 02
   '37716' = 02
   '37721' = 02
   '37722' = 02
   '37723' = 02
   '37724' = 02
   '37730' = 02
   '37731' = 02
   '37732' = 02
   '37733' = 02
   '37734' = 02
   '37739' = 02
   '37741' = 02
   '37742' = 02
   '37743' = 02
   '37749' = 02
   '37751' = 01
   '37752' = 01
   '37753' = 01
   '37754' = 01
   '37761' = 01
   '37762' = 01
   '37763' = 01
   '37771' = 01
   '37772' = 01
   '37773' = 01
   '37775' = 01
   '3779'  = 01
   '37800' = 02
   '37801' = 02
   '37802' = 02
   '37803' = 02
   '37804' = 02
   '37805' = 02
   '37806' = 02
   '37807' = 02
   '37808' = 02
   '37810' = 02
   '37811' = 02
   '37812' = 02
   '37813' = 02
   '37814' = 02
   '37815' = 02
   '37816' = 02
   '37817' = 02
   '37818' = 02
   '37820' = 02
   '37821' = 02
   '37822' = 02
   '37823' = 02
   '37824' = 02
   '37830' = 02
   '37831' = 02
   '37832' = 02
   '37833' = 02
   '37834' = 02
   '37835' = 02
   '37840' = 02
   '37841' = 02
   '37842' = 02
   '37843' = 02
   '37844' = 02
   '37845' = 02
   '37850' = 02
   '37851' = 02
   '37852' = 02
   '37853' = 02
   '37854' = 02
   '37855' = 02
   '37856' = 02
   '37860' = 02
   '37861' = 02
   '37862' = 02
   '37863' = 02
   '37871' = 02
   '37872' = 02
   '37873' = 02
   '37881' = 02
   '37882' = 02
   '37883' = 02
   '37884' = 02
   '37885' = 02
   '37886' = 01
   '37887' = 02
   '3789'  = 02
   '37900' = 02
   '37901' = 02
   '37902' = 02
   '37903' = 02
   '37904' = 02
   '37905' = 02
   '37906' = 02
   '37907' = 02
   '37909' = 02
   '37911' = 02
   '37912' = 02
   '37913' = 02
   '37914' = 02
   '37915' = 02
   '37916' = 02
   '37919' = 02
   '37921' = 02
   '37922' = 02
   '37923' = 02
   '37924' = 02
   '37925' = 02
   '37926' = 02
   '37927' = 02
   '37929' = 02
   '37931' = 02
   '37932' = 02
   '37933' = 02
   '37934' = 02
   '37939' = 02
   '37940' = 02
   '37941' = 02
   '37942' = 02
   '37943' = 02
   '37945' = 01
   '37946' = 02
   '37949' = 02
   '37950' = 02
   '37951' = 02
   '37952' = 02
   '37953' = 02
   '37954' = 02
   '37955' = 02
   '37956' = 02
   '37957' = 02
   '37958' = 02
   '37959' = 02
   '37960' = 02
   '37961' = 02
   '37962' = 02
   '37963' = 02
   '3798'  = 02
   '37990' = 02
   '37991' = 02
   '37992' = 02
   '37993' = 02
   '37999' = 02
   '38000' = 03
   '38001' = 08
   '38002' = 08
   '38003' = 08
   '38010' = 03
   '38011' = 03
   '38012' = 03
   '38013' = 03
   '38014' = 03
   '38015' = 03
   '38016' = 03
   '38021' = 03
   '38022' = 03
   '38023' = 03
   '38030' = 03
   '38031' = 03
   '38032' = 03
   '38039' = 03
   '3804'  = 03
   '38050' = 03
   '38051' = 03
   '38052' = 03
   '38053' = 03
   '38081' = 03
   '38089' = 03
   '3809'  = 03
   '38100' = 03
   '38101' = 03
   '38102' = 03
   '38103' = 03
   '38104' = 03
   '38105' = 03
   '38106' = 03
   '38110' = 03
   '38119' = 03
   '38120' = 03
   '38129' = 03
   '3813'  = 03
   '3814'  = 03
   '38150' = 03
   '38151' = 03
   '38152' = 03
   '38160' = 03
   '38161' = 03
   '38162' = 03
   '38163' = 03
   '3817'  = 03
   '38181' = 03
   '38189' = 03
   '3819'  = 03
   '38200' = 03
   '38201' = 03
   '38202' = 03
   '3821'  = 03
   '3822'  = 03
   '3823'  = 03
   '3824'  = 03
   '3829'  = 03
   '38300' = 03
   '38301' = 03
   '38302' = 03
   '3831'  = 03
   '38320' = 03
   '38321' = 03
   '38322' = 03
   '38330' = 03
   '38331' = 03
   '38332' = 03
   '38333' = 03
   '38381' = 03
   '38389' = 03
   '3839'  = 03
   '38400' = 03
   '38401' = 03
   '38409' = 03
   '3841'  = 03
   '38420' = 03
   '38421' = 03
   '38422' = 03
   '38423' = 03
   '38424' = 03
   '38425' = 03
   '38481' = 03
   '38482' = 03
   '3849'  = 03
   '38500' = 03
   '38501' = 03
   '38502' = 03
   '38503' = 03
   '38509' = 03
   '38510' = 03
   '38511' = 03
   '38512' = 03
   '38513' = 03
   '38519' = 03
   '38521' = 03
   '38522' = 03
   '38523' = 03
   '38524' = 03
   '38530' = 03
   '38531' = 03
   '38532' = 03
   '38533' = 03
   '38535' = 03
   '38582' = 03
   '38583' = 03
   '38589' = 03
   '3859'  = 03
   '38600' = 03
   '38601' = 03
   '38602' = 03
   '38603' = 03
   '38604' = 03
   '38610' = 03
   '38611' = 03
   '38612' = 03
   '38619' = 03
   '3862'  = 03
   '38630' = 03
   '38631' = 03
   '38632' = 03
   '38633' = 03
   '38634' = 03
   '38635' = 03
   '38640' = 03
   '38641' = 03
   '38642' = 03
   '38643' = 03
   '38648' = 03
   '38650' = 03
   '38651' = 03
   '38652' = 03
   '38653' = 03
   '38654' = 03
   '38655' = 03
   '38656' = 03
   '38658' = 03
   '3868'  = 03
   '3869'  = 03
   '3870'  = 03
   '3871'  = 03
   '3872'  = 03
   '3878'  = 03
   '3879'  = 03
   '38800' = 03
   '38801' = 03
   '38802' = 03
   '38810' = 03
   '38811' = 03
   '38812' = 03
   '3882'  = 03
   '38830' = 03
   '38831' = 03
   '38832' = 03
   '38840' = 03
   '38841' = 03
   '38842' = 03
   '38843' = 03
   '38844' = 03
   '38845' = 19
   '3885'  = 03
   '38860' = 03
   '38861' = 01
   '38869' = 03
   '38870' = 03
   '38871' = 03
   '38872' = 03
   '3888'  = 03
   '3889'  = 03
   '38900' = 03
   '38901' = 03
   '38902' = 03
   '38903' = 03
   '38904' = 03
   '38905' = 03
   '38906' = 03
   '38908' = 03
   '38910' = 03
   '38911' = 03
   '38912' = 03
   '38913' = 03
   '38914' = 03
   '38915' = 03
   '38916' = 03
   '38917' = 03
   '38918' = 03
   '38920' = 03
   '38921' = 03
   '38922' = 03
   '3897'  = 03
   '3898'  = 03
   '3899'  = 03
   '390'   = 08
   '3910'  = 05
   '3911'  = 05
   '3912'  = 05
   '3918'  = 05
   '3919'  = 05
   '3920'  = 05
   '3929'  = 05
   '393'   = 05
   '3940'  = 05
   '3941'  = 05
   '3942'  = 05
   '3949'  = 05
   '3950'  = 05
   '3951'  = 05
   '3952'  = 05
   '3959'  = 05
   '3960'  = 05
   '3961'  = 05
   '3962'  = 05
   '3963'  = 05
   '3968'  = 05
   '3969'  = 05
   '3970'  = 05
   '3971'  = 05
   '3979'  = 05
   '3980'  = 05
   '39890' = 05
   '39891' = 05
   '39899' = 05
   '4010'  = 05
   '4011'  = 05
   '4019'  = 05
   '40200' = 05
   '40201' = 05
   '40210' = 05
   '40211' = 05
   '40290' = 05
   '40291' = 05
   '40300' = 11
   '40301' = 11
   '40310' = 11
   '40311' = 11
   '40390' = 11
   '40391' = 11
   '40400' = 05
   '40401' = 05
   '40402' = 11
   '40403' = 05
   '40410' = 05
   '40411' = 05
   '40412' = 11
   '40413' = 05
   '40490' = 05
   '40491' = 05
   '40492' = 11
   '40493' = 05
   '40501' = 05
   '40509' = 05
   '40511' = 05
   '40519' = 05
   '40591' = 05
   '40599' = 05
   '41000' = 05
   '41001' = 05
   '41002' = 05
   '41010' = 05
   '41011' = 05
   '41012' = 05
   '41020' = 05
   '41021' = 05
   '41022' = 05
   '41030' = 05
   '41031' = 05
   '41032' = 05
   '41040' = 05
   '41041' = 05
   '41042' = 05
   '41050' = 05
   '41051' = 05
   '41052' = 05
   '41060' = 05
   '41061' = 05
   '41062' = 05
   '41070' = 05
   '41071' = 05
   '41072' = 05
   '41080' = 05
   '41081' = 05
   '41082' = 05
   '41090' = 05
   '41091' = 05
   '41092' = 05
   '4110'  = 05
   '4111'  = 05
   '41181' = 05
   '41189' = 05
   '412'   = 05
   '4130'  = 05
   '4131'  = 05
   '4139'  = 05
   '41400' = 05
   '41401' = 05
   '41402' = 05
   '41403' = 05
   '41404' = 05
   '41405' = 05
   '41406' = 05
   '41407' = 05
   '41410' = 05
   '41411' = 05
   '41412' = 05
   '41419' = 05
   '4142'  = 05
   '4143'  = 05
   '4144'  = 05
   '4148'  = 05
   '4149'  = 05
   '4150'  = 05
   '41511' = 04
   '41512' = 04
   '41513' = 04
   '41519' = 04
   '4160'  = 05
   '4161'  = 05
   '4162'  = 04
   '4168'  = 05
   '4169'  = 05
   '4170'  = 05
   '4171'  = 05
   '4178'  = 05
   '4179'  = 05
   '4200'  = 05
   '42090' = 05
   '42091' = 05
   '42099' = 05
   '4210'  = 05
   '4211'  = 05
   '4219'  = 05
   '4220'  = 05
   '42290' = 05
   '42291' = 05
   '42292' = 05
   '42293' = 05
   '42299' = 05
   '4230'  = 05
   '4231'  = 05
   '4232'  = 05
   '4233'  = 05
   '4238'  = 05
   '4239'  = 05
   '4240'  = 05
   '4241'  = 05
   '4242'  = 05
   '4243'  = 05
   '42490' = 05
   '42491' = 05
   '42499' = 05
   '4250'  = 05
   '42511' = 05
   '42518' = 05
   '4252'  = 05
   '4253'  = 05
   '4254'  = 05
   '4255'  = 05
   '4257'  = 05
   '4258'  = 05
   '4259'  = 05
   '4260'  = 05
   '42610' = 05
   '42611' = 05
   '42612' = 05
   '42613' = 05
   '4262'  = 05
   '4263'  = 05
   '4264'  = 05
   '42650' = 05
   '42651' = 05
   '42652' = 05
   '42653' = 05
   '42654' = 05
   '4266'  = 05
   '4267'  = 05
   '42681' = 05
   '42682' = 05
   '42689' = 05
   '4269'  = 05
   '4270'  = 05
   '4271'  = 05
   '4272'  = 05
   '42731' = 05
   '42732' = 05
   '42741' = 05
   '42742' = 05
   '4275'  = 05
   '42760' = 05
   '42761' = 05
   '42769' = 05
   '42781' = 05
   '42789' = 05
   '4279'  = 05
   '4280'  = 05
   '4281'  = 05
   '42820' = 05
   '42821' = 05
   '42822' = 05
   '42823' = 05
   '42830' = 05
   '42831' = 05
   '42832' = 05
   '42833' = 05
   '42840' = 05
   '42841' = 05
   '42842' = 05
   '42843' = 05
   '4289'  = 05
   '4290'  = 05
   '4291'  = 05
   '4292'  = 05
   '4293'  = 05
   '4294'  = 05
   '4295'  = 05
   '4296'  = 05
   '42971' = 05
   '42979' = 05
   '42981' = 05
   '42982' = 05
   '42983' = 05
   '42989' = 05
   '4299'  = 05
   '430'   = 01
   '431'   = 01
   '4320'  = 01
   '4321'  = 01
   '4329'  = 01
   '43300' = 01
   '43301' = 01
   '43310' = 01
   '43311' = 01
   '43320' = 01
   '43321' = 01
   '43330' = 01
   '43331' = 01
   '43380' = 01
   '43381' = 01
   '43390' = 01
   '43391' = 01
   '43400' = 01
   '43401' = 01
   '43410' = 01
   '43411' = 01
   '43490' = 01
   '43491' = 01
   '4350'  = 01
   '4351'  = 01
   '4352'  = 01
   '4353'  = 01
   '4358'  = 01
   '4359'  = 01
   '436'   = 01
   '4370'  = 01
   '4371'  = 01
   '4372'  = 01
   '4373'  = 01
   '4374'  = 01
   '4375'  = 01
   '4376'  = 01
   '4377'  = 01
   '4378'  = 01
   '4379'  = 01
   '4380'  = 01
   '43810' = 01
   '43811' = 01
   '43812' = 01
   '43813' = 01
   '43814' = 01
   '43819' = 01
   '43820' = 01
   '43821' = 01
   '43822' = 01
   '43830' = 01
   '43831' = 01
   '43832' = 01
   '43840' = 01
   '43841' = 01
   '43842' = 01
   '43850' = 01
   '43851' = 01
   '43852' = 01
   '43853' = 01
   '4386'  = 01
   '4387'  = 01
   '43881' = 01
   '43882' = 01
   '43883' = 01
   '43884' = 01
   '43885' = 01
   '43889' = 01
   '4389'  = 01
   '4400'  = 05
   '4401'  = 11
   '44020' = 05
   '44021' = 05
   '44022' = 05
   '44023' = 05
   '44024' = 05
   '44029' = 05
   '44030' = 05
   '44031' = 05
   '44032' = 05
   '4404'  = 05
   '4408'  = 05
   '4409'  = 05
   '44100' = 05
   '44101' = 05
   '44102' = 05
   '44103' = 05
   '4411'  = 05
   '4412'  = 05
   '4413'  = 05
   '4414'  = 05
   '4415'  = 05
   '4416'  = 05
   '4417'  = 05
   '4419'  = 05
   '4420'  = 05
   '4421'  = 11
   '4422'  = 05
   '4423'  = 05
   '44281' = 05
   '44282' = 05
   '44283' = 05
   '44284' = 05
   '44289' = 05
   '4429'  = 05
   '4430'  = 08
   '4431'  = 05
   '44321' = 05
   '44322' = 05
   '44323' = 11
   '44324' = 05
   '44329' = 05
   '44381' = 05
   '44382' = 05
   '44389' = 05
   '4439'  = 05
   '44401' = 05
   '44409' = 05
   '4441'  = 05
   '44421' = 05
   '44422' = 05
   '44481' = 05
   '44489' = 05
   '4449'  = 05
   '44501' = 05
   '44502' = 05
   '44581' = 11
   '44589' = 05
   '4460'  = 08
   '4461'  = 08
   '44620' = 08
   '44621' = 08
   '44629' = 08
   '4463'  = 08
   '4464'  = 08
   '4465'  = 08
   '4466'  = 08
   '4467'  = 08
   '4470'  = 05
   '4471'  = 05
   '4472'  = 05
   '4473'  = 11
   '4474'  = 06
   '4475'  = 05
   '4476'  = 08
   '44770' = 05
   '44771' = 05
   '44772' = 05
   '44773' = 05
   '4478'  = 05
   '4479'  = 05
   '4480'  = 05
   '4481'  = 09
   '4489'  = 05
   '449'   = 05
   '4510'  = 05
   '45111' = 05
   '45119' = 05
   '4512'  = 05
   '45181' = 05
   '45182' = 05
   '45183' = 05
   '45184' = 05
   '45189' = 05
   '4519'  = 05
   '452'   = 07
   '4530'  = 07
   '4531'  = 05
   '4532'  = 05
   '4533'  = 11
   '45340' = 05
   '45341' = 05
   '45342' = 05
   '45350' = 05
   '45351' = 05
   '45352' = 05
   '4536'  = 05
   '45371' = 05
   '45372' = 05
   '45373' = 05
   '45374' = 05
   '45375' = 05
   '45376' = 05
   '45377' = 05
   '45379' = 05
   '45381' = 05
   '45382' = 05
   '45383' = 05
   '45384' = 05
   '45385' = 05
   '45386' = 05
   '45387' = 05
   '45389' = 05
   '4539'  = 05
   '4540'  = 05
   '4541'  = 05
   '4542'  = 05
   '4548'  = 05
   '4549'  = 05
   '4550'  = 06
   '4551'  = 06
   '4552'  = 06
   '4553'  = 06
   '4554'  = 06
   '4555'  = 06
   '4556'  = 06
   '4557'  = 06
   '4558'  = 06
   '4559'  = 06
   '4560'  = 06
   '4561'  = 06
   '45620' = 06
   '45621' = 06
   '4563'  = 05
   '4564'  = 12
   '4565'  = 12
   '4566'  = 13
   '4568'  = 05
   '4570'  = 09
   '4571'  = 09
   '4572'  = 09
   '4578'  = 16
   '4579'  = 16
   '4580'  = 05
   '4581'  = 05
   '45821' = 05
   '45829' = 05
   '4588'  = 05
   '4589'  = 05
   '4590'  = 05
   '45910' = 05
   '45911' = 05
   '45912' = 05
   '45913' = 05
   '45919' = 05
   '4592'  = 05
   '45930' = 05
   '45931' = 05
   '45932' = 05
   '45933' = 05
   '45939' = 05
   '45981' = 05
   '45989' = 05
   '4599'  = 05
   '460'   = 03
   '4610'  = 03
   '4611'  = 03
   '4612'  = 03
   '4613'  = 03
   '4618'  = 03
   '4619'  = 03
   '462'   = 03
   '463'   = 03
   '46400' = 03
   '46401' = 03
   '46410' = 04
   '46411' = 04
   '46420' = 03
   '46421' = 03
   '46430' = 03
   '46431' = 03
   '4644'  = 03
   '46450' = 03
   '46451' = 03
   '4650'  = 03
   '4658'  = 03
   '4659'  = 03
   '4660'  = 04
   '46611' = 04
   '46619' = 04
   '470'   = 03
   '4710'  = 03
   '4711'  = 03
   '4718'  = 03
   '4719'  = 03
   '4720'  = 03
   '4721'  = 03
   '4722'  = 03
   '4730'  = 03
   '4731'  = 03
   '4732'  = 03
   '4733'  = 03
   '4738'  = 03
   '4739'  = 03
   '47400' = 03
   '47401' = 03
   '47402' = 03
   '47410' = 03
   '47411' = 03
   '47412' = 03
   '4742'  = 03
   '4748'  = 03
   '4749'  = 03
   '475'   = 03
   '4760'  = 03
   '4761'  = 03
   '4770'  = 03
   '4771'  = 03
   '4772'  = 03
   '4778'  = 03
   '4779'  = 03
   '4780'  = 03
   '47811' = 03
   '47819' = 03
   '47820' = 03
   '47821' = 03
   '47822' = 03
   '47824' = 03
   '47825' = 03
   '47826' = 03
   '47829' = 03
   '47830' = 03
   '47831' = 03
   '47832' = 03
   '47833' = 03
   '47834' = 03
   '4784'  = 03
   '4785'  = 03
   '4786'  = 03
   '47870' = 03
   '47871' = 03
   '47874' = 03
   '47875' = 03
   '47879' = 03
   '4788'  = 03
   '4789'  = 03
   '4800'  = 04
   '4801'  = 04
   '4802'  = 04
   '4803'  = 04
   '4808'  = 04
   '4809'  = 04
   '481'   = 04
   '4820'  = 04
   '4821'  = 04
   '4822'  = 04
   '48230' = 04
   '48231' = 04
   '48232' = 04
   '48239' = 04
   '48240' = 04
   '48241' = 04
   '48242' = 04
   '48249' = 04
   '48281' = 04
   '48282' = 04
   '48283' = 04
   '48284' = 04
   '48289' = 04
   '4829'  = 04
   '4830'  = 04
   '4831'  = 04
   '4838'  = 04
   '4841'  = 04
   '4843'  = 04
   '4845'  = 04
   '4846'  = 04
   '4847'  = 04
   '4848'  = 04
   '485'   = 04
   '486'   = 04
   '4870'  = 04
   '4871'  = 03
   '4878'  = 18
   '48801' = 04
   '48802' = 04
   '48809' = 18
   '48811' = 04
   '48812' = 04
   '48819' = 18
   '48881' = 04
   '48882' = 04
   '48889' = 18
   '490'   = 04
   '4910'  = 04
   '4911'  = 04
   '49120' = 04
   '49121' = 04
   '49122' = 04
   '4918'  = 04
   '4919'  = 04
   '4920'  = 04
   '4928'  = 04
   '49300' = 04
   '49301' = 04
   '49302' = 04
   '49310' = 04
   '49311' = 04
   '49312' = 04
   '49320' = 04
   '49321' = 04
   '49322' = 04
   '49381' = 04
   '49382' = 04
   '49390' = 04
   '49391' = 04
   '49392' = 04
   '4940'  = 04
   '4941'  = 04
   '4950'  = 04
   '4951'  = 04
   '4952'  = 04
   '4953'  = 04
   '4954'  = 04
   '4955'  = 04
   '4956'  = 04
   '4957'  = 04
   '4958'  = 04
   '4959'  = 04
   '496'   = 04
   '500'   = 04
   '501'   = 04
   '502'   = 04
   '503'   = 04
   '504'   = 04
   '505'   = 04
   '5060'  = 04
   '5061'  = 04
   '5062'  = 04
   '5063'  = 04
   '5064'  = 04
   '5069'  = 04
   '5070'  = 04
   '5071'  = 04
   '5078'  = 04
   '5080'  = 04
   '5081'  = 04
   '5082'  = 04
   '5088'  = 04
   '5089'  = 04
   '5100'  = 04
   '5109'  = 04
   '5110'  = 04
   '5111'  = 04
   '51181' = 04
   '51189' = 04
   '5119'  = 04
   '5120'  = 04
   '5121'  = 04
   '5122'  = 04
   '51281' = 04
   '51282' = 04
   '51283' = 04
   '51284' = 04
   '51289' = 04
   '5130'  = 04
   '5131'  = 04
   '514'   = 04
   '515'   = 04
   '5160'  = 04
   '5161'  = 04
   '5162'  = 04
   '51630' = 04
   '51631' = 04
   '51632' = 04
   '51633' = 04
   '51634' = 04
   '51635' = 04
   '51636' = 04
   '51637' = 04
   '5164'  = 04
   '5165'  = 04
   '51661' = 04
   '51662' = 04
   '51663' = 04
   '51664' = 04
   '51669' = 04
   '5168'  = 04
   '5169'  = 04
   '5171'  = 04
   '5172'  = 04
   '5173'  = 04
   '5178'  = 04
   '5180'  = 04
   '5181'  = 04
   '5182'  = 04
   '5183'  = 04
   '5184'  = 04
   '51851' = 04
   '51852' = 04
   '51853' = 04
   '5186'  = 04
   '5187'  = 04
   '51881' = 04
   '51882' = 04
   '51883' = 04
   '51884' = 04
   '51889' = 04
   '51900' = 04
   '51901' = 04
   '51902' = 04
   '51909' = 04
   '51911' = 04
   '51919' = 04
   '5192'  = 04
   '5193'  = 04
   '5194'  = 04
   '5198'  = 04
   '5199'  = 04
   '5200'  = 03
   '5201'  = 03
   '5202'  = 03
   '5203'  = 03
   '5204'  = 03
   '5205'  = 03
   '5206'  = 03
   '5207'  = 03
   '5208'  = 03
   '5209'  = 03
   '52100' = 03
   '52101' = 03
   '52102' = 03
   '52103' = 03
   '52104' = 03
   '52105' = 03
   '52106' = 03
   '52107' = 03
   '52108' = 03
   '52109' = 03
   '52110' = 03
   '52111' = 03
   '52112' = 03
   '52113' = 03
   '52114' = 03
   '52115' = 03
   '52120' = 03
   '52121' = 03
   '52122' = 03
   '52123' = 03
   '52124' = 03
   '52125' = 03
   '52130' = 03
   '52131' = 03
   '52132' = 03
   '52133' = 03
   '52134' = 03
   '52135' = 03
   '52140' = 03
   '52141' = 03
   '52142' = 03
   '52149' = 03
   '5215'  = 03
   '5216'  = 03
   '5217'  = 03
   '52181' = 03
   '52189' = 03
   '5219'  = 03
   '5220'  = 03
   '5221'  = 03
   '5222'  = 03
   '5223'  = 03
   '5224'  = 03
   '5225'  = 03
   '5226'  = 03
   '5227'  = 03
   '5228'  = 03
   '5229'  = 03
   '52300' = 03
   '52301' = 03
   '52310' = 03
   '52311' = 03
   '52320' = 03
   '52321' = 03
   '52322' = 03
   '52323' = 03
   '52324' = 03
   '52325' = 03
   '52330' = 03
   '52331' = 03
   '52332' = 03
   '52333' = 03
   '52340' = 03
   '52341' = 03
   '52342' = 03
   '5235'  = 03
   '5236'  = 03
   '5238'  = 03
   '5239'  = 03
   '52400' = 03
   '52401' = 03
   '52402' = 03
   '52403' = 03
   '52404' = 03
   '52405' = 03
   '52406' = 03
   '52407' = 03
   '52409' = 03
   '52410' = 03
   '52411' = 03
   '52412' = 03
   '52419' = 03
   '52420' = 03
   '52421' = 03
   '52422' = 03
   '52423' = 03
   '52424' = 03
   '52425' = 03
   '52426' = 03
   '52427' = 03
   '52428' = 03
   '52429' = 03
   '52430' = 03
   '52431' = 03
   '52432' = 03
   '52433' = 03
   '52434' = 03
   '52435' = 03
   '52436' = 03
   '52437' = 03
   '52439' = 03
   '5244'  = 03
   '52450' = 03
   '52451' = 03
   '52452' = 03
   '52453' = 03
   '52454' = 03
   '52455' = 03
   '52456' = 03
   '52457' = 03
   '52459' = 03
   '52460' = 03
   '52461' = 03
   '52462' = 03
   '52463' = 03
   '52464' = 03
   '52469' = 03
   '52470' = 03
   '52471' = 03
   '52472' = 03
   '52473' = 03
   '52474' = 03
   '52475' = 03
   '52476' = 03
   '52479' = 03
   '52481' = 03
   '52482' = 03
   '52489' = 03
   '5249'  = 03
   '5250'  = 03
   '52510' = 03
   '52511' = 03
   '52512' = 03
   '52513' = 03
   '52519' = 03
   '52520' = 03
   '52521' = 03
   '52522' = 03
   '52523' = 03
   '52524' = 03
   '52525' = 03
   '52526' = 03
   '5253'  = 03
   '52540' = 03
   '52541' = 03
   '52542' = 03
   '52543' = 03
   '52544' = 03
   '52550' = 03
   '52551' = 03
   '52552' = 03
   '52553' = 03
   '52554' = 03
   '52560' = 03
   '52561' = 03
   '52562' = 03
   '52563' = 03
   '52564' = 03
   '52565' = 03
   '52566' = 03
   '52567' = 03
   '52569' = 03
   '52571' = 03
   '52572' = 03
   '52573' = 03
   '52579' = 03
   '5258'  = 03
   '5259'  = 03
   '5260'  = 03
   '5261'  = 03
   '5262'  = 03
   '5263'  = 03
   '5264'  = 03
   '5265'  = 03
   '52661' = 03
   '52662' = 03
   '52663' = 03
   '52669' = 03
   '52681' = 03
   '52689' = 03
   '5269'  = 03
   '5270'  = 03
   '5271'  = 03
   '5272'  = 03
   '5273'  = 03
   '5274'  = 03
   '5275'  = 03
   '5276'  = 03
   '5277'  = 03
   '5278'  = 03
   '5279'  = 03
   '52800' = 03
   '52801' = 03
   '52802' = 03
   '52809' = 03
   '5281'  = 03
   '5282'  = 03
   '5283'  = 03
   '5284'  = 03
   '5285'  = 03
   '5286'  = 03
   '52871' = 03
   '52872' = 03
   '52879' = 03
   '5288'  = 03
   '5289'  = 03
   '5290'  = 03
   '5291'  = 03
   '5292'  = 03
   '5293'  = 03
   '5294'  = 03
   '5295'  = 03
   '5296'  = 03
   '5298'  = 03
   '5299'  = 03
   '5300'  = 06
   '53010' = 06
   '53011' = 06
   '53012' = 06
   '53013' = 06
   '53019' = 06
   '53020' = 06
   '53021' = 06
   '5303'  = 06
   '5304'  = 06
   '5305'  = 06
   '5306'  = 06
   '5307'  = 06
   '53081' = 06
   '53082' = 06
   '53083' = 06
   '53084' = 06
   '53085' = 06
   '53086' = 06
   '53087' = 06
   '53089' = 06
   '5309'  = 06
   '53100' = 06
   '53101' = 06
   '53110' = 06
   '53111' = 06
   '53120' = 06
   '53121' = 06
   '53130' = 06
   '53131' = 06
   '53140' = 06
   '53141' = 06
   '53150' = 06
   '53151' = 06
   '53160' = 06
   '53161' = 06
   '53170' = 06
   '53171' = 06
   '53190' = 06
   '53191' = 06
   '53200' = 06
   '53201' = 06
   '53210' = 06
   '53211' = 06
   '53220' = 06
   '53221' = 06
   '53230' = 06
   '53231' = 06
   '53240' = 06
   '53241' = 06
   '53250' = 06
   '53251' = 06
   '53260' = 06
   '53261' = 06
   '53270' = 06
   '53271' = 06
   '53290' = 06
   '53291' = 06
   '53300' = 06
   '53301' = 06
   '53310' = 06
   '53311' = 06
   '53320' = 06
   '53321' = 06
   '53330' = 06
   '53331' = 06
   '53340' = 06
   '53341' = 06
   '53350' = 06
   '53351' = 06
   '53360' = 06
   '53361' = 06
   '53370' = 06
   '53371' = 06
   '53390' = 06
   '53391' = 06
   '53400' = 06
   '53401' = 06
   '53410' = 06
   '53411' = 06
   '53420' = 06
   '53421' = 06
   '53430' = 06
   '53431' = 06
   '53440' = 06
   '53441' = 06
   '53450' = 06
   '53451' = 06
   '53460' = 06
   '53461' = 06
   '53470' = 06
   '53471' = 06
   '53490' = 06
   '53491' = 06
   '53500' = 06
   '53501' = 06
   '53510' = 06
   '53511' = 06
   '53520' = 06
   '53521' = 06
   '53530' = 06
   '53531' = 06
   '53540' = 06
   '53541' = 06
   '53550' = 06
   '53551' = 06
   '53560' = 06
   '53561' = 06
   '53570' = 06
   '53571' = 06
   '5360'  = 06
   '5361'  = 06
   '5362'  = 06
   '5363'  = 06
   '53640' = 06
   '53641' = 06
   '53642' = 06
   '53649' = 06
   '5368'  = 06
   '5369'  = 06
   '5370'  = 06
   '5371'  = 06
   '5372'  = 06
   '5373'  = 06
   '5374'  = 06
   '5375'  = 06
   '5376'  = 06
   '53781' = 06
   '53782' = 06
   '53783' = 06
   '53784' = 06
   '53789' = 06
   '5379'  = 06
   '538'   = 06
   '53901' = 06
   '53909' = 06
   '53981' = 06
   '53989' = 06
   '5400'  = 06
   '5401'  = 06
   '5409'  = 06
   '541'   = 06
   '542'   = 06
   '5430'  = 06
   '5439'  = 06
   '55000' = 06
   '55001' = 06
   '55002' = 06
   '55003' = 06
   '55010' = 06
   '55011' = 06
   '55012' = 06
   '55013' = 06
   '55090' = 06
   '55091' = 06
   '55092' = 06
   '55093' = 06
   '55100' = 06
   '55101' = 06
   '55102' = 06
   '55103' = 06
   '5511'  = 06
   '55120' = 06
   '55121' = 06
   '55129' = 06
   '5513'  = 06
   '5518'  = 06
   '5519'  = 06
   '55200' = 06
   '55201' = 06
   '55202' = 06
   '55203' = 06
   '5521'  = 06
   '55220' = 06
   '55221' = 06
   '55229' = 06
   '5523'  = 06
   '5528'  = 06
   '5529'  = 06
   '55300' = 06
   '55301' = 06
   '55302' = 06
   '55303' = 06
   '5531'  = 06
   '55320' = 06
   '55321' = 06
   '55329' = 06
   '5533'  = 06
   '5538'  = 06
   '5539'  = 06
   '5550'  = 06
   '5551'  = 06
   '5552'  = 06
   '5559'  = 06
   '5560'  = 06
   '5561'  = 06
   '5562'  = 06
   '5563'  = 06
   '5564'  = 06
   '5565'  = 06
   '5566'  = 06
   '5568'  = 06
   '5569'  = 06
   '5570'  = 06
   '5571'  = 06
   '5579'  = 06
   '5581'  = 06
   '5582'  = 06
   '5583'  = 06
   '55841' = 06
   '55842' = 06
   '5589'  = 06
   '5600'  = 06
   '5601'  = 06
   '5602'  = 06
   '56030' = 06
   '56031' = 06
   '56032' = 06
   '56039' = 06
   '56081' = 06
   '56089' = 06
   '5609'  = 06
   '56200' = 06
   '56201' = 06
   '56202' = 06
   '56203' = 06
   '56210' = 06
   '56211' = 06
   '56212' = 06
   '56213' = 06
   '56400' = 06
   '56401' = 06
   '56402' = 06
   '56409' = 06
   '5641'  = 06
   '5642'  = 06
   '5643'  = 06
   '5644'  = 06
   '5645'  = 06
   '5646'  = 06
   '5647'  = 06
   '56481' = 06
   '56489' = 06
   '5649'  = 06
   '5650'  = 06
   '5651'  = 06
   '566'   = 06
   '5670'  = 06
   '5671'  = 06
   '56721' = 06
   '56722' = 06
   '56723' = 06
   '56729' = 06
   '56731' = 06
   '56738' = 06
   '56739' = 06
   '56781' = 06
   '56782' = 06
   '56789' = 06
   '5679'  = 06
   '5680'  = 06
   '56881' = 06
   '56882' = 06
   '56889' = 06
   '5689'  = 06
   '5690'  = 06
   '5691'  = 06
   '5692'  = 06
   '5693'  = 06
   '56941' = 06
   '56942' = 06
   '56943' = 06
   '56944' = 06
   '56949' = 06
   '5695'  = 06
   '56960' = 06
   '56961' = 06
   '56962' = 06
   '56969' = 06
   '56971' = 06
   '56979' = 06
   '56981' = 06
   '56982' = 06
   '56983' = 06
   '56984' = 06
   '56985' = 06
   '56986' = 06
   '56987' = 06
   '56989' = 06
   '5699'  = 06
   '570'   = 07
   '5710'  = 07
   '5711'  = 07
   '5712'  = 07
   '5713'  = 07
   '57140' = 07
   '57141' = 07
   '57142' = 07
   '57149' = 07
   '5715'  = 07
   '5716'  = 07
   '5718'  = 07
   '5719'  = 07
   '5720'  = 07
   '5721'  = 07
   '5722'  = 07
   '5723'  = 07
   '5724'  = 07
   '5728'  = 07
   '5730'  = 07
   '5731'  = 07
   '5732'  = 07
   '5733'  = 07
   '5734'  = 07
   '5735'  = 04
   '5738'  = 07
   '5739'  = 07
   '57400' = 07
   '57401' = 07
   '57410' = 07
   '57411' = 07
   '57420' = 07
   '57421' = 07
   '57430' = 07
   '57431' = 07
   '57440' = 07
   '57441' = 07
   '57450' = 07
   '57451' = 07
   '57460' = 07
   '57461' = 07
   '57470' = 07
   '57471' = 07
   '57480' = 07
   '57481' = 07
   '57490' = 07
   '57491' = 07
   '5750'  = 07
   '57510' = 07
   '57511' = 07
   '57512' = 07
   '5752'  = 07
   '5753'  = 07
   '5754'  = 07
   '5755'  = 07
   '5756'  = 07
   '5758'  = 07
   '5759'  = 07
   '5760'  = 07
   '5761'  = 07
   '5762'  = 07
   '5763'  = 07
   '5764'  = 07
   '5765'  = 07
   '5768'  = 07
   '5769'  = 07
   '5770'  = 07
   '5771'  = 07
   '5772'  = 07
   '5778'  = 07
   '5779'  = 07
   '5780'  = 06
   '5781'  = 06
   '5789'  = 06
   '5790'  = 06
   '5791'  = 06
   '5792'  = 06
   '5793'  = 06
   '5794'  = 06
   '5798'  = 06
   '5799'  = 06
   '5800'  = 11
   '5804'  = 11
   '58081' = 11
   '58089' = 11
   '5809'  = 11
   '5810'  = 11
   '5811'  = 11
   '5812'  = 11
   '5813'  = 11
   '58181' = 11
   '58189' = 11
   '5819'  = 11
   '5820'  = 11
   '5821'  = 11
   '5822'  = 11
   '5824'  = 11
   '58281' = 11
   '58289' = 11
   '5829'  = 11
   '5830'  = 11
   '5831'  = 11
   '5832'  = 11
   '5834'  = 11
   '5836'  = 11
   '5837'  = 11
   '58381' = 11
   '58389' = 11
   '5839'  = 11
   '5845'  = 11
   '5846'  = 11
   '5847'  = 11
   '5848'  = 11
   '5849'  = 11
   '5851'  = 11
   '5852'  = 11
   '5853'  = 11
   '5854'  = 11
   '5855'  = 11
   '5856'  = 11
   '5859'  = 11
   '586'   = 11
   '587'   = 11
   '5880'  = 11
   '5881'  = 11
   '58881' = 11
   '58889' = 11
   '5889'  = 11
   '5890'  = 11
   '5891'  = 11
   '5899'  = 11
   '59000' = 11
   '59001' = 11
   '59010' = 11
   '59011' = 11
   '5902'  = 11
   '5903'  = 11
   '59080' = 11
   '59081' = 11
   '5909'  = 11
   '591'   = 11
   '5920'  = 11
   '5921'  = 11
   '5929'  = 11
   '5930'  = 11
   '5931'  = 11
   '5932'  = 11
   '5933'  = 11
   '5934'  = 11
   '5935'  = 11
   '5936'  = 11
   '59370' = 11
   '59371' = 11
   '59372' = 11
   '59373' = 11
   '59381' = 11
   '59382' = 11
   '59389' = 11
   '5939'  = 11
   '5940'  = 11
   '5941'  = 11
   '5942'  = 11
   '5948'  = 11
   '5949'  = 11
   '5950'  = 11
   '5951'  = 11
   '5952'  = 11
   '5953'  = 11
   '5954'  = 11
   '59581' = 11
   '59582' = 11
   '59589' = 11
   '5959'  = 11
   '5960'  = 11
   '5961'  = 11
   '5962'  = 11
   '5963'  = 11
   '5964'  = 11
   '59651' = 11
   '59652' = 11
   '59653' = 11
   '59654' = 11
   '59655' = 11
   '59659' = 11
   '5966'  = 11
   '5967'  = 11
   '59681' = 11
   '59682' = 11
   '59683' = 11
   '59689' = 11
   '5969'  = 11
   '5970'  = 11
   '59780' = 11
   '59781' = 11
   '59789' = 11
   '59800' = 11
   '59801' = 11
   '5981'  = 11
   '5982'  = 11
   '5988'  = 11
   '5989'  = 11
   '5990'  = 11
   '5991'  = 11
   '5992'  = 11
   '5993'  = 11
   '5994'  = 11
   '5995'  = 11
   '59960' = 11
   '59969' = 11
   '59970' = 11
   '59971' = 11
   '59972' = 11
   '59981' = 11
   '59982' = 11
   '59983' = 11
   '59984' = 11
   '59989' = 11
   '5999'  = 11
   '60000' = 12
   '60001' = 12
   '60010' = 12
   '60011' = 12
   '60020' = 12
   '60021' = 12
   '6003'  = 12
   '60090' = 12
   '60091' = 12
   '6010'  = 12
   '6011'  = 12
   '6012'  = 12
   '6013'  = 12
   '6014'  = 12
   '6018'  = 12
   '6019'  = 12
   '6020'  = 12
   '6021'  = 12
   '6022'  = 12
   '6023'  = 12
   '6028'  = 12
   '6029'  = 12
   '6030'  = 12
   '6031'  = 12
   '6038'  = 12
   '6039'  = 12
   '6040'  = 12
   '60490' = 12
   '60491' = 12
   '60499' = 12
   '605'   = 12
   '6060'  = 12
   '6061'  = 12
   '6068'  = 12
   '6069'  = 12
   '6070'  = 12
   '6071'  = 12
   '6072'  = 12
   '6073'  = 12
   '60781' = 12
   '60782' = 12
   '60783' = 12
   '60784' = 12
   '60785' = 12
   '60789' = 12
   '6079'  = 12
   '6080'  = 12
   '6081'  = 12
   '60820' = 12
   '60821' = 12
   '60822' = 12
   '60823' = 12
   '60824' = 12
   '6083'  = 12
   '6084'  = 12
   '60881' = 12
   '60882' = 12
   '60883' = 12
   '60884' = 12
   '60885' = 12
   '60886' = 12
   '60887' = 12
   '60889' = 12
   '6089'  = 12
   '6100'  = 09
   '6101'  = 09
   '6102'  = 09
   '6103'  = 09
   '6104'  = 09
   '6108'  = 09
   '6109'  = 09
   '6110'  = 09
   '6111'  = 09
   '6112'  = 09
   '6113'  = 09
   '6114'  = 09
   '6115'  = 09
   '6116'  = 09
   '61171' = 09
   '61172' = 09
   '61179' = 09
   '61181' = 09
   '61182' = 09
   '61183' = 09
   '61189' = 09
   '6119'  = 09
   '6120'  = 09
   '6121'  = 09
   '6140'  = 13
   '6141'  = 13
   '6142'  = 13
   '6143'  = 13
   '6144'  = 13
   '6145'  = 13
   '6146'  = 13
   '6147'  = 13
   '6148'  = 13
   '6149'  = 13
   '6150'  = 13
   '6151'  = 13
   '6159'  = 13
   '6160'  = 13
   '61610' = 13
   '61611' = 13
   '6162'  = 13
   '6163'  = 13
   '6164'  = 13
   '61650' = 13
   '61651' = 13
   '61681' = 13
   '61689' = 13
   '6169'  = 13
   '6170'  = 13
   '6171'  = 13
   '6172'  = 13
   '6173'  = 13
   '6174'  = 13
   '6175'  = 06
   '6176'  = 09
   '6178'  = 13
   '6179'  = 13
   '61800' = 13
   '61801' = 13
   '61802' = 13
   '61803' = 13
   '61804' = 13
   '61805' = 13
   '61809' = 13
   '6181'  = 13
   '6182'  = 13
   '6183'  = 13
   '6184'  = 13
   '6185'  = 13
   '6186'  = 13
   '6187'  = 13
   '61881' = 13
   '61882' = 13
   '61883' = 13
   '61884' = 13
   '61889' = 13
   '6189'  = 13
   '6190'  = 13
   '6191'  = 06
   '6192'  = 13
   '6198'  = 13
   '6199'  = 13
   '6200'  = 13
   '6201'  = 13
   '6202'  = 13
   '6203'  = 13
   '6204'  = 13
   '6205'  = 13
   '6206'  = 13
   '6207'  = 13
   '6208'  = 13
   '6209'  = 13
   '6210'  = 13
   '6211'  = 13
   '6212'  = 13
   '62130' = 13
   '62131' = 13
   '62132' = 13
   '62133' = 13
   '62134' = 13
   '62135' = 13
   '6214'  = 13
   '6215'  = 13
   '6216'  = 13
   '6217'  = 13
   '6218'  = 13
   '6219'  = 13
   '6220'  = 13
   '62210' = 13
   '62211' = 13
   '62212' = 13
   '6222'  = 13
   '6223'  = 13
   '6224'  = 13
   '6225'  = 13
   '6226'  = 13
   '6227'  = 13
   '6228'  = 13
   '6229'  = 13
   '6230'  = 13
   '6231'  = 13
   '6232'  = 13
   '6233'  = 13
   '6234'  = 13
   '6235'  = 13
   '6236'  = 13
   '6237'  = 13
   '6238'  = 13
   '6239'  = 13
   '62401' = 13
   '62402' = 13
   '62409' = 13
   '6241'  = 13
   '6242'  = 13
   '6243'  = 13
   '6244'  = 13
   '6245'  = 13
   '6246'  = 13
   '6248'  = 13
   '6249'  = 13
   '6250'  = 13
   '6251'  = 13
   '6252'  = 13
   '6253'  = 13
   '6254'  = 13
   '6255'  = 13
   '6256'  = 13
   '62570' = 13
   '62571' = 13
   '62579' = 13
   '6258'  = 13
   '6259'  = 13
   '6260'  = 13
   '6261'  = 13
   '6262'  = 13
   '6263'  = 13
   '6264'  = 13
   '6265'  = 13
   '6266'  = 13
   '6267'  = 13
   '6268'  = 13
   '6269'  = 13
   '6270'  = 13
   '6271'  = 13
   '6272'  = 13
   '6273'  = 13
   '6274'  = 13
   '6278'  = 13
   '6279'  = 13
   '6280'  = 13
   '6281'  = 13
   '6282'  = 13
   '6283'  = 13
   '6284'  = 13
   '6288'  = 13
   '6289'  = 13
   '6290'  = 13
   '6291'  = 13
   '62920' = 13
   '62921' = 13
   '62922' = 13
   '62923' = 13
   '62929' = 13
   '62931' = 13
   '62932' = 13
   '62981' = 13
   '62989' = 13
   '6299'  = 13
   '630'   = 14
   '6310'  = 14
   '6318'  = 14
   '632'   = 14
   '63300' = 14
   '63301' = 14
   '63310' = 14
   '63311' = 14
   '63320' = 14
   '63321' = 14
   '63380' = 14
   '63381' = 14
   '63390' = 14
   '63391' = 14
   '63400' = 14
   '63401' = 14
   '63402' = 14
   '63410' = 14
   '63411' = 14
   '63412' = 14
   '63420' = 14
   '63421' = 14
   '63422' = 14
   '63430' = 14
   '63431' = 14
   '63432' = 14
   '63440' = 14
   '63441' = 14
   '63442' = 14
   '63450' = 14
   '63451' = 14
   '63452' = 14
   '63460' = 14
   '63461' = 14
   '63462' = 14
   '63470' = 14
   '63471' = 14
   '63472' = 14
   '63480' = 14
   '63481' = 14
   '63482' = 14
   '63490' = 14
   '63491' = 14
   '63492' = 14
   '63500' = 14
   '63501' = 14
   '63502' = 14
   '63510' = 14
   '63511' = 14
   '63512' = 14
   '63520' = 14
   '63521' = 14
   '63522' = 14
   '63530' = 14
   '63531' = 14
   '63532' = 14
   '63540' = 14
   '63541' = 14
   '63542' = 14
   '63550' = 14
   '63551' = 14
   '63552' = 14
   '63560' = 14
   '63561' = 14
   '63562' = 14
   '63570' = 14
   '63571' = 14
   '63572' = 14
   '63580' = 14
   '63581' = 14
   '63582' = 14
   '63590' = 14
   '63591' = 14
   '63592' = 14
   '63600' = 14
   '63601' = 14
   '63602' = 14
   '63610' = 14
   '63611' = 14
   '63612' = 14
   '63620' = 14
   '63621' = 14
   '63622' = 14
   '63630' = 14
   '63631' = 14
   '63632' = 14
   '63640' = 14
   '63641' = 14
   '63642' = 14
   '63650' = 14
   '63651' = 14
   '63652' = 14
   '63660' = 14
   '63661' = 14
   '63662' = 14
   '63670' = 14
   '63671' = 14
   '63672' = 14
   '63680' = 14
   '63681' = 14
   '63682' = 14
   '63690' = 14
   '63691' = 14
   '63692' = 14
   '63700' = 14
   '63701' = 14
   '63702' = 14
   '63710' = 14
   '63711' = 14
   '63712' = 14
   '63720' = 14
   '63721' = 14
   '63722' = 14
   '63730' = 14
   '63731' = 14
   '63732' = 14
   '63740' = 14
   '63741' = 14
   '63742' = 14
   '63750' = 14
   '63751' = 14
   '63752' = 14
   '63760' = 14
   '63761' = 14
   '63762' = 14
   '63770' = 14
   '63771' = 14
   '63772' = 14
   '63780' = 14
   '63781' = 14
   '63782' = 14
   '63790' = 14
   '63791' = 14
   '63792' = 14
   '6380'  = 14
   '6381'  = 14
   '6382'  = 14
   '6383'  = 14
   '6384'  = 14
   '6385'  = 14
   '6386'  = 14
   '6387'  = 14
   '6388'  = 14
   '6389'  = 14
   '6390'  = 14
   '6391'  = 14
   '6392'  = 14
   '6393'  = 14
   '6394'  = 14
   '6395'  = 14
   '6396'  = 14
   '6398'  = 14
   '6399'  = 14
   '64000' = 14
   '64001' = 14
   '64003' = 14
   '64080' = 14
   '64081' = 14
   '64083' = 14
   '64090' = 14
   '64091' = 14
   '64093' = 14
   '64100' = 14
   '64101' = 14
   '64103' = 14
   '64110' = 14
   '64111' = 14
   '64113' = 14
   '64120' = 14
   '64121' = 14
   '64123' = 14
   '64130' = 14
   '64131' = 14
   '64133' = 14
   '64180' = 14
   '64181' = 14
   '64183' = 14
   '64190' = 14
   '64191' = 14
   '64193' = 14
   '64200' = 14
   '64201' = 14
   '64202' = 14
   '64203' = 14
   '64204' = 14
   '64210' = 14
   '64211' = 14
   '64212' = 14
   '64213' = 14
   '64214' = 14
   '64220' = 14
   '64221' = 14
   '64222' = 14
   '64223' = 14
   '64224' = 14
   '64230' = 14
   '64231' = 14
   '64232' = 14
   '64233' = 14
   '64234' = 14
   '64240' = 14
   '64241' = 14
   '64242' = 14
   '64243' = 14
   '64244' = 14
   '64250' = 14
   '64251' = 14
   '64252' = 14
   '64253' = 14
   '64254' = 14
   '64260' = 14
   '64261' = 14
   '64262' = 14
   '64263' = 14
   '64264' = 14
   '64270' = 14
   '64271' = 14
   '64272' = 14
   '64273' = 14
   '64274' = 14
   '64290' = 14
   '64291' = 14
   '64292' = 14
   '64293' = 14
   '64294' = 14
   '64300' = 14
   '64301' = 14
   '64303' = 14
   '64310' = 14
   '64311' = 14
   '64313' = 14
   '64320' = 14
   '64321' = 14
   '64323' = 14
   '64380' = 14
   '64381' = 14
   '64383' = 14
   '64390' = 14
   '64391' = 14
   '64393' = 14
   '64400' = 14
   '64403' = 14
   '64410' = 14
   '64413' = 14
   '64420' = 14
   '64421' = 14
   '64510' = 14
   '64511' = 14
   '64513' = 14
   '64520' = 14
   '64521' = 14
   '64523' = 14
   '64600' = 14
   '64601' = 14
   '64603' = 14
   '64610' = 14
   '64611' = 14
   '64612' = 14
   '64613' = 14
   '64614' = 14
   '64620' = 14
   '64621' = 14
   '64622' = 14
   '64623' = 14
   '64624' = 14
   '64630' = 14
   '64631' = 14
   '64633' = 14
   '64640' = 14
   '64641' = 14
   '64642' = 14
   '64643' = 14
   '64644' = 14
   '64650' = 14
   '64651' = 14
   '64652' = 14
   '64653' = 14
   '64654' = 14
   '64660' = 14
   '64661' = 14
   '64662' = 14
   '64663' = 14
   '64664' = 14
   '64670' = 14
   '64671' = 14
   '64673' = 14
   '64680' = 14
   '64681' = 14
   '64682' = 14
   '64683' = 14
   '64684' = 14
   '64690' = 14
   '64691' = 14
   '64693' = 14
   '64700' = 14
   '64701' = 14
   '64702' = 14
   '64703' = 14
   '64704' = 14
   '64710' = 14
   '64711' = 14
   '64712' = 14
   '64713' = 14
   '64714' = 14
   '64720' = 14
   '64721' = 14
   '64722' = 14
   '64723' = 14
   '64724' = 14
   '64730' = 14
   '64731' = 14
   '64732' = 14
   '64733' = 14
   '64734' = 14
   '64740' = 14
   '64741' = 14
   '64742' = 14
   '64743' = 14
   '64744' = 14
   '64750' = 14
   '64751' = 14
   '64752' = 14
   '64753' = 14
   '64754' = 14
   '64760' = 14
   '64761' = 14
   '64762' = 14
   '64763' = 14
   '64764' = 14
   '64780' = 14
   '64781' = 14
   '64782' = 14
   '64783' = 14
   '64784' = 14
   '64790' = 14
   '64791' = 14
   '64792' = 14
   '64793' = 14
   '64794' = 14
   '64800' = 14
   '64801' = 14
   '64802' = 14
   '64803' = 14
   '64804' = 14
   '64810' = 14
   '64811' = 14
   '64812' = 14
   '64813' = 14
   '64814' = 14
   '64820' = 14
   '64821' = 14
   '64822' = 14
   '64823' = 14
   '64824' = 14
   '64830' = 14
   '64831' = 14
   '64832' = 14
   '64833' = 14
   '64834' = 14
   '64840' = 14
   '64841' = 14
   '64842' = 14
   '64843' = 14
   '64844' = 14
   '64850' = 14
   '64851' = 14
   '64852' = 14
   '64853' = 14
   '64854' = 14
   '64860' = 14
   '64861' = 14
   '64862' = 14
   '64863' = 14
   '64864' = 14
   '64870' = 14
   '64871' = 14
   '64872' = 14
   '64873' = 14
   '64874' = 14
   '64880' = 14
   '64881' = 14
   '64882' = 14
   '64883' = 14
   '64884' = 14
   '64890' = 14
   '64891' = 14
   '64892' = 14
   '64893' = 14
   '64894' = 14
   '64900' = 14
   '64901' = 14
   '64902' = 14
   '64903' = 14
   '64904' = 14
   '64910' = 14
   '64911' = 14
   '64912' = 14
   '64913' = 14
   '64914' = 14
   '64920' = 14
   '64921' = 14
   '64922' = 14
   '64923' = 14
   '64924' = 14
   '64930' = 14
   '64931' = 14
   '64932' = 14
   '64933' = 14
   '64934' = 14
   '64940' = 14
   '64941' = 14
   '64942' = 14
   '64943' = 14
   '64944' = 14
   '64950' = 14
   '64951' = 14
   '64953' = 14
   '64960' = 14
   '64961' = 14
   '64962' = 14
   '64963' = 14
   '64964' = 14
   '64970' = 14
   '64971' = 14
   '64973' = 14
   '64981' = 14
   '64982' = 14
   '650'   = 14
   '65100' = 14
   '65101' = 14
   '65103' = 14
   '65110' = 14
   '65111' = 14
   '65113' = 14
   '65120' = 14
   '65121' = 14
   '65123' = 14
   '65130' = 14
   '65131' = 14
   '65133' = 14
   '65140' = 14
   '65141' = 14
   '65143' = 14
   '65150' = 14
   '65151' = 14
   '65153' = 14
   '65160' = 14
   '65161' = 14
   '65163' = 14
   '65170' = 14
   '65171' = 14
   '65173' = 14
   '65180' = 14
   '65181' = 14
   '65183' = 14
   '65190' = 14
   '65191' = 14
   '65193' = 14
   '65200' = 14
   '65201' = 14
   '65203' = 14
   '65210' = 14
   '65211' = 14
   '65213' = 14
   '65220' = 14
   '65221' = 14
   '65223' = 14
   '65230' = 14
   '65231' = 14
   '65233' = 14
   '65240' = 14
   '65241' = 14
   '65243' = 14
   '65250' = 14
   '65251' = 14
   '65253' = 14
   '65260' = 14
   '65261' = 14
   '65263' = 14
   '65270' = 14
   '65271' = 14
   '65273' = 14
   '65280' = 14
   '65281' = 14
   '65283' = 14
   '65290' = 14
   '65291' = 14
   '65293' = 14
   '65300' = 14
   '65301' = 14
   '65303' = 14
   '65310' = 14
   '65311' = 14
   '65313' = 14
   '65320' = 14
   '65321' = 14
   '65323' = 14
   '65330' = 14
   '65331' = 14
   '65333' = 14
   '65340' = 14
   '65341' = 14
   '65343' = 14
   '65350' = 14
   '65351' = 14
   '65353' = 14
   '65360' = 14
   '65361' = 14
   '65363' = 14
   '65370' = 14
   '65371' = 14
   '65373' = 14
   '65380' = 14
   '65381' = 14
   '65383' = 14
   '65390' = 14
   '65391' = 14
   '65393' = 14
   '65400' = 14
   '65401' = 14
   '65402' = 14
   '65403' = 14
   '65404' = 14
   '65410' = 14
   '65411' = 14
   '65412' = 14
   '65413' = 14
   '65414' = 14
   '65420' = 14
   '65421' = 14
   '65423' = 14
   '65430' = 14
   '65431' = 14
   '65432' = 14
   '65433' = 14
   '65434' = 14
   '65440' = 14
   '65441' = 14
   '65442' = 14
   '65443' = 14
   '65444' = 14
   '65450' = 14
   '65451' = 14
   '65452' = 14
   '65453' = 14
   '65454' = 14
   '65460' = 14
   '65461' = 14
   '65462' = 14
   '65463' = 14
   '65464' = 14
   '65470' = 14
   '65471' = 14
   '65472' = 14
   '65473' = 14
   '65474' = 14
   '65480' = 14
   '65481' = 14
   '65482' = 14
   '65483' = 14
   '65484' = 14
   '65490' = 14
   '65491' = 14
   '65492' = 14
   '65493' = 14
   '65494' = 14
   '65500' = 14
   '65501' = 14
   '65503' = 14
   '65510' = 14
   '65511' = 14
   '65513' = 14
   '65520' = 14
   '65521' = 14
   '65523' = 14
   '65530' = 14
   '65531' = 14
   '65533' = 14
   '65540' = 14
   '65541' = 14
   '65543' = 14
   '65550' = 14
   '65551' = 14
   '65553' = 14
   '65560' = 14
   '65561' = 14
   '65563' = 14
   '65570' = 14
   '65571' = 14
   '65573' = 14
   '65580' = 14
   '65581' = 14
   '65583' = 14
   '65590' = 14
   '65591' = 14
   '65593' = 14
   '65600' = 14
   '65601' = 14
   '65603' = 14
   '65610' = 14
   '65611' = 14
   '65613' = 14
   '65620' = 14
   '65621' = 14
   '65623' = 14
   '65630' = 14
   '65631' = 14
   '65633' = 14
   '65640' = 14
   '65641' = 14
   '65643' = 14
   '65650' = 14
   '65651' = 14
   '65653' = 14
   '65660' = 14
   '65661' = 14
   '65663' = 14
   '65670' = 14
   '65671' = 14
   '65673' = 14
   '65680' = 14
   '65681' = 14
   '65683' = 14
   '65690' = 14
   '65691' = 14
   '65693' = 14
   '65700' = 14
   '65701' = 14
   '65703' = 14
   '65800' = 14
   '65801' = 14
   '65803' = 14
   '65810' = 14
   '65811' = 14
   '65813' = 14
   '65820' = 14
   '65821' = 14
   '65823' = 14
   '65830' = 14
   '65831' = 14
   '65833' = 14
   '65840' = 14
   '65841' = 14
   '65843' = 14
   '65880' = 14
   '65881' = 14
   '65883' = 14
   '65890' = 14
   '65891' = 14
   '65893' = 14
   '65900' = 14
   '65901' = 14
   '65903' = 14
   '65910' = 14
   '65911' = 14
   '65913' = 14
   '65920' = 14
   '65921' = 14
   '65923' = 14
   '65930' = 14
   '65931' = 14
   '65933' = 14
   '65940' = 14
   '65941' = 14
   '65943' = 14
   '65950' = 14
   '65951' = 14
   '65953' = 14
   '65960' = 14
   '65961' = 14
   '65963' = 14
   '65970' = 14
   '65971' = 14
   '65973' = 14
   '65980' = 14
   '65981' = 14
   '65983' = 14
   '65990' = 14
   '65991' = 14
   '65993' = 14
   '66000' = 14
   '66001' = 14
   '66003' = 14
   '66010' = 14
   '66011' = 14
   '66013' = 14
   '66020' = 14
   '66021' = 14
   '66023' = 14
   '66030' = 14
   '66031' = 14
   '66033' = 14
   '66040' = 14
   '66041' = 14
   '66043' = 14
   '66050' = 14
   '66051' = 14
   '66053' = 14
   '66060' = 14
   '66061' = 14
   '66063' = 14
   '66070' = 14
   '66071' = 14
   '66073' = 14
   '66080' = 14
   '66081' = 14
   '66083' = 14
   '66090' = 14
   '66091' = 14
   '66093' = 14
   '66100' = 14
   '66101' = 14
   '66103' = 14
   '66110' = 14
   '66111' = 14
   '66113' = 14
   '66120' = 14
   '66121' = 14
   '66123' = 14
   '66130' = 14
   '66131' = 14
   '66133' = 14
   '66140' = 14
   '66141' = 14
   '66143' = 14
   '66190' = 14
   '66191' = 14
   '66193' = 14
   '66200' = 14
   '66201' = 14
   '66203' = 14
   '66210' = 14
   '66211' = 14
   '66213' = 14
   '66220' = 14
   '66221' = 14
   '66223' = 14
   '66230' = 14
   '66231' = 14
   '66233' = 14
   '66300' = 14
   '66301' = 14
   '66303' = 14
   '66310' = 14
   '66311' = 14
   '66313' = 14
   '66320' = 14
   '66321' = 14
   '66323' = 14
   '66330' = 14
   '66331' = 14
   '66333' = 14
   '66340' = 14
   '66341' = 14
   '66343' = 14
   '66350' = 14
   '66351' = 14
   '66353' = 14
   '66360' = 14
   '66361' = 14
   '66363' = 14
   '66380' = 14
   '66381' = 14
   '66383' = 14
   '66390' = 14
   '66391' = 14
   '66393' = 14
   '66400' = 14
   '66401' = 14
   '66404' = 14
   '66410' = 14
   '66411' = 14
   '66414' = 14
   '66420' = 14
   '66421' = 14
   '66424' = 14
   '66430' = 14
   '66431' = 14
   '66434' = 14
   '66440' = 14
   '66441' = 14
   '66444' = 14
   '66450' = 14
   '66451' = 14
   '66454' = 14
   '66460' = 14
   '66461' = 14
   '66464' = 14
   '66480' = 14
   '66481' = 14
   '66484' = 14
   '66490' = 14
   '66491' = 14
   '66494' = 14
   '66500' = 14
   '66501' = 14
   '66503' = 14
   '66510' = 14
   '66511' = 14
   '66520' = 14
   '66522' = 14
   '66524' = 14
   '66530' = 14
   '66531' = 14
   '66534' = 14
   '66540' = 14
   '66541' = 14
   '66544' = 14
   '66550' = 14
   '66551' = 14
   '66554' = 14
   '66560' = 14
   '66561' = 14
   '66564' = 14
   '66570' = 14
   '66571' = 14
   '66572' = 14
   '66574' = 14
   '66580' = 14
   '66581' = 14
   '66582' = 14
   '66583' = 14
   '66584' = 14
   '66590' = 14
   '66591' = 14
   '66592' = 14
   '66593' = 14
   '66594' = 14
   '66600' = 14
   '66602' = 14
   '66604' = 14
   '66610' = 14
   '66612' = 14
   '66614' = 14
   '66620' = 14
   '66622' = 14
   '66624' = 14
   '66630' = 14
   '66632' = 14
   '66634' = 14
   '66700' = 14
   '66702' = 14
   '66704' = 14
   '66710' = 14
   '66712' = 14
   '66714' = 14
   '66800' = 14
   '66801' = 14
   '66802' = 14
   '66803' = 14
   '66804' = 14
   '66810' = 14
   '66811' = 14
   '66812' = 14
   '66813' = 14
   '66814' = 14
   '66820' = 14
   '66821' = 14
   '66822' = 14
   '66823' = 14
   '66824' = 14
   '66880' = 14
   '66881' = 14
   '66882' = 14
   '66883' = 14
   '66884' = 14
   '66890' = 14
   '66891' = 14
   '66892' = 14
   '66893' = 14
   '66894' = 14
   '66900' = 14
   '66901' = 14
   '66902' = 14
   '66903' = 14
   '66904' = 14
   '66910' = 14
   '66911' = 14
   '66912' = 14
   '66913' = 14
   '66914' = 14
   '66920' = 14
   '66921' = 14
   '66922' = 14
   '66923' = 14
   '66924' = 14
   '66930' = 14
   '66932' = 14
   '66934' = 14
   '66940' = 14
   '66941' = 14
   '66942' = 14
   '66943' = 14
   '66944' = 14
   '66950' = 14
   '66951' = 14
   '66960' = 14
   '66961' = 14
   '66970' = 14
   '66971' = 14
   '66980' = 14
   '66981' = 14
   '66982' = 14
   '66983' = 14
   '66984' = 14
   '66990' = 14
   '66991' = 14
   '66992' = 14
   '66993' = 14
   '66994' = 14
   '67000' = 14
   '67002' = 14
   '67004' = 14
   '67010' = 14
   '67012' = 14
   '67014' = 14
   '67020' = 14
   '67022' = 14
   '67024' = 14
   '67030' = 14
   '67032' = 14
   '67034' = 14
   '67080' = 14
   '67082' = 14
   '67084' = 14
   '67100' = 14
   '67101' = 14
   '67102' = 14
   '67103' = 14
   '67104' = 14
   '67110' = 14
   '67111' = 14
   '67112' = 14
   '67113' = 14
   '67114' = 14
   '67120' = 14
   '67121' = 14
   '67122' = 14
   '67123' = 14
   '67124' = 14
   '67130' = 14
   '67131' = 14
   '67133' = 14
   '67140' = 14
   '67142' = 14
   '67144' = 14
   '67150' = 14
   '67151' = 14
   '67152' = 14
   '67153' = 14
   '67154' = 14
   '67180' = 14
   '67181' = 14
   '67182' = 14
   '67183' = 14
   '67184' = 14
   '67190' = 14
   '67191' = 14
   '67192' = 14
   '67193' = 14
   '67194' = 14
   '67200' = 14
   '67202' = 14
   '67204' = 14
   '67300' = 14
   '67301' = 14
   '67302' = 14
   '67303' = 14
   '67304' = 14
   '67310' = 14
   '67311' = 14
   '67312' = 14
   '67313' = 14
   '67314' = 14
   '67320' = 14
   '67321' = 14
   '67322' = 14
   '67323' = 14
   '67324' = 14
   '67330' = 14
   '67331' = 14
   '67332' = 14
   '67333' = 14
   '67334' = 14
   '67380' = 14
   '67381' = 14
   '67382' = 14
   '67383' = 14
   '67384' = 14
   '67400' = 14
   '67401' = 14
   '67402' = 14
   '67403' = 14
   '67404' = 14
   '67410' = 14
   '67412' = 14
   '67414' = 14
   '67420' = 14
   '67422' = 14
   '67424' = 14
   '67430' = 14
   '67432' = 14
   '67434' = 14
   '67440' = 14
   '67442' = 14
   '67444' = 14
   '67450' = 14
   '67451' = 14
   '67452' = 14
   '67453' = 14
   '67454' = 14
   '67480' = 14
   '67482' = 14
   '67484' = 14
   '67490' = 14
   '67492' = 14
   '67494' = 14
   '67500' = 14
   '67501' = 14
   '67502' = 14
   '67503' = 14
   '67504' = 14
   '67510' = 14
   '67511' = 14
   '67512' = 14
   '67513' = 14
   '67514' = 14
   '67520' = 14
   '67521' = 14
   '67522' = 14
   '67523' = 14
   '67524' = 14
   '67580' = 14
   '67581' = 14
   '67582' = 14
   '67583' = 14
   '67584' = 14
   '67590' = 14
   '67591' = 14
   '67592' = 14
   '67593' = 14
   '67594' = 14
   '67600' = 14
   '67601' = 14
   '67602' = 14
   '67603' = 14
   '67604' = 14
   '67610' = 14
   '67611' = 14
   '67612' = 14
   '67613' = 14
   '67614' = 14
   '67620' = 14
   '67621' = 14
   '67622' = 14
   '67623' = 14
   '67624' = 14
   '67630' = 14
   '67631' = 14
   '67632' = 14
   '67633' = 14
   '67634' = 14
   '67640' = 14
   '67641' = 14
   '67642' = 14
   '67643' = 14
   '67644' = 14
   '67650' = 14
   '67651' = 14
   '67652' = 14
   '67653' = 14
   '67654' = 14
   '67660' = 14
   '67661' = 14
   '67662' = 14
   '67663' = 14
   '67664' = 14
   '67680' = 14
   '67681' = 14
   '67682' = 14
   '67683' = 14
   '67684' = 14
   '67690' = 14
   '67691' = 14
   '67692' = 14
   '67693' = 14
   '67694' = 14
   '677'   = 14
   '67800' = 14
   '67801' = 14
   '67803' = 14
   '67810' = 14
   '67811' = 14
   '67813' = 14
   '67900' = 14
   '67901' = 14
   '67902' = 14
   '67903' = 14
   '67904' = 14
   '67910' = 14
   '67911' = 14
   '67912' = 14
   '67913' = 14
   '67914' = 14
   '6800'  = 09
   '6801'  = 09
   '6802'  = 09
   '6803'  = 09
   '6804'  = 09
   '6805'  = 09
   '6806'  = 09
   '6807'  = 09
   '6808'  = 09
   '6809'  = 09
   '68100' = 09
   '68101' = 09
   '68102' = 09
   '68110' = 09
   '68111' = 09
   '6819'  = 09
   '6820'  = 09
   '6821'  = 09
   '6822'  = 09
   '6823'  = 09
   '6824'  = 09
   '6825'  = 09
   '6826'  = 09
   '6827'  = 09
   '6828'  = 09
   '6829'  = 09
   '683'   = 16
   '684'   = 09
   '6850'  = 09
   '6851'  = 09
   '68600' = 09
   '68601' = 09
   '68609' = 09
   '6861'  = 09
   '6868'  = 09
   '6869'  = 09
   '69010' = 09
   '69011' = 09
   '69012' = 09
   '69018' = 09
   '6908'  = 09
   '6910'  = 09
   '6918'  = 09
   '6920'  = 09
   '6921'  = 09
   '6922'  = 09
   '6923'  = 09
   '6924'  = 09
   '6925'  = 09
   '6926'  = 09
   '69270' = 09
   '69271' = 09
   '69272' = 09
   '69273' = 09
   '69274' = 09
   '69275' = 09
   '69276' = 09
   '69277' = 09
   '69279' = 09
   '69281' = 09
   '69282' = 09
   '69283' = 09
   '69284' = 09
   '69289' = 09
   '6929'  = 09
   '6930'  = 09
   '6931'  = 09
   '6938'  = 09
   '6939'  = 09
   '6940'  = 09
   '6941'  = 09
   '6942'  = 09
   '6943'  = 09
   '6944'  = 09
   '6945'  = 09
   '69460' = 09
   '69461' = 02
   '6948'  = 09
   '6949'  = 09
   '6950'  = 09
   '69510' = 09
   '69511' = 09
   '69512' = 09
   '69513' = 09
   '69514' = 09
   '69515' = 09
   '69519' = 09
   '6952'  = 09
   '6953'  = 09
   '6954'  = 09
   '69550' = 09
   '69551' = 09
   '69552' = 09
   '69553' = 09
   '69554' = 09
   '69555' = 09
   '69556' = 09
   '69557' = 09
   '69558' = 09
   '69559' = 09
   '69581' = 09
   '69589' = 09
   '6959'  = 09
   '6960'  = 08
   '6961'  = 09
   '6962'  = 09
   '6963'  = 09
   '6964'  = 09
   '6965'  = 09
   '6968'  = 09
   '6970'  = 09
   '6971'  = 09
   '6978'  = 09
   '6979'  = 09
   '6980'  = 09
   '6981'  = 12
   '6982'  = 09
   '6983'  = 09
   '6984'  = 09
   '6988'  = 09
   '6989'  = 09
   '700'   = 09
   '7010'  = 09
   '7011'  = 09
   '7012'  = 09
   '7013'  = 09
   '7014'  = 09
   '7015'  = 09
   '7018'  = 09
   '7019'  = 09
   '7020'  = 09
   '70211' = 09
   '70219' = 09
   '7028'  = 09
   '7030'  = 09
   '7038'  = 09
   '7039'  = 09
   '70400' = 09
   '70401' = 09
   '70402' = 09
   '70409' = 09
   '7041'  = 09
   '7042'  = 09
   '7043'  = 09
   '70441' = 09
   '70442' = 09
   '7048'  = 09
   '7049'  = 09
   '7050'  = 09
   '7051'  = 09
   '70521' = 09
   '70522' = 09
   '70581' = 09
   '70582' = 09
   '70583' = 09
   '70589' = 09
   '7059'  = 09
   '7060'  = 09
   '7061'  = 09
   '7062'  = 09
   '7063'  = 09
   '7068'  = 09
   '7069'  = 09
   '70700' = 09
   '70701' = 09
   '70702' = 09
   '70703' = 09
   '70704' = 09
   '70705' = 09
   '70706' = 09
   '70707' = 09
   '70709' = 09
   '70710' = 09
   '70711' = 09
   '70712' = 09
   '70713' = 09
   '70714' = 09
   '70715' = 09
   '70719' = 09
   '70720' = 09
   '70721' = 09
   '70722' = 09
   '70723' = 09
   '70724' = 09
   '70725' = 09
   '7078'  = 09
   '7079'  = 09
   '7080'  = 09
   '7081'  = 09
   '7082'  = 09
   '7083'  = 09
   '7084'  = 09
   '7085'  = 09
   '7088'  = 09
   '7089'  = 09
   '70900' = 09
   '70901' = 09
   '70909' = 09
   '7091'  = 09
   '7092'  = 09
   '7093'  = 09
   '7094'  = 09
   '7098'  = 09
   '7099'  = 09
   '7100'  = 08
   '7101'  = 08
   '7102'  = 08
   '7103'  = 08
   '7104'  = 08
   '7105'  = 08
   '7108'  = 08
   '7109'  = 08
   '71100' = 08
   '71101' = 08
   '71102' = 08
   '71103' = 08
   '71104' = 08
   '71105' = 08
   '71106' = 08
   '71107' = 08
   '71108' = 08
   '71109' = 08
   '71110' = 08
   '71111' = 08
   '71112' = 08
   '71113' = 08
   '71114' = 08
   '71115' = 08
   '71116' = 08
   '71117' = 08
   '71118' = 08
   '71119' = 08
   '71120' = 08
   '71121' = 08
   '71122' = 08
   '71123' = 08
   '71124' = 08
   '71125' = 08
   '71126' = 08
   '71127' = 08
   '71128' = 08
   '71129' = 08
   '71130' = 08
   '71131' = 08
   '71132' = 08
   '71133' = 08
   '71134' = 08
   '71135' = 08
   '71136' = 08
   '71137' = 08
   '71138' = 08
   '71139' = 08
   '71140' = 08
   '71141' = 08
   '71142' = 08
   '71143' = 08
   '71144' = 08
   '71145' = 08
   '71146' = 08
   '71147' = 08
   '71148' = 08
   '71149' = 08
   '71150' = 08
   '71151' = 08
   '71152' = 08
   '71153' = 08
   '71154' = 08
   '71155' = 08
   '71156' = 08
   '71157' = 08
   '71158' = 08
   '71159' = 08
   '71160' = 08
   '71161' = 08
   '71162' = 08
   '71163' = 08
   '71164' = 08
   '71165' = 08
   '71166' = 08
   '71167' = 08
   '71168' = 08
   '71169' = 08
   '71170' = 08
   '71171' = 08
   '71172' = 08
   '71173' = 08
   '71174' = 08
   '71175' = 08
   '71176' = 08
   '71177' = 08
   '71178' = 08
   '71179' = 08
   '71180' = 08
   '71181' = 08
   '71182' = 08
   '71183' = 08
   '71184' = 08
   '71185' = 08
   '71186' = 08
   '71187' = 08
   '71188' = 08
   '71189' = 08
   '71190' = 08
   '71191' = 08
   '71192' = 08
   '71193' = 08
   '71194' = 08
   '71195' = 08
   '71196' = 08
   '71197' = 08
   '71198' = 08
   '71199' = 08
   '71210' = 08
   '71211' = 08
   '71212' = 08
   '71213' = 08
   '71214' = 08
   '71215' = 08
   '71216' = 08
   '71217' = 08
   '71218' = 08
   '71219' = 08
   '71220' = 08
   '71221' = 08
   '71222' = 08
   '71223' = 08
   '71224' = 08
   '71225' = 08
   '71226' = 08
   '71227' = 08
   '71228' = 08
   '71229' = 08
   '71230' = 08
   '71231' = 08
   '71232' = 08
   '71233' = 08
   '71234' = 08
   '71235' = 08
   '71236' = 08
   '71237' = 08
   '71238' = 08
   '71239' = 08
   '71280' = 08
   '71281' = 08
   '71282' = 08
   '71283' = 08
   '71284' = 08
   '71285' = 08
   '71286' = 08
   '71287' = 08
   '71288' = 08
   '71289' = 08
   '71290' = 08
   '71291' = 08
   '71292' = 08
   '71293' = 08
   '71294' = 08
   '71295' = 08
   '71296' = 08
   '71297' = 08
   '71298' = 08
   '71299' = 08
   '7130'  = 08
   '7131'  = 08
   '7132'  = 08
   '7133'  = 08
   '7134'  = 08
   '7135'  = 08
   '7136'  = 08
   '7137'  = 08
   '7138'  = 08
   '7140'  = 08
   '7141'  = 08
   '7142'  = 08
   '71430' = 08
   '71431' = 08
   '71432' = 08
   '71433' = 08
   '7144'  = 08
   '71481' = 04
   '71489' = 08
   '7149'  = 08
   '71500' = 08
   '71504' = 08
   '71509' = 08
   '71510' = 08
   '71511' = 08
   '71512' = 08
   '71513' = 08
   '71514' = 08
   '71515' = 08
   '71516' = 08
   '71517' = 08
   '71518' = 08
   '71520' = 08
   '71521' = 08
   '71522' = 08
   '71523' = 08
   '71524' = 08
   '71525' = 08
   '71526' = 08
   '71527' = 08
   '71528' = 08
   '71530' = 08
   '71531' = 08
   '71532' = 08
   '71533' = 08
   '71534' = 08
   '71535' = 08
   '71536' = 08
   '71537' = 08
   '71538' = 08
   '71580' = 08
   '71589' = 08
   '71590' = 08
   '71591' = 08
   '71592' = 08
   '71593' = 08
   '71594' = 08
   '71595' = 08
   '71596' = 08
   '71597' = 08
   '71598' = 08
   '71600' = 08
   '71601' = 08
   '71602' = 08
   '71603' = 08
   '71604' = 08
   '71605' = 08
   '71606' = 08
   '71607' = 08
   '71608' = 08
   '71609' = 08
   '71610' = 08
   '71611' = 08
   '71612' = 08
   '71613' = 08
   '71614' = 08
   '71615' = 08
   '71616' = 08
   '71617' = 08
   '71618' = 08
   '71619' = 08
   '71620' = 08
   '71621' = 08
   '71622' = 08
   '71623' = 08
   '71624' = 08
   '71625' = 08
   '71626' = 08
   '71627' = 08
   '71628' = 08
   '71629' = 08
   '71630' = 08
   '71631' = 08
   '71632' = 08
   '71633' = 08
   '71634' = 08
   '71635' = 08
   '71636' = 08
   '71637' = 08
   '71638' = 08
   '71639' = 08
   '71640' = 08
   '71641' = 08
   '71642' = 08
   '71643' = 08
   '71644' = 08
   '71645' = 08
   '71646' = 08
   '71647' = 08
   '71648' = 08
   '71649' = 08
   '71650' = 08
   '71651' = 08
   '71652' = 08
   '71653' = 08
   '71654' = 08
   '71655' = 08
   '71656' = 08
   '71657' = 08
   '71658' = 08
   '71659' = 08
   '71660' = 08
   '71661' = 08
   '71662' = 08
   '71663' = 08
   '71664' = 08
   '71665' = 08
   '71666' = 08
   '71667' = 08
   '71668' = 08
   '71680' = 08
   '71681' = 08
   '71682' = 08
   '71683' = 08
   '71684' = 08
   '71685' = 08
   '71686' = 08
   '71687' = 08
   '71688' = 08
   '71689' = 08
   '71690' = 08
   '71691' = 08
   '71692' = 08
   '71693' = 08
   '71694' = 08
   '71695' = 08
   '71696' = 08
   '71697' = 08
   '71698' = 08
   '71699' = 08
   '7170'  = 08
   '7171'  = 08
   '7172'  = 08
   '7173'  = 08
   '71740' = 08
   '71741' = 08
   '71742' = 08
   '71743' = 08
   '71749' = 08
   '7175'  = 08
   '7176'  = 08
   '7177'  = 08
   '71781' = 08
   '71782' = 08
   '71783' = 08
   '71784' = 08
   '71785' = 08
   '71789' = 08
   '7179'  = 08
   '71800' = 08
   '71801' = 08
   '71802' = 08
   '71803' = 08
   '71804' = 08
   '71805' = 08
   '71807' = 08
   '71808' = 08
   '71809' = 08
   '71810' = 08
   '71811' = 08
   '71812' = 08
   '71813' = 08
   '71814' = 08
   '71815' = 08
   '71817' = 08
   '71818' = 08
   '71819' = 08
   '71820' = 08
   '71821' = 08
   '71822' = 08
   '71823' = 08
   '71824' = 08
   '71825' = 08
   '71826' = 08
   '71827' = 08
   '71828' = 08
   '71829' = 08
   '71830' = 08
   '71831' = 08
   '71832' = 08
   '71833' = 08
   '71834' = 08
   '71835' = 08
   '71836' = 08
   '71837' = 08
   '71838' = 08
   '71839' = 08
   '71840' = 08
   '71841' = 08
   '71842' = 08
   '71843' = 08
   '71844' = 08
   '71845' = 08
   '71846' = 08
   '71847' = 08
   '71848' = 08
   '71849' = 08
   '71850' = 08
   '71851' = 08
   '71852' = 08
   '71853' = 08
   '71854' = 08
   '71855' = 08
   '71856' = 08
   '71857' = 08
   '71858' = 08
   '71859' = 08
   '71865' = 08
   '71870' = 08
   '71871' = 08
   '71872' = 08
   '71873' = 08
   '71874' = 08
   '71875' = 08
   '71876' = 08
   '71877' = 08
   '71878' = 08
   '71879' = 08
   '71880' = 08
   '71881' = 08
   '71882' = 08
   '71883' = 08
   '71884' = 08
   '71885' = 08
   '71886' = 08
   '71887' = 08
   '71888' = 08
   '71889' = 08
   '71890' = 08
   '71891' = 08
   '71892' = 08
   '71893' = 08
   '71894' = 08
   '71895' = 08
   '71897' = 08
   '71898' = 08
   '71899' = 08
   '71900' = 08
   '71901' = 08
   '71902' = 08
   '71903' = 08
   '71904' = 08
   '71905' = 08
   '71906' = 08
   '71907' = 08
   '71908' = 08
   '71909' = 08
   '71910' = 08
   '71911' = 08
   '71912' = 08
   '71913' = 08
   '71914' = 08
   '71915' = 08
   '71916' = 08
   '71917' = 08
   '71918' = 08
   '71919' = 08
   '71920' = 08
   '71921' = 08
   '71922' = 08
   '71923' = 08
   '71924' = 08
   '71925' = 08
   '71926' = 08
   '71927' = 08
   '71928' = 08
   '71929' = 08
   '71930' = 08
   '71931' = 08
   '71932' = 08
   '71933' = 08
   '71934' = 08
   '71935' = 08
   '71936' = 08
   '71937' = 08
   '71938' = 08
   '71939' = 08
   '71940' = 08
   '71941' = 08
   '71942' = 08
   '71943' = 08
   '71944' = 08
   '71945' = 08
   '71946' = 08
   '71947' = 08
   '71948' = 08
   '71949' = 08
   '71950' = 08
   '71951' = 08
   '71952' = 08
   '71953' = 08
   '71954' = 08
   '71955' = 08
   '71956' = 08
   '71957' = 08
   '71958' = 08
   '71959' = 08
   '71960' = 08
   '71961' = 08
   '71962' = 08
   '71963' = 08
   '71964' = 08
   '71965' = 08
   '71966' = 08
   '71967' = 08
   '71968' = 08
   '71969' = 08
   '7197'  = 08
   '71980' = 08
   '71981' = 08
   '71982' = 08
   '71983' = 08
   '71984' = 08
   '71985' = 08
   '71986' = 08
   '71987' = 08
   '71988' = 08
   '71989' = 08
   '71990' = 08
   '71991' = 08
   '71992' = 08
   '71993' = 08
   '71994' = 08
   '71995' = 08
   '71996' = 08
   '71997' = 08
   '71998' = 08
   '71999' = 08
   '7200'  = 08
   '7201'  = 08
   '7202'  = 08
   '72081' = 08
   '72089' = 08
   '7209'  = 08
   '7210'  = 08
   '7211'  = 08
   '7212'  = 08
   '7213'  = 08
   '72141' = 08
   '72142' = 08
   '7215'  = 08
   '7216'  = 08
   '7217'  = 08
   '7218'  = 08
   '72190' = 08
   '72191' = 08
   '7220'  = 08
   '72210' = 08
   '72211' = 08
   '7222'  = 08
   '72230' = 08
   '72231' = 08
   '72232' = 08
   '72239' = 08
   '7224'  = 08
   '72251' = 08
   '72252' = 08
   '7226'  = 08
   '72270' = 08
   '72271' = 08
   '72272' = 08
   '72273' = 08
   '72280' = 08
   '72281' = 08
   '72282' = 08
   '72283' = 08
   '72290' = 08
   '72291' = 08
   '72292' = 08
   '72293' = 08
   '7230'  = 08
   '7231'  = 08
   '7232'  = 01
   '7233'  = 01
   '7234'  = 01
   '7235'  = 08
   '7236'  = 09
   '7237'  = 08
   '7238'  = 08
   '7239'  = 08
   '72400' = 08
   '72401' = 08
   '72402' = 08
   '72403' = 08
   '72409' = 08
   '7241'  = 08
   '7242'  = 08
   '7243'  = 08
   '7244'  = 08
   '7245'  = 08
   '7246'  = 08
   '72470' = 08
   '72471' = 08
   '72479' = 08
   '7248'  = 08
   '7249'  = 08
   '725'   = 08
   '7260'  = 08
   '72610' = 08
   '72611' = 08
   '72612' = 08
   '72613' = 08
   '72619' = 08
   '7262'  = 08
   '72630' = 08
   '72631' = 08
   '72632' = 08
   '72633' = 08
   '72639' = 08
   '7264'  = 08
   '7265'  = 08
   '72660' = 08
   '72661' = 08
   '72662' = 08
   '72663' = 08
   '72664' = 08
   '72665' = 08
   '72669' = 08
   '72670' = 08
   '72671' = 08
   '72672' = 08
   '72673' = 08
   '72679' = 08
   '7268'  = 08
   '72690' = 08
   '72691' = 08
   '72700' = 08
   '72701' = 08
   '72702' = 08
   '72703' = 08
   '72704' = 08
   '72705' = 08
   '72706' = 08
   '72709' = 08
   '7271'  = 08
   '7272'  = 08
   '7273'  = 08
   '72740' = 08
   '72741' = 08
   '72742' = 08
   '72743' = 08
   '72749' = 08
   '72750' = 08
   '72751' = 08
   '72759' = 08
   '72760' = 08
   '72761' = 08
   '72762' = 08
   '72763' = 08
   '72764' = 08
   '72765' = 08
   '72766' = 08
   '72767' = 08
   '72768' = 08
   '72769' = 08
   '72781' = 08
   '72782' = 08
   '72783' = 08
   '72789' = 08
   '7279'  = 08
   '7280'  = 08
   '72810' = 08
   '72811' = 08
   '72812' = 08
   '72813' = 08
   '72819' = 08
   '7282'  = 08
   '7283'  = 08
   '7284'  = 08
   '7285'  = 08
   '7286'  = 08
   '72871' = 08
   '72879' = 08
   '72881' = 08
   '72882' = 08
   '72883' = 08
   '72884' = 08
   '72885' = 08
   '72886' = 08
   '72887' = 08
   '72888' = 08
   '72889' = 08
   '7289'  = 08
   '7290'  = 08
   '7291'  = 08
   '7292'  = 01
   '72930' = 09
   '72931' = 09
   '72939' = 09
   '7294'  = 08
   '7295'  = 08
   '7296'  = 08
   '72971' = 08
   '72972' = 08
   '72973' = 08
   '72979' = 08
   '72981' = 08
   '72982' = 08
   '72989' = 08
   '72990' = 08
   '72991' = 08
   '72992' = 08
   '72999' = 08
   '73000' = 08
   '73001' = 08
   '73002' = 08
   '73003' = 08
   '73004' = 08
   '73005' = 08
   '73006' = 08
   '73007' = 08
   '73008' = 08
   '73009' = 08
   '73010' = 08
   '73011' = 08
   '73012' = 08
   '73013' = 08
   '73014' = 08
   '73015' = 08
   '73016' = 08
   '73017' = 08
   '73018' = 08
   '73019' = 08
   '73020' = 08
   '73021' = 08
   '73022' = 08
   '73023' = 08
   '73024' = 08
   '73025' = 08
   '73026' = 08
   '73027' = 08
   '73028' = 08
   '73029' = 08
   '73030' = 08
   '73031' = 08
   '73032' = 08
   '73033' = 08
   '73034' = 08
   '73035' = 08
   '73036' = 08
   '73037' = 08
   '73038' = 08
   '73039' = 08
   '73070' = 08
   '73071' = 08
   '73072' = 08
   '73073' = 08
   '73074' = 08
   '73075' = 08
   '73076' = 08
   '73077' = 08
   '73078' = 08
   '73079' = 08
   '73080' = 08
   '73081' = 08
   '73082' = 08
   '73083' = 08
   '73084' = 08
   '73085' = 08
   '73086' = 08
   '73087' = 08
   '73088' = 08
   '73089' = 08
   '73090' = 08
   '73091' = 08
   '73092' = 08
   '73093' = 08
   '73094' = 08
   '73095' = 08
   '73096' = 08
   '73097' = 08
   '73098' = 08
   '73099' = 08
   '7310'  = 08
   '7311'  = 08
   '7312'  = 08
   '7313'  = 08
   '7318'  = 08
   '7320'  = 08
   '7321'  = 08
   '7322'  = 08
   '7323'  = 08
   '7324'  = 08
   '7325'  = 08
   '7326'  = 08
   '7327'  = 08
   '7328'  = 08
   '7329'  = 08
   '73300' = 08
   '73301' = 08
   '73302' = 08
   '73303' = 08
   '73309' = 08
   '73310' = 08
   '73311' = 08
   '73312' = 08
   '73313' = 08
   '73314' = 08
   '73315' = 08
   '73316' = 08
   '73319' = 08
   '73320' = 08
   '73321' = 08
   '73322' = 08
   '73329' = 08
   '7333'  = 08
   '73340' = 08
   '73341' = 08
   '73342' = 08
   '73343' = 08
   '73344' = 08
   '73345' = 08
   '73349' = 08
   '7335'  = 08
   '7336'  = 04
   '7337'  = 08
   '73381' = 08
   '73382' = 08
   '73390' = 08
   '73391' = 08
   '73392' = 08
   '73393' = 08
   '73394' = 08
   '73395' = 08
   '73396' = 08
   '73397' = 08
   '73398' = 08
   '73399' = 08
   '734'   = 08
   '7350'  = 08
   '7351'  = 08
   '7352'  = 08
   '7353'  = 08
   '7354'  = 08
   '7355'  = 08
   '7358'  = 08
   '7359'  = 08
   '73600' = 08
   '73601' = 08
   '73602' = 08
   '73603' = 08
   '73604' = 08
   '73605' = 01
   '73606' = 01
   '73607' = 01
   '73609' = 08
   '7361'  = 08
   '73620' = 08
   '73621' = 08
   '73622' = 08
   '73629' = 08
   '73630' = 08
   '73631' = 08
   '73632' = 08
   '73639' = 08
   '73641' = 08
   '73642' = 08
   '7365'  = 08
   '7366'  = 08
   '73670' = 08
   '73671' = 08
   '73672' = 08
   '73673' = 08
   '73674' = 01
   '73675' = 08
   '73676' = 08
   '73679' = 08
   '73681' = 08
   '73689' = 08
   '7369'  = 08
   '7370'  = 08
   '73710' = 08
   '73711' = 08
   '73712' = 08
   '73719' = 08
   '73720' = 08
   '73721' = 08
   '73722' = 08
   '73729' = 08
   '73730' = 08
   '73731' = 08
   '73732' = 08
   '73733' = 08
   '73734' = 08
   '73739' = 08
   '73740' = 08
   '73741' = 08
   '73742' = 08
   '73743' = 08
   '7378'  = 08
   '7379'  = 08
   '7380'  = 03
   '73810' = 08
   '73811' = 08
   '73812' = 08
   '73819' = 08
   '7382'  = 08
   '7383'  = 08
   '7384'  = 08
   '7385'  = 08
   '7386'  = 08
   '7387'  = 03
   '7388'  = 08
   '7389'  = 08
   '7390'  = 08
   '7391'  = 08
   '7392'  = 08
   '7393'  = 08
   '7394'  = 08
   '7395'  = 08
   '7396'  = 08
   '7397'  = 08
   '7398'  = 08
   '7399'  = 08
   '7400'  = 01
   '7401'  = 01
   '7402'  = 01
   '74100' = 01
   '74101' = 01
   '74102' = 01
   '74103' = 01
   '74190' = 01
   '74191' = 01
   '74192' = 01
   '74193' = 01
   '7420'  = 01
   '7421'  = 01
   '7422'  = 01
   '7423'  = 01
   '7424'  = 01
   '74251' = 01
   '74253' = 01
   '74259' = 01
   '7428'  = 01
   '7429'  = 01
   '74300' = 02
   '74303' = 02
   '74306' = 02
   '74310' = 02
   '74311' = 02
   '74312' = 02
   '74320' = 02
   '74321' = 02
   '74322' = 02
   '74330' = 02
   '74331' = 02
   '74332' = 02
   '74333' = 02
   '74334' = 02
   '74335' = 02
   '74336' = 02
   '74337' = 02
   '74339' = 02
   '74341' = 02
   '74342' = 02
   '74343' = 02
   '74344' = 02
   '74345' = 02
   '74346' = 02
   '74347' = 02
   '74348' = 02
   '74349' = 02
   '74351' = 02
   '74352' = 02
   '74353' = 02
   '74354' = 02
   '74355' = 02
   '74356' = 02
   '74357' = 02
   '74358' = 02
   '74359' = 02
   '74361' = 02
   '74362' = 02
   '74363' = 02
   '74364' = 02
   '74365' = 02
   '74366' = 02
   '74369' = 02
   '7438'  = 02
   '7439'  = 02
   '74400' = 03
   '74401' = 03
   '74402' = 03
   '74403' = 03
   '74404' = 03
   '74405' = 03
   '74409' = 03
   '7441'  = 03
   '74421' = 03
   '74422' = 03
   '74423' = 03
   '74424' = 03
   '74429' = 03
   '7443'  = 03
   '74441' = 03
   '74442' = 03
   '74443' = 03
   '74446' = 03
   '74447' = 03
   '74449' = 03
   '7445'  = 09
   '74481' = 03
   '74482' = 03
   '74483' = 03
   '74484' = 03
   '74489' = 03
   '7449'  = 09
   '7450'  = 05
   '74510' = 05
   '74511' = 05
   '74512' = 05
   '74519' = 05
   '7452'  = 05
   '7453'  = 05
   '7454'  = 05
   '7455'  = 05
   '74560' = 05
   '74561' = 05
   '74569' = 05
   '7457'  = 05
   '7458'  = 05
   '7459'  = 05
   '74600' = 05
   '74601' = 05
   '74602' = 05
   '74609' = 05
   '7461'  = 05
   '7462'  = 05
   '7463'  = 05
   '7464'  = 05
   '7465'  = 05
   '7466'  = 05
   '7467'  = 05
   '74681' = 05
   '74682' = 05
   '74683' = 05
   '74684' = 05
   '74685' = 05
   '74686' = 05
   '74687' = 05
   '74689' = 05
   '7469'  = 05
   '7470'  = 05
   '74710' = 05
   '74711' = 05
   '74720' = 05
   '74721' = 05
   '74722' = 05
   '74729' = 05
   '74731' = 05
   '74732' = 05
   '74739' = 05
   '74740' = 05
   '74741' = 05
   '74742' = 05
   '74749' = 05
   '7475'  = 05
   '74760' = 05
   '74761' = 05
   '74762' = 05
   '74763' = 05
   '74764' = 05
   '74769' = 05
   '74781' = 01
   '74782' = 01
   '74783' = 15
   '74789' = 05
   '7479'  = 05
   '7480'  = 03
   '7481'  = 03
   '7482'  = 03
   '7483'  = 03
   '7484'  = 04
   '7485'  = 04
   '74860' = 04
   '74861' = 04
   '74869' = 04
   '7488'  = 04
   '7489'  = 04
   '74900' = 03
   '74901' = 03
   '74902' = 03
   '74903' = 03
   '74904' = 03
   '74910' = 03
   '74911' = 03
   '74912' = 03
   '74913' = 03
   '74914' = 03
   '74920' = 03
   '74921' = 03
   '74922' = 03
   '74923' = 03
   '74924' = 03
   '74925' = 03
   '7500'  = 03
   '75010' = 03
   '75011' = 03
   '75012' = 03
   '75013' = 03
   '75015' = 03
   '75016' = 03
   '75019' = 03
   '75021' = 03
   '75022' = 03
   '75023' = 03
   '75024' = 03
   '75025' = 03
   '75026' = 03
   '75027' = 03
   '75029' = 03
   '7503'  = 06
   '7504'  = 06
   '7505'  = 06
   '7506'  = 06
   '7507'  = 06
   '7508'  = 06
   '7509'  = 06
   '7510'  = 06
   '7511'  = 06
   '7512'  = 06
   '7513'  = 06
   '7514'  = 06
   '7515'  = 06
   '75160' = 07
   '75161' = 07
   '75162' = 07
   '75169' = 07
   '7517'  = 07
   '7518'  = 06
   '7519'  = 06
   '7520'  = 13
   '75210' = 13
   '75211' = 13
   '75219' = 13
   '7522'  = 13
   '75231' = 13
   '75232' = 13
   '75233' = 13
   '75234' = 13
   '75235' = 13
   '75236' = 13
   '75239' = 13
   '75240' = 13
   '75241' = 13
   '75242' = 13
   '75243' = 13
   '75244' = 13
   '75245' = 13
   '75246' = 13
   '75247' = 13
   '75249' = 13
   '75251' = 12
   '75252' = 12
   '75261' = 12
   '75262' = 12
   '75263' = 12
   '75264' = 12
   '75265' = 12
   '75269' = 12
   '7527'  = 12
   '75281' = 12
   '75289' = 12
   '7529'  = 12
   '7530'  = 11
   '75310' = 11
   '75311' = 11
   '75312' = 11
   '75313' = 11
   '75314' = 11
   '75315' = 11
   '75316' = 11
   '75317' = 11
   '75319' = 11
   '75320' = 11
   '75321' = 11
   '75322' = 11
   '75323' = 11
   '75329' = 11
   '7533'  = 11
   '7534'  = 11
   '7535'  = 11
   '7536'  = 11
   '7537'  = 11
   '7538'  = 11
   '7539'  = 11
   '7540'  = 08
   '7541'  = 08
   '7542'  = 08
   '75430' = 08
   '75431' = 08
   '75432' = 08
   '75433' = 08
   '75435' = 08
   '75440' = 08
   '75441' = 08
   '75442' = 08
   '75443' = 08
   '75444' = 08
   '75450' = 08
   '75451' = 08
   '75452' = 08
   '75453' = 08
   '75459' = 08
   '75460' = 08
   '75461' = 08
   '75462' = 08
   '75469' = 08
   '75470' = 08
   '75471' = 08
   '75479' = 08
   '75481' = 04
   '75482' = 04
   '75489' = 08
   '75500' = 08
   '75501' = 08
   '75502' = 08
   '75510' = 08
   '75511' = 08
   '75512' = 08
   '75513' = 08
   '75514' = 08
   '75520' = 08
   '75521' = 08
   '75522' = 08
   '75523' = 08
   '75524' = 08
   '75525' = 08
   '75526' = 08
   '75527' = 08
   '75528' = 08
   '75529' = 08
   '75530' = 08
   '75531' = 08
   '75532' = 08
   '75533' = 08
   '75534' = 08
   '75535' = 08
   '75536' = 08
   '75537' = 08
   '75538' = 08
   '75539' = 08
   '7554'  = 08
   '75550' = 08
   '75551' = 08
   '75552' = 08
   '75553' = 08
   '75554' = 08
   '75555' = 08
   '75556' = 08
   '75557' = 08
   '75558' = 08
   '75559' = 08
   '75560' = 08
   '75561' = 08
   '75562' = 08
   '75563' = 08
   '75564' = 08
   '75565' = 08
   '75566' = 08
   '75567' = 08
   '75569' = 08
   '7558'  = 08
   '7559'  = 08
   '7560'  = 08
   '75610' = 08
   '75611' = 08
   '75612' = 08
   '75613' = 08
   '75614' = 08
   '75615' = 08
   '75616' = 08
   '75617' = 01
   '75619' = 08
   '7562'  = 08
   '7563'  = 04
   '7564'  = 08
   '75650' = 08
   '75651' = 08
   '75652' = 08
   '75653' = 08
   '75654' = 08
   '75655' = 08
   '75656' = 08
   '75659' = 08
   '7566'  = 04
   '75670' = 06
   '75671' = 06
   '75672' = 06
   '75673' = 06
   '75679' = 06
   '75681' = 08
   '75682' = 08
   '75683' = 08
   '75689' = 08
   '7569'  = 08
   '7570'  = 09
   '7571'  = 09
   '7572'  = 09
   '75731' = 09
   '75732' = 09
   '75733' = 09
   '75739' = 09
   '7574'  = 09
   '7575'  = 09
   '7576'  = 09
   '7578'  = 09
   '7579'  = 09
   '7580'  = 19
   '7581'  = 19
   '7582'  = 19
   '75831' = 19
   '75832' = 19
   '75833' = 19
   '75839' = 19
   '7584'  = 23
   '7585'  = 23
   '7586'  = 12
   '7587'  = 12
   '75881' = 12
   '75889' = 12
   '7589'  = 23
   '7590'  = 16
   '7591'  = 10
   '7592'  = 10
   '7593'  = 06
   '7594'  = 06
   '7595'  = 01
   '7596'  = 17
   '7597'  = 08
   '75981' = 08
   '75982' = 05
   '75983' = 19
   '75989' = 08
   '7599'  = 23
   '7600'  = 15
   '7601'  = 15
   '7602'  = 15
   '7603'  = 15
   '7604'  = 15
   '7605'  = 15
   '76061' = 15
   '76062' = 15
   '76063' = 15
   '76064' = 15
   '76070' = 15
   '76071' = 15
   '76072' = 15
   '76073' = 15
   '76074' = 15
   '76075' = 15
   '76076' = 15
   '76077' = 15
   '76078' = 15
   '76079' = 15
   '7608'  = 15
   '7609'  = 15
   '7610'  = 15
   '7611'  = 15
   '7612'  = 15
   '7613'  = 15
   '7614'  = 15
   '7615'  = 15
   '7616'  = 15
   '7617'  = 15
   '7618'  = 15
   '7619'  = 15
   '7620'  = 15
   '7621'  = 15
   '7622'  = 15
   '7623'  = 15
   '7624'  = 15
   '7625'  = 15
   '7626'  = 15
   '7627'  = 15
   '7628'  = 15
   '7629'  = 15
   '7630'  = 15
   '7631'  = 15
   '7632'  = 15
   '7633'  = 15
   '7634'  = 15
   '7635'  = 15
   '7636'  = 15
   '7637'  = 15
   '76381' = 15
   '76382' = 15
   '76383' = 15
   '76384' = 15
   '76389' = 15
   '7639'  = 15
   '76400' = 15
   '76401' = 15
   '76402' = 15
   '76403' = 15
   '76404' = 15
   '76405' = 15
   '76406' = 15
   '76407' = 15
   '76408' = 15
   '76409' = 15
   '76410' = 15
   '76411' = 15
   '76412' = 15
   '76413' = 15
   '76414' = 15
   '76415' = 15
   '76416' = 15
   '76417' = 15
   '76418' = 15
   '76419' = 15
   '76420' = 15
   '76421' = 15
   '76422' = 15
   '76423' = 15
   '76424' = 15
   '76425' = 15
   '76426' = 15
   '76427' = 15
   '76428' = 15
   '76429' = 15
   '76490' = 15
   '76491' = 15
   '76492' = 15
   '76493' = 15
   '76494' = 15
   '76495' = 15
   '76496' = 15
   '76497' = 15
   '76498' = 15
   '76499' = 15
   '76500' = 15
   '76501' = 15
   '76502' = 15
   '76503' = 15
   '76504' = 15
   '76505' = 15
   '76506' = 15
   '76507' = 15
   '76508' = 15
   '76509' = 15
   '76510' = 15
   '76511' = 15
   '76512' = 15
   '76513' = 15
   '76514' = 15
   '76515' = 15
   '76516' = 15
   '76517' = 15
   '76518' = 15
   '76519' = 15
   '76520' = 15
   '76521' = 15
   '76522' = 15
   '76523' = 15
   '76524' = 15
   '76525' = 15
   '76526' = 15
   '76527' = 15
   '76528' = 15
   '76529' = 15
   '7660'  = 15
   '7661'  = 15
   '76621' = 15
   '76622' = 15
   '7670'  = 15
   '76711' = 15
   '76719' = 15
   '7672'  = 15
   '7673'  = 15
   '7674'  = 15
   '7675'  = 15
   '7676'  = 15
   '7677'  = 15
   '7678'  = 15
   '7679'  = 15
   '7680'  = 15
   '7681'  = 15
   '7682'  = 15
   '7683'  = 15
   '7684'  = 15
   '7685'  = 15
   '7686'  = 15
   '76870' = 15
   '76871' = 15
   '76872' = 15
   '76873' = 15
   '7689'  = 15
   '769'   = 15
   '7700'  = 15
   '77010' = 15
   '77011' = 15
   '77012' = 15
   '77013' = 15
   '77014' = 15
   '77015' = 15
   '77016' = 15
   '77017' = 15
   '77018' = 15
   '7702'  = 15
   '7703'  = 15
   '7704'  = 15
   '7705'  = 15
   '7706'  = 15
   '7707'  = 04
   '77081' = 15
   '77082' = 15
   '77083' = 15
   '77084' = 15
   '77085' = 15
   '77086' = 15
   '77087' = 15
   '77088' = 15
   '77089' = 15
   '7709'  = 15
   '7710'  = 15
   '7711'  = 15
   '7712'  = 15
   '7713'  = 15
   '7714'  = 15
   '7715'  = 15
   '7716'  = 15
   '7717'  = 15
   '77181' = 15
   '77182' = 15
   '77183' = 15
   '77189' = 15
   '7720'  = 15
   '77210' = 15
   '77211' = 15
   '77212' = 15
   '77213' = 15
   '77214' = 15
   '7722'  = 15
   '7723'  = 15
   '7724'  = 15
   '7725'  = 15
   '7726'  = 15
   '7728'  = 15
   '7729'  = 15
   '7730'  = 15
   '7731'  = 15
   '7732'  = 15
   '7733'  = 15
   '7734'  = 15
   '7735'  = 15
   '7740'  = 15
   '7741'  = 15
   '7742'  = 15
   '77430' = 15
   '77431' = 15
   '77439' = 15
   '7744'  = 15
   '7745'  = 15
   '7746'  = 15
   '7747'  = 15
   '7750'  = 15
   '7751'  = 15
   '7752'  = 15
   '7753'  = 15
   '7754'  = 15
   '7755'  = 15
   '7756'  = 15
   '7757'  = 15
   '77581' = 15
   '77589' = 15
   '7759'  = 15
   '7760'  = 15
   '7761'  = 15
   '7762'  = 15
   '7763'  = 15
   '7764'  = 15
   '7765'  = 15
   '7766'  = 15
   '7767'  = 15
   '7768'  = 15
   '7769'  = 15
   '7771'  = 15
   '7772'  = 15
   '7773'  = 15
   '7774'  = 15
   '77750' = 15
   '77751' = 15
   '77752' = 15
   '77753' = 15
   '7776'  = 15
   '7778'  = 15
   '7779'  = 15
   '7780'  = 15
   '7781'  = 15
   '7782'  = 15
   '7783'  = 15
   '7784'  = 15
   '7785'  = 15
   '7786'  = 15
   '7787'  = 15
   '7788'  = 15
   '7789'  = 15
   '7790'  = 15
   '7791'  = 15
   '7792'  = 15
   '77931' = 15
   '77932' = 15
   '77933' = 15
   '77934' = 10
   '7794'  = 15
   '7795'  = 15
   '7796'  = 15
   '7797'  = 01
   '77981' = 15
   '77982' = 15
   '77983' = 15
   '77984' = 15
   '77985' = 15
   '77989' = 15
   '7799'  = 15
   '78001' = 01
   '78002' = 19
   '78003' = 01
   '78009' = 01
   '7801'  = 19
   '7802'  = 05
   '78031' = 01
   '78032' = 01
   '78033' = 01
   '78039' = 01
   '7804'  = 03
   '78050' = 19
   '78051' = 03
   '78052' = 19
   '78053' = 03
   '78054' = 19
   '78055' = 19
   '78056' = 19
   '78057' = 03
   '78058' = 19
   '78059' = 19
   '78060' = 18
   '78061' = 18
   '78062' = 18
   '78063' = 18
   '78064' = 23
   '78065' = 23
   '78066' = 18
   '78071' = 23
   '78072' = 01
   '78079' = 23
   '7808'  = 09
   '78091' = 23
   '78092' = 23
   '78093' = 23
   '78094' = 23
   '78095' = 23
   '78096' = 23
   '78097' = 23
   '78099' = 23
   '7810'  = 01
   '7811'  = 01
   '7812'  = 01
   '7813'  = 01
   '7814'  = 01
   '7815'  = 04
   '7816'  = 01
   '7817'  = 10
   '7818'  = 01
   '78191' = 01
   '78192' = 01
   '78193' = 08
   '78194' = 01
   '78199' = 01
   '7820'  = 01
   '7821'  = 09
   '7822'  = 09
   '7823'  = 23
   '7824'  = 07
   '7825'  = 23
   '78261' = 23
   '78262' = 23
   '7827'  = 16
   '7828'  = 09
   '7829'  = 09
   '7830'  = 10
   '7831'  = 10
   '78321' = 10
   '78322' = 10
   '7833'  = 10
   '78340' = 10
   '78341' = 10
   '78342' = 10
   '78343' = 10
   '7835'  = 10
   '7836'  = 10
   '7837'  = 10
   '7839'  = 10
   '7840'  = 01
   '7841'  = 03
   '7842'  = 09
   '7843'  = 01
   '78440' = 03
   '78441' = 03
   '78442' = 03
   '78443' = 03
   '78444' = 03
   '78449' = 03
   '78451' = 01
   '78452' = 01
   '78459' = 01
   '78460' = 19
   '78461' = 19
   '78469' = 19
   '7847'  = 03
   '7848'  = 03
   '78491' = 03
   '78492' = 03
   '78499' = 03
   '7850'  = 05
   '7851'  = 05
   '7852'  = 05
   '7853'  = 05
   '7854'  = 05
   '78550' = 05
   '78551' = 05
   '78552' = 18
   '78559' = 18
   '7856'  = 16
   '7859'  = 05
   '78600' = 04
   '78601' = 04
   '78602' = 04
   '78603' = 04
   '78604' = 04
   '78605' = 04
   '78606' = 04
   '78607' = 04
   '78609' = 04
   '7861'  = 04
   '7862'  = 04
   '78630' = 04
   '78631' = 04
   '78639' = 04
   '7864'  = 04
   '78650' = 05
   '78651' = 05
   '78652' = 04
   '78659' = 05
   '7866'  = 04
   '7867'  = 04
   '7868'  = 04
   '7869'  = 04
   '78701' = 06
   '78702' = 06
   '78703' = 06
   '78704' = 06
   '7871'  = 06
   '78720' = 06
   '78721' = 06
   '78722' = 06
   '78723' = 06
   '78724' = 06
   '78729' = 06
   '7873'  = 06
   '7874'  = 06
   '7875'  = 06
   '78760' = 06
   '78761' = 06
   '78762' = 06
   '78763' = 06
   '7877'  = 06
   '78791' = 06
   '78799' = 06
   '7880'  = 11
   '7881'  = 11
   '78820' = 11
   '78821' = 11
   '78829' = 11
   '78830' = 11
   '78831' = 11
   '78832' = 11
   '78833' = 11
   '78834' = 11
   '78835' = 11
   '78836' = 11
   '78837' = 11
   '78838' = 11
   '78839' = 11
   '78841' = 11
   '78842' = 11
   '78843' = 11
   '7885'  = 11
   '78861' = 11
   '78862' = 11
   '78863' = 11
   '78864' = 11
   '78865' = 11
   '78869' = 11
   '7887'  = 11
   '7888'  = 11
   '78891' = 11
   '78899' = 11
   '78900' = 06
   '78901' = 06
   '78902' = 06
   '78903' = 06
   '78904' = 06
   '78905' = 06
   '78906' = 06
   '78907' = 06
   '78909' = 06
   '7891'  = 07
   '7892'  = 16
   '78930' = 06
   '78931' = 06
   '78932' = 06
   '78933' = 06
   '78934' = 06
   '78935' = 06
   '78936' = 06
   '78937' = 06
   '78939' = 06
   '78940' = 06
   '78941' = 06
   '78942' = 06
   '78943' = 06
   '78944' = 06
   '78945' = 06
   '78946' = 06
   '78947' = 06
   '78949' = 06
   '78951' = 23
   '78959' = 23
   '78960' = 06
   '78961' = 06
   '78962' = 06
   '78963' = 06
   '78964' = 06
   '78965' = 06
   '78966' = 06
   '78967' = 06
   '78969' = 06
   '7897'  = 06
   '7899'  = 06
   '79001' = 16
   '79009' = 16
   '7901'  = 23
   '79021' = 10
   '79022' = 10
   '79029' = 10
   '7903'  = 20
   '7904'  = 23
   '7905'  = 23
   '7906'  = 23
   '7907'  = 18
   '7908'  = 18
   '79091' = 23
   '79092' = 23
   '79093' = 23
   '79094' = 23
   '79095' = 23
   '79099' = 23
   '7910'  = 11
   '7911'  = 11
   '7912'  = 11
   '7913'  = 23
   '7914'  = 07
   '7915'  = 10
   '7916'  = 10
   '7917'  = 11
   '7919'  = 11
   '7920'  = 01
   '7921'  = 06
   '7922'  = 12
   '7923'  = 14
   '7924'  = 03
   '7925'  = 23
   '7929'  = 23
   '7930'  = 01
   '79311' = 04
   '79319' = 04
   '7932'  = 05
   '7933'  = 07
   '7934'  = 06
   '7935'  = 11
   '7936'  = 06
   '7937'  = 08
   '79380' = 09
   '79381' = 09
   '79382' = 09
   '79389' = 09
   '79391' = 23
   '79399' = 23
   '79400' = 01
   '79401' = 01
   '79402' = 01
   '79409' = 01
   '79410' = 01
   '79411' = 02
   '79412' = 02
   '79413' = 02
   '79414' = 02
   '79415' = 03
   '79416' = 03
   '79417' = 08
   '79419' = 01
   '7942'  = 04
   '79430' = 05
   '79431' = 05
   '79439' = 05
   '7944'  = 11
   '7945'  = 10
   '7946'  = 10
   '7947'  = 10
   '7948'  = 07
   '7949'  = 11
   '79500' = 13
   '79501' = 13
   '79502' = 13
   '79503' = 13
   '79504' = 13
   '79505' = 13
   '79506' = 13
   '79507' = 13
   '79508' = 13
   '79509' = 13
   '79510' = 13
   '79511' = 13
   '79512' = 13
   '79513' = 13
   '79514' = 13
   '79515' = 13
   '79516' = 13
   '79518' = 13
   '79519' = 13
   '7952'  = 23
   '79531' = 18
   '79539' = 18
   '7954'  = 23
   '79551' = 04
   '79552' = 04
   '7956'  = 08
   '79571' = 16
   '79579' = 16
   '79581' = 23
   '79582' = 23
   '79589' = 23
   '7960'  = 21
   '7961'  = 01
   '7962'  = 05
   '7963'  = 05
   '7964'  = 23
   '7965'  = 14
   '7966'  = 23
   '79670' = 06
   '79671' = 06
   '79672' = 06
   '79673' = 06
   '79674' = 06
   '79675' = 06
   '79676' = 06
   '79677' = 06
   '79678' = 06
   '79679' = 06
   '7969'  = 23
   '797'   = 19
   '7980'  = 01
   '7981'  = 05
   '7982'  = 05
   '7989'  = 23
   '79901' = 04
   '79902' = 04
   '7991'  = 04
   '79921' = 19
   '79922' = 19
   '79923' = 19
   '79924' = 19
   '79925' = 19
   '79929' = 19
   '7993'  = 23
   '7994'  = 23
   '79951' = 19
   '79952' = 19
   '79953' = 01
   '79954' = 19
   '79955' = 19
   '79959' = 19
   '79981' = 23
   '79982' = 23
   '79989' = 23
   '7999'  = 23
   '80000' = 01
   '80001' = 01
   '80002' = 01
   '80003' = 01
   '80004' = 01
   '80005' = 01
   '80006' = 01
   '80009' = 01
   '80010' = 01
   '80011' = 01
   '80012' = 01
   '80013' = 01
   '80014' = 01
   '80015' = 01
   '80016' = 01
   '80019' = 01
   '80020' = 01
   '80021' = 01
   '80022' = 01
   '80023' = 01
   '80024' = 01
   '80025' = 01
   '80026' = 01
   '80029' = 01
   '80030' = 01
   '80031' = 01
   '80032' = 01
   '80033' = 01
   '80034' = 01
   '80035' = 01
   '80036' = 01
   '80039' = 01
   '80040' = 01
   '80041' = 01
   '80042' = 01
   '80043' = 01
   '80044' = 01
   '80045' = 01
   '80046' = 01
   '80049' = 01
   '80050' = 01
   '80051' = 01
   '80052' = 01
   '80053' = 01
   '80054' = 01
   '80055' = 01
   '80056' = 01
   '80059' = 01
   '80060' = 01
   '80061' = 01
   '80062' = 01
   '80063' = 01
   '80064' = 01
   '80065' = 01
   '80066' = 01
   '80069' = 01
   '80070' = 01
   '80071' = 01
   '80072' = 01
   '80073' = 01
   '80074' = 01
   '80075' = 01
   '80076' = 01
   '80079' = 01
   '80080' = 01
   '80081' = 01
   '80082' = 01
   '80083' = 01
   '80084' = 01
   '80085' = 01
   '80086' = 01
   '80089' = 01
   '80090' = 01
   '80091' = 01
   '80092' = 01
   '80093' = 01
   '80094' = 01
   '80095' = 01
   '80096' = 01
   '80099' = 01
   '80100' = 01
   '80101' = 01
   '80102' = 01
   '80103' = 01
   '80104' = 01
   '80105' = 01
   '80106' = 01
   '80109' = 01
   '80110' = 01
   '80111' = 01
   '80112' = 01
   '80113' = 01
   '80114' = 01
   '80115' = 01
   '80116' = 01
   '80119' = 01
   '80120' = 01
   '80121' = 01
   '80122' = 01
   '80123' = 01
   '80124' = 01
   '80125' = 01
   '80126' = 01
   '80129' = 01
   '80130' = 01
   '80131' = 01
   '80132' = 01
   '80133' = 01
   '80134' = 01
   '80135' = 01
   '80136' = 01
   '80139' = 01
   '80140' = 01
   '80141' = 01
   '80142' = 01
   '80143' = 01
   '80144' = 01
   '80145' = 01
   '80146' = 01
   '80149' = 01
   '80150' = 01
   '80151' = 01
   '80152' = 01
   '80153' = 01
   '80154' = 01
   '80155' = 01
   '80156' = 01
   '80159' = 01
   '80160' = 01
   '80161' = 01
   '80162' = 01
   '80163' = 01
   '80164' = 01
   '80165' = 01
   '80166' = 01
   '80169' = 01
   '80170' = 01
   '80171' = 01
   '80172' = 01
   '80173' = 01
   '80174' = 01
   '80175' = 01
   '80176' = 01
   '80179' = 01
   '80180' = 01
   '80181' = 01
   '80182' = 01
   '80183' = 01
   '80184' = 01
   '80185' = 01
   '80186' = 01
   '80189' = 01
   '80190' = 01
   '80191' = 01
   '80192' = 01
   '80193' = 01
   '80194' = 01
   '80195' = 01
   '80196' = 01
   '80199' = 01
   '8020'  = 03
   '8021'  = 03
   '80220' = 03
   '80221' = 03
   '80222' = 03
   '80223' = 03
   '80224' = 03
   '80225' = 03
   '80226' = 03
   '80227' = 03
   '80228' = 03
   '80229' = 03
   '80230' = 03
   '80231' = 03
   '80232' = 03
   '80233' = 03
   '80234' = 03
   '80235' = 03
   '80236' = 03
   '80237' = 03
   '80238' = 03
   '80239' = 03
   '8024'  = 03
   '8025'  = 03
   '8026'  = 02
   '8027'  = 02
   '8028'  = 08
   '8029'  = 08
   '80300' = 01
   '80301' = 01
   '80302' = 01
   '80303' = 01
   '80304' = 01
   '80305' = 01
   '80306' = 01
   '80309' = 01
   '80310' = 01
   '80311' = 01
   '80312' = 01
   '80313' = 01
   '80314' = 01
   '80315' = 01
   '80316' = 01
   '80319' = 01
   '80320' = 01
   '80321' = 01
   '80322' = 01
   '80323' = 01
   '80324' = 01
   '80325' = 01
   '80326' = 01
   '80329' = 01
   '80330' = 01
   '80331' = 01
   '80332' = 01
   '80333' = 01
   '80334' = 01
   '80335' = 01
   '80336' = 01
   '80339' = 01
   '80340' = 01
   '80341' = 01
   '80342' = 01
   '80343' = 01
   '80344' = 01
   '80345' = 01
   '80346' = 01
   '80349' = 01
   '80350' = 01
   '80351' = 01
   '80352' = 01
   '80353' = 01
   '80354' = 01
   '80355' = 01
   '80356' = 01
   '80359' = 01
   '80360' = 01
   '80361' = 01
   '80362' = 01
   '80363' = 01
   '80364' = 01
   '80365' = 01
   '80366' = 01
   '80369' = 01
   '80370' = 01
   '80371' = 01
   '80372' = 01
   '80373' = 01
   '80374' = 01
   '80375' = 01
   '80376' = 01
   '80379' = 01
   '80380' = 01
   '80381' = 01
   '80382' = 01
   '80383' = 01
   '80384' = 01
   '80385' = 01
   '80386' = 01
   '80389' = 01
   '80390' = 01
   '80391' = 01
   '80392' = 01
   '80393' = 01
   '80394' = 01
   '80395' = 01
   '80396' = 01
   '80399' = 01
   '80400' = 01
   '80401' = 01
   '80402' = 01
   '80403' = 01
   '80404' = 01
   '80405' = 01
   '80406' = 01
   '80409' = 01
   '80410' = 01
   '80411' = 01
   '80412' = 01
   '80413' = 01
   '80414' = 01
   '80415' = 01
   '80416' = 01
   '80419' = 01
   '80420' = 01
   '80421' = 01
   '80422' = 01
   '80423' = 01
   '80424' = 01
   '80425' = 01
   '80426' = 01
   '80429' = 01
   '80430' = 01
   '80431' = 01
   '80432' = 01
   '80433' = 01
   '80434' = 01
   '80435' = 01
   '80436' = 01
   '80439' = 01
   '80440' = 01
   '80441' = 01
   '80442' = 01
   '80443' = 01
   '80444' = 01
   '80445' = 01
   '80446' = 01
   '80449' = 01
   '80450' = 01
   '80451' = 01
   '80452' = 01
   '80453' = 01
   '80454' = 01
   '80455' = 01
   '80456' = 01
   '80459' = 01
   '80460' = 01
   '80461' = 01
   '80462' = 01
   '80463' = 01
   '80464' = 01
   '80465' = 01
   '80466' = 01
   '80469' = 01
   '80470' = 01
   '80471' = 01
   '80472' = 01
   '80473' = 01
   '80474' = 01
   '80475' = 01
   '80476' = 01
   '80479' = 01
   '80480' = 01
   '80481' = 01
   '80482' = 01
   '80483' = 01
   '80484' = 01
   '80485' = 01
   '80486' = 01
   '80489' = 01
   '80490' = 01
   '80491' = 01
   '80492' = 01
   '80493' = 01
   '80494' = 01
   '80495' = 01
   '80496' = 01
   '80499' = 01
   '80500' = 08
   '80501' = 08
   '80502' = 08
   '80503' = 08
   '80504' = 08
   '80505' = 08
   '80506' = 08
   '80507' = 08
   '80508' = 08
   '80510' = 08
   '80511' = 08
   '80512' = 08
   '80513' = 08
   '80514' = 08
   '80515' = 08
   '80516' = 08
   '80517' = 08
   '80518' = 08
   '8052'  = 08
   '8053'  = 08
   '8054'  = 08
   '8055'  = 08
   '8056'  = 08
   '8057'  = 08
   '8058'  = 08
   '8059'  = 08
   '80600' = 01
   '80601' = 01
   '80602' = 01
   '80603' = 01
   '80604' = 01
   '80605' = 01
   '80606' = 01
   '80607' = 01
   '80608' = 01
   '80609' = 01
   '80610' = 01
   '80611' = 01
   '80612' = 01
   '80613' = 01
   '80614' = 01
   '80615' = 01
   '80616' = 01
   '80617' = 01
   '80618' = 01
   '80619' = 01
   '80620' = 01
   '80621' = 01
   '80622' = 01
   '80623' = 01
   '80624' = 01
   '80625' = 01
   '80626' = 01
   '80627' = 01
   '80628' = 01
   '80629' = 01
   '80630' = 01
   '80631' = 01
   '80632' = 01
   '80633' = 01
   '80634' = 01
   '80635' = 01
   '80636' = 01
   '80637' = 01
   '80638' = 01
   '80639' = 01
   '8064'  = 01
   '8065'  = 01
   '80660' = 01
   '80661' = 01
   '80662' = 01
   '80669' = 01
   '80670' = 01
   '80671' = 01
   '80672' = 01
   '80679' = 01
   '8068'  = 01
   '8069'  = 01
   '80700' = 04
   '80701' = 04
   '80702' = 04
   '80703' = 04
   '80704' = 04
   '80705' = 04
   '80706' = 04
   '80707' = 04
   '80708' = 04
   '80709' = 04
   '80710' = 04
   '80711' = 04
   '80712' = 04
   '80713' = 04
   '80714' = 04
   '80715' = 04
   '80716' = 04
   '80717' = 04
   '80718' = 04
   '80719' = 04
   '8072'  = 04
   '8073'  = 04
   '8074'  = 04
   '8075'  = 03
   '8076'  = 03
   '8080'  = 08
   '8081'  = 08
   '8082'  = 08
   '8083'  = 08
   '80841' = 08
   '80842' = 08
   '80843' = 08
   '80844' = 08
   '80849' = 08
   '80851' = 08
   '80852' = 08
   '80853' = 08
   '80854' = 08
   '80859' = 08
   '8088'  = 08
   '8089'  = 08
   '8090'  = 08
   '8091'  = 08
   '81000' = 08
   '81001' = 08
   '81002' = 08
   '81003' = 08
   '81010' = 08
   '81011' = 08
   '81012' = 08
   '81013' = 08
   '81100' = 08
   '81101' = 08
   '81102' = 08
   '81103' = 08
   '81109' = 08
   '81110' = 08
   '81111' = 08
   '81112' = 08
   '81113' = 08
   '81119' = 08
   '81200' = 08
   '81201' = 08
   '81202' = 08
   '81203' = 08
   '81209' = 08
   '81210' = 08
   '81211' = 08
   '81212' = 08
   '81213' = 08
   '81219' = 08
   '81220' = 08
   '81221' = 08
   '81230' = 08
   '81231' = 08
   '81240' = 08
   '81241' = 08
   '81242' = 08
   '81243' = 08
   '81244' = 08
   '81249' = 08
   '81250' = 08
   '81251' = 08
   '81252' = 08
   '81253' = 08
   '81254' = 08
   '81259' = 08
   '81300' = 08
   '81301' = 08
   '81302' = 08
   '81303' = 08
   '81304' = 08
   '81305' = 08
   '81306' = 08
   '81307' = 08
   '81308' = 08
   '81310' = 08
   '81311' = 08
   '81312' = 08
   '81313' = 08
   '81314' = 08
   '81315' = 08
   '81316' = 08
   '81317' = 08
   '81318' = 08
   '81320' = 08
   '81321' = 08
   '81322' = 08
   '81323' = 08
   '81330' = 08
   '81331' = 08
   '81332' = 08
   '81333' = 08
   '81340' = 08
   '81341' = 08
   '81342' = 08
   '81343' = 08
   '81344' = 08
   '81345' = 08
   '81346' = 08
   '81347' = 08
   '81350' = 08
   '81351' = 08
   '81352' = 08
   '81353' = 08
   '81354' = 08
   '81380' = 08
   '81381' = 08
   '81382' = 08
   '81383' = 08
   '81390' = 08
   '81391' = 08
   '81392' = 08
   '81393' = 08
   '81400' = 08
   '81401' = 08
   '81402' = 08
   '81403' = 08
   '81404' = 08
   '81405' = 08
   '81406' = 08
   '81407' = 08
   '81408' = 08
   '81409' = 08
   '81410' = 08
   '81411' = 08
   '81412' = 08
   '81413' = 08
   '81414' = 08
   '81415' = 08
   '81416' = 08
   '81417' = 08
   '81418' = 08
   '81419' = 08
   '81500' = 08
   '81501' = 08
   '81502' = 08
   '81503' = 08
   '81504' = 08
   '81509' = 08
   '81510' = 08
   '81511' = 08
   '81512' = 08
   '81513' = 08
   '81514' = 08
   '81519' = 08
   '81600' = 08
   '81601' = 08
   '81602' = 08
   '81603' = 08
   '81610' = 08
   '81611' = 08
   '81612' = 08
   '81613' = 08
   '8170'  = 08
   '8171'  = 08
   '8180'  = 08
   '8181'  = 08
   '8190'  = 21
   '8191'  = 21
   '82000' = 08
   '82001' = 08
   '82002' = 08
   '82003' = 08
   '82009' = 08
   '82010' = 08
   '82011' = 08
   '82012' = 08
   '82013' = 08
   '82019' = 08
   '82020' = 08
   '82021' = 08
   '82022' = 08
   '82030' = 08
   '82031' = 08
   '82032' = 08
   '8208'  = 08
   '8209'  = 08
   '82100' = 08
   '82101' = 08
   '82110' = 08
   '82111' = 08
   '82120' = 08
   '82121' = 08
   '82122' = 08
   '82123' = 08
   '82129' = 08
   '82130' = 08
   '82131' = 08
   '82132' = 08
   '82133' = 08
   '82139' = 08
   '8220'  = 08
   '8221'  = 08
   '82300' = 08
   '82301' = 08
   '82302' = 08
   '82310' = 08
   '82311' = 08
   '82312' = 08
   '82320' = 08
   '82321' = 08
   '82322' = 08
   '82330' = 08
   '82331' = 08
   '82332' = 08
   '82340' = 08
   '82341' = 08
   '82342' = 08
   '82380' = 08
   '82381' = 08
   '82382' = 08
   '82390' = 08
   '82391' = 08
   '82392' = 08
   '8240'  = 08
   '8241'  = 08
   '8242'  = 08
   '8243'  = 08
   '8244'  = 08
   '8245'  = 08
   '8246'  = 08
   '8247'  = 08
   '8248'  = 08
   '8249'  = 08
   '8250'  = 08
   '8251'  = 08
   '82520' = 08
   '82521' = 08
   '82522' = 08
   '82523' = 08
   '82524' = 08
   '82525' = 08
   '82529' = 08
   '82530' = 08
   '82531' = 08
   '82532' = 08
   '82533' = 08
   '82534' = 08
   '82535' = 08
   '82539' = 08
   '8260'  = 08
   '8261'  = 08
   '8270'  = 08
   '8271'  = 08
   '8280'  = 21
   '8281'  = 21
   '8290'  = 08
   '8291'  = 08
   '8300'  = 03
   '8301'  = 03
   '83100' = 08
   '83101' = 08
   '83102' = 08
   '83103' = 08
   '83104' = 08
   '83109' = 08
   '83110' = 08
   '83111' = 08
   '83112' = 08
   '83113' = 08
   '83114' = 08
   '83119' = 08
   '83200' = 08
   '83201' = 08
   '83202' = 08
   '83203' = 08
   '83204' = 08
   '83209' = 08
   '83210' = 08
   '83211' = 08
   '83212' = 08
   '83213' = 08
   '83214' = 08
   '83219' = 08
   '8322'  = 08
   '83300' = 08
   '83301' = 08
   '83302' = 08
   '83303' = 08
   '83304' = 08
   '83305' = 08
   '83309' = 08
   '83310' = 08
   '83311' = 08
   '83312' = 08
   '83313' = 08
   '83314' = 08
   '83315' = 08
   '83319' = 08
   '83400' = 08
   '83401' = 08
   '83402' = 08
   '83410' = 08
   '83411' = 08
   '83412' = 08
   '83500' = 08
   '83501' = 08
   '83502' = 08
   '83503' = 08
   '83510' = 08
   '83511' = 08
   '83512' = 08
   '83513' = 08
   '8360'  = 08
   '8361'  = 08
   '8362'  = 08
   '8363'  = 08
   '8364'  = 08
   '83650' = 08
   '83651' = 08
   '83652' = 08
   '83653' = 08
   '83654' = 08
   '83659' = 08
   '83660' = 08
   '83661' = 08
   '83662' = 08
   '83663' = 08
   '83664' = 08
   '83669' = 08
   '8370'  = 08
   '8371'  = 08
   '83800' = 08
   '83801' = 08
   '83802' = 08
   '83803' = 08
   '83804' = 08
   '83805' = 08
   '83806' = 08
   '83809' = 08
   '83810' = 08
   '83811' = 08
   '83812' = 08
   '83813' = 08
   '83814' = 08
   '83815' = 08
   '83816' = 08
   '83819' = 08
   '83900' = 08
   '83901' = 08
   '83902' = 08
   '83903' = 08
   '83904' = 08
   '83905' = 08
   '83906' = 08
   '83907' = 08
   '83908' = 08
   '83910' = 08
   '83911' = 08
   '83912' = 08
   '83913' = 08
   '83914' = 08
   '83915' = 08
   '83916' = 08
   '83917' = 08
   '83918' = 08
   '83920' = 08
   '83921' = 08
   '83930' = 08
   '83931' = 08
   '83940' = 08
   '83941' = 08
   '83942' = 08
   '83949' = 08
   '83950' = 08
   '83951' = 08
   '83952' = 08
   '83959' = 08
   '83961' = 04
   '83969' = 08
   '83971' = 04
   '83979' = 08
   '8398'  = 08
   '8399'  = 08
   '8400'  = 08
   '8401'  = 08
   '8402'  = 08
   '8403'  = 08
   '8404'  = 08
   '8405'  = 08
   '8406'  = 08
   '8407'  = 08
   '8408'  = 08
   '8409'  = 08
   '8410'  = 08
   '8411'  = 08
   '8412'  = 08
   '8413'  = 08
   '8418'  = 08
   '8419'  = 08
   '84200' = 08
   '84201' = 08
   '84202' = 08
   '84209' = 08
   '84210' = 08
   '84211' = 08
   '84212' = 08
   '84213' = 08
   '84219' = 08
   '8430'  = 08
   '8431'  = 08
   '8438'  = 08
   '8439'  = 08
   '8440'  = 08
   '8441'  = 08
   '8442'  = 08
   '8443'  = 08
   '8448'  = 08
   '8449'  = 08
   '84500' = 08
   '84501' = 08
   '84502' = 08
   '84503' = 08
   '84509' = 08
   '84510' = 08
   '84511' = 08
   '84512' = 08
   '84513' = 08
   '84519' = 08
   '8460'  = 08
   '8461'  = 08
   '8462'  = 08
   '8463'  = 08
   '8468'  = 08
   '8469'  = 08
   '8470'  = 08
   '8471'  = 08
   '8472'  = 08
   '8473'  = 08
   '8474'  = 08
   '8479'  = 08
   '8480'  = 08
   '8481'  = 03
   '8482'  = 08
   '8483'  = 04
   '84840' = 04
   '84841' = 04
   '84842' = 04
   '84849' = 04
   '8485'  = 08
   '8488'  = 08
   '8489'  = 08
   '8500'  = 01
   '85011' = 01
   '85012' = 01
   '8502'  = 01
   '8503'  = 01
   '8504'  = 01
   '8505'  = 01
   '8509'  = 01
   '85100' = 01
   '85101' = 01
   '85102' = 01
   '85103' = 01
   '85104' = 01
   '85105' = 01
   '85106' = 01
   '85109' = 01
   '85110' = 01
   '85111' = 01
   '85112' = 01
   '85113' = 01
   '85114' = 01
   '85115' = 01
   '85116' = 01
   '85119' = 01
   '85120' = 01
   '85121' = 01
   '85122' = 01
   '85123' = 01
   '85124' = 01
   '85125' = 01
   '85126' = 01
   '85129' = 01
   '85130' = 01
   '85131' = 01
   '85132' = 01
   '85133' = 01
   '85134' = 01
   '85135' = 01
   '85136' = 01
   '85139' = 01
   '85140' = 01
   '85141' = 01
   '85142' = 01
   '85143' = 01
   '85144' = 01
   '85145' = 01
   '85146' = 01
   '85149' = 01
   '85150' = 01
   '85151' = 01
   '85152' = 01
   '85153' = 01
   '85154' = 01
   '85155' = 01
   '85156' = 01
   '85159' = 01
   '85160' = 01
   '85161' = 01
   '85162' = 01
   '85163' = 01
   '85164' = 01
   '85165' = 01
   '85166' = 01
   '85169' = 01
   '85170' = 01
   '85171' = 01
   '85172' = 01
   '85173' = 01
   '85174' = 01
   '85175' = 01
   '85176' = 01
   '85179' = 01
   '85180' = 01
   '85181' = 01
   '85182' = 01
   '85183' = 01
   '85184' = 01
   '85185' = 01
   '85186' = 01
   '85189' = 01
   '85190' = 01
   '85191' = 01
   '85192' = 01
   '85193' = 01
   '85194' = 01
   '85195' = 01
   '85196' = 01
   '85199' = 01
   '85200' = 01
   '85201' = 01
   '85202' = 01
   '85203' = 01
   '85204' = 01
   '85205' = 01
   '85206' = 01
   '85209' = 01
   '85210' = 01
   '85211' = 01
   '85212' = 01
   '85213' = 01
   '85214' = 01
   '85215' = 01
   '85216' = 01
   '85219' = 01
   '85220' = 01
   '85221' = 01
   '85222' = 01
   '85223' = 01
   '85224' = 01
   '85225' = 01
   '85226' = 01
   '85229' = 01
   '85230' = 01
   '85231' = 01
   '85232' = 01
   '85233' = 01
   '85234' = 01
   '85235' = 01
   '85236' = 01
   '85239' = 01
   '85240' = 01
   '85241' = 01
   '85242' = 01
   '85243' = 01
   '85244' = 01
   '85245' = 01
   '85246' = 01
   '85249' = 01
   '85250' = 01
   '85251' = 01
   '85252' = 01
   '85253' = 01
   '85254' = 01
   '85255' = 01
   '85256' = 01
   '85259' = 01
   '85300' = 01
   '85301' = 01
   '85302' = 01
   '85303' = 01
   '85304' = 01
   '85305' = 01
   '85306' = 01
   '85309' = 01
   '85310' = 01
   '85311' = 01
   '85312' = 01
   '85313' = 01
   '85314' = 01
   '85315' = 01
   '85316' = 01
   '85319' = 01
   '85400' = 01
   '85401' = 01
   '85402' = 01
   '85403' = 01
   '85404' = 01
   '85405' = 01
   '85406' = 01
   '85409' = 01
   '85410' = 01
   '85411' = 01
   '85412' = 01
   '85413' = 01
   '85414' = 01
   '85415' = 01
   '85416' = 01
   '85419' = 01
   '8600'  = 04
   '8601'  = 04
   '8602'  = 04
   '8603'  = 04
   '8604'  = 04
   '8605'  = 04
   '86100' = 05
   '86101' = 05
   '86102' = 05
   '86103' = 05
   '86110' = 05
   '86111' = 05
   '86112' = 05
   '86113' = 05
   '86120' = 04
   '86121' = 04
   '86122' = 04
   '86130' = 04
   '86131' = 04
   '86132' = 04
   '8620'  = 04
   '8621'  = 04
   '86221' = 04
   '86222' = 06
   '86229' = 04
   '86231' = 04
   '86232' = 06
   '86239' = 04
   '8628'  = 21
   '8629'  = 21
   '8630'  = 06
   '8631'  = 06
   '86320' = 06
   '86321' = 06
   '86329' = 06
   '86330' = 06
   '86331' = 06
   '86339' = 06
   '86340' = 06
   '86341' = 06
   '86342' = 06
   '86343' = 06
   '86344' = 06
   '86345' = 06
   '86346' = 06
   '86349' = 06
   '86350' = 06
   '86351' = 06
   '86352' = 06
   '86353' = 06
   '86354' = 06
   '86355' = 06
   '86356' = 06
   '86359' = 06
   '86380' = 06
   '86381' = 07
   '86382' = 07
   '86383' = 07
   '86384' = 07
   '86385' = 06
   '86389' = 06
   '86390' = 06
   '86391' = 07
   '86392' = 07
   '86393' = 07
   '86394' = 07
   '86395' = 06
   '86399' = 06
   '86400' = 07
   '86401' = 07
   '86402' = 07
   '86403' = 07
   '86404' = 07
   '86405' = 07
   '86409' = 07
   '86410' = 07
   '86411' = 07
   '86412' = 07
   '86413' = 07
   '86414' = 07
   '86415' = 07
   '86419' = 07
   '86500' = 16
   '86501' = 16
   '86502' = 16
   '86503' = 16
   '86504' = 16
   '86509' = 16
   '86510' = 16
   '86511' = 16
   '86512' = 16
   '86513' = 16
   '86514' = 16
   '86519' = 16
   '86600' = 11
   '86601' = 11
   '86602' = 11
   '86603' = 11
   '86610' = 11
   '86611' = 11
   '86612' = 11
   '86613' = 11
   '8670'  = 11
   '8671'  = 11
   '8672'  = 11
   '8673'  = 11
   '8674'  = 13
   '8675'  = 13
   '8676'  = 12
   '8677'  = 12
   '8678'  = 12
   '8679'  = 12
   '86800' = 06
   '86801' = 10
   '86802' = 07
   '86803' = 06
   '86804' = 11
   '86809' = 21
   '86810' = 06
   '86811' = 10
   '86812' = 07
   '86813' = 06
   '86814' = 11
   '86819' = 21
   '8690'  = 21
   '8691'  = 21
   '8700'  = 02
   '8701'  = 02
   '8702'  = 02
   '8703'  = 02
   '8704'  = 02
   '8708'  = 02
   '8709'  = 02
   '8710'  = 02
   '8711'  = 02
   '8712'  = 02
   '8713'  = 02
   '8714'  = 02
   '8715'  = 02
   '8716'  = 02
   '8717'  = 02
   '8719'  = 02
   '87200' = 03
   '87201' = 03
   '87202' = 03
   '87210' = 03
   '87211' = 03
   '87212' = 03
   '87261' = 03
   '87262' = 03
   '87263' = 03
   '87264' = 03
   '87269' = 03
   '87271' = 03
   '87272' = 03
   '87273' = 03
   '87274' = 03
   '87279' = 03
   '8728'  = 03
   '8729'  = 03
   '8730'  = 09
   '8731'  = 09
   '87320' = 03
   '87321' = 03
   '87322' = 03
   '87323' = 03
   '87329' = 03
   '87330' = 03
   '87331' = 03
   '87332' = 03
   '87333' = 03
   '87339' = 03
   '87340' = 09
   '87341' = 09
   '87342' = 09
   '87343' = 03
   '87344' = 03
   '87349' = 09
   '87350' = 09
   '87351' = 09
   '87352' = 09
   '87353' = 03
   '87354' = 03
   '87359' = 09
   '87360' = 03
   '87361' = 03
   '87362' = 03
   '87363' = 03
   '87364' = 03
   '87365' = 03
   '87369' = 03
   '87370' = 03
   '87371' = 03
   '87372' = 03
   '87373' = 03
   '87374' = 03
   '87375' = 03
   '87379' = 03
   '8738'  = 09
   '8739'  = 09
   '87400' = 03
   '87401' = 03
   '87402' = 04
   '87410' = 03
   '87411' = 03
   '87412' = 04
   '8742'  = 10
   '8743'  = 10
   '8744'  = 03
   '8745'  = 03
   '8748'  = 09
   '8749'  = 09
   '8750'  = 09
   '8751'  = 21
   '8760'  = 09
   '8761'  = 09
   '8770'  = 09
   '8771'  = 09
   '8780'  = 12
   '8781'  = 12
   '8782'  = 12
   '8783'  = 12
   '8784'  = 13
   '8785'  = 13
   '8786'  = 13
   '8787'  = 13
   '8788'  = 12
   '8789'  = 12
   '8790'  = 09
   '8791'  = 09
   '8792'  = 09
   '8793'  = 21
   '8794'  = 09
   '8795'  = 21
   '8796'  = 09
   '8797'  = 21
   '8798'  = 09
   '8799'  = 21
   '88000' = 09
   '88001' = 09
   '88002' = 09
   '88003' = 09
   '88009' = 09
   '88010' = 21
   '88011' = 21
   '88012' = 21
   '88013' = 21
   '88019' = 21
   '88020' = 08
   '88021' = 08
   '88022' = 08
   '88023' = 08
   '88029' = 08
   '88100' = 09
   '88101' = 09
   '88102' = 09
   '88110' = 21
   '88111' = 21
   '88112' = 21
   '88120' = 08
   '88121' = 08
   '88122' = 08
   '8820'  = 09
   '8821'  = 21
   '8822'  = 08
   '8830'  = 09
   '8831'  = 21
   '8832'  = 08
   '8840'  = 09
   '8841'  = 21
   '8842'  = 08
   '8850'  = 21
   '8851'  = 21
   '8860'  = 21
   '8861'  = 21
   '8870'  = 21
   '8871'  = 21
   '8872'  = 21
   '8873'  = 21
   '8874'  = 21
   '8875'  = 21
   '8876'  = 21
   '8877'  = 21
   '8900'  = 09
   '8901'  = 21
   '8902'  = 08
   '8910'  = 09
   '8911'  = 21
   '8912'  = 08
   '8920'  = 09
   '8921'  = 21
   '8922'  = 08
   '8930'  = 09
   '8931'  = 21
   '8932'  = 08
   '8940'  = 09
   '8941'  = 21
   '8942'  = 08
   '8950'  = 21
   '8951'  = 21
   '8960'  = 21
   '8961'  = 21
   '8962'  = 21
   '8963'  = 21
   '8970'  = 21
   '8971'  = 21
   '8972'  = 21
   '8973'  = 21
   '8974'  = 21
   '8975'  = 21
   '8976'  = 21
   '8977'  = 21
   '90000' = 21
   '90001' = 21
   '90002' = 21
   '90003' = 21
   '9001'  = 21
   '90081' = 21
   '90082' = 21
   '90089' = 21
   '9009'  = 21
   '9010'  = 21
   '9011'  = 21
   '9012'  = 21
   '9013'  = 21
   '90140' = 21
   '90141' = 21
   '90142' = 21
   '90181' = 21
   '90182' = 21
   '90183' = 21
   '90189' = 21
   '9019'  = 21
   '9020'  = 21
   '90210' = 21
   '90211' = 21
   '90219' = 21
   '90220' = 21
   '90221' = 21
   '90222' = 21
   '90223' = 21
   '90224' = 21
   '90225' = 21
   '90226' = 21
   '90227' = 21
   '90229' = 21
   '90231' = 21
   '90232' = 21
   '90233' = 21
   '90234' = 21
   '90239' = 21
   '90240' = 21
   '90241' = 21
   '90242' = 21
   '90249' = 21
   '90250' = 21
   '90251' = 21
   '90252' = 21
   '90253' = 21
   '90254' = 21
   '90255' = 21
   '90256' = 21
   '90259' = 21
   '90281' = 21
   '90282' = 21
   '90287' = 21
   '90289' = 21
   '9029'  = 21
   '90300' = 21
   '90301' = 21
   '90302' = 21
   '9031'  = 21
   '9032'  = 21
   '9033'  = 21
   '9034'  = 21
   '9035'  = 21
   '9038'  = 21
   '9039'  = 21
   '9040'  = 21
   '9041'  = 21
   '9042'  = 21
   '9043'  = 21
   '90440' = 21
   '90441' = 21
   '90442' = 21
   '90450' = 21
   '90451' = 21
   '90452' = 21
   '90453' = 21
   '90454' = 21
   '9046'  = 21
   '9047'  = 21
   '9048'  = 21
   '9049'  = 21
   '9050'  = 01
   '9051'  = 08
   '9052'  = 08
   '9053'  = 08
   '9054'  = 08
   '9055'  = 08
   '9056'  = 08
   '9057'  = 08
   '9058'  = 08
   '9059'  = 08
   '9060'  = 09
   '9061'  = 09
   '9062'  = 09
   '9063'  = 09
   '9064'  = 09
   '9065'  = 09
   '9066'  = 09
   '9067'  = 09
   '9068'  = 09
   '9069'  = 09
   '9070'  = 01
   '9071'  = 01
   '9072'  = 01
   '9073'  = 01
   '9074'  = 01
   '9075'  = 01
   '9079'  = 01
   '9080'  = 04
   '9081'  = 06
   '9082'  = 12
   '9083'  = 05
   '9084'  = 05
   '9085'  = 21
   '9086'  = 21
   '9089'  = 21
   '9090'  = 21
   '9091'  = 21
   '9092'  = 21
   '9093'  = 21
   '9094'  = 21
   '9095'  = 21
   '9099'  = 21
   '9100'  = 09
   '9101'  = 09
   '9102'  = 09
   '9103'  = 09
   '9104'  = 09
   '9105'  = 09
   '9106'  = 09
   '9107'  = 09
   '9108'  = 09
   '9109'  = 09
   '9110'  = 09
   '9111'  = 09
   '9112'  = 09
   '9113'  = 09
   '9114'  = 09
   '9115'  = 09
   '9116'  = 09
   '9117'  = 09
   '9118'  = 09
   '9119'  = 09
   '9120'  = 09
   '9121'  = 09
   '9122'  = 09
   '9123'  = 09
   '9124'  = 09
   '9125'  = 09
   '9126'  = 09
   '9127'  = 09
   '9128'  = 09
   '9129'  = 09
   '9130'  = 09
   '9131'  = 09
   '9132'  = 09
   '9133'  = 09
   '9134'  = 09
   '9135'  = 09
   '9136'  = 09
   '9137'  = 09
   '9138'  = 09
   '9139'  = 09
   '9140'  = 09
   '9141'  = 09
   '9142'  = 09
   '9143'  = 09
   '9144'  = 09
   '9145'  = 09
   '9146'  = 09
   '9147'  = 09
   '9148'  = 09
   '9149'  = 09
   '9150'  = 09
   '9151'  = 09
   '9152'  = 09
   '9153'  = 09
   '9154'  = 09
   '9155'  = 09
   '9156'  = 09
   '9157'  = 09
   '9158'  = 09
   '9159'  = 09
   '9160'  = 09
   '9161'  = 09
   '9162'  = 09
   '9163'  = 09
   '9164'  = 09
   '9165'  = 09
   '9166'  = 09
   '9167'  = 09
   '9168'  = 09
   '9169'  = 09
   '9170'  = 09
   '9171'  = 09
   '9172'  = 09
   '9173'  = 09
   '9174'  = 09
   '9175'  = 09
   '9176'  = 09
   '9177'  = 09
   '9178'  = 09
   '9179'  = 09
   '9180'  = 02
   '9181'  = 02
   '9182'  = 02
   '9189'  = 02
   '9190'  = 09
   '9191'  = 09
   '9192'  = 09
   '9193'  = 09
   '9194'  = 09
   '9195'  = 09
   '9196'  = 09
   '9197'  = 09
   '9198'  = 09
   '9199'  = 09
   '920'   = 09
   '9210'  = 02
   '9211'  = 02
   '9212'  = 02
   '9213'  = 02
   '9219'  = 02
   '9220'  = 09
   '9221'  = 09
   '9222'  = 09
   '92231' = 09
   '92232' = 09
   '92233' = 09
   '9224'  = 12
   '9228'  = 09
   '9229'  = 09
   '92300' = 09
   '92301' = 09
   '92302' = 09
   '92303' = 09
   '92309' = 09
   '92310' = 09
   '92311' = 09
   '92320' = 09
   '92321' = 09
   '9233'  = 09
   '9238'  = 09
   '9239'  = 09
   '92400' = 09
   '92401' = 09
   '92410' = 09
   '92411' = 09
   '92420' = 09
   '92421' = 09
   '9243'  = 09
   '9244'  = 09
   '9245'  = 09
   '9248'  = 09
   '9249'  = 09
   '9251'  = 21
   '9252'  = 21
   '9260'  = 12
   '92611' = 21
   '92612' = 21
   '92619' = 21
   '9268'  = 21
   '9269'  = 21
   '92700' = 21
   '92701' = 21
   '92702' = 21
   '92703' = 21
   '92709' = 21
   '92710' = 21
   '92711' = 21
   '92720' = 21
   '92721' = 21
   '9273'  = 21
   '9278'  = 21
   '9279'  = 21
   '92800' = 21
   '92801' = 21
   '92810' = 21
   '92811' = 21
   '92820' = 21
   '92821' = 21
   '9283'  = 21
   '9288'  = 21
   '9289'  = 21
   '9290'  = 21
   '9299'  = 21
   '9300'  = 02
   '9301'  = 02
   '9302'  = 02
   '9308'  = 02
   '9309'  = 02
   '931'   = 03
   '932'   = 03
   '9330'  = 03
   '9331'  = 03
   '9340'  = 04
   '9341'  = 04
   '9348'  = 04
   '9349'  = 04
   '9350'  = 03
   '9351'  = 06
   '9352'  = 06
   '936'   = 06
   '937'   = 06
   '938'   = 06
   '9390'  = 11
   '9391'  = 13
   '9392'  = 13
   '9393'  = 12
   '9399'  = 11
   '9400'  = 02
   '9401'  = 02
   '9402'  = 02
   '9403'  = 02
   '9404'  = 02
   '9405'  = 02
   '9409'  = 02
   '94100' = 22
   '94101' = 22
   '94102' = 02
   '94103' = 22
   '94104' = 22
   '94105' = 22
   '94106' = 22
   '94107' = 22
   '94108' = 22
   '94109' = 22
   '94110' = 22
   '94111' = 22
   '94112' = 02
   '94113' = 22
   '94114' = 22
   '94115' = 22
   '94116' = 22
   '94117' = 22
   '94118' = 22
   '94119' = 22
   '94120' = 22
   '94121' = 22
   '94122' = 02
   '94123' = 22
   '94124' = 22
   '94125' = 22
   '94126' = 22
   '94127' = 22
   '94128' = 22
   '94129' = 22
   '94130' = 22
   '94131' = 22
   '94132' = 02
   '94133' = 22
   '94134' = 22
   '94135' = 22
   '94136' = 22
   '94137' = 22
   '94138' = 22
   '94139' = 22
   '94140' = 22
   '94141' = 22
   '94142' = 02
   '94143' = 22
   '94144' = 22
   '94145' = 22
   '94146' = 22
   '94147' = 22
   '94148' = 22
   '94149' = 22
   '94150' = 22
   '94151' = 22
   '94152' = 02
   '94153' = 22
   '94154' = 22
   '94155' = 22
   '94156' = 22
   '94157' = 22
   '94158' = 22
   '94159' = 22
   '94200' = 22
   '94201' = 22
   '94202' = 22
   '94203' = 22
   '94204' = 22
   '94205' = 22
   '94209' = 22
   '94210' = 22
   '94211' = 22
   '94212' = 22
   '94213' = 22
   '94214' = 22
   '94215' = 22
   '94219' = 22
   '94220' = 22
   '94221' = 22
   '94222' = 22
   '94223' = 22
   '94224' = 22
   '94225' = 22
   '94229' = 22
   '94230' = 22
   '94231' = 22
   '94232' = 22
   '94233' = 22
   '94234' = 22
   '94235' = 22
   '94239' = 22
   '94240' = 22
   '94241' = 22
   '94242' = 22
   '94243' = 22
   '94244' = 22
   '94245' = 22
   '94249' = 22
   '94250' = 22
   '94251' = 22
   '94252' = 22
   '94253' = 22
   '94254' = 22
   '94255' = 22
   '94259' = 22
   '94300' = 22
   '94301' = 22
   '94302' = 22
   '94303' = 22
   '94304' = 22
   '94305' = 22
   '94306' = 22
   '94309' = 22
   '94310' = 22
   '94311' = 22
   '94312' = 22
   '94313' = 22
   '94314' = 22
   '94315' = 22
   '94316' = 22
   '94319' = 22
   '94320' = 22
   '94321' = 22
   '94322' = 22
   '94323' = 22
   '94324' = 22
   '94325' = 22
   '94326' = 22
   '94329' = 22
   '94330' = 22
   '94331' = 22
   '94332' = 22
   '94333' = 22
   '94334' = 22
   '94335' = 22
   '94336' = 22
   '94339' = 22
   '94340' = 22
   '94341' = 22
   '94342' = 22
   '94343' = 22
   '94344' = 22
   '94345' = 22
   '94346' = 22
   '94349' = 22
   '94350' = 22
   '94351' = 22
   '94352' = 22
   '94353' = 22
   '94354' = 22
   '94355' = 22
   '94356' = 22
   '94359' = 22
   '94400' = 22
   '94401' = 22
   '94402' = 22
   '94403' = 22
   '94404' = 22
   '94405' = 22
   '94406' = 22
   '94407' = 22
   '94408' = 22
   '94410' = 22
   '94411' = 22
   '94412' = 22
   '94413' = 22
   '94414' = 22
   '94415' = 22
   '94416' = 22
   '94417' = 22
   '94418' = 22
   '94420' = 22
   '94421' = 22
   '94422' = 22
   '94423' = 22
   '94424' = 22
   '94425' = 22
   '94426' = 22
   '94427' = 22
   '94428' = 22
   '94430' = 22
   '94431' = 22
   '94432' = 22
   '94433' = 22
   '94434' = 22
   '94435' = 22
   '94436' = 22
   '94437' = 22
   '94438' = 22
   '94440' = 22
   '94441' = 22
   '94442' = 22
   '94443' = 22
   '94444' = 22
   '94445' = 22
   '94446' = 22
   '94447' = 22
   '94448' = 22
   '94450' = 22
   '94451' = 22
   '94452' = 22
   '94453' = 22
   '94454' = 22
   '94455' = 22
   '94456' = 22
   '94457' = 22
   '94458' = 22
   '94500' = 22
   '94501' = 22
   '94502' = 22
   '94503' = 22
   '94504' = 22
   '94505' = 22
   '94506' = 22
   '94509' = 22
   '94510' = 22
   '94511' = 22
   '94512' = 22
   '94513' = 22
   '94514' = 22
   '94515' = 22
   '94516' = 22
   '94519' = 22
   '94520' = 22
   '94521' = 22
   '94522' = 22
   '94523' = 22
   '94524' = 22
   '94525' = 22
   '94526' = 22
   '94529' = 22
   '94530' = 22
   '94531' = 22
   '94532' = 22
   '94533' = 22
   '94534' = 22
   '94535' = 22
   '94536' = 22
   '94539' = 22
   '94540' = 22
   '94541' = 22
   '94542' = 22
   '94543' = 22
   '94544' = 22
   '94545' = 22
   '94546' = 22
   '94549' = 22
   '94550' = 22
   '94551' = 22
   '94552' = 22
   '94553' = 22
   '94554' = 22
   '94555' = 22
   '94556' = 22
   '94559' = 22
   '9460'  = 22
   '9461'  = 22
   '9462'  = 22
   '9463'  = 22
   '9464'  = 22
   '9465'  = 22
   '9470'  = 03
   '9471'  = 04
   '9472'  = 06
   '9473'  = 06
   '9474'  = 13
   '9478'  = 22
   '9479'  = 22
   '94800' = 22
   '94810' = 22
   '94811' = 22
   '94820' = 22
   '94821' = 22
   '94822' = 22
   '94830' = 22
   '94831' = 22
   '94832' = 22
   '94833' = 22
   '94840' = 22
   '94841' = 22
   '94842' = 22
   '94843' = 22
   '94844' = 22
   '94850' = 22
   '94851' = 22
   '94852' = 22
   '94853' = 22
   '94854' = 22
   '94855' = 22
   '94860' = 22
   '94861' = 22
   '94862' = 22
   '94863' = 22
   '94864' = 22
   '94865' = 22
   '94866' = 22
   '94870' = 22
   '94871' = 22
   '94872' = 22
   '94873' = 22
   '94874' = 22
   '94875' = 22
   '94876' = 22
   '94877' = 22
   '94880' = 22
   '94881' = 22
   '94882' = 22
   '94883' = 22
   '94884' = 22
   '94885' = 22
   '94886' = 22
   '94887' = 22
   '94888' = 22
   '94890' = 22
   '94891' = 22
   '94892' = 22
   '94893' = 22
   '94894' = 22
   '94895' = 22
   '94896' = 22
   '94897' = 22
   '94898' = 22
   '94899' = 22
   '9490'  = 22
   '9491'  = 22
   '9492'  = 22
   '9493'  = 22
   '9494'  = 22
   '9495'  = 22
   '9500'  = 02
   '9501'  = 01
   '9502'  = 01
   '9503'  = 01
   '9509'  = 01
   '9510'  = 01
   '9511'  = 01
   '9512'  = 01
   '9513'  = 01
   '9514'  = 01
   '9515'  = 03
   '9516'  = 01
   '9517'  = 01
   '9518'  = 01
   '9519'  = 01
   '95200' = 01
   '95201' = 01
   '95202' = 01
   '95203' = 01
   '95204' = 01
   '95205' = 01
   '95206' = 01
   '95207' = 01
   '95208' = 01
   '95209' = 01
   '95210' = 01
   '95211' = 01
   '95212' = 01
   '95213' = 01
   '95214' = 01
   '95215' = 01
   '95216' = 01
   '95217' = 01
   '95218' = 01
   '95219' = 01
   '9522'  = 01
   '9523'  = 01
   '9524'  = 01
   '9528'  = 01
   '9529'  = 01
   '9530'  = 01
   '9531'  = 01
   '9532'  = 01
   '9533'  = 01
   '9534'  = 01
   '9535'  = 01
   '9538'  = 01
   '9539'  = 01
   '9540'  = 01
   '9541'  = 01
   '9548'  = 01
   '9549'  = 01
   '9550'  = 01
   '9551'  = 01
   '9552'  = 01
   '9553'  = 01
   '9554'  = 01
   '9555'  = 01
   '9556'  = 01
   '9557'  = 01
   '9558'  = 01
   '9559'  = 01
   '9560'  = 01
   '9561'  = 01
   '9562'  = 01
   '9563'  = 01
   '9564'  = 01
   '9565'  = 01
   '9568'  = 01
   '9569'  = 01
   '9570'  = 01
   '9571'  = 01
   '9578'  = 01
   '9579'  = 01
   '9580'  = 04
   '9581'  = 04
   '9582'  = 21
   '9583'  = 18
   '9584'  = 21
   '9585'  = 11
   '9586'  = 08
   '9587'  = 04
   '9588'  = 21
   '95890' = 21
   '95891' = 21
   '95892' = 21
   '95893' = 21
   '95899' = 21
   '95901' = 21
   '95909' = 21
   '95911' = 21
   '95912' = 21
   '95913' = 21
   '95914' = 21
   '95919' = 21
   '9592'  = 21
   '9593'  = 21
   '9594'  = 21
   '9595'  = 21
   '9596'  = 21
   '9597'  = 21
   '9598'  = 21
   '9599'  = 21
   '9600'  = 21
   '9601'  = 21
   '9602'  = 21
   '9603'  = 21
   '9604'  = 21
   '9605'  = 21
   '9606'  = 21
   '9607'  = 21
   '9608'  = 21
   '9609'  = 21
   '9610'  = 21
   '9611'  = 21
   '9612'  = 21
   '9613'  = 21
   '9614'  = 21
   '9615'  = 21
   '9616'  = 21
   '9617'  = 21
   '9618'  = 21
   '9619'  = 21
   '9620'  = 21
   '9621'  = 21
   '9622'  = 21
   '9623'  = 21
   '9624'  = 21
   '9625'  = 21
   '9626'  = 21
   '9627'  = 21
   '9628'  = 21
   '9629'  = 21
   '9630'  = 21
   '9631'  = 21
   '9632'  = 21
   '9633'  = 21
   '9634'  = 21
   '9635'  = 21
   '9638'  = 21
   '9639'  = 21
   '9640'  = 21
   '9641'  = 21
   '9642'  = 21
   '9643'  = 21
   '9644'  = 21
   '9645'  = 21
   '9646'  = 21
   '9647'  = 21
   '9648'  = 21
   '9649'  = 21
   '96500' = 21
   '96501' = 21
   '96502' = 21
   '96509' = 21
   '9651'  = 21
   '9654'  = 21
   '9655'  = 21
   '96561' = 21
   '96569' = 21
   '9657'  = 21
   '9658'  = 21
   '9659'  = 21
   '9660'  = 21
   '9661'  = 21
   '9662'  = 21
   '9663'  = 21
   '9664'  = 21
   '9670'  = 21
   '9671'  = 21
   '9672'  = 21
   '9673'  = 21
   '9674'  = 21
   '9675'  = 21
   '9676'  = 21
   '9678'  = 21
   '9679'  = 21
   '9680'  = 21
   '9681'  = 21
   '9682'  = 21
   '9683'  = 21
   '9684'  = 21
   '9685'  = 21
   '9686'  = 21
   '9687'  = 21
   '9689'  = 21
   '96900' = 21
   '96901' = 21
   '96902' = 21
   '96903' = 21
   '96904' = 21
   '96905' = 21
   '96909' = 21
   '9691'  = 21
   '9692'  = 21
   '9693'  = 21
   '9694'  = 21
   '9695'  = 21
   '9696'  = 21
   '96970' = 21
   '96971' = 21
   '96972' = 21
   '96973' = 21
   '96979' = 21
   '9698'  = 21
   '9699'  = 21
   '9700'  = 21
   '9701'  = 21
   '97081' = 21
   '97089' = 21
   '9709'  = 21
   '9710'  = 21
   '9711'  = 21
   '9712'  = 21
   '9713'  = 21
   '9719'  = 21
   '9720'  = 21
   '9721'  = 21
   '9722'  = 21
   '9723'  = 21
   '9724'  = 21
   '9725'  = 21
   '9726'  = 21
   '9727'  = 21
   '9728'  = 21
   '9729'  = 21
   '9730'  = 21
   '9731'  = 21
   '9732'  = 21
   '9733'  = 21
   '9734'  = 21
   '9735'  = 21
   '9736'  = 21
   '9738'  = 21
   '9739'  = 21
   '9740'  = 21
   '9741'  = 21
   '9742'  = 21
   '9743'  = 21
   '9744'  = 21
   '9745'  = 21
   '9746'  = 21
   '9747'  = 21
   '9750'  = 21
   '9751'  = 21
   '9752'  = 21
   '9753'  = 21
   '9754'  = 21
   '9755'  = 21
   '9756'  = 21
   '9757'  = 21
   '9758'  = 21
   '9760'  = 21
   '9761'  = 21
   '9762'  = 21
   '9763'  = 21
   '9764'  = 21
   '9765'  = 02
   '9766'  = 21
   '9767'  = 21
   '9768'  = 21
   '9769'  = 21
   '9770'  = 21
   '9771'  = 21
   '9772'  = 21
   '9773'  = 21
   '9774'  = 21
   '9778'  = 21
   '9779'  = 21
   '9780'  = 21
   '9781'  = 21
   '9782'  = 21
   '9783'  = 21
   '9784'  = 21
   '9785'  = 21
   '9786'  = 21
   '9788'  = 21
   '9789'  = 21
   '9790'  = 21
   '9791'  = 21
   '9792'  = 21
   '9793'  = 21
   '9794'  = 21
   '9795'  = 21
   '9796'  = 21
   '9797'  = 21
   '9799'  = 21
   '9800'  = 21
   '9801'  = 21
   '9802'  = 21
   '9803'  = 21
   '9808'  = 21
   '9809'  = 21
   '981'   = 21
   '9820'  = 21
   '9821'  = 21
   '9822'  = 21
   '9823'  = 21
   '9824'  = 21
   '9828'  = 21
   '9830'  = 21
   '9831'  = 21
   '9832'  = 21
   '9839'  = 21
   '9840'  = 21
   '9841'  = 21
   '9848'  = 21
   '9849'  = 21
   '9850'  = 21
   '9851'  = 21
   '9852'  = 21
   '9853'  = 21
   '9854'  = 21
   '9855'  = 21
   '9856'  = 21
   '9858'  = 21
   '9859'  = 21
   '986'   = 21
   '9870'  = 21
   '9871'  = 21
   '9872'  = 21
   '9873'  = 21
   '9874'  = 21
   '9875'  = 21
   '9876'  = 21
   '9877'  = 21
   '9878'  = 21
   '9879'  = 21
   '9880'  = 21
   '9881'  = 21
   '9882'  = 21
   '9888'  = 21
   '9889'  = 21
   '9890'  = 21
   '9891'  = 21
   '9892'  = 21
   '9893'  = 21
   '9894'  = 21
   '9895'  = 21
   '9896'  = 21
   '9897'  = 21
   '98981' = 21
   '98982' = 21
   '98983' = 21
   '98984' = 21
   '98989' = 21
   '9899'  = 21
   '990'   = 21
   '9910'  = 21
   '9911'  = 21
   '9912'  = 21
   '9913'  = 21
   '9914'  = 21
   '9915'  = 21
   '9916'  = 21
   '9918'  = 21
   '9919'  = 21
   '9920'  = 21
   '9921'  = 21
   '9922'  = 21
   '9923'  = 21
   '9924'  = 21
   '9925'  = 21
   '9926'  = 21
   '9927'  = 21
   '9928'  = 21
   '9929'  = 21
   '9930'  = 03
   '9931'  = 03
   '9932'  = 21
   '9933'  = 21
   '9934'  = 21
   '9938'  = 21
   '9939'  = 21
   '9940'  = 21
   '9941'  = 21
   '9942'  = 21
   '9943'  = 21
   '9944'  = 21
   '9945'  = 21
   '9946'  = 03
   '9947'  = 21
   '9948'  = 21
   '9949'  = 21
   '9950'  = 21
   '9951'  = 21
   '99520' = 21
   '99521' = 21
   '99522' = 21
   '99523' = 21
   '99524' = 21
   '99527' = 21
   '99529' = 21
   '9953'  = 21
   '9954'  = 21
   '99550' = 21
   '99551' = 21
   '99552' = 21
   '99553' = 21
   '99554' = 21
   '99555' = 21
   '99559' = 21
   '99560' = 21
   '99561' = 21
   '99562' = 21
   '99563' = 21
   '99564' = 21
   '99565' = 21
   '99566' = 21
   '99567' = 21
   '99568' = 21
   '99569' = 21
   '9957'  = 21
   '99580' = 21
   '99581' = 21
   '99582' = 21
   '99583' = 21
   '99584' = 21
   '99585' = 21
   '99586' = 21
   '99589' = 21
   '99590' = 18
   '99591' = 18
   '99592' = 18
   '99593' = 18
   '99594' = 18
   '99600' = 05
   '99601' = 05
   '99602' = 05
   '99603' = 05
   '99604' = 05
   '99609' = 05
   '9961'  = 05
   '9962'  = 01
   '99630' = 11
   '99631' = 11
   '99632' = 13
   '99639' = 11
   '99640' = 08
   '99641' = 08
   '99642' = 08
   '99643' = 08
   '99644' = 08
   '99645' = 08
   '99646' = 08
   '99647' = 08
   '99649' = 08
   '99651' = 02
   '99652' = 21
   '99653' = 02
   '99654' = 09
   '99655' = 21
   '99656' = 21
   '99657' = 21
   '99659' = 21
   '99660' = 21
   '99661' = 05
   '99662' = 05
   '99663' = 01
   '99664' = 11
   '99665' = 11
   '99666' = 08
   '99667' = 08
   '99668' = 21
   '99669' = 21
   '99670' = 21
   '99671' = 05
   '99672' = 05
   '99673' = 05
   '99674' = 05
   '99675' = 01
   '99676' = 11
   '99677' = 08
   '99678' = 08
   '99679' = 21
   '99680' = 21
   '99681' = 11
   '99682' = 07
   '99683' = 05
   '99684' = 04
   '99685' = 16
   '99686' = 07
   '99687' = 21
   '99688' = 21
   '99689' = 21
   '99690' = 08
   '99691' = 08
   '99692' = 08
   '99693' = 08
   '99694' = 08
   '99695' = 08
   '99696' = 08
   '99699' = 08
   '99700' = 01
   '99701' = 01
   '99702' = 01
   '99709' = 01
   '9971'  = 05
   '9972'  = 05
   '99731' = 04
   '99732' = 04
   '99739' = 04
   '99741' = 06
   '99749' = 06
   '9975'  = 11
   '99760' = 08
   '99761' = 08
   '99762' = 08
   '99769' = 08
   '99771' = 06
   '99772' = 11
   '99779' = 05
   '99791' = 21
   '99799' = 21
   '99800' = 21
   '99801' = 21
   '99802' = 21
   '99809' = 21
   '99811' = 21
   '99812' = 21
   '99813' = 21
   '9982'  = 21
   '99830' = 21
   '99831' = 21
   '99832' = 21
   '99833' = 21
   '9984'  = 21
   '99851' = 18
   '99859' = 18
   '9986'  = 21
   '9987'  = 21
   '99881' = 21
   '99882' = 02
   '99883' = 21
   '99889' = 21
   '9989'  = 21
   '9990'  = 18
   '9991'  = 04
   '9992'  = 05
   '99931' = 05
   '99932' = 05
   '99933' = 05
   '99934' = 18
   '99939' = 18
   '99941' = 21
   '99942' = 21
   '99949' = 21
   '99951' = 21
   '99952' = 21
   '99959' = 21
   '99960' = 16
   '99961' = 16
   '99962' = 16
   '99963' = 16
   '99969' = 16
   '99970' = 16
   '99971' = 16
   '99972' = 16
   '99973' = 16
   '99974' = 16
   '99975' = 16
   '99976' = 16
   '99977' = 16
   '99978' = 16
   '99979' = 16
   '99980' = 16
   '99981' = 05
   '99982' = 05
   '99983' = 16
   '99984' = 16
   '99985' = 16
   '99988' = 05
   '99989' = 16
   '9999'  = 21
   'V010'  = 23
   'V011'  = 23
   'V012'  = 23
   'V013'  = 23
   'V014'  = 23
   'V015'  = 23
   'V016'  = 23
   'V0171' = 23
   'V0179' = 23
   'V0181' = 23
   'V0182' = 23
   'V0183' = 23
   'V0184' = 23
   'V0189' = 23
   'V019'  = 23
   'V020'  = 23
   'V021'  = 23
   'V022'  = 23
   'V023'  = 23
   'V024'  = 23
   'V0251' = 23
   'V0252' = 23
   'V0253' = 23
   'V0254' = 23
   'V0259' = 23
   'V0260' = 07
   'V0261' = 07
   'V0262' = 07
   'V0269' = 07
   'V027'  = 23
   'V028'  = 23
   'V029'  = 23
   'V030'  = 23
   'V031'  = 23
   'V032'  = 23
   'V033'  = 23
   'V034'  = 23
   'V035'  = 23
   'V036'  = 23
   'V037'  = 23
   'V0381' = 23
   'V0382' = 23
   'V0389' = 23
   'V039'  = 23
   'V040'  = 23
   'V041'  = 23
   'V042'  = 23
   'V043'  = 23
   'V044'  = 23
   'V045'  = 23
   'V046'  = 23
   'V047'  = 23
   'V0481' = 23
   'V0482' = 23
   'V0489' = 23
   'V050'  = 23
   'V051'  = 23
   'V052'  = 23
   'V053'  = 23
   'V054'  = 23
   'V058'  = 23
   'V059'  = 23
   'V060'  = 23
   'V061'  = 23
   'V062'  = 23
   'V063'  = 23
   'V064'  = 23
   'V065'  = 23
   'V066'  = 23
   'V068'  = 23
   'V069'  = 23
   'V070'  = 23
   'V071'  = 23
   'V072'  = 23
   'V0731' = 23
   'V0739' = 23
   'V074'  = 23
   'V0751' = 23
   'V0752' = 23
   'V0759' = 23
   'V078'  = 23
   'V079'  = 23
   'V08'   = 18
   'V090'  = 18
   'V091'  = 18
   'V092'  = 18
   'V093'  = 18
   'V094'  = 18
   'V0950' = 18
   'V0951' = 18
   'V096'  = 18
   'V0970' = 18
   'V0971' = 18
   'V0980' = 18
   'V0981' = 18
   'V0990' = 18
   'V0991' = 18
   'V1000' = 17
   'V1001' = 17
   'V1002' = 17
   'V1003' = 17
   'V1004' = 17
   'V1005' = 17
   'V1006' = 17
   'V1007' = 17
   'V1009' = 17
   'V1011' = 17
   'V1012' = 17
   'V1020' = 17
   'V1021' = 17
   'V1022' = 17
   'V1029' = 17
   'V103'  = 17
   'V1040' = 17
   'V1041' = 17
   'V1042' = 17
   'V1043' = 17
   'V1044' = 17
   'V1045' = 17
   'V1046' = 17
   'V1047' = 17
   'V1048' = 17
   'V1049' = 17
   'V1050' = 17
   'V1051' = 17
   'V1052' = 17
   'V1053' = 17
   'V1059' = 17
   'V1060' = 17
   'V1061' = 17
   'V1062' = 17
   'V1063' = 17
   'V1069' = 17
   'V1071' = 17
   'V1072' = 17
   'V1079' = 17
   'V1081' = 17
   'V1082' = 17
   'V1083' = 17
   'V1084' = 17
   'V1085' = 17
   'V1086' = 17
   'V1087' = 17
   'V1088' = 17
   'V1089' = 17
   'V1090' = 17
   'V1091' = 17
   'V110'  = 23
   'V111'  = 23
   'V112'  = 23
   'V113'  = 23
   'V114'  = 23
   'V118'  = 23
   'V119'  = 23
   'V1200' = 23
   'V1201' = 23
   'V1202' = 23
   'V1203' = 23
   'V1204' = 23
   'V1209' = 23
   'V121'  = 23
   'V1221' = 23
   'V1229' = 23
   'V123'  = 23
   'V1240' = 23
   'V1241' = 23
   'V1242' = 23
   'V1249' = 23
   'V1250' = 23
   'V1251' = 23
   'V1252' = 23
   'V1253' = 23
   'V1254' = 23
   'V1255' = 23
   'V1259' = 23
   'V1260' = 23
   'V1261' = 23
   'V1269' = 23
   'V1270' = 23
   'V1271' = 23
   'V1272' = 23
   'V1279' = 23
   'V1300' = 23
   'V1301' = 23
   'V1302' = 23
   'V1303' = 23
   'V1309' = 23
   'V131'  = 23
   'V1321' = 23
   'V1322' = 17
   'V1323' = 23
   'V1324' = 23
   'V1329' = 23
   'V133'  = 23
   'V134'  = 23
   'V1351' = 23
   'V1352' = 23
   'V1359' = 23
   'V1361' = 23
   'V1362' = 23
   'V1363' = 23
   'V1364' = 23
   'V1365' = 23
   'V1366' = 23
   'V1367' = 23
   'V1368' = 23
   'V1369' = 23
   'V137'  = 23
   'V1381' = 23
   'V1389' = 23
   'V139'  = 23
   'V140'  = 23
   'V141'  = 23
   'V142'  = 23
   'V143'  = 23
   'V144'  = 23
   'V145'  = 23
   'V146'  = 23
   'V147'  = 23
   'V148'  = 23
   'V149'  = 23
   'V1501' = 23
   'V1502' = 23
   'V1503' = 23
   'V1504' = 23
   'V1505' = 23
   'V1506' = 23
   'V1507' = 23
   'V1508' = 23
   'V1509' = 23
   'V151'  = 23
   'V1521' = 23
   'V1522' = 23
   'V1529' = 23
   'V153'  = 23
   'V1541' = 23
   'V1542' = 23
   'V1549' = 23
   'V1551' = 23
   'V1552' = 23
   'V1553' = 23
   'V1559' = 23
   'V156'  = 23
   'V157'  = 23
   'V1580' = 23
   'V1581' = 23
   'V1582' = 23
   'V1583' = 23
   'V1584' = 23
   'V1585' = 23
   'V1586' = 23
   'V1587' = 23
   'V1588' = 23
   'V1589' = 23
   'V159'  = 23
   'V160'  = 23
   'V161'  = 23
   'V162'  = 23
   'V163'  = 23
   'V1640' = 23
   'V1641' = 23
   'V1642' = 23
   'V1643' = 23
   'V1649' = 23
   'V1651' = 23
   'V1652' = 23
   'V1659' = 23
   'V166'  = 23
   'V167'  = 23
   'V168'  = 23
   'V169'  = 23
   'V170'  = 23
   'V171'  = 23
   'V172'  = 23
   'V173'  = 23
   'V1741' = 23
   'V1749' = 23
   'V175'  = 23
   'V176'  = 23
   'V177'  = 23
   'V1781' = 23
   'V1789' = 23
   'V180'  = 23
   'V1811' = 23
   'V1819' = 23
   'V182'  = 23
   'V183'  = 23
   'V184'  = 23
   'V1851' = 23
   'V1859' = 23
   'V1861' = 23
   'V1869' = 23
   'V187'  = 23
   'V188'  = 23
   'V189'  = 23
   'V190'  = 23
   'V1911' = 23
   'V1919' = 23
   'V192'  = 23
   'V193'  = 23
   'V194'  = 23
   'V195'  = 23
   'V196'  = 23
   'V197'  = 23
   'V198'  = 23
   'V200'  = 23
   'V201'  = 23
   'V202'  = 23
   'V2031' = 23
   'V2032' = 23
   'V210'  = 23
   'V211'  = 23
   'V212'  = 23
   'V2130' = 23
   'V2131' = 23
   'V2132' = 23
   'V2133' = 23
   'V2134' = 23
   'V2135' = 23
   'V218'  = 23
   'V219'  = 23
   'V220'  = 23
   'V221'  = 23
   'V222'  = 23
   'V230'  = 14
   'V231'  = 14
   'V232'  = 14
   'V233'  = 14
   'V2341' = 14
   'V2342' = 14
   'V2349' = 14
   'V235'  = 14
   'V237'  = 14
   'V2381' = 14
   'V2382' = 14
   'V2383' = 14
   'V2384' = 14
   'V2385' = 14
   'V2386' = 14
   'V2387' = 14
   'V2389' = 14
   'V239'  = 14
   'V240'  = 14
   'V241'  = 23
   'V242'  = 23
   'V2501' = 23
   'V2502' = 23
   'V2503' = 23
   'V2504' = 23
   'V2509' = 23
   'V2511' = 23
   'V2512' = 23
   'V2513' = 23
   'V252'  = 12
   'V253'  = 13
   'V2540' = 23
   'V2541' = 23
   'V2542' = 23
   'V2543' = 23
   'V2549' = 23
   'V255'  = 23
   'V258'  = 23
   'V259'  = 23
   'V260'  = 12
   'V261'  = 23
   'V2621' = 23
   'V2622' = 23
   'V2629' = 23
   'V2631' = 23
   'V2632' = 23
   'V2633' = 23
   'V2634' = 23
   'V2635' = 23
   'V2639' = 23
   'V2641' = 23
   'V2642' = 23
   'V2649' = 23
   'V2651' = 23
   'V2652' = 23
   'V2681' = 23
   'V2682' = 23
   'V2689' = 23
   'V269'  = 23
   'V270'  = 23
   'V271'  = 23
   'V272'  = 23
   'V273'  = 23
   'V274'  = 23
   'V275'  = 23
   'V276'  = 23
   'V277'  = 23
   'V279'  = 23
   'V280'  = 14
   'V281'  = 14
   'V282'  = 14
   'V283'  = 23
   'V284'  = 23
   'V285'  = 23
   'V286'  = 23
   'V2881' = 23
   'V2882' = 23
   'V2889' = 23
   'V289'  = 23
   'V290'  = 23
   'V291'  = 23
   'V292'  = 23
   'V293'  = 23
   'V298'  = 23
   'V299'  = 23
   'V3000' = 15
   'V3001' = 15
   'V301'  = 15
   'V302'  = 15
   'V3100' = 15
   'V3101' = 15
   'V311'  = 15
   'V312'  = 15
   'V3200' = 15
   'V3201' = 15
   'V321'  = 15
   'V322'  = 15
   'V3300' = 15
   'V3301' = 15
   'V331'  = 15
   'V332'  = 15
   'V3400' = 15
   'V3401' = 15
   'V341'  = 15
   'V342'  = 15
   'V3500' = 15
   'V3501' = 15
   'V351'  = 15
   'V352'  = 15
   'V3600' = 15
   'V3601' = 15
   'V361'  = 15
   'V362'  = 15
   'V3700' = 15
   'V3701' = 15
   'V371'  = 15
   'V372'  = 15
   'V3900' = 15
   'V3901' = 15
   'V391'  = 15
   'V392'  = 15
   'V400'  = 23
   'V401'  = 23
   'V402'  = 23
   'V4031' = 23
   'V4039' = 23
   'V409'  = 23
   'V410'  = 23
   'V411'  = 23
   'V412'  = 23
   'V413'  = 23
   'V414'  = 23
   'V415'  = 23
   'V416'  = 23
   'V417'  = 23
   'V418'  = 23
   'V419'  = 23
   'V420'  = 11
   'V421'  = 05
   'V422'  = 05
   'V423'  = 09
   'V424'  = 08
   'V425'  = 02
   'V426'  = 04
   'V427'  = 07
   'V4281' = 16
   'V4282' = 16
   'V4283' = 07
   'V4284' = 23
   'V4289' = 23
   'V429'  = 23
   'V430'  = 02
   'V431'  = 02
   'V4321' = 05
   'V4322' = 05
   'V433'  = 05
   'V434'  = 05
   'V435'  = 11
   'V4360' = 08
   'V4361' = 08
   'V4362' = 08
   'V4363' = 08
   'V4364' = 08
   'V4365' = 08
   'V4366' = 08
   'V4369' = 08
   'V437'  = 08
   'V4381' = 23
   'V4382' = 23
   'V4383' = 23
   'V4389' = 23
   'V440'  = 23
   'V441'  = 23
   'V442'  = 23
   'V443'  = 23
   'V444'  = 23
   'V4450' = 23
   'V4451' = 23
   'V4452' = 23
   'V4459' = 23
   'V446'  = 23
   'V447'  = 23
   'V448'  = 23
   'V449'  = 23
   'V4500' = 23
   'V4501' = 23
   'V4502' = 23
   'V4509' = 23
   'V4511' = 23
   'V4512' = 23
   'V452'  = 23
   'V453'  = 23
   'V454'  = 23
   'V4551' = 23
   'V4552' = 23
   'V4559' = 23
   'V4561' = 23
   'V4569' = 23
   'V4571' = 23
   'V4572' = 23
   'V4573' = 23
   'V4574' = 11
   'V4575' = 23
   'V4576' = 04
   'V4577' = 12
   'V4578' = 02
   'V4579' = 23
   'V4581' = 23
   'V4582' = 23
   'V4583' = 23
   'V4584' = 23
   'V4585' = 23
   'V4586' = 23
   'V4587' = 23
   'V4588' = 23
   'V4589' = 23
   'V460'  = 23
   'V4611' = 23
   'V4612' = 23
   'V4613' = 23
   'V4614' = 23
   'V462'  = 23
   'V463'  = 23
   'V468'  = 23
   'V469'  = 23
   'V470'  = 23
   'V471'  = 23
   'V472'  = 23
   'V473'  = 23
   'V474'  = 23
   'V475'  = 23
   'V479'  = 23
   'V480'  = 23
   'V481'  = 23
   'V482'  = 23
   'V483'  = 23
   'V484'  = 23
   'V485'  = 23
   'V486'  = 23
   'V487'  = 23
   'V488'  = 23
   'V489'  = 23
   'V490'  = 23
   'V491'  = 23
   'V492'  = 23
   'V493'  = 23
   'V494'  = 23
   'V495'  = 23
   'V4960' = 23
   'V4961' = 23
   'V4962' = 23
   'V4963' = 23
   'V4964' = 23
   'V4965' = 23
   'V4966' = 23
   'V4967' = 23
   'V4970' = 23
   'V4971' = 23
   'V4972' = 23
   'V4973' = 23
   'V4974' = 23
   'V4975' = 23
   'V4976' = 23
   'V4977' = 23
   'V4981' = 23
   'V4982' = 23
   'V4983' = 23
   'V4984' = 23
   'V4985' = 23
   'V4986' = 23
   'V4987' = 23
   'V4989' = 23
   'V499'  = 23
   'V500'  = 09
   'V501'  = 09
   'V502'  = 12
   'V503'  = 23
   'V5041' = 09
   'V5042' = 13
   'V5049' = 23
   'V508'  = 23
   'V509'  = 23
   'V510'  = 09
   'V518'  = 09
   'V520'  = 08
   'V521'  = 08
   'V522'  = 23
   'V523'  = 23
   'V524'  = 23
   'V528'  = 23
   'V529'  = 23
   'V5301' = 01
   'V5302' = 01
   'V5309' = 01
   'V531'  = 23
   'V532'  = 23
   'V5331' = 05
   'V5332' = 05
   'V5339' = 05
   'V534'  = 23
   'V5350' = 06
   'V5351' = 06
   'V5359' = 06
   'V536'  = 11
   'V537'  = 08
   'V538'  = 23
   'V5390' = 23
   'V5391' = 23
   'V5399' = 23
   'V5401' = 08
   'V5402' = 08
   'V5409' = 08
   'V5410' = 08
   'V5411' = 08
   'V5412' = 08
   'V5413' = 08
   'V5414' = 08
   'V5415' = 08
   'V5416' = 08
   'V5417' = 08
   'V5419' = 08
   'V5420' = 08
   'V5421' = 08
   'V5422' = 08
   'V5423' = 08
   'V5424' = 08
   'V5425' = 08
   'V5426' = 08
   'V5427' = 08
   'V5429' = 08
   'V5481' = 08
   'V5482' = 08
   'V5489' = 08
   'V549'  = 08
   'V550'  = 04
   'V551'  = 06
   'V552'  = 06
   'V553'  = 06
   'V554'  = 06
   'V555'  = 11
   'V556'  = 11
   'V557'  = 13
   'V558'  = 23
   'V559'  = 23
   'V560'  = 11
   'V561'  = 11
   'V562'  = 11
   'V5631' = 11
   'V5632' = 11
   'V568'  = 11
   'V570'  = 23
   'V571'  = 23
   'V5721' = 23
   'V5722' = 23
   'V573'  = 23
   'V574'  = 23
   'V5781' = 23
   'V5789' = 23
   'V579'  = 23
   'V580'  = 17
   'V5811' = 17
   'V5812' = 17
   'V582'  = 23
   'V5830' = 23
   'V5831' = 23
   'V5832' = 23
   'V5841' = 23
   'V5842' = 23
   'V5843' = 23
   'V5844' = 23
   'V5849' = 23
   'V585'  = 23
   'V5861' = 23
   'V5862' = 23
   'V5863' = 23
   'V5864' = 23
   'V5865' = 23
   'V5866' = 23
   'V5867' = 23
   'V5868' = 23
   'V5869' = 23
   'V5871' = 23
   'V5872' = 23
   'V5873' = 23
   'V5874' = 23
   'V5875' = 23
   'V5876' = 23
   'V5877' = 23
   'V5878' = 23
   'V5881' = 23
   'V5882' = 23
   'V5883' = 23
   'V5889' = 23
   'V589'  = 23
   'V5901' = 23
   'V5902' = 23
   'V5909' = 23
   'V591'  = 09
   'V592'  = 08
   'V593'  = 23
   'V594'  = 11
   'V595'  = 23
   'V596'  = 07
   'V5970' = 23
   'V5971' = 23
   'V5972' = 23
   'V5973' = 23
   'V5974' = 23
   'V598'  = 23
   'V599'  = 23
   'V600'  = 23
   'V601'  = 23
   'V602'  = 23
   'V603'  = 23
   'V604'  = 23
   'V605'  = 23
   'V606'  = 23
   'V6081' = 23
   'V6089' = 23
   'V609'  = 23
   'V6101' = 23
   'V6102' = 23
   'V6103' = 23
   'V6104' = 23
   'V6105' = 23
   'V6106' = 23
   'V6107' = 23
   'V6108' = 23
   'V6109' = 23
   'V6110' = 23
   'V6111' = 23
   'V6112' = 23
   'V6120' = 23
   'V6121' = 23
   'V6122' = 23
   'V6123' = 23
   'V6124' = 23
   'V6125' = 23
   'V6129' = 23
   'V613'  = 23
   'V6141' = 23
   'V6142' = 23
   'V6149' = 23
   'V615'  = 13
   'V616'  = 14
   'V617'  = 14
   'V618'  = 23
   'V619'  = 23
   'V620'  = 23
   'V621'  = 23
   'V6221' = 23
   'V6222' = 23
   'V6229' = 23
   'V623'  = 23
   'V624'  = 23
   'V625'  = 23
   'V626'  = 23
   'V6281' = 23
   'V6282' = 23
   'V6283' = 23
   'V6284' = 19
   'V6285' = 23
   'V6289' = 23
   'V629'  = 23
   'V630'  = 23
   'V631'  = 23
   'V632'  = 23
   'V638'  = 23
   'V639'  = 23
   'V6400' = 23
   'V6401' = 23
   'V6402' = 23
   'V6403' = 23
   'V6404' = 23
   'V6405' = 23
   'V6406' = 23
   'V6407' = 23
   'V6408' = 23
   'V6409' = 23
   'V641'  = 23
   'V642'  = 23
   'V643'  = 23
   'V6441' = 23
   'V6442' = 23
   'V6443' = 23
   'V650'  = 23
   'V6511' = 23
   'V6519' = 23
   'V652'  = 23
   'V653'  = 23
   'V6540' = 23
   'V6541' = 23
   'V6542' = 23
   'V6543' = 23
   'V6544' = 23
   'V6545' = 23
   'V6546' = 23
   'V6549' = 23
   'V655'  = 23
   'V658'  = 23
   'V659'  = 23
   'V660'  = 23
   'V661'  = 23
   'V662'  = 23
   'V663'  = 23
   'V664'  = 23
   'V665'  = 23
   'V666'  = 23
   'V667'  = 23
   'V669'  = 23
   'V6700' = 23
   'V6701' = 23
   'V6709' = 23
   'V671'  = 17
   'V672'  = 17
   'V673'  = 23
   'V674'  = 23
   'V6751' = 23
   'V6759' = 23
   'V676'  = 23
   'V679'  = 23
   'V6801' = 23
   'V6809' = 23
   'V681'  = 23
   'V682'  = 23
   'V6881' = 23
   'V6889' = 23
   'V689'  = 23
   'V690'  = 23
   'V691'  = 23
   'V692'  = 23
   'V693'  = 23
   'V694'  = 23
   'V695'  = 23
   'V698'  = 23
   'V699'  = 23
   'V700'  = 23
   'V701'  = 23
   'V702'  = 23
   'V703'  = 23
   'V704'  = 23
   'V705'  = 23
   'V706'  = 23
   'V707'  = 23
   'V708'  = 23
   'V709'  = 23
   'V7101' = 19
   'V7102' = 19
   'V7109' = 19
   'V711'  = 17
   'V712'  = 04
   'V713'  = 21
   'V714'  = 21
   'V715'  = 23
   'V716'  = 21
   'V717'  = 05
   'V7181' = 23
   'V7182' = 23
   'V7183' = 23
   'V7189' = 23
   'V719'  = 23
   'V720'  = 23
   'V7211' = 23
   'V7212' = 23
   'V7219' = 23
   'V722'  = 23
   'V7231' = 23
   'V7232' = 23
   'V7240' = 23
   'V7241' = 23
   'V7242' = 23
   'V725'  = 23
   'V7260' = 23
   'V7261' = 23
   'V7262' = 23
   'V7263' = 23
   'V7269' = 23
   'V727'  = 23
   'V7281' = 23
   'V7282' = 23
   'V7283' = 23
   'V7284' = 23
   'V7285' = 23
   'V7286' = 23
   'V729'  = 23
   'V730'  = 23
   'V731'  = 23
   'V732'  = 23
   'V733'  = 23
   'V734'  = 23
   'V735'  = 23
   'V736'  = 23
   'V7381' = 23
   'V7388' = 23
   'V7389' = 23
   'V7398' = 23
   'V7399' = 23
   'V740'  = 23
   'V741'  = 23
   'V742'  = 23
   'V743'  = 23
   'V744'  = 23
   'V745'  = 23
   'V746'  = 23
   'V748'  = 23
   'V749'  = 23
   'V750'  = 23
   'V751'  = 23
   'V752'  = 23
   'V753'  = 23
   'V754'  = 23
   'V755'  = 23
   'V756'  = 23
   'V757'  = 23
   'V758'  = 23
   'V759'  = 23
   'V760'  = 23
   'V7610' = 23
   'V7611' = 23
   'V7612' = 23
   'V7619' = 23
   'V762'  = 23
   'V763'  = 23
   'V7641' = 23
   'V7642' = 23
   'V7643' = 23
   'V7644' = 23
   'V7645' = 23
   'V7646' = 23
   'V7647' = 23
   'V7649' = 23
   'V7650' = 23
   'V7651' = 23
   'V7652' = 23
   'V7681' = 23
   'V7689' = 23
   'V769'  = 23
   'V770'  = 23
   'V771'  = 23
   'V772'  = 23
   'V773'  = 23
   'V774'  = 23
   'V775'  = 23
   'V776'  = 23
   'V777'  = 23
   'V778'  = 23
   'V7791' = 23
   'V7799' = 23
   'V780'  = 23
   'V781'  = 23
   'V782'  = 23
   'V783'  = 23
   'V788'  = 23
   'V789'  = 23
   'V790'  = 23
   'V791'  = 23
   'V792'  = 23
   'V793'  = 23
   'V798'  = 23
   'V799'  = 23
   'V8001' = 23
   'V8009' = 23
   'V801'  = 23
   'V802'  = 23
   'V803'  = 23
   'V810'  = 23
   'V811'  = 23
   'V812'  = 23
   'V813'  = 23
   'V814'  = 23
   'V815'  = 23
   'V816'  = 23
   'V820'  = 23
   'V821'  = 23
   'V822'  = 23
   'V823'  = 23
   'V824'  = 23
   'V825'  = 23
   'V826'  = 23
   'V8271' = 23
   'V8279' = 23
   'V8281' = 23
   'V8289' = 23
   'V829'  = 23
   'V8301' = 23
   'V8302' = 23
   'V8381' = 23
   'V8389' = 23
   'V8401' = 23
   'V8402' = 23
   'V8403' = 23
   'V8404' = 23
   'V8409' = 23
   'V8481' = 23
   'V8489' = 23
   'V850'  = 23
   'V851'  = 23
   'V8521' = 23
   'V8522' = 23
   'V8523' = 23
   'V8524' = 23
   'V8525' = 23
   'V8530' = 23
   'V8531' = 23
   'V8532' = 23
   'V8533' = 23
   'V8534' = 23
   'V8535' = 23
   'V8536' = 23
   'V8537' = 23
   'V8538' = 23
   'V8539' = 23
   'V8541' = 10
   'V8542' = 10
   'V8543' = 10
   'V8544' = 10
   'V8545' = 10
   'V8551' = 23
   'V8552' = 23
   'V8553' = 23
   'V8554' = 23
   'V860'  = 23
   'V861'  = 23
   'V8701' = 23
   'V8702' = 23
   'V8709' = 23
   'V8711' = 23
   'V8712' = 23
   'V8719' = 23
   'V872'  = 23
   'V8731' = 23
   'V8732' = 23
   'V8739' = 23
   'V8741' = 23
   'V8742' = 23
   'V8743' = 23
   'V8744' = 23
   'V8745' = 23
   'V8746' = 23
   'V8749' = 23
   'V8801' = 13
   'V8802' = 13
   'V8803' = 13
   'V8811' = 23
   'V8812' = 23
   'V8821' = 23
   'V8822' = 23
   'V8829' = 23
   'V8901' = 23
   'V8902' = 23
   'V8903' = 23
   'V8904' = 23
   'V8905' = 23
   'V8909' = 23
   'V9001' = 23
   'V9009' = 23
   'V9010' = 23
   'V9011' = 23
   'V9012' = 23
   'V902'  = 23
   'V9031' = 23
   'V9032' = 23
   'V9033' = 23
   'V9039' = 23
   'V9081' = 23
   'V9083' = 23
   'V9089' = 23
   'V909'  = 23
   'V9100' = 23
   'V9101' = 23
   'V9102' = 23
   'V9103' = 23
   'V9109' = 23
   'V9110' = 23
   'V9111' = 23
   'V9112' = 23
   'V9119' = 23
   'V9120' = 23
   'V9121' = 23
   'V9122' = 23
   'V9129' = 23
   'V9190' = 23
   'V9191' = 23
   'V9192' = 23
   'V9199' = 23
   OTHER   = .;

   /* -------------------------------------------------------------- */
/* ---   FORMATS FOR DRG STRATIFIERS                          --- */
/* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR DRG CATEGORIES     --- */
/* -------------------------------------------------------------- */
/* CMS-DRG TO MODIFIED DRG ($DRGFMT for DRGs V24 or earlier) removed in V6.0 */
/* MS-DRG TO MODIFIED DRG (V25 or later)*/
value $DRGF2T
001 = 7701
002 = 7701
003 = 7799
004 = 7799
005 = 7702
006 = 7702
007 = 7703
008 = 7704
009 = 7705
010 = 7706
011 = 7799
012 = 7799
013 = 7799
014 = 7705
015 = 7705
016 = 7705
017 = 7705
020 = 0101
021 = 0101
022 = 0101
023 = 0102
024 = 0102
025 = 0103
026 = 0103
027 = 0103
028 = 0104
029 = 0104
030 = 0104
031 = 0105
032 = 0105
033 = 0105
034 = 0106
035 = 0106
036 = 0106
037 = 0107
038 = 0107
039 = 0107
040 = 0108
041 = 0108
042 = 0108
052 = 0109
053 = 0109
054 = 0110
055 = 0110
056 = 0111
057 = 0111
058 = 0112
059 = 0112
060 = 0112
061 = 0113
062 = 0113
063 = 0113
064 = 0114
065 = 0114
066 = 0114
067 = 0115
068 = 0115
069 = 0116
070 = 0117
071 = 0117
072 = 0117
073 = 0118
074 = 0118
075 = 0119
076 = 0119
077 = 0120
078 = 0120
079 = 0120
080 = 0121
081 = 0121
082 = 0122
083 = 0122
084 = 0122
085 = 0123
086 = 0123
087 = 0123
088 = 0124
089 = 0124
090 = 0124
091 = 0125
092 = 0125
093 = 0125
094 = 0126
095 = 0126
096 = 0126
097 = 0127
098 = 0127
099 = 0127
100 = 0128
101 = 0128
102 = 0129
103 = 0129
113 = 0201
114 = 0201
115 = 0202
116 = 0203
117 = 0203
121 = 0204
122 = 0204
123 = 0205
124 = 0206
125 = 0206
129 = 0301
130 = 0301
131 = 0301
132 = 0301
133 = 0302
134 = 0302
135 = 0303
136 = 0303
137 = 0304
138 = 0304
139 = 0305
146 = 0306
147 = 0306
148 = 0306
149 = 0307
150 = 0308
151 = 0308
152 = 0309
153 = 0309
154 = 0310
155 = 0310
156 = 0310
157 = 0311
158 = 0311
159 = 0311
163 = 0401
164 = 0401
165 = 0401
166 = 0402
167 = 0402
168 = 0402
175 = 0403
176 = 0403
177 = 0404
178 = 0404
179 = 0404
180 = 0405
181 = 0405
182 = 0405
183 = 0406
184 = 0406
185 = 0406
186 = 0407
187 = 0407
188 = 0407
189 = 0408
190 = 0409
191 = 0409
192 = 0409
193 = 0410
194 = 0410
195 = 0410
196 = 0411
197 = 0411
198 = 0411
199 = 0412
200 = 0412
201 = 0412
202 = 0413
203 = 0413
204 = 0414
205 = 0415
206 = 0415
207 = 0416
208 = 0416
215 = 0501
216 = 0503
217 = 0503
218 = 0503
219 = 0503
220 = 0503
221 = 0503
222 = 0504
223 = 0504
224 = 0504
225 = 0504
226 = 0504
227 = 0504
228 = 0505
229 = 0505
230 = 0505
231 = 0506
232 = 0506
233 = 0507
234 = 0507
235 = 0507
236 = 0507
/* --------------------- */
/* MDRG 0508 added back  */
/* per spec 3-24-2016    */
/* --------------------- */
237 = 0508
238 = 0508
239 = 0509
240 = 0509
241 = 0509
242 = 0510
243 = 0510
244 = 0510
245 = 0510
246 = 0511
247 = 0511
248 = 0502
249 = 0502
250 = 0513
251 = 0513
252 = 0514
253 = 0514
254 = 0514
255 = 0515
256 = 0515
257 = 0515
258 = 0516
259 = 0516
260 = 0517
261 = 0517
262 = 0517
263 = 0518
264 = 0519
265 = 0510
266 = 0540
267 = 0540
268 = 0541
269 = 0541
270 = 0542
271 = 0542
272 = 0542
273 = 0543
274 = 0543
280 = 0520
281 = 0520
282 = 0520
283 = 0521
284 = 0521
285 = 0521
286 = 0522
287 = 0522
288 = 0523
289 = 0523
290 = 0523
291 = 0524
292 = 0524
293 = 0524
294 = 0525
295 = 0525
296 = 0526
297 = 0526
298 = 0526
299 = 0527
300 = 0527
301 = 0527
302 = 0528
303 = 0528
304 = 0529
305 = 0529
306 = 0530
307 = 0530
308 = 0531
309 = 0531
310 = 0531
311 = 0532
312 = 0533
313 = 0534
314 = 0535
315 = 0535
316 = 0535
326 = 0601
327 = 0601
328 = 0601
329 = 0602
330 = 0602
331 = 0602
332 = 0603
333 = 0603
334 = 0603
335 = 0604
336 = 0604
337 = 0604
338 = 0605
339 = 0605
340 = 0605
341 = 0606
342 = 0606
343 = 0606
344 = 0607
345 = 0607
346 = 0607
347 = 0608
348 = 0608
349 = 0608
350 = 0609
351 = 0609
352 = 0609
353 = 0610
354 = 0610
355 = 0610
356 = 0611
357 = 0611
358 = 0611
368 = 0612
369 = 0612
370 = 0612
371 = 0613
372 = 0613
373 = 0613
374 = 0614
375 = 0614
376 = 0614
377 = 0615
378 = 0615
379 = 0615
380 = 0616
381 = 0616
382 = 0616
383 = 0617
384 = 0617
385 = 0618
386 = 0618
387 = 0618
388 = 0619
389 = 0619
390 = 0619
391 = 0620
392 = 0620
393 = 0621
394 = 0621
395 = 0621
405 = 0701
406 = 0701
407 = 0701
408 = 0702
409 = 0702
410 = 0702
411 = 0703
412 = 0703
413 = 0703
414 = 0704
415 = 0704
416 = 0704
417 = 0705
418 = 0705
419 = 0705
420 = 0706
421 = 0706
422 = 0706
423 = 0707
424 = 0707
425 = 0707
432 = 0708
433 = 0708
434 = 0708
435 = 0709
436 = 0709
437 = 0709
438 = 0710
439 = 0710
440 = 0710
441 = 0711
442 = 0711
443 = 0711
444 = 0712
445 = 0712
446 = 0712
453 = 0801
454 = 0801
455 = 0801
456 = 0802
457 = 0802
458 = 0802
459 = 0803
460 = 0803
461 = 0804
462 = 0804
463 = 0805
464 = 0805
465 = 0805
466 = 0806
467 = 0806
468 = 0806
469 = 0807
470 = 0807
471 = 0808
472 = 0808
473 = 0808
474 = 0809
475 = 0809
476 = 0809
477 = 0810
478 = 0810
479 = 0810
480 = 0811
481 = 0811
482 = 0811
483 = 0812
484 = 0812
485 = 0813
486 = 0813
487 = 0813
488 = 0814
489 = 0814
490 = 0815
491 = 0815
492 = 0816
493 = 0816
494 = 0816
495 = 0817
496 = 0817
497 = 0817
498 = 0818
499 = 0818
500 = 0819
501 = 0819
502 = 0819
503 = 0820
504 = 0820
505 = 0820
506 = 0821
507 = 0822
508 = 0822
509 = 0823
510 = 0824
511 = 0824
512 = 0824
513 = 0825
514 = 0825
515 = 0826
516 = 0826
517 = 0826
518 = 0815
519 = 0815
520 = 0815
533 = 0827
534 = 0827
535 = 0828
536 = 0828
537 = 0829
538 = 0829
539 = 0830
540 = 0830
541 = 0830
542 = 0831
543 = 0831
544 = 0831
545 = 0832
546 = 0832
547 = 0832
548 = 0833
549 = 0833
550 = 0833
551 = 0834
552 = 0834
553 = 0835
554 = 0835
555 = 0836
556 = 0836
557 = 0837
558 = 0837
559 = 0838
560 = 0838
561 = 0838
562 = 0839
563 = 0839
564 = 0840
565 = 0840
566 = 0840
570 = 0901
571 = 0901
572 = 0901
573 = 0901
574 = 0901
575 = 0901
576 = 0902
577 = 0902
578 = 0902
579 = 0903
580 = 0903
581 = 0903
582 = 0904
583 = 0904
584 = 0905
585 = 0905
592 = 0906
593 = 0906
594 = 0906
595 = 0907
596 = 0907
597 = 0908
598 = 0908
599 = 0908
600 = 0909
601 = 0909
602 = 0910
603 = 0910
604 = 0911
605 = 0911
606 = 0912
607 = 0912
614 = 1001
615 = 1001
616 = 1002
617 = 1002
618 = 1002
619 = 1003
620 = 1003
621 = 1003
622 = 1004
623 = 1004
624 = 1004
625 = 1005
626 = 1005
627 = 1005
628 = 1006
629 = 1006
630 = 1006
637 = 1007
638 = 1007
639 = 1007
640 = 1008
641 = 1008
642 = 1009
643 = 1010
644 = 1010
645 = 1010
652 = 1101
653 = 1102
654 = 1102
655 = 1102
656 = 1103
657 = 1103
658 = 1103
659 = 1104
660 = 1104
661 = 1104
662 = 1105
663 = 1105
664 = 1105
665 = 1106
666 = 1106
667 = 1106
668 = 1107
669 = 1107
670 = 1107
671 = 1108
672 = 1108
673 = 1109
674 = 1109
675 = 1109
682 = 1110
683 = 1110
684 = 1110
685 = 1111
686 = 1112
687 = 1112
688 = 1112
689 = 1113
690 = 1113
691 = 1114
692 = 1114
693 = 1115
694 = 1115
695 = 1116
696 = 1116
697 = 1117
698 = 1118
699 = 1118
700 = 1118
707 = 1201
708 = 1201
709 = 1202
710 = 1202
711 = 1203
712 = 1203
713 = 1204
714 = 1204
715 = 1205
716 = 1205
717 = 1206
718 = 1206
722 = 1207
723 = 1207
724 = 1207
725 = 1208
726 = 1208
727 = 1209
728 = 1209
729 = 1210
730 = 1210
734 = 1301
735 = 1301
736 = 1302
737 = 1302
738 = 1302
739 = 1303
740 = 1303
741 = 1303
742 = 1304
743 = 1304
744 = 1305
745 = 1305
746 = 1306
747 = 1306
748 = 1307
749 = 1308
750 = 1308
754 = 1309
755 = 1309
756 = 1309
757 = 1310
758 = 1310
759 = 1310
760 = 1311
761 = 1311
765 = 1401
766 = 1401
767 = 1402
768 = 1402
769 = 1403
770 = 1404
774 = 1405
775 = 1405
776 = 1406
777 = 1407
778 = 1408
779 = 1409
780 = 1410
781 = 1411
782 = 1412
789 = 1501
790 = 1502
791 = 1503
792 = 1504
793 = 1505
794 = 1506
795 = 1507
799 = 1601
800 = 1601
801 = 1601
802 = 1602
803 = 1602
804 = 1602
808 = 1603
809 = 1603
810 = 1603
811 = 1604
812 = 1604
813 = 1605
814 = 1606
815 = 1606
816 = 1606
820 = 1707
821 = 1707
822 = 1707
823 = 1708
824 = 1708
825 = 1708
826 = 1709
827 = 1709
828 = 1709
829 = 1710
830 = 1710
834 = 1711
835 = 1711
836 = 1711
837 = 1712
838 = 1712
839 = 1712
840 = 1713
841 = 1713
842 = 1713
843 = 1714
844 = 1714
845 = 1714
846 = 1715
847 = 1715
848 = 1715
849 = 1716
853 = 1801
854 = 1801
855 = 1801
856 = 1802
857 = 1802
858 = 1802
862 = 1803
863 = 1803
864 = 1804
865 = 1805
866 = 1805
867 = 1806
868 = 1806
869 = 1806
870 = 1807
871 = 1808
872 = 1808
876 = 1909
880 = 1910
881 = 1911
882 = 1912
883 = 1913
884 = 1914
885 = 1915
886 = 1916
887 = 1917
894 = 2018
895 = 2019
896 = 2020
897 = 2020
901 = 2101
902 = 2101
903 = 2101
904 = 2102
905 = 2102
906 = 2103
907 = 2104
908 = 2104
909 = 2104
913 = 2105
914 = 2105
915 = 2106
916 = 2106
917 = 2107
918 = 2107
919 = 2108
920 = 2108
921 = 2108
922 = 2109
923 = 2109
927 = 2210
928 = 2201
929 = 2201
933 = 2212
934 = 2213
935 = 2214
939 = 2301
940 = 2301
941 = 2301
945 = 2302
946 = 2302
947 = 2303
948 = 2303
949 = 2304
950 = 2304
951 = 2305
955 = 2406
956 = 2407
957 = 2408
958 = 2408
959 = 2408
963 = 2409
964 = 2409
965 = 2409
969 = 2501
970 = 2501
974 = 2502
975 = 2502
976 = 2502
977 = 2503
981 = 8899
982 = 8899
983 = 8899
984 = 8899
985 = 8899
986 = 8899
987 = 8899
988 = 8899
989 = 8899
/* ---------------------------------*/
/* -- OTHER logic changed to work --*/
/* -- with new MDRG length of 4   --*/ 
/* ---------------------------------*/
998 = 8898
999 = 8898
other = 9999;

/* ---------------------------------------------------------------- */
/* --- BLOOD STREAM INFECTION NEONATES                            - */
/*        PROVIDER INDICATOR / NQI # 3                            - */
/* ---------------------------------------------------------------- */
value $GESTC1D
"76521" = "1" /* Less than 24 completed weeks of gestation  */
other   = "0";
 
value $GESTC2D
"76522" = "1" /* 24 COMPLETED WEEKS OF GESTATION  */
other   = "0";
value $GESTC3D
"76523" = "1" /* 25-26 COMPLETED WEEKS OF GESTATION */
other   = "0";
value $GESTC4D
"76524" = "1" /* 27-28 COMPLETED WEEKS OF GESTATION */
other   = "0";
value $GESTC5D
"76525" = "1" /* 29-30 COMPLETED WEEKS OF GESTATION */
other   = "0";
value $GESTC6D
"76526" = "1" /* 31-32 completed weeks of gestation */
other   = "0";
value $GESTC7D
"76527" = "1" /* 33-34 completed weeks of gestation */
other   = "0";
value $GESTC8D
"76528" = "1" /* 35-36 completed weeks of gestation */
other   = "0";
value $GESTC9D
"76529" = "1" /* 37 or more completed weeks of gestation */
other   = "0";

/*  Congenital Anamolies */
/* ICD-9-CM Diagnosis Codes: */
value $CONGN1D
'5602 ' = '1'
'7503 ' = '1'
'7504 ' = '1'
'7505 ' = '1'
'7507 ' = '1'
'7508 ' = '1'
'7509 ' = '1'
'7510 ' = '1'
'7511 ' = '1'
'7512 ' = '1'
'7513 ' = '1'
'7514 ' = '1'
'7515 ' = '1'
'75160' = '1'
'75161' = '1'
'75169' = '1'
'7517 ' = '1'
'7518 ' = '1'
'7519 ' = '1'
'75670' = '1'
'75679' = '1'
'7711 ' = '1'
other   = '0';
value $CONGN2D
'7530 ' = '1'
'75310' = '1'
'75312' = '1'
'75314' = '1'
'75315' = '1'
'75319' = '1'
'75320' = '1'
'75321' = '1'
'75322' = '1'
'75323' = '1'
'7533 ' = '1'
'7534 ' = '1'
'7536 ' = '1'
'7537 ' = '1'
'7538 ' = '1'
'7539 ' = '1'
'75671' = '1'
other   = '0';
value $CONGN3D
'74100' = '1'
'74101' = '1'
'74102' = '1'
'74103' = '1'
'74190' = '1'
'74191' = '1'
'74192' = '1'
'74193' = '1'
'7420 ' = '1'
'7421 ' = '1'
'7422 ' = '1'
'7423 ' = '1'
'7424 ' = '1'
'74259' = '1'
'7428 ' = '1'
'7429 ' = '1'
other   = '0';
value $CONGN4D
'5194 ' = '1'
'5533 ' = '1'
'7483 ' = '1'
'7484 ' = '1'
'74860' = '1'
'74869' = '1'
'7488 ' = '1'
'7489 ' = '1'
'7506 ' = '1'
'7566 ' = '1'
other   = '0';
value $CONGN5D
'4240 ' = '1'
'4241 ' = '1'
'4251 ' = '1'
'4253 ' = '1'
'7450 ' = '1'
'74510' = '1'
'74511' = '1'
'74512' = '1'
'74519' = '1'
'7452 ' = '1'
'7453 ' = '1'
'74560' = '1'
'74561' = '1'
'74569' = '1'
'74601' = '1'
'74609' = '1'
'7461 ' = '1'
'7462 ' = '1'
'7463 ' = '1'
'7464 ' = '1'
'7465 ' = '1'
'7466 ' = '1'
'7467 ' = '1'
'74681' = '1'
'74682' = '1'
'74683' = '1'
'74684' = '1'
'74685' = '1'
'74710' = '1'
'74711' = '1'
'74721' = '1'
'74722' = '1'
'74729' = '1'
'74740' = '1'
'74741' = '1'
'74742' = '1'
'74749' = '1'
other   = '0';
value $CONGN6D
'75650' = '1'
'75651' = '1'
'75655' = '1'
'75659' = '1'
other   = '0';
value $CONGN7D
'7583 ' = '1'
'7585 ' = '1'
'75889' = '1'
'7589 ' = '1'
'7594 ' = '1'
'7597 ' = '1'
'75989' = '1'
'7599 ' = '1'
other   = '0'
;
value $CONGN8D
'7596 ' = '1'
'7765 ' = '1'
'7780 ' = '1'
other   = '0'
;

/* IMMUNOCOMPROMISED addition to create IMMUNE flag for risk adjustment */
/* ICD-9-CM DIAGNOSIS CODES (INCLUDES ALL 4TH AND 5TH DIGITS) */
value $IMMUNID
"042"   = "1" /* HUMAN IMMUNODEFICIENCY VIRUS DISEASE */
"1363"  = "1" /* PNEUMOCYSTOSIS */
"1992"  = "1" /* MALIG NEOPL-TRANSP ORGAN */
"23873" = "1" /* HI GRDE MYELODYS SYN LES */
"23876" = "1" /* MYELOFI W MYELO METAPLAS */
"23877" = "1" /* POST TP LYMPHPROLIF DIS */
"23879" = "1" /* LYMPH/HEMATPOITC TIS NEC */
"260  " = "1" /* KWASHIORKOR */
"261  " = "1" /* NUTRITIONAL MARASMUS */
"262  " = "1" /* OTH SEVERE MALNUTRITION */
"27900" = "1" /* HYPOGAMMAGLOBULINEM NOS */
"27901" = "1" /* SELECTIVE IGA IMMUNODEF */
"27902" = "1" /* SELECTIVE IGM IMMUNODEF */
"27903" = "1" /* SELECTIVE IG DEFIC NEC */
"27904" = "1" /* CONG HYPOGAMMAGLOBULINEM */
"27905" = "1" /* IMMUNODEFIC W HYPER-IGM */
"27906" = "1" /* COMMON VARIABL IMMUNODEF */
"27909" = "1" /* HUMORAL IMMUNITY DEF NEC */
"27910" = "1" /* IMMUNDEF T-CELL DEF NOS */
"27911" = "1" /* DIGEORGES SYNDROME */
"27912" = "1" /* WISKOTT-ALDRICH SYNDROME */
"27913" = "1" /* NEZELOFS SYNDROME */
"27919" = "1" /* DEFIC CELL IMMUNITY NOS */
"2792"  = "1" /* COMBINED IMMUNITY DEFICIENCY */
"2793"  = "1" /* UNSPECIFIED IMMUNITY DEFICIENCY */
"2794"  = "1" /* AUTOIMMUNE DISEASE, NOT ELSEWHERE CLASSIFIED */
"27941" = "1" /* AUTOIMMUN LYMPHPROF SYND */
"27949" = "1" /* AUTOIMMUNE DISEASE NEC */
"27950" = "1" /* GRAFT-VERSUS-HOST NOS */
"27951" = "1" /* AC GRAFT-VERSUS-HOST DIS */
"27952" = "1" /* CHRONC GRAFT-VS-HOST DIS */
"27953" = "1" /* AC ON CHRN GRFT-VS-HOST */
"2798"  = "1" /* OTHER SPECIFIED DISORDERS INVOLVING THE IMMUNE MECHANISM */
"2799"  = "1" /* UNSPECIFIED DISORDER OF IMMUNE MECHANISM */
"28409" = "1" /* CONST APLASTC ANEMIA NEC */
"2841 " = "1" /* PANCYTOPENIA */
"28411 " = "1" /* ANTINEOPLASTIC CHEMOTHERAPY INDUCED PANCYTOPENIA */
"28412 " = "1" /* OTHER DRUG INDUCED PANCYTOPENIA */
"28419 " = "1" /* OTHER PANCYTOPENIA */
"2880 " = "1" /* AGRANULOCYTOSIS */
"28800" = "1" /* NEUTROPENIA NOS */
"28801" = "1" /* CONGENITAL NEUTROPENIA */
"28802" = "1" /* CYCLIC NEUTROPENIA */
"28803" = "1" /* DRUG INDUCED NEUTROPENIA */
"28809" = "1" /* NEUTROPENIA NEC */
"2881 " = "1" /* FUNCTION DIS NEUTROPHILS */
"2882 " = "1" /* GENETIC ANOMALY LEUKOCYT */
"2884 " = "1" /* HEMOPHAGOCYTIC SYNDROMES */
"28850" = "1" /* LEUKOCYTOPENIA NOS */
"28851" = "1" /* LYMPHOCYTOPENIA */
"28859" = "1" /* DECREASED WBC COUNT NEC */
"28953" = "1" /* NEUTROPENIC SPLENOMEGALY */
"28983" = "1" /* MYELOFIBROSIS */
"40301" = "1" /* MAL HYP KIDNEY W CHR KID */
"40311" = "1" /* BEN HYP KIDNEY W CHR KID */
"40391" = "1" /* HYP KIDNEY NOS W CHR KID */
"40402" = "1" /* MAL HY HRT/KID W CHR KID */
"40403" = "1" /* MAL HYP HRT/KID W HF/KID */
"40412" = "1" /* BEN HYP HT/KID W CHR KID */
"40413" = "1" /* BEN HYP HT/KID W HF/KID */
"40492" = "1" /* HYP HT/KID NOS W CHR KID */
"40493" = "1" /* HYP HRT/KID NOS W HF/KID */
"5793 " = "1" /* INTEST POSTOP NONABSORB */
"585  " = "1" /* CHRONIC RENAL FAILURE */
"5855 " = "1" /* CHRON KIDNEY DIS STAGE V */
"5856 " = "1" /* END STAGE RENAL DISEASE */
"9968"  = "1" /* COMPLICATIONS OF TRANSPLANTED ORGAN */
"99680" = "1" /* COMP ORGAN TRANSPLNT NOS */
"99681" = "1" /* COMPL KIDNEY TRANSPLANT */
"99682" = "1" /* COMPL LIVER TRANSPLANT */
"99683" = "1" /* COMPL HEART TRANSPLANT */
"99684" = "1" /* COMPL LUNG TRANSPLANT */
"99685" = "1" /* COMPL MARROW TRANSPLANT */
"99686" = "1" /* COMPL PANCREAS TRANSPLNT */
"99687" = "1" /* COMP INTESTINE TRANSPLNT */
'99688' = "1" /* STEM CELL TRANSPLANT COMPLICATIONS */
"99689" = "1" /* COMP OTH ORGAN TRANSPLNT */
"V420"  = "1" /* KIDNEY REPLACED BY TRANSPLANT */
"V421"  = "1" /* HEART REPLACED BY TRANSPLANT */
"V426"  = "1" /* LUNG REPLACED BY TRANSPLANT */
"V427"  = "1" /* LIVER REPLACED BY TRANSPLANT */
"V428"  = "1" /* OTHER SPECIFIED ORGAN OR TISSUE */
"V4281" = "1" /* BONE MARROW SPECIFIED BY TRANSPLANT */
"V4282" = "1" /* PERIPHERAL STEM CELLS REPLACED BY TRANSPLANT */
"V4283" = "1" /* PANCREAS REPLACED BY TRANSPLANT */
"V4284" = "1" /* INTESTINES REPLACE BY TRANSPLANT */
"V4289" = "1" /* OTHER REPLACED BY TRANSPLANT */
"V451 " = "1" /* RENAL DIALYSIS STATUS */
"V4511" = "1" /* RENAL DIALYSIS STATUS */
"V560 " = "1" /* RENAL DIALYSIS ENCOUNTER */
"V561 " = "1" /* FT/ADJ XTRCORP DIAL CATH */
"V562 " = "1" /* FIT/ADJ PERIT DIAL CATH */
other   = "0";

/* IMMUNOCOMPROMISED addition to create IMMUNE flag for risk adjustment */
/* ICD-9-CM PROCEDURE CODES (INCLUDES 4TH AND 5TH DIGITS:) */
value $IMMUNIP
"0018" = "1" /* INFUS IMMUNOSUP ANTIBODY */
"335"  = "1" /* LUNG TRANSPLANT */
"3350" = "1" /* LUNG TRANSPLANT NOS */
"3351" = "1" /* UNILAT LUNG TRANSPLANT */
"3352" = "1" /* BILAT LUNG TRANSPLANT */
"336"  = "1" /* COMBINED HEART-LUNG TRANSPLANTATION */
"375"  = "1" /* HEART TRANSPLANTATION */
"3751" = "1" /* HEART TRANSPLANTATION */
"410"  = "1" /* OPERATIONS ON BONE MAROW AND SPLEEN */
"4100" = "1" /* BONE MARROW TRNSPLNT NOS */
"4101" = "1" /* AUTO BONE MT W/O PURG */
"4102" = "1" /* ALO BONE MARROW TRNSPLNT */
"4103" = "1" /* ALLOGRFT BONE MARROW NOS */
"4104" = "1" /* AUTO HEM STEM CT W/O PUR */
"4105" = "1" /* ALLO HEM STEM CT W/O PUR */
"4106" = "1" /* CORD BLD STEM CELL TRANS */
"4107" = "1" /* AUTO HEM STEM CT W PURG */
"4108" = "1" /* ALLO HEM STEM CT W PURG */
"4109" = "1" /* AUTO BONE MT W PURGING */
"4697" = "1" /* TRANSPLANT OF INTESTINE */
"5051" = "1" /* AUXILIARY LIVER TRANSPL */
"5059" = "1" /* LIVER TRANSPLANT NEC */
"5280" = "1" /* PANCREATIC TRANSPLANT, NOS */
"5281" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5282" = "1" /* REIMPLANTATION OF PANCREATIC TISSUE */
"5283" = "1" /* HETEROTRANSPLANT OF PANCREAS */
"5285" = "1" /* ALLOTRANSPLANTATION OF CELLS OF ISLETS OF LNGERHANS */
"5286" = "1" /* TRANSPLANTATION OF CELLS OF ISLETS OF LANGERHANS, NOS */
"5569" = "1" /* OTHER KIDNEY TRANSPLANTATION */
other  = "0";

/* Low Birth Weight (Outcome of Interest) */
/* ICD-9-CM Diagnosis Codes:              */
value $ACSLBWD
'76400' = 1  /* LIGHT-FOR-DATES WTNOS */
'76401' = 1  /* LIGHT-FOR-DATES <500G */
'76402' = 1  /* LT-FOR-DATES 500-749G */
'76403' = 1  /* LT-FOR-DATES 750-999G */
'76404' = 1  /* LT-FOR-DATES 1000-1249G */
'76405' = 1  /* LT-FOR-DATES 1250-1499G */
'76406' = 1  /* LT-FOR-DATES 1500-1749G */
'76407' = 1  /* LT-FOR-DATES 1750-1999G */
'76408' = 1  /* LT-FOR-DATES 2000-2499G */
'76410' = 1  /* LT-FOR-DATE W/MAL WTNOS */
'76411' = 1  /* LT-FOR-DATE W/MAL <500G */
'76412' = 1  /* LT-DATE W/MAL 500-749G */
'76413' = 1  /* LT-DATE W/MAL 750-999G */
'76414' = 1  /* LT-DATE W/MAL 1000-1249G */
'76415' = 1  /* LT-DATE W/MAL 1250-1499G */
'76416' = 1  /* LT-DATE W/MAL 1500-1749G */
'76417' = 1  /* LT-DATE W/MAL 1750-1999G */
'76418' = 1  /* LT-DATE W/MAL 2000-2499G */
'76420' = 1  /* FETAL MALNUTRITION WTNOS */
'76421' = 1  /* FETAL MALNUTRITION <500G */
'76422' = 1  /* FETAL MALNUTR 500-749G */
'76423' = 1  /* FETAL MAL 750-999G */
'76424' = 1  /* FETAL MAL 1000-1249G */
'76425' = 1  /* FETAL MAL 1250-1499G */
'76426' = 1  /* FETAL MAL 1500-1749G */
'76427' = 1  /* FETAL MALNUTR 1750-1999G */
'76428' = 1  /* FETAL MALNUTR 2000-2499G */
'76490' = 1  /* FET GROWTH RETARD WTNOS */
'76491' = 1  /* FET GROWTH RETARD <500G */
'76492' = 1  /* FET GROWTH RET 500-749G */
'76493' = 1  /* FET GROWTH RET 750-999G */
'76494' = 1  /* FET GRWTH RET 1000-1249G */
'76495' = 1  /* FET GRWTH RET 1250-1499G */
'76496' = 1  /* FET GRWTH RET 1500-1749G */
'76497' = 1  /* FET GRWTH RET 1750-1999G */
'76498' = 1  /* FET GRWTH RET 2000-2499G */
'76500' = 1  /* EXTREME IMMATUR WTNOS */
'76501' = 1  /* EXTREME IMMATUR <500G */
'76502' = 1  /* EXTREME IMMATUR 500-749G */
'76503' = 1  /* EXTREME IMMATUR 750-999G */
'76504' = 1  /* EXTREME IMMAT 1000-1249G */
'76505' = 1  /* EXTREME IMMAT 1250-1499G */
'76506' = 1  /* EXTREME IMMAT 1500-1749G */
'76507' = 1  /* EXTREME IMMAT 1750-1999G */
'76508' = 1  /* EXTREME IMMAT 2000-2499G */
'76510' = 1  /* PRETERM INFANT NEC WTNOS */
'76511' = 1  /* PRETERM NEC <500G */
'76512' = 1  /* PRETERM NEC 500-749G */
'76513' = 1  /* PRETERM NEC 750-999G */
'76514' = 1  /* PRETERM NEC 1000-1249G */
'76515' = 1  /* PRETERM NEC 1250-1499G */
'76516' = 1  /* PRETERM NEC 1500-1749G */
'76517' = 1  /* PRETERM NEC 1750-1999G */
'76518' = 1  /* PRETERM NEC 2000-2499G */
other   = 0;


/* -------------------------------------------------------------- */
/* ---   FORMATS FOR DRG STRATIFIERS                         --- */
/* ---   ONE FORMAT PER QI.  NUMBER REFERS TO N VARIABLE IN   --- */
/* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR DRG CATEGORIES    --- */
/* -------------------------------------------------------------- */

/* CMS-DRG TO MDC (MDCFMT for DRGs V24 or earlier) removed in V6.0 */
/* MS-DRG TO MDC (MDCF2T for DRGs V25 or later*/
value MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77
015 = 77
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
other  = 99
;


value DRG1C
0101 = '1'
0102 = '1'
0103 = '1'
0104 = '1'
0105 = '1'
0106 = '1'
0107 = '1'
0108 = '1'
0201 = '1'
0202 = '1'
0203 = '1'
0301 = '1'
0302 = '1'
0303 = '1'
0304 = '1'
0305 = '1'
0501 = '1'
0502 = '1'
0503 = '1'
0504 = '1'
0505 = '1'
0506 = '1'
0507 = '1'
0508 = '1'
0509 = '1'
0510 = '1'
0511 = '1'
0513 = '1'
0514 = '1'
0515 = '1'
0516 = '1'
0517 = '1'
0518 = '1'
0519 = '1'
0540 = '1'
0599 = '1'
0609 = '1'
0801 = '1'
0802 = '1'
0803 = '1'
0804 = '1'
0805 = '1'
0806 = '1'
0807 = '1'
0808 = '1'
0809 = '1'
0810 = '1'
0811 = '1'
0812 = '1'
0813 = '1'
0814 = '1'
0815 = '1'
0816 = '1'
0817 = '1'
0818 = '1'
0819 = '1'
0820 = '1'
0821 = '1'
0822 = '1'
0823 = '1'
0824 = '1'
0825 = '1'
0826 = '1'
0899 = '1'
0904 = '1'
0905 = '1'
1001 = '1'
1002 = '1'
1004 = '1'
1005 = '1'
1006 = '1'
1203 = '1'
1601 = '1'
1602 = '1'
7701 = '1'
7705 = '1'
other = '0';
/* DRGS SURGICAL CLASS =2, TYPE OF DRGS = CLEAN CONTAMINATED */
value DRG2C
0113 = '1'
0401 = '1'
0402 = '1'
0601 = '1'
0602 = '1'
0603 = '1'
0604 = '1'
0606 = '1'
0607 = '1'
0608 = '1'
0611 = '1'
0701 = '1'
0702 = '1'
0703 = '1'
0704 = '1'
0705 = '1'
0706 = '1'
0707 = '1'
0902 = '1'
0903 = '1'
1003 = '1'
1101 = '1'
1102 = '1'
1103 = '1'
1104 = '1'
1105 = '1'
1106 = '1'
1107 = '1'
1108 = '1'
1109 = '1'
1201 = '1'
1202 = '1'
1204 = '1'
1205 = '1'
1206 = '1'
1301 = '1'
1302 = '1'
1303 = '1'
1304 = '1'
1305 = '1'
1306 = '1'
1307 = '1'
1308 = '1'
1401 = '1'
1402 = '1'
1403 = '1'
1404 = '1'
1405 = '1'
7702 = '1'
7703 = '1'
7704 = '1'
7706 = '1'
7799 = '1'
8899 = '1'
other = '0';
/* DRGS SURGICAL CLASS =3, TYPE OF DRGS = POTENTIALLY CONTAMINATED */
value DRG3C
0901 = '1'
2101 = '1'
2102 = '1'
2103 = '1'
2104 = '1'
2201 = '1'
2210 = '1'
2406 = '1'
2407 = '1'
2408 = '1'
other = '0';
/* DRGS CLASS =4, TYPE OF DRGS = LIKELY INFECTED                    */
value DRG4C
0605 = '1'
1801 = '1'
1802 = '1'
1899 = '1'
other = '0';
/* DRGS CLASS =9, TYPE OF DRGS = SURGICAL PROCEDURES NOT SPECIFIED  */
value DRG9C
1707 = '1'
1708 = '1'
1709 = '1'
1710 = '1'
1799 = '1'
1909 = '1'
2301 = '1'
2501 = '1'
other = '0';

/* -------------------------------------------------------------- */
/* ---   FORMAT FOR AGE STRATIFIERS                           --- */
/* ---   MODULE 3. ASSIGNS ARRAY INDEX FOR AGE CATEGORIES     --- */
/* -------------------------------------------------------------- */
value AGEFMT
low - 4 = 1
5 -  9 = 2
10 - 14 = 3
15 - 17 = 4
18 - 24 = 5
25 - 29 = 6
30 - 34 = 7
35 - 39 = 8
40 - 44 = 9
45 - 49 = 10
50 - 54 = 11
55 - 59 = 12
60 - 64 = 13
65 - 69 = 14
70 - 74 = 15
75 - 79 = 16
80 - 84 = 17
85 - high = 18
;

/*  Multiple Birth                    */
/* ICD-9-CM Diagnosis Codes: */
value $MULTIPD
'65100' = '1'  /* TWIN PREGNANCY-UNSPEC */
'65101' = '1'  /* TWIN PREGNANCY-DELIVERED */
'65103' = '1'  /* TWIN PREGNANCY-ANTEPART */
'65110' = '1'  /* TRIPLET PREGNANCY-UNSPEC */
'65111' = '1'  /* TRIPLET PREGNANCY-DELIV */
'65113' = '1'  /* TRIPLET PREG-ANTEPARTUM */
'65120' = '1'  /* QUADRUPLET PREG-UNSPEC */
'65121' = '1'  /* QUADRUPLET PREG-DELIVER */
'65123' = '1'  /* QUADRUPLET PREG-ANTEPART */
'65130' = '1'  /* TWINS W FETAL LOSS-UNSP */
'65131' = '1'  /* TWINS W FETAL LOSS-DEL */
'65133' = '1'  /* TWINS W FETAL LOSS-ANTE */
'65140' = '1'  /* TRIPLETS W FET LOSS-UNSP */
'65141' = '1'  /* TRIPLETS W FET LOSS-DEL */
'65143' = '1'  /* TRIPLETS W FET LOSS-ANTE */
'65150' = '1'  /* QUADS W FETAL LOSS-UNSP */
'65151' = '1'  /* QUADS W FETAL LOSS-DEL */
'65153' = '1'  /* QUADS W FETAL LOSS-ANTE */
'65160' = '1'  /* MULT GES W FET LOSS-UNSP */
'65161' = '1'  /* MULT GES W FET LOSS-DEL */
'65163' = '1'  /* MULT GES W FET LOSS-ANTE */
'65180' = '1'  /* MULTI GESTAT NEC-UNSPEC */
'65181' = '1'  /* MULTI GESTAT NEC-DELIVER */
'65183' = '1'  /* MULTI GEST NEC-ANTEPART */
'65190' = '1'  /* MULTI GESTAT NOS-UNSPEC */
'65191' = '1'  /* MULT GESTATION NOS-DELIV */
'65193' = '1'  /* MULTI GEST NOS-ANTEPART */
'65260' = '1'  /* MULT GEST MALPRESEN-UNSP */
'65261' = '1'  /* MULT GEST MALPRES-DELIV */
'65263' = '1'  /* MULT GES MALPRES-ANTEPAR */
'66050' = '1'  /* LOCKED TWINS-UNSPECIFIED */
'66051' = '1'  /* LOCKED TWINS-DELIVERED */
'66053' = '1'  /* LOCKED TWINS-ANTEPARTUM */
'66230' = '1'  /* DELAY DEL 2ND TWIN-UNSP */
'66231' = '1'  /* DELAY DEL 2ND TWIN-DELIV */
'66233' = '1'  /* DELAY DEL 2 TWIN-ANTEPAR */
'7615 ' = '1'  /* MULT PREGNANCY AFF NB */
'V271 ' = '1'  /* DELIVER-SINGLE STILLBORN */
'V272 ' = '1'  /* DELIVER-TWINS, BOTH LIVE */
'V273 ' = '1'  /* DEL-TWINS, 1 NB, 1 SB */
'V274 ' = '1'  /* DELIVER-TWINS, BOTH SB */
'V275 ' = '1'  /* DEL-MULT BIRTH, ALL LIVE */
'V276 ' = '1'  /* DEL-MULT BRTH, SOME LIVE */
'V277 ' = '1'  /* DEL-MULT BIRTH, ALL SB */
other  = '0';

value $PRCLASS
'0001' = 2
'0002' = 2
'0003' = 2
'0009' = 2
'0010' = 2
'0011' = 2
'0012' = 2
'0013' = 2
'0014' = 2
'0015' = 2
'0016' = 2
'0017' = 2
'0018' = 2
'0021' = 1
'0022' = 1
'0023' = 1
'0024' = 1
'0025' = 1
'0028' = 1
'0029' = 1
'0031' = 1
'0032' = 1
'0033' = 1
'0034' = 1
'0035' = 1
'0039' = 1
'0040' = 2
'0041' = 2
'0042' = 2
'0043' = 2
'0044' = 2
'0045' = 2
'0046' = 2
'0047' = 2
'0048' = 2
'0049' = 2
'0050' = 4
'0051' = 4
'0052' = 4
'0053' = 4
'0054' = 4
'0055' = 2
'0056' = 4
'0057' = 4
'0058' = 3
'0059' = 3
'0060' = 2
'0061' = 4
'0062' = 4
'0063' = 2
'0064' = 2
'0065' = 2
'0066' = 4
'0067' = 3
'0068' = 3
'0069' = 3
'0070' = 4
'0071' = 4
'0072' = 4
'0073' = 4
'0074' = 2
'0075' = 2
'0076' = 2
'0077' = 2
'0080' = 4
'0081' = 4
'0082' = 4
'0083' = 4
'0084' = 4
'0085' = 4
'0086' = 4
'0087' = 4
'0091' = 2
'0092' = 2
'0093' = 2
'0094' = 1
'0095' = 2  /** ADDED FOR V4.5 **/
'0101' = 2
'0102' = 2
'0109' = 2
'0110' = 1
'0111' = 1
'0112' = 3
'0113' = 1
'0114' = 3
'0115' = 3
'0116' = 1
'0117' = 1
'0118' = 3
'0119' = 3
'0120' = 4
'0121' = 4
'0122' = 4
'0123' = 4
'0124' = 4
'0125' = 4
'0126' = 2
'0127' = 2
'0128' = 4
'0129' = 4
'0131' = 4
'0132' = 4
'0139' = 4
'0141' = 4
'0142' = 4
'0151' = 4
'0152' = 4
'0153' = 4
'0159' = 4
'016' = 4
'0201' = 4
'0202' = 4
'0203' = 4
'0204' = 4
'0205' = 4
'0206' = 4
'0207' = 4
'0211' = 4
'0212' = 4
'0213' = 4
'0214' = 4
'022'  = 4
'0221' = 4
'0222' = 4
'0231' = 4
'0232' = 4
'0233' = 4
'0234' = 4
'0235' = 4
'0239' = 4
'0241' = 2
'0242' = 4
'0243' = 4
'0291' = 4
'0292' = 4
'0293' = 4
'0294' = 4
'0295' = 2
'0296' = 2
'0299' = 4
'0301' = 4
'0302' = 4
'0309' = 4
'031' = 4
'0321' = 4
'0329' = 4
'0331' = 1
'0332' = 3
'0339' = 3
'034' = 4
'0351' = 4
'0352' = 4
'0353' = 4
'0359' = 4
'036' = 4
'0371' = 4
'0372' = 4
'0379' = 4
'038' = 2
'0390' = 2
'0391' = 2
'0392' = 2
'0393' = 4
'0394' = 4
'0395' = 2
'0396' = 2
'0397' = 4
'0398' = 4
'0399' = 4
'0401' = 4
'0402' = 4
'0403' = 4
'0404' = 4
'0405' = 4
'0406' = 4
'0407' = 4
'0411' = 1
'0412' = 3
'0419' = 3
'042' = 2
'043' = 4
'0441' = 4
'0442' = 4
'0443' = 4
'0444' = 4
'0449' = 4
'045' = 4
'046' = 4
'0471' = 4
'0472' = 4
'0473' = 4
'0474' = 4
'0475' = 4
'0476' = 4
'0479' = 4
'0480' = 2
'0481' = 2
'0489' = 2
'0491' = 4
'0492' = 4
'0493' = 4
'0499' = 4
'050' = 4
'0511' = 3
'0519' = 3
'0521' = 4
'0522' = 4
'0523' = 4
'0524' = 4
'0525' = 4
'0529' = 4
'0531' = 2
'0532' = 2
'0539' = 2
'0581' = 4
'0589' = 4
'059' = 4
'0601' = 2
'0602' = 4
'0609' = 4
'0611' = 1
'0612' = 3
'0613' = 3
'0619' = 3
'062' = 4
'0631' = 4
'0639' = 4
'064' = 4
'0650' = 4
'0651' = 4
'0652' = 4
'066' = 4
'067' = 4
'0681' = 4
'0689' = 4
'0691' = 4
'0692' = 4
'0693' = 4
'0694' = 4
'0695' = 4
'0698' = 4
'0699' = 4
'0700' = 4
'0701' = 4
'0702' = 4
'0711' = 1
'0712' = 3
'0713' = 3
'0714' = 3
'0715' = 3
'0716' = 3
'0717' = 3
'0719' = 3
'0721' = 4
'0722' = 4
'0729' = 4
'073' = 4
'0741' = 4
'0742' = 4
'0743' = 4
'0744' = 4
'0745' = 4
'0749' = 4
'0751' = 4
'0752' = 4
'0753' = 4
'0754' = 4
'0759' = 4
'0761' = 4
'0762' = 4
'0763' = 4
'0764' = 4
'0765' = 4
'0768' = 4
'0769' = 4
'0771' = 4
'0772' = 4
'0779' = 4
'0780' = 4
'0781' = 4
'0782' = 4
'0791' = 4
'0792' = 4
'0793' = 4
'0794' = 4
'0799' = 4
'0801' = 2
'0802' = 2
'0809' = 2
'0811' = 3
'0819' = 1
'0820' = 4
'0821' = 4
'0822' = 4
'0823' = 4
'0824' = 4
'0825' = 4
'0831' = 4
'0832' = 4
'0833' = 4
'0834' = 4
'0835' = 4
'0836' = 4
'0837' = 4
'0838' = 4
'0841' = 4
'0842' = 4
'0843' = 4
'0844' = 4
'0849' = 4
'0851' = 4
'0852' = 4
'0859' = 4
'0861' = 4
'0862' = 4
'0863' = 4
'0864' = 4
'0869' = 4
'0870' = 4
'0871' = 4
'0872' = 4
'0873' = 4
'0874' = 4
'0881' = 2
'0882' = 2
'0883' = 2
'0884' = 2
'0885' = 2
'0886' = 2
'0887' = 2
'0889' = 2
'0891' = 4
'0892' = 4
'0893' = 4
'0899' = 4
'090' = 4
'0911' = 3
'0912' = 3
'0919' = 3
'0920' = 4
'0921' = 4
'0922' = 4
'0923' = 4
'093' = 4
'0941' = 4
'0942' = 4
'0943' = 4
'0944' = 4
'0949' = 4
'0951' = 4
'0952' = 4
'0953' = 4
'0959' = 4
'096' = 4
'0971' = 4
'0972' = 4
'0973' = 4
'0981' = 4
'0982' = 4
'0983' = 4
'0991' = 4
'0999' = 4
'100' = 4
'101' = 4
'1021' = 3
'1029' = 3
'1031' = 4
'1032' = 4
'1033' = 4
'1041' = 4
'1042' = 4
'1043' = 4
'1044' = 4
'1049' = 4
'105' = 4
'106' = 4
'1091' = 4
'1099' = 4
'110' = 4
'111' = 4
'1121' = 3
'1122' = 3
'1129' = 3
'1131' = 4
'1132' = 4
'1139' = 4
'1141' = 4
'1142' = 4
'1143' = 4
'1149' = 4
'1151' = 4
'1152' = 4
'1153' = 4
'1159' = 4
'1160' = 4
'1161' = 4
'1162' = 4
'1163' = 4
'1164' = 4
'1169' = 4
'1171' = 4
'1172' = 4
'1173' = 4
'1174' = 4
'1175' = 4
'1176' = 4
'1179' = 4
'1191' = 4
'1192' = 4
'1199' = 4
'1200' = 4
'1201' = 4
'1202' = 4
'1211' = 4
'1212' = 4
'1213' = 4
'1214' = 4
'1221' = 3
'1222' = 3
'1229' = 3
'1231' = 4
'1232' = 4
'1233' = 4
'1234' = 4
'1235' = 4
'1239' = 4
'1240' = 4
'1241' = 4
'1242' = 4
'1243' = 4
'1244' = 4
'1251' = 4
'1252' = 4
'1253' = 4
'1254' = 4
'1255' = 4
'1259' = 4
'1261' = 4
'1262' = 4
'1263' = 4
'1264' = 4
'1265' = 4
'1266' = 4
'1267' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1269' = 4
'1271' = 4
'1272' = 4
'1273' = 4
'1274' = 4
'1279' = 4
'1281' = 4
'1282' = 4
'1283' = 4
'1284' = 4
'1285' = 4
'1286' = 4
'1287' = 4
'1288' = 4
'1289' = 4
'1291' = 4
'1292' = 4
'1293' = 4
'1297' = 4
'1298' = 4
'1299' = 4
'1300' = 4
'1301' = 4
'1302' = 4
'1311' = 4
'1319' = 4
'132' = 4
'133' = 4
'1341' = 4
'1342' = 4
'1343' = 4
'1351' = 4
'1359' = 4
'1361' = 4
'1362' = 4
'1363' = 4
'1364' = 4
'1365' = 4
'1366' = 4
'1369' = 4
'1370' = 4
'1371' = 4
'1372' = 4
'138' = 4
'139' = 4
'1390' = 4
'1391' = 4
'1400' = 4
'1401' = 4
'1402' = 4
'1411' = 3
'1419' = 3
'1421' = 4
'1422' = 4
'1423' = 2
'1424' = 2
'1425' = 2
'1426' = 4
'1427' = 4
'1429' = 4
'1431' = 4
'1432' = 4
'1433' = 2
'1434' = 2
'1435' = 2
'1439' = 4
'1441' = 4
'1449' = 4
'1451' = 4
'1452' = 4
'1453' = 4
'1454' = 4
'1455' = 4
'1459' = 4
'146' = 4
'1471' = 4
'1472' = 4
'1473' = 4
'1474' = 4
'1475' = 4
'1479' = 4
'149' = 4
'1501' = 3
'1509' = 3
'1511' = 4
'1512' = 4
'1513' = 4
'1519' = 4
'1521' = 4
'1522' = 4
'1529' = 4
'153' = 4
'154' = 4
'155' = 4
'156' = 4
'157' = 4
'159' = 4
'1601' = 4
'1602' = 4
'1609' = 4
'161' = 4
'1621' = 1
'1622' = 3
'1623' = 3
'1629' = 3
'1631' = 4
'1639' = 4
'1641' = 4
'1642' = 4
'1649' = 4
'1651' = 4
'1652' = 4
'1659' = 4
'1661' = 4
'1662' = 4
'1663' = 4
'1664' = 4
'1665' = 4
'1666' = 4
'1669' = 4
'1671' = 4
'1672' = 4
'1681' = 4
'1682' = 4
'1689' = 4
'1691' = 2
'1692' = 4
'1693' = 4
'1698' = 4
'1699' = 4
'1741' = 2
'1742' = 2
'1743' = 2
'1744' = 2
'1745' = 2
'1749' = 2
'1751' = 4
'1752' = 4
'1753' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1754' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1755' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1756' = 4   /** Added new in V4.4 (Nov 2011)  **/
'1761' = 4
'1762' = 4
'1763' = 4
'1769' = 4
'1770' = 2
'1771' = 1
'1781' = 2   /** Added new in V4.4 (Nov 2011)  **/
'1801' = 2
'1802' = 2
'1809' = 2
'1811' = 1
'1812' = 1
'1819' = 1
'1821' = 4
'1829' = 2
'1831' = 4
'1839' = 4
'184'  = 2
'185'  = 4
'186'  = 4
'1871' = 4
'1872' = 4
'1879' = 4
'189' = 4
'190' = 4
'1911' = 4
'1919' = 4
'1921' = 4
'1929' = 4
'193' = 4
'194' = 4
'1952' = 4
'1953' = 4
'1954' = 4
'1955' = 4
'196' = 4
'199' = 4
'2001' = 4
'2009' = 2
'201' = 2
'2021' = 4
'2022' = 4
'2023' = 4
'2031' = 1
'2032' = 3
'2039' = 3
'2041' = 4
'2042' = 4
'2049' = 4
'2051' = 4
'2059' = 4
'2061' = 4
'2062' = 4
'2071' = 4
'2072' = 4
'2079' = 4
'208' = 2
'2091' = 4
'2092' = 4
'2093' = 4
'2094' = 2
'2095' = 4
'2096' = 4
'2097' = 4
'2098' = 4
'2099' = 4
'2100' = 2
'2101' = 2
'2102' = 2
'2103' = 2
'2104' = 4
'2105' = 4
'2106' = 4
'2107' = 4
'2109' = 4
'211' = 2
'2121' = 1
'2122' = 1
'2129' = 1
'2130' = 2
'2131' = 2
'2132' = 2
'214' = 4
'215' = 4
'2161' = 4
'2162' = 4
'2169' = 4
'2171' = 2
'2172' = 4
'2181' = 2
'2182' = 4
'2183' = 4
'2184' = 4
'2185' = 4
'2186' = 4
'2187' = 4
'2188' = 4
'2189' = 4
'2191' = 2
'2199' = 4
'2200' = 2
'2201' = 2
'2202' = 2
'2211' = 1
'2212' = 3
'2219' = 1
'222' = 2
'2231' = 4
'2239' = 4
'2241' = 4
'2242' = 4
'2250' = 4
'2251' = 4
'2252' = 4
'2253' = 4
'2260' = 4
'2261' = 4
'2262' = 4
'2263' = 4
'2264' = 4
'2271' = 4
'2279' = 4
'229' = 4
'2301' = 2
'2309' = 2
'2311' = 2
'2319' = 2
'232' = 2
'233' = 2
'2341' = 2
'2342' = 2
'2343' = 2
'2349' = 2
'235' = 2
'236' = 2
'2370' = 2
'2371' = 2
'2372' = 2
'2373' = 2
'240' = 2
'2411' = 1
'2412' = 1
'2419' = 1
'242' = 4
'2431' = 2
'2432' = 2
'2439' = 2
'244' = 4
'245' = 4
'246' = 2
'247' = 2
'248' = 2
'2491' = 2
'2499' = 2
'2501' = 1
'2502' = 3
'2509' = 1
'251' = 4
'252' = 4
'253' = 4
'254' = 4
'2551' = 2
'2559' = 4
'2591' = 2
'2592' = 2
'2593' = 2
'2594' = 4
'2599' = 4
'260' = 2
'2611' = 1
'2612' = 3
'2619' = 1
'2621' = 4
'2629' = 4
'2630' = 4
'2631' = 4
'2632' = 4
'2641' = 4
'2642' = 4
'2649' = 4
'2691' = 2
'2699' = 4
'270' = 4
'271' = 4
'2721' = 3
'2722' = 3
'2723' = 1
'2724' = 1
'2729' = 1
'2731' = 4
'2732' = 4
'2741' = 2
'2742' = 4
'2743' = 4
'2749' = 4
'2751' = 2
'2752' = 2
'2753' = 4
'2754' = 4
'2755' = 4
'2756' = 4
'2757' = 4
'2759' = 4
'2761' = 4
'2762' = 4
'2763' = 4
'2764' = 2
'2769' = 4
'2771' = 4
'2772' = 4
'2773' = 4
'2779' = 4
'2791' = 2
'2792' = 4
'2799' = 4
'280' = 4
'2811' = 3
'2819' = 3
'282' = 4
'283' = 4
'284' = 4
'285' = 4
'286' = 4
'287' = 4
'2891' = 4
'2892' = 4
'2899' = 4
'290' = 4
'2911' = 1
'2912' = 1
'2919' = 1
'292' = 4
'293' = 4
'2931' = 4
'2932' = 4
'2933' = 4
'2939' = 4
'294' = 4
'2951' = 4
'2952' = 4
'2953' = 4
'2954' = 4
'2959' = 4
'2991' = 2
'2992' = 4
'2999' = 4
'3001' = 4
'3009' = 4
'301' = 4
'3021' = 4
'3022' = 4
'3029' = 4
'303' = 4
'304' = 4
'310' = 2
'311' = 2
'3121' = 4
'3129' = 4
'313' = 4
'3141' = 1
'3142' = 1
'3143' = 1
'3144' = 1
'3145' = 3
'3148' = 1
'3149' = 1
'315' = 4
'3161' = 4
'3162' = 4
'3163' = 4
'3164' = 4
'3169' = 4
'3171' = 4
'3172' = 4
'3173' = 4
'3174' = 4
'3175' = 4
'3179' = 4
'3191' = 4
'3192' = 4
'3193' = 2
'3194' = 2
'3195' = 2
'3198' = 4
'3199' = 4
'320' = 4
'3201' = 2
'3209' = 4
'321' = 4
'3221' = 4
'3222' = 4
'3223' = 4
'3224' = 4
'3225' = 4
'3226' = 4
'3227' = 4
'3228' = 2
'3229' = 4
'323' = 4
'324' = 4
'325' = 4
'326' = 4
'329' = 4
'330' = 4
'331' = 4
'3321' = 1
'3322' = 1
'3323' = 1
'3324' = 1
'3325' = 3
'3326' = 1
'3327' = 3
'3328' = 3
'3329' = 3
'3331' = 2
'3332' = 2
'3333' = 2
'3334' = 4
'3339' = 4
'3341' = 4
'3342' = 4
'3343' = 4
'3348' = 4
'3349' = 4
'335' = 4
'3350' = 4
'3351' = 4
'3352' = 4
'336' = 4
'3371' = 2
'3372' = 2
'3373' = 2
'3378' = 2
'3379' = 2
'3391' = 2
'3392' = 4
'3393' = 4
'3398' = 4
'3399' = 4
'3401' = 2
'3402' = 4
'3403' = 4
'3404' = 2
'3405' = 2
'3409' = 2
'341' = 4
'3421' = 3
'3422' = 3
'3423' = 1
'3424' = 1
'3425' = 1
'3426' = 3
'3427' = 3
'3428' = 3
'3429' = 3
'343' = 4
'344' = 4
'3451' = 4
'3459' = 4
'346' = 4
'3471' = 2
'3472' = 2
'3473' = 4
'3474' = 4
'3479' = 4
'3481' = 4
'3482' = 4
'3483' = 4
'3484' = 4
'3485' = 4
'3489' = 4
'3491' = 2
'3492' = 2
'3493' = 4
'3499' = 4
'3500' = 4
'3501' = 4
'3502' = 4
'3503' = 4
'3504' = 4
'3505' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3506' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3507' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3508' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3509' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3510' = 4
'3511' = 4
'3512' = 4
'3513' = 4
'3514' = 4
'3520' = 4
'3521' = 4
'3522' = 4
'3523' = 4
'3524' = 4
'3525' = 4
'3526' = 4
'3527' = 4
'3528' = 4
'3531' = 4
'3532' = 4
'3533' = 4
'3534' = 4
'3535' = 4
'3539' = 4
'3541' = 2
'3542' = 4
'3550' = 4
'3551' = 4
'3552' = 4
'3553' = 4
'3554' = 4
'3555' = 4
'3560' = 4
'3561' = 4
'3562' = 4
'3563' = 4
'3570' = 4
'3571' = 4
'3572' = 4
'3573' = 4
'3581' = 4
'3582' = 4
'3583' = 4
'3584' = 4
'3591' = 4
'3592' = 4
'3593' = 4
'3594' = 4
'3595' = 4
'3596' = 4
'3597' = 4
'3598' = 4
'3599' = 4
'3600' = 4
'3601' = 4
'3602' = 4
'3603' = 4
'3604' = 2
'3605' = 4
'3606' = 2
'3607' = 2
'3609' = 4
'3610' = 4
'3611' = 4
'3612' = 4
'3613' = 4
'3614' = 4
'3615' = 4
'3616' = 4
'3617' = 4
'3619' = 4
'362' = 4
'363' = 4
'3631' = 4
'3632' = 4
'3633' = 4
'3634' = 4
'3639' = 4
'3691' = 4
'3699' = 4
'370' = 2
'3710' = 4
'3711' = 4
'3712' = 4
'3720' = 1
'3721' = 1
'3722' = 1
'3723' = 1
'3724' = 3
'3725' = 1
'3726' = 1
'3727' = 1
'3728' = 1
'3729' = 1
'3731' = 4
'3732' = 4
'3733' = 4
'3734' = 4
'3735' = 4
'3736' = 2
'3737' = 4
'374' = 4
'3741' = 4
'3749' = 4
'375' = 4
'3751' = 4
'3752' = 4
'3753' = 4
'3754' = 4
'3760' = 4
'3761' = 4
'3762' = 4
'3763' = 4
'3764' = 4
'3765' = 4
'3766' = 4
'3767' = 4
'3768' = 4
'3770' = 2
'3771' = 2
'3772' = 2
'3773' = 2
'3774' = 4
'3775' = 4
'3776' = 4
'3777' = 4
'3778' = 2
'3779' = 4
'3780' = 4
'3781' = 2
'3782' = 2
'3783' = 2
'3785' = 4
'3786' = 4
'3787' = 4
'3789' = 4
'3790' = 2
'3791' = 4
'3792' = 2
'3793' = 2
'3794' = 4
'3795' = 4
'3796' = 4
'3797' = 4
'3798' = 4
'3799' = 4
'3800' = 4
'3801' = 4
'3802' = 4
'3803' = 4
'3804' = 4
'3805' = 4
'3806' = 4
'3807' = 4
'3808' = 4
'3809' = 4
'3810' = 4
'3811' = 4
'3812' = 4
'3813' = 4
'3814' = 4
'3815' = 4
'3816' = 4
'3818' = 4
'3821' = 3
'3822' = 1
'3823' = 1
'3824' = 1
'3825' = 1
'3826' = 4   /** Added new in V4.4 (Nov 2011)  **/
'3829' = 3
'3830' = 4
'3831' = 4
'3832' = 4
'3833' = 4
'3834' = 4
'3835' = 4
'3836' = 4
'3837' = 4
'3838' = 4
'3839' = 4
'3840' = 4
'3841' = 4
'3842' = 4
'3843' = 4
'3844' = 4
'3845' = 4
'3846' = 4
'3847' = 4
'3848' = 4
'3849' = 4
'3850' = 4
'3851' = 4
'3852' = 4
'3853' = 4
'3855' = 4
'3857' = 4
'3859' = 4
'3860' = 4
'3861' = 4
'3862' = 4
'3863' = 4
'3864' = 4
'3865' = 4
'3866' = 4
'3867' = 4
'3868' = 4
'3869' = 4
'387' = 4
'3880' = 4
'3881' = 4
'3882' = 4
'3883' = 4
'3884' = 4
'3885' = 4
'3886' = 4
'3887' = 4
'3888' = 4
'3889' = 4
'3891' = 2
'3892' = 2
'3893' = 2
'3894' = 2
'3895' = 2
'3897' = 2
'3898' = 2
'3899' = 2
'390' = 4
'391'  = 4
'3921' = 4
'3922' = 4
'3923' = 4
'3924' = 4
'3925' = 4
'3926' = 4
'3927' = 4
'3928' = 4
'3929' = 4
'3930' = 4
'3931' = 4
'3932' = 4
'3941' = 4
'3942' = 4
'3943' = 4
'3949' = 4
'3950' = 4
'3951' = 4
'3952' = 4
'3953' = 4
'3954' = 4
'3955' = 4
'3956' = 4
'3957' = 4
'3958' = 4
'3959' = 4
'3961' = 2
'3962' = 2
'3963' = 2
'3964' = 2
'3965' = 4
'3966' = 2
'397'  = 4
'3971' = 4
'3972' = 4
'3973' = 4
'3974' = 4
'3975' = 4
'3976' = 4
'3977' = 4
'3978' = 4
'3979' = 4
'398'  = 4
'3981' = 4
'3982' = 4
'3983' = 4
'3984' = 4
'3985' = 4
'3986' = 4
'3987' = 4
'3988' = 4
'3989' = 4
'3990' = 2
'3991' = 4
'3992' = 4
'3993' = 4
'3994' = 4
'3995' = 2
'3996' = 2
'3997' = 2
'3998' = 4
'3999' = 4
'400'  = 4
'4011' = 3
'4019' = 3
'4021' = 4
'4022' = 4
'4023' = 4
'4024' = 4
'4029' = 4
'403' = 4
'4040' = 4
'4041' = 4
'4042' = 4
'4050' = 4
'4051' = 4
'4052' = 4
'4053' = 4
'4054' = 4
'4059' = 4
'4061' = 4
'4062' = 4
'4063' = 4
'4064' = 4
'4069' = 4
'409' = 4
'410' = 2
'4100' = 2
'4101' = 2
'4102' = 2
'4103' = 2
'4104' = 2
'4105' = 2
'4106' = 2
'4107' = 2
'4108' = 2
'4109' = 2
'411' = 2
'412' = 4
'4131' = 1
'4132' = 1
'4133' = 3
'4138' = 1
'4139' = 1
'4141' = 4
'4142' = 4
'4143' = 4
'415' = 4
'4191' = 2
'4192' = 2
'4193' = 4
'4194' = 4
'4195' = 4
'4198' = 2
'4199' = 4
'4201' = 4
'4209' = 4
'4210' = 4
'4211' = 4
'4212' = 4
'4219' = 4
'4221' = 3
'4222' = 1
'4223' = 1
'4224' = 1
'4225' = 3
'4229' = 1
'4231' = 4
'4232' = 4
'4233' = 2
'4239' = 4
'4240' = 4
'4241' = 4
'4242' = 4
'4251' = 4
'4252' = 4
'4253' = 4
'4254' = 4
'4255' = 4
'4256' = 4
'4258' = 4
'4259' = 4
'4261' = 4
'4262' = 4
'4263' = 4
'4264' = 4
'4265' = 4
'4266' = 4
'4268' = 4
'4269' = 4
'427' = 4
'4281' = 2
'4282' = 4
'4283' = 4
'4284' = 4
'4285' = 4
'4286' = 4
'4287' = 4
'4289' = 4
'4291' = 4
'4292' = 2
'4299' = 2
'430' = 4
'431' = 4
'4311' = 2
'4319' = 2
'432' = 4
'433' = 4
'4341' = 2
'4342' = 4
'4349' = 4
'435' = 4
'436' = 4
'437' = 4
'4381' = 4
'4382' = 4   /** Added new in V4.4 (Nov 2011)  **/
'4389' = 4
'4391' = 4
'4399' = 4
'4400' = 4
'4401' = 4
'4402' = 4
'4403' = 4
'4411' = 3
'4412' = 1
'4413' = 1
'4414' = 1
'4415' = 3
'4419' = 1
'442' = 4
'4421' = 4
'4422' = 2
'4429' = 4
'4431' = 4
'4432' = 4
'4438' = 4
'4439' = 4
'4440' = 4
'4441' = 4
'4442' = 4
'4443' = 2
'4444' = 2
'4449' = 2
'445' = 4
'4461' = 4
'4462' = 2
'4463' = 4
'4464' = 4
'4465' = 4
'4466' = 4
'4467' = 4
'4468' = 4
'4469' = 4
'4491' = 4
'4492' = 4
'4493' = 2
'4494' = 2
'4495' = 4
'4496' = 4
'4497' = 4
'4498' = 4
'4499' = 4
'4500' = 4
'4501' = 4
'4502' = 4
'4503' = 4
'4511' = 3
'4512' = 1
'4513' = 1
'4514' = 1
'4515' = 3
'4516' = 1
'4519' = 1
'4521' = 3
'4522' = 1
'4523' = 1
'4524' = 1
'4525' = 1
'4526' = 3
'4527' = 1
'4528' = 1
'4529' = 1
'4530' = 2
'4531' = 4
'4532' = 4
'4533' = 4
'4534' = 4
'4541' = 4
'4542' = 2
'4543' = 2
'4549' = 4
'4550' = 4
'4551' = 4
'4552' = 4
'4561' = 4
'4562' = 4
'4563' = 4
'4571' = 4
'4572' = 4
'4573' = 4
'4574' = 4
'4575' = 4
'4576' = 4
'4579' = 4
'458' = 4
'4590' = 4
'4591' = 4
'4592' = 4
'4593' = 4
'4594' = 4
'4595' = 4
'4601' = 4
'4602' = 4
'4603' = 4
'4604' = 4
'4610' = 4
'4611' = 4
'4612' = 4
'4613' = 4
'4614' = 2
'4620' = 4
'4621' = 4
'4622' = 4
'4623' = 4
'4624' = 2
'4631' = 2
'4632' = 2
'4639' = 2
'4640' = 4
'4641' = 4
'4642' = 4
'4643' = 4
'4650' = 4
'4651' = 4
'4652' = 4
'4660' = 4
'4661' = 4
'4662' = 4
'4663' = 4
'4664' = 4
'4671' = 4
'4672' = 4
'4673' = 4
'4674' = 4
'4675' = 4
'4676' = 4
'4679' = 4
'4680' = 4
'4681' = 4
'4682' = 4
'4685' = 2
'4686' = 2
'4687' = 2
'4691' = 4
'4692' = 4
'4693' = 4
'4694' = 4
'4695' = 2
'4696' = 2
'4697' = 4
'4699' = 4
'470' = 4
'4701' = 4
'4709' = 4
'471' = 4
'4711' = 4
'4719' = 4
'472' = 4
'4791' = 4
'4792' = 4
'4799' = 4
'480' = 4
'481' = 4
'4821' = 3
'4822' = 1
'4823' = 1
'4824' = 1
'4825' = 3
'4826' = 1
'4829' = 1
'4831' = 2
'4832' = 2
'4833' = 2
'4834' = 2
'4835' = 4
'4836' = 2
'4840' = 4
'4841' = 4
'4849' = 4
'485' = 4
'4850' = 4
'4861' = 4
'4862' = 4
'4863' = 4
'4864' = 4
'4865' = 4
'4866' = 4
'4869' = 4
'4871' = 4
'4872' = 4
'4873' = 4
'4874' = 4
'4875' = 4
'4876' = 4
'4879' = 4
'4881' = 4
'4882' = 4
'4891' = 4
'4892' = 4
'4893' = 4
'4899' = 4
'4901' = 4
'4902' = 4
'4903' = 2
'4904' = 4
'4911' = 4
'4912' = 4
'4921' = 1
'4922' = 1
'4923' = 1
'4929' = 1
'493' = 4
'4931' = 2
'4939' = 4
'4941' = 2
'4942' = 2
'4943' = 2
'4944' = 4
'4945' = 4
'4946' = 4
'4947' = 2
'4949' = 4
'4951' = 4
'4952' = 4
'4959' = 4
'496' = 4
'4971' = 4
'4972' = 4
'4973' = 4
'4974' = 4
'4975' = 4
'4976' = 4
'4979' = 4
'4991' = 4
'4992' = 4
'4993' = 4
'4994' = 4
'4995' = 4
'4999' = 4
'500' = 4
'5011' = 1
'5012' = 3
'5013' = 1
'5019' = 3
'5021' = 4
'5022' = 4
'5023' = 4
'5024' = 4
'5025' = 4
'5026' = 4
'5029' = 4
'503' = 4
'504' = 4
'5051' = 4
'5059' = 4
'5061' = 4
'5069' = 4
'5091' = 2
'5092' = 2
'5093' = 2
'5094' = 2
'5099' = 2
'5101' = 2
'5102' = 4
'5103' = 4
'5104' = 4
'5110' = 1
'5111' = 1
'5112' = 1
'5113' = 3
'5114' = 1
'5115' = 1
'5119' = 3
'5121' = 4
'5122' = 4
'5123' = 4
'5124' = 4
'5131' = 4
'5132' = 4
'5133' = 4
'5134' = 4
'5135' = 4
'5136' = 4
'5137' = 4
'5139' = 4
'5141' = 4
'5142' = 4
'5143' = 4
'5149' = 4
'5151' = 4
'5159' = 4
'5161' = 4
'5162' = 4
'5163' = 4
'5164' = 2
'5169' = 4
'5171' = 4
'5172' = 4
'5179' = 4
'5181' = 4
'5182' = 4
'5183' = 4
'5184' = 2
'5185' = 2
'5186' = 2
'5187' = 2
'5188' = 2
'5189' = 4
'5191' = 4
'5192' = 4
'5193' = 4
'5194' = 4
'5195' = 4
'5196' = 2
'5197' = 2
'5198' = 2
'5199' = 4
'5201' = 4
'5209' = 4
'5211' = 1
'5212' = 3
'5213' = 1
'5214' = 1
'5219' = 3
'522' = 4
'5221' = 2
'5222' = 4
'523' = 4
'524' = 4
'5251' = 4
'5252' = 4
'5253' = 4
'5259' = 4
'526' = 4
'527' = 4
'5280' = 4
'5281' = 4
'5282' = 4
'5283' = 4
'5284' = 2
'5285' = 2
'5286' = 2
'5291' = 4
'5292' = 4
'5293' = 2
'5294' = 2
'5295' = 4
'5296' = 4
'5297' = 2
'5298' = 2
'5299' = 4
'5300' = 4
'5301' = 4
'5302' = 4
'5303' = 4
'5304' = 4
'5305' = 4
'5310' = 4
'5311' = 4
'5312' = 4
'5313' = 4
'5314' = 4
'5315' = 4
'5316' = 4
'5317' = 4
'5321' = 4
'5329' = 4
'5331' = 4
'5339' = 4
'5341' = 4
'5349' = 4
'5351' = 4
'5359' = 4
'5361' = 4
'5369' = 4
'537' = 4
'5380' = 4
'5381' = 4
'5382' = 4
'539' = 4
'540' = 4
'5411' = 4
'5412' = 4
'5419' = 4
'5421' = 3
'5422' = 3
'5423' = 3
'5424' = 1
'5425' = 1
'5429' = 3
'543' = 4
'544' = 4
'545' = 4
'5451' = 4
'5459' = 4
'5461' = 4
'5462' = 4
'5463' = 4
'5464' = 4
'5471' = 4
'5472' = 4
'5473' = 4
'5474' = 4
'5475' = 4
'5491' = 2
'5492' = 4
'5493' = 4
'5494' = 4
'5495' = 4
'5496' = 2
'5497' = 2
'5498' = 2
'5499' = 2
'5501' = 4
'5502' = 4
'5503' = 4
'5504' = 4
'5511' = 4
'5512' = 4
'5521' = 1
'5522' = 1
'5523' = 1
'5524' = 3
'5529' = 3
'5531' = 4
'5532' = 4
'5533' = 4
'5534' = 4
'5535' = 4
'5539' = 4
'554' = 4
'5551' = 4
'5552' = 4
'5553' = 4
'5554' = 4
'5561' = 4
'5569' = 4
'557' = 4
'5581' = 4
'5582' = 4
'5583' = 4
'5584' = 4
'5585' = 4
'5586' = 4
'5587' = 4
'5589' = 4
'5591' = 4
'5592' = 2
'5593' = 2
'5594' = 2
'5595' = 2
'5596' = 2
'5597' = 4
'5598' = 4
'5599' = 4
'560' = 4
'561' = 4
'562' = 4
'5631' = 1
'5632' = 1
'5633' = 1
'5634' = 3
'5635' = 1
'5639' = 3
'5640' = 4
'5641' = 4
'5642' = 4
'5651' = 4
'5652' = 4
'5661' = 4
'5662' = 4
'5671' = 4
'5672' = 4
'5673' = 4
'5674' = 4
'5675' = 4
'5679' = 4
'5681' = 4
'5682' = 4
'5683' = 4
'5684' = 4
'5685' = 4
'5686' = 4
'5689' = 4
'5691' = 2
'5692' = 4
'5693' = 4
'5694' = 4
'5695' = 4
'5699' = 4
'570' = 2
'5711' = 2
'5712' = 4
'5717' = 2
'5718' = 4
'5719' = 4
'5721' = 4
'5722' = 4
'5731' = 1
'5732' = 1
'5733' = 3
'5734' = 3
'5739' = 3
'5741' = 4
'5749' = 4
'5751' = 4
'5759' = 4
'576' = 4
'5771' = 4
'5779' = 4
'5781' = 4
'5782' = 4
'5783' = 4
'5784' = 4
'5785' = 4
'5786' = 4
'5787' = 4
'5788' = 4
'5789' = 4
'5791' = 4
'5792' = 2
'5793' = 4
'5794' = 2
'5795' = 2
'5796' = 4
'5797' = 4
'5798' = 4
'5799' = 4
'580' = 4
'581' = 4
'5821' = 1
'5822' = 1
'5823' = 1
'5824' = 1
'5829' = 1
'583' = 2
'5831' = 2
'5839' = 2
'5841' = 4
'5842' = 4
'5843' = 4
'5844' = 4
'5845' = 4
'5846' = 4
'5847' = 4
'5849' = 4
'585' = 4
'586' = 2
'5891' = 4
'5892' = 4
'5893' = 4
'5899' = 4
'5900' = 4
'5901' = 4
'5902' = 4
'5903' = 4
'5909' = 4
'5911' = 4
'5912' = 4
'5919' = 4
'5921' = 3
'5929' = 3
'593' = 4
'594' = 4
'595' = 4
'596' = 4
'5971' = 4
'5972' = 2
'5979' = 4
'598' = 2
'5991' = 4
'5992' = 4
'5993' = 2
'5994' = 2
'5995' = 2
'5996' = 2
'5999' = 2
'600' = 4
'6011' = 1
'6012' = 3
'6013' = 1
'6014' = 3
'6015' = 3
'6018' = 3
'6019' = 3
'602' = 4
'6021' = 4
'6029' = 4
'603' = 4
'604' = 4
'605' = 4
'6061' = 4
'6062' = 4
'6069' = 4
'6071' = 2
'6072' = 4
'6073' = 4
'6079' = 4
'6081' = 4
'6082' = 4
'6091' = 2
'6092' = 2
'6093' = 4
'6094' = 4
'6095' = 4
'6096' = 4
'6097' = 4
'6099' = 4
'610' = 2
'6111' = 1
'6119' = 1
'612' = 4
'613' = 2
'6141' = 2
'6142' = 4
'6149' = 4
'6191' = 2
'6192' = 4
'6199' = 4
'620' = 4
'6211' = 1
'6212' = 3
'6219' = 3
'622' = 4
'623' = 4
'6241' = 4
'6242' = 4
'625' = 4
'6261' = 4
'6269' = 4
'627' = 4
'6291' = 2
'6292' = 2
'6299' = 4
'6301' = 1
'6309' = 3
'631' = 4
'632' = 4
'633' = 4
'634' = 4
'6351' = 4
'6352' = 2
'6353' = 4
'6359' = 4
'636' = 2
'6370' = 2
'6371' = 2
'6372' = 2
'6373' = 2
'6381' = 4
'6382' = 4
'6383' = 4
'6384' = 2
'6385' = 4
'6389' = 4
'6391' = 2
'6392' = 4
'6393' = 4
'6394' = 4
'6395' = 4
'6399' = 4
'640' = 4
'6411' = 3
'6419' = 1
'642' = 4
'643' = 4
'6441' = 4
'6442' = 4
'6443' = 4
'6444' = 4
'6445' = 4
'6449' = 4
'645' = 4
'6491' = 2
'6492' = 4
'6493' = 4
'6494' = 2
'6495' = 4
'6496' = 4
'6497' = 4
'6498' = 4
'6499' = 4
'650' = 4
'6501' = 4
'6509' = 4
'6511' = 3
'6512' = 3
'6513' = 3
'6514' = 3
'6519' = 3
'6521' = 4
'6522' = 4
'6523' = 4
'6524' = 4
'6525' = 4
'6529' = 4
'653' = 4
'6531' = 4
'6539' = 4
'654' = 4
'6541' = 4
'6549' = 4
'6551' = 4
'6552' = 4
'6553' = 4
'6554' = 4
'6561' = 4
'6562' = 4
'6563' = 4
'6564' = 4
'6571' = 4
'6572' = 4
'6573' = 4
'6574' = 4
'6575' = 4
'6576' = 4
'6579' = 4
'658' = 4
'6581' = 4
'6589' = 4
'6591' = 4
'6592' = 4
'6593' = 4
'6594' = 4
'6595' = 4
'6599' = 4
'660' = 4
'6601' = 4
'6602' = 4
'6611' = 3
'6619' = 3
'6621' = 4
'6622' = 4
'6629' = 4
'6631' = 4
'6632' = 4
'6639' = 4
'664' = 4
'6651' = 4
'6652' = 4
'6661' = 4
'6662' = 4
'6663' = 4
'6669' = 4
'6671' = 4
'6672' = 4
'6673' = 4
'6674' = 4
'6679' = 4
'668' = 2
'6691' = 2
'6692' = 4
'6693' = 4
'6694' = 4
'6695' = 4
'6696' = 4
'6697' = 4
'6699' = 4
'670' = 2
'6711' = 3
'6712' = 3
'6719' = 3
'672' = 4
'6731' = 4
'6732' = 4
'6733' = 4
'6739' = 4
'674' = 4
'675' = 4
'6751' = 4
'6759' = 4
'6761' = 4
'6762' = 4
'6769' = 4
'680' = 4
'6811' = 1
'6812' = 1
'6813' = 3
'6814' = 3
'6815' = 3
'6816' = 3
'6819' = 3
'6821' = 4
'6822' = 4
'6823' = 4
'6824' = 4   /** Added new in V4.4 (Nov 2011)  **/
'6825' = 4   /** Added new in V4.4 (Nov 2011)  **/
'6829' = 4
'683' = 4
'6831' = 4
'6839' = 4
'684' = 4
'6841' = 4
'6849' = 4
'685' = 4
'6851' = 4
'6859' = 4
'686' = 4
'6861' = 4
'6869' = 4
'687' = 4
'6871' = 4
'6879' = 4
'688' = 4
'689' = 4
'6901' = 4
'6902' = 4
'6909' = 3
'6911' = 4
'6919' = 4
'6921' = 4
'6922' = 4
'6923' = 4
'6929' = 4
'693' = 4
'6941' = 4
'6942' = 4
'6949' = 4
'6951' = 4
'6952' = 4
'6959' = 2
'696' = 2
'697' = 2
'6991' = 2
'6992' = 2
'6993' = 2
'6994' = 2
'6995' = 4
'6996' = 2
'6997' = 4
'6998' = 4
'6999' = 4
'700' = 2
'7011' = 2
'7012' = 4
'7013' = 4
'7014' = 4
'7021' = 1
'7022' = 1
'7023' = 3
'7024' = 3
'7029' = 3
'7031' = 4
'7032' = 4
'7033' = 4
'704' = 4
'7050' = 4
'7051' = 4
'7052' = 4
'7061' = 4
'7062' = 4
'7071' = 4
'7072' = 4
'7073' = 4
'7074' = 4
'7075' = 4
'7076' = 4
'7077' = 4
'7079' = 4
'708' = 4
'7091' = 4
'7092' = 4
'7094' = 2
'7095' = 2
'7101' = 4
'7109' = 4
'7111' = 3
'7119' = 3
'7121' = 2
'7122' = 4
'7123' = 4
'7124' = 4
'7129' = 4
'713' = 4
'714' = 4
'715' = 4
'7161' = 4
'7162' = 4
'7171' = 4
'7172' = 4
'7179' = 4
'718' = 4
'719' = 4
'720' = 2
'721' = 2
'7221' = 2
'7229' = 2
'7231' = 2
'7239' = 2
'724' = 2
'7251' = 2
'7252' = 2
'7253' = 2
'7254' = 2
'726' = 2
'7271' = 2
'7279' = 2
'728' = 2
'729' = 2
'7301' = 2
'7309' = 2
'731' = 2
'7321' = 2
'7322' = 2
'733' = 2
'734' = 2
'7351' = 2
'7359' = 2
'736' = 2
'738' = 2
'7391' = 2
'7392' = 2
'7393' = 2
'7394' = 4
'7399' = 4
'740' = 4
'741' = 4
'742' = 4
'743' = 4
'744' = 4
'7491' = 4
'7499' = 4
'750' = 2
'751' = 1
'752' = 2
'7531' = 1
'7532' = 1
'7533' = 1
'7534' = 1
'7535' = 1
'7536' = 4
'7537' = 2
'7538' = 1
'754' = 2
'7550' = 4
'7551' = 4
'7552' = 4
'7561' = 4
'7562' = 2
'7569' = 2
'757' = 2
'758' = 2
'7591' = 2
'7592' = 2
'7593' = 4
'7594' = 2
'7599' = 4
'7601' = 4
'7609' = 4
'7611' = 3
'7619' = 3
'762' = 4
'7631' = 4
'7639' = 4
'7641' = 4
'7642' = 4
'7643' = 4
'7644' = 4
'7645' = 4
'7646' = 4
'765' = 4
'7661' = 4
'7662' = 4
'7663' = 4
'7664' = 4
'7665' = 4
'7666' = 4
'7667' = 4
'7668' = 4
'7669' = 4
'7670' = 4
'7671' = 2
'7672' = 4
'7673' = 2
'7674' = 4
'7675' = 2
'7676' = 4
'7677' = 4
'7678' = 2
'7679' = 4
'7691' = 4
'7692' = 4
'7693' = 2
'7694' = 4
'7695' = 2
'7696' = 2
'7697' = 4
'7699' = 4
'7700' = 4
'7701' = 4
'7702' = 4
'7703' = 4
'7704' = 4
'7705' = 4
'7706' = 4
'7707' = 4
'7708' = 4
'7709' = 4
'7710' = 4
'7711' = 4
'7712' = 4
'7713' = 4
'7714' = 4
'7715' = 4
'7716' = 4
'7717' = 4
'7718' = 4
'7719' = 4
'7720' = 4
'7721' = 4
'7722' = 4
'7723' = 4
'7724' = 4
'7725' = 4
'7726' = 4
'7727' = 4
'7728' = 4
'7729' = 4
'7730' = 4
'7731' = 4
'7732' = 4
'7733' = 4
'7734' = 4
'7735' = 4
'7736' = 4
'7737' = 4
'7738' = 4
'7739' = 4
'7740' = 3
'7741' = 3
'7742' = 3
'7743' = 3
'7744' = 3
'7745' = 3
'7746' = 3
'7747' = 3
'7748' = 3
'7749' = 3
'7751' = 4
'7752' = 4
'7753' = 4
'7754' = 4
'7756' = 4
'7757' = 4
'7758' = 4
'7759' = 4
'7760' = 4
'7761' = 4
'7762' = 4
'7763' = 4
'7764' = 4
'7765' = 4
'7766' = 4
'7767' = 4
'7768' = 4
'7769' = 4
'7770' = 4
'7771' = 4
'7772' = 4
'7773' = 4
'7774' = 4
'7775' = 4
'7776' = 4
'7777' = 4
'7778' = 4
'7779' = 4
'7780' = 4
'7781' = 4
'7782' = 4
'7783' = 4
'7784' = 4
'7785' = 4
'7786' = 4
'7787' = 4
'7788' = 4
'7789' = 4
'7790' = 4
'7791' = 4
'7792' = 4
'7793' = 4
'7794' = 4
'7795' = 4
'7796' = 4
'7797' = 4
'7798' = 4
'7799' = 4
'7800' = 4
'7801' = 4
'7802' = 4
'7803' = 4
'7804' = 4
'7805' = 4
'7806' = 4
'7807' = 4
'7808' = 4
'7809' = 4
'7810' = 4
'7811' = 4
'7812' = 4
'7813' = 4
'7814' = 4
'7815' = 4
'7816' = 4
'7817' = 4
'7818' = 4
'7819' = 4
'7820' = 4
'7822' = 4
'7823' = 4
'7824' = 4
'7825' = 4
'7827' = 4
'7828' = 4
'7829' = 4
'7830' = 4
'7831' = 4
'7832' = 4
'7833' = 4
'7834' = 4
'7835' = 4
'7837' = 4
'7838' = 4
'7839' = 4
'7840' = 4
'7841' = 4
'7842' = 4
'7843' = 4
'7844' = 4
'7845' = 4
'7846' = 4
'7847' = 4
'7848' = 4
'7849' = 4
'7850' = 4
'7851' = 4
'7852' = 4
'7853' = 4
'7854' = 4
'7855' = 4
'7856' = 4
'7857' = 4
'7858' = 4
'7859' = 4
'7860' = 4
'7861' = 4
'7862' = 4
'7863' = 4
'7864' = 4
'7865' = 4
'7866' = 4
'7867' = 4
'7868' = 4
'7869' = 4
'7870' = 4
'7871' = 4
'7872' = 4
'7873' = 4
'7874' = 4
'7875' = 4
'7876' = 4
'7877' = 4
'7878' = 4
'7879' = 4
'7880' = 3
'7881' = 3
'7882' = 3
'7883' = 3
'7884' = 3
'7885' = 3
'7886' = 3
'7887' = 3
'7888' = 3
'7889' = 3
'7890' = 4
'7891' = 4
'7892' = 4
'7893' = 4
'7894' = 4
'7895' = 4
'7896' = 4
'7897' = 4
'7898' = 4
'7899' = 4
'7900' = 2
'7901' = 2
'7902' = 2
'7903' = 2
'7904' = 2
'7905' = 2
'7906' = 2
'7907' = 2
'7908' = 2
'7909' = 2
'7910' = 4
'7911' = 4
'7912' = 4
'7913' = 4
'7914' = 4
'7915' = 4
'7916' = 4
'7917' = 4
'7918' = 4
'7919' = 4
'7920' = 4
'7921' = 4
'7922' = 4
'7923' = 4
'7924' = 4
'7925' = 4
'7926' = 4
'7927' = 4
'7928' = 4
'7929' = 4
'7930' = 4
'7931' = 4
'7932' = 4
'7933' = 4
'7934' = 4
'7935' = 4
'7936' = 4
'7937' = 4
'7938' = 4
'7939' = 4
'7940' = 4
'7941' = 4
'7942' = 4
'7945' = 4
'7946' = 4
'7949' = 4
'7950' = 4
'7951' = 4
'7952' = 4
'7955' = 4
'7956' = 4
'7959' = 4
'7960' = 4
'7961' = 4
'7962' = 4
'7963' = 4
'7964' = 4
'7965' = 4
'7966' = 4
'7967' = 4
'7968' = 4
'7969' = 4
'7970' = 2
'7971' = 2
'7972' = 2
'7973' = 2
'7974' = 2
'7975' = 2
'7976' = 2
'7977' = 2
'7978' = 2
'7979' = 2
'7980' = 4
'7981' = 4
'7982' = 4
'7983' = 4
'7984' = 4
'7985' = 4
'7986' = 4
'7987' = 4
'7988' = 4
'7989' = 4
'7990' = 4
'7991' = 4
'7992' = 4
'7993' = 4
'7994' = 4
'7995' = 4
'7996' = 4
'7997' = 4
'7998' = 4
'7999' = 4
'8000' = 4
'8001' = 4
'8002' = 4
'8003' = 4
'8004' = 4
'8005' = 4
'8006' = 4
'8007' = 4
'8008' = 4
'8009' = 4
'8010' = 4
'8011' = 4
'8012' = 4
'8013' = 4
'8014' = 4
'8015' = 4
'8016' = 4
'8017' = 4
'8018' = 4
'8019' = 4
'8020' = 3
'8021' = 3
'8022' = 3
'8023' = 3
'8024' = 3
'8025' = 3
'8026' = 3
'8027' = 3
'8028' = 3
'8029' = 3
'8030' = 1
'8031' = 1
'8032' = 1
'8033' = 1
'8034' = 1
'8035' = 1
'8036' = 1
'8037' = 1
'8038' = 1
'8039' = 1
'8040' = 4
'8041' = 4
'8042' = 4
'8043' = 4
'8044' = 4
'8045' = 4
'8046' = 4
'8047' = 4
'8048' = 4
'8049' = 4
'805' = 4
'8050' = 4
'8051' = 4
'8052' = 2
'8059' = 4
'806' = 4
'8070' = 4
'8071' = 4
'8072' = 4
'8073' = 4
'8074' = 4
'8075' = 4
'8076' = 4
'8077' = 4
'8078' = 4
'8079' = 4
'8080' = 4
'8081' = 4
'8082' = 4
'8083' = 4
'8084' = 4
'8085' = 4
'8086' = 4
'8087' = 4
'8088' = 4
'8089' = 4
'8090' = 4
'8091' = 4
'8092' = 4
'8093' = 4
'8094' = 4
'8095' = 4
'8096' = 4
'8097' = 4
'8098' = 4
'8099' = 4
'8100' = 4
'8101' = 4
'8102' = 4
'8103' = 4
'8104' = 4
'8105' = 4
'8106' = 4
'8107' = 4
'8108' = 4
'8109' = 4
'8111' = 4
'8112' = 4
'8113' = 4
'8114' = 4
'8115' = 4
'8116' = 4
'8117' = 4
'8118' = 4
'8120' = 4
'8121' = 4
'8122' = 4
'8123' = 4
'8124' = 4
'8125' = 4
'8126' = 4
'8127' = 4
'8128' = 4
'8129' = 4
'8130' = 4
'8131' = 4
'8132' = 4
'8133' = 4
'8134' = 4
'8135' = 4
'8136' = 4
'8137' = 4
'8138' = 4
'8139' = 4
'8140' = 4
'8141' = 4
'8142' = 4
'8143' = 4
'8144' = 4
'8145' = 4
'8146' = 4
'8147' = 4
'8148' = 4
'8149' = 4
'8151' = 4
'8152' = 4
'8153' = 4
'8154' = 4
'8155' = 4
'8156' = 4
'8157' = 4
'8159' = 4
'8161' = 4
'8162' = 4
'8163' = 4
'8164' = 4
'8165' = 4
'8166' = 4
'8169' = 4
'8171' = 4
'8172' = 4
'8173' = 4
'8174' = 4
'8175' = 4
'8179' = 4
'8180' = 4
'8181' = 4
'8182' = 4
'8183' = 4
'8184' = 4
'8185' = 4
'8186' = 4
'8187' = 4
'8188' = 4
'8191' = 2
'8192' = 2
'8193' = 4
'8194' = 4
'8195' = 4
'8196' = 4
'8197' = 4
'8198' = 3
'8199' = 4
'8201' = 4
'8202' = 4
'8203' = 4
'8204' = 2
'8209' = 4
'8211' = 4
'8212' = 4
'8219' = 4
'8221' = 4
'8222' = 4
'8229' = 4
'8231' = 4
'8232' = 4
'8233' = 4
'8234' = 4
'8235' = 4
'8236' = 4
'8239' = 4
'8241' = 4
'8242' = 4
'8243' = 4
'8244' = 4
'8245' = 4
'8246' = 4
'8251' = 4
'8252' = 4
'8253' = 4
'8254' = 4
'8255' = 4
'8256' = 4
'8257' = 4
'8258' = 4
'8259' = 4
'8261' = 4
'8269' = 4
'8271' = 4
'8272' = 4
'8279' = 4
'8281' = 4
'8282' = 4
'8283' = 4
'8284' = 4
'8285' = 4
'8286' = 4
'8289' = 4
'8291' = 4
'8292' = 2
'8293' = 2
'8294' = 2
'8295' = 2
'8296' = 2
'8299' = 4
'8301' = 4
'8302' = 4
'8303' = 4
'8309' = 4
'8311' = 4
'8312' = 4
'8313' = 4
'8314' = 4
'8319' = 4
'8321' = 3
'8329' = 3
'8331' = 4
'8332' = 4
'8339' = 4
'8341' = 4
'8342' = 4
'8343' = 4
'8344' = 4
'8345' = 4
'8349' = 4
'835' = 4
'8361' = 4
'8362' = 4
'8363' = 4
'8364' = 4
'8365' = 4
'8371' = 4
'8372' = 4
'8373' = 4
'8374' = 4
'8375' = 4
'8376' = 4
'8377' = 4
'8379' = 4
'8381' = 4
'8382' = 4
'8383' = 4
'8384' = 4
'8385' = 4
'8386' = 4
'8387' = 4
'8388' = 4
'8389' = 4
'8391' = 4
'8392' = 4
'8393' = 4
'8394' = 2
'8395' = 2
'8396' = 2
'8397' = 2
'8398' = 2
'8399' = 4
'8400' = 4
'8401' = 4
'8402' = 4
'8403' = 4
'8404' = 4
'8405' = 4
'8406' = 4
'8407' = 4
'8408' = 4
'8409' = 4
'8410' = 4
'8411' = 4
'8412' = 4
'8413' = 4
'8414' = 4
'8415' = 4
'8416' = 4
'8417' = 4
'8418' = 4
'8419' = 4
'8421' = 4
'8422' = 4
'8423' = 4
'8424' = 4
'8425' = 4
'8426' = 4
'8427' = 4
'8428' = 4
'8429' = 4
'843' = 4
'8440' = 4
'8441' = 2
'8442' = 2
'8443' = 2
'8444' = 4
'8445' = 2
'8446' = 2
'8447' = 2
'8448' = 4
'8451' = 2
'8452' = 2
'8453' = 2
'8454' = 2
'8455' = 2
'8456' = 2
'8457' = 2
'8458' = 4
'8459' = 4
'8460' = 4
'8461' = 4
'8462' = 4
'8463' = 4
'8464' = 4
'8465' = 4
'8466' = 4
'8467' = 4
'8468' = 4
'8469' = 4
'8471' = 2
'8472' = 2
'8473' = 2
'8491' = 4
'8492' = 4
'8493' = 4
'8494' = 4
'8499' = 4
'850' = 2
'8511' = 1
'8512' = 3
'8519' = 1
'8520' = 4
'8521' = 4
'8522' = 4
'8523' = 4
'8524' = 4
'8525' = 4
'8531' = 4
'8532' = 4
'8533' = 4
'8534' = 4
'8535' = 4
'8536' = 4
'8541' = 4
'8542' = 4
'8543' = 4
'8544' = 4
'8545' = 4
'8546' = 4
'8547' = 4
'8548' = 4
'8550' = 4
'8551' = 2
'8552' = 2
'8553' = 4
'8554' = 4
'8555' = 4
'856'  = 4
'857'  = 4
'8570' = 4
'8581' = 2
'8582' = 4
'8583' = 4
'8584' = 4
'8585' = 4
'8586' = 4
'8587' = 4
'8589' = 4
'8591' = 2
'8592' = 2
'8593' = 4
'8594' = 4
'8595' = 4
'8596' = 4
'8599' = 4
'8601' = 2
'8602' = 2
'8603' = 2
'8604' = 2
'8605' = 2
'8606' = 4
'8607' = 2
'8609' = 2
'8611' = 1
'8619' = 1
'8621' = 4
'8622' = 4
'8623' = 2
'8624' = 2
'8625' = 4
'8626' = 2
'8627' = 2
'8628' = 2
'863' = 2
'864' = 4
'8651' = 2
'8659' = 2
'8660' = 4
'8661' = 4
'8662' = 4
'8663' = 4
'8664' = 2
'8665' = 4
'8666' = 4
'8667' = 4
'8669' = 4
'8670' = 4
'8671' = 4
'8672' = 4
'8673' = 4
'8674' = 4
'8675' = 4
'8681' = 4
'8682' = 4
'8683' = 4
'8684' = 4
'8685' = 4
'8686' = 4
'8687' = 4
'8689' = 4
'8690' = 4
'8691' = 4
'8692' = 2
'8693' = 4
'8694' = 4
'8695' = 4
'8696' = 4
'8697' = 4
'8698' = 4
'8699' = 2
'8701' = 1
'8702' = 1
'8703' = 1
'8704' = 1
'8705' = 1
'8706' = 1
'8707' = 1
'8708' = 1
'8709' = 1
'8711' = 1
'8712' = 1
'8713' = 1
'8714' = 1
'8715' = 1
'8716' = 1
'8717' = 1
'8721' = 1
'8722' = 1
'8723' = 1
'8724' = 1
'8729' = 1
'8731' = 1
'8732' = 1
'8733' = 1
'8734' = 1
'8735' = 1
'8736' = 1
'8737' = 1
'8738' = 1
'8739' = 1
'8741' = 1
'8742' = 1
'8743' = 1
'8744' = 1
'8749' = 1
'8751' = 1
'8752' = 1
'8753' = 3
'8754' = 1
'8759' = 1
'8761' = 1
'8762' = 1
'8763' = 1
'8764' = 1
'8765' = 1
'8766' = 1
'8769' = 1
'8771' = 1
'8772' = 1
'8773' = 1
'8774' = 1
'8775' = 1
'8776' = 1
'8777' = 1
'8778' = 1
'8779' = 1
'8781' = 1
'8782' = 1
'8783' = 1
'8784' = 1
'8785' = 1
'8789' = 1
'8791' = 1
'8792' = 1
'8793' = 1
'8794' = 1
'8795' = 1
'8799' = 1
'8801' = 1
'8802' = 1
'8803' = 1
'8804' = 1
'8809' = 1
'8811' = 1
'8812' = 1
'8813' = 1
'8814' = 1
'8815' = 1
'8816' = 1
'8819' = 1
'8821' = 1
'8822' = 1
'8823' = 1
'8824' = 1
'8825' = 1
'8826' = 1
'8827' = 1
'8828' = 1
'8829' = 1
'8831' = 1
'8832' = 1
'8833' = 1
'8834' = 1
'8835' = 1
'8836' = 1
'8837' = 1
'8838' = 1
'8839' = 1
'8840' = 1
'8841' = 1
'8842' = 1
'8843' = 1
'8844' = 1
'8845' = 1
'8846' = 1
'8847' = 1
'8848' = 1
'8849' = 1
'8850' = 1
'8851' = 1
'8852' = 1
'8853' = 1
'8854' = 1
'8855' = 1
'8856' = 1
'8857' = 1
'8858' = 1
'8860' = 1
'8861' = 1
'8862' = 1
'8863' = 1
'8864' = 1
'8865' = 1
'8866' = 1
'8867' = 1
'8868' = 1
'8871' = 1
'8872' = 1
'8873' = 1
'8874' = 1
'8875' = 1
'8876' = 1
'8877' = 1
'8878' = 1
'8879' = 1
'8881' = 1
'8882' = 1
'8883' = 1
'8884' = 1
'8885' = 1
'8886' = 1
'8889' = 1
'8890' = 1
'8891' = 1
'8892' = 1
'8893' = 1
'8894' = 1
'8895' = 1
'8896' = 1
'8897' = 1
'8898' = 1
'8899' = 1
'8901' = 1
'8902' = 1
'8903' = 1
'8904' = 1
'8905' = 1
'8906' = 1
'8907' = 1
'8908' = 1
'8909' = 1
'8910' = 1
'8911' = 1
'8912' = 1
'8913' = 1
'8914' = 1
'8915' = 1
'8916' = 1
'8917' = 1
'8918' = 1
'8919' = 1
'8921' = 1
'8922' = 1
'8923' = 1
'8924' = 1
'8925' = 1
'8926' = 1
'8929' = 1
'8931' = 1
'8932' = 1
'8933' = 1
'8934' = 1
'8935' = 1
'8936' = 1
'8937' = 1
'8938' = 1
'8939' = 1
'8941' = 1
'8942' = 1
'8943' = 1
'8944' = 1
'8945' = 1
'8946' = 1
'8947' = 1
'8948' = 1
'8949' = 1
'8950' = 1
'8951' = 1
'8952' = 1
'8953' = 1
'8954' = 1
'8955' = 1
'8956' = 1
'8957' = 1
'8958' = 1
'8959' = 1
'8960' = 1
'8961' = 1
'8962' = 1
'8963' = 1
'8964' = 1
'8965' = 1
'8966' = 1
'8967' = 1
'8968' = 1
'8969' = 1
'897' = 1
'898' = 1
'9001' = 1
'9002' = 1
'9003' = 1
'9004' = 1
'9005' = 1
'9006' = 1
'9009' = 1
'9011' = 1
'9012' = 1
'9013' = 1
'9014' = 1
'9015' = 1
'9016' = 1
'9019' = 1
'9021' = 1
'9022' = 1
'9023' = 1
'9024' = 1
'9025' = 1
'9026' = 1
'9029' = 1
'9031' = 1
'9032' = 1
'9033' = 1
'9034' = 1
'9035' = 1
'9036' = 1
'9039' = 1
'9041' = 1
'9042' = 1
'9043' = 1
'9044' = 1
'9045' = 1
'9046' = 1
'9049' = 1
'9051' = 1
'9052' = 1
'9053' = 1
'9054' = 1
'9055' = 1
'9056' = 1
'9059' = 1
'9061' = 1
'9062' = 1
'9063' = 1
'9064' = 1
'9065' = 1
'9066' = 1
'9069' = 1
'9071' = 1
'9072' = 1
'9073' = 1
'9074' = 1
'9075' = 1
'9076' = 1
'9079' = 1
'9081' = 1
'9082' = 1
'9083' = 1
'9084' = 1
'9085' = 1
'9086' = 1
'9089' = 1
'9091' = 1
'9092' = 1
'9093' = 1
'9094' = 1
'9095' = 1
'9096' = 1
'9099' = 1
'9101' = 1
'9102' = 1
'9103' = 1
'9104' = 1
'9105' = 1
'9106' = 1
'9109' = 1
'9111' = 1
'9112' = 1
'9113' = 1
'9114' = 1
'9115' = 1
'9116' = 1
'9119' = 1
'9121' = 1
'9122' = 1
'9123' = 1
'9124' = 1
'9125' = 1
'9126' = 1
'9129' = 1
'9131' = 1
'9132' = 1
'9133' = 1
'9134' = 1
'9135' = 1
'9136' = 1
'9139' = 1
'9141' = 1
'9142' = 1
'9143' = 1
'9144' = 1
'9145' = 1
'9146' = 1
'9149' = 1
'9151' = 1
'9152' = 1
'9153' = 1
'9154' = 1
'9155' = 1
'9156' = 1
'9159' = 1
'9161' = 1
'9162' = 1
'9163' = 1
'9164' = 1
'9165' = 1
'9166' = 1
'9169' = 1
'9171' = 1
'9172' = 1
'9173' = 1
'9174' = 1
'9175' = 1
'9176' = 1
'9179' = 1
'9181' = 1
'9182' = 1
'9183' = 1
'9184' = 1
'9185' = 1
'9186' = 1
'9189' = 1
'9191' = 1
'9192' = 1
'9193' = 1
'9194' = 1
'9195' = 1
'9196' = 1
'9199' = 1
'9201' = 1
'9202' = 1
'9203' = 1
'9204' = 1
'9205' = 1
'9209' = 1
'9211' = 1
'9212' = 1
'9213' = 1
'9214' = 1
'9215' = 1
'9216' = 1
'9217' = 1
'9218' = 1
'9219' = 1
'9220' = 2
'9221' = 2
'9222' = 2
'9223' = 2
'9224' = 2
'9225' = 2
'9226' = 2
'9227' = 4
'9228' = 2
'9229' = 2
'923' = 2
'9230' = 2
'9231' = 2
'9232' = 2
'9233' = 2
'9239' = 2
'9301' = 1
'9302' = 1
'9303' = 1
'9304' = 1
'9305' = 1
'9306' = 1
'9307' = 1
'9308' = 1
'9309' = 1
'9311' = 2
'9312' = 2
'9313' = 2
'9314' = 2
'9315' = 2
'9316' = 2
'9317' = 2
'9318' = 2
'9319' = 2
'9321' = 2
'9322' = 2
'9323' = 2
'9324' = 2
'9325' = 2
'9326' = 2
'9327' = 2
'9328' = 2
'9329' = 2
'9331' = 2
'9332' = 2
'9333' = 2
'9334' = 2
'9335' = 2
'9336' = 2
'9337' = 2
'9338' = 2
'9339' = 2
'9341' = 2
'9342' = 2
'9343' = 2
'9344' = 2
'9345' = 2
'9346' = 2
'9351' = 2
'9352' = 2
'9353' = 2
'9354' = 2
'9355' = 2
'9356' = 2
'9357' = 2
'9358' = 2
'9359' = 2
'9361' = 2
'9362' = 2
'9363' = 2
'9364' = 2
'9365' = 2
'9366' = 2
'9367' = 2
'9371' = 2
'9372' = 2
'9373' = 2
'9374' = 2
'9375' = 2
'9376' = 2
'9377' = 2
'9378' = 2
'9381' = 2
'9382' = 2
'9383' = 2
'9384' = 2
'9385' = 2
'9389' = 2
'9390' = 2
'9391' = 2
'9392' = 2
'9393' = 2
'9394' = 2
'9395' = 2
'9396' = 2
'9397' = 2
'9398' = 2
'9399' = 2
'9401' = 1
'9402' = 1
'9403' = 1
'9408' = 1
'9409' = 1
'9411' = 1
'9412' = 1
'9413' = 1
'9419' = 1
'9421' = 2
'9422' = 2
'9423' = 2
'9424' = 2
'9425' = 2
'9426' = 2
'9427' = 2
'9429' = 2
'9431' = 2
'9432' = 2
'9433' = 2
'9434' = 2
'9435' = 2
'9436' = 2
'9437' = 2
'9438' = 2
'9439' = 2
'9441' = 2
'9442' = 2
'9443' = 2
'9444' = 2
'9445' = 2
'9446' = 2
'9449' = 2
'9451' = 2
'9452' = 2
'9453' = 2
'9454' = 2
'9455' = 2
'9459' = 2
'9461' = 2
'9462' = 2
'9463' = 2
'9464' = 2
'9465' = 2
'9466' = 2
'9467' = 2
'9468' = 2
'9469' = 2
'9501' = 1
'9502' = 1
'9503' = 1
'9504' = 3
'9505' = 1
'9506' = 1
'9507' = 1
'9509' = 1
'9511' = 1
'9512' = 1
'9513' = 1
'9514' = 1
'9515' = 1
'9516' = 1
'9521' = 1
'9522' = 1
'9523' = 1
'9524' = 1
'9525' = 1
'9526' = 1
'9531' = 2
'9532' = 2
'9533' = 2
'9534' = 2
'9535' = 2
'9536' = 2
'9541' = 1
'9542' = 1
'9543' = 1
'9544' = 1
'9545' = 1
'9546' = 1
'9547' = 1
'9548' = 2
'9549' = 2
'9601' = 2
'9602' = 2
'9603' = 2
'9604' = 2
'9605' = 2
'9606' = 2
'9607' = 2
'9608' = 2
'9609' = 2
'9611' = 2
'9614' = 2
'9615' = 2
'9616' = 2
'9617' = 2
'9618' = 2
'9619' = 2
'9621' = 2
'9622' = 2
'9623' = 2
'9624' = 2
'9625' = 2
'9626' = 2
'9627' = 2
'9628' = 2
'9629' = 2
'9631' = 2
'9632' = 2
'9633' = 2
'9634' = 2
'9635' = 2
'9636' = 2
'9637' = 2
'9638' = 2
'9639' = 2
'9641' = 2
'9642' = 2
'9643' = 2
'9644' = 2
'9645' = 2
'9646' = 2
'9647' = 2
'9648' = 2
'9649' = 2
'9651' = 2
'9652' = 2
'9653' = 2
'9654' = 2
'9655' = 2
'9656' = 2
'9657' = 2
'9658' = 2
'9659' = 2
'966' = 2
'9670' = 2
'9671' = 2
'9672' = 2
'9701' = 2
'9702' = 2
'9703' = 2
'9704' = 2
'9705' = 2
'9711' = 2
'9712' = 2
'9713' = 2
'9714' = 2
'9715' = 2
'9716' = 2
'9721' = 2
'9722' = 2
'9723' = 2
'9724' = 2
'9725' = 2
'9726' = 2
'9729' = 2
'9731' = 2
'9732' = 2
'9733' = 2
'9734' = 2
'9735' = 2
'9736' = 2
'9737' = 2
'9738' = 2
'9739' = 2
'9741' = 2
'9742' = 2
'9743' = 2
'9744' = 2
'9749' = 2
'9751' = 2
'9752' = 2
'9753' = 2
'9754' = 2
'9755' = 2
'9756' = 2
'9759' = 2
'9761' = 2
'9762' = 2
'9763' = 2
'9764' = 2
'9765' = 2
'9769' = 2
'9771' = 2
'9772' = 2
'9773' = 2
'9774' = 2
'9775' = 2
'9779' = 2
'9781' = 2
'9782' = 2
'9783' = 2
'9784' = 2
'9785' = 2
'9786' = 2
'9787' = 2
'9788' = 2
'9789' = 2
'9801' = 2
'9802' = 2
'9803' = 2
'9804' = 2
'9805' = 2
'9811' = 2
'9812' = 2
'9813' = 2
'9814' = 2
'9815' = 2
'9816' = 2
'9817' = 2
'9818' = 2
'9819' = 2
'9820' = 2
'9821' = 2
'9822' = 2
'9823' = 2
'9824' = 2
'9825' = 2
'9826' = 2
'9827' = 2
'9828' = 2
'9829' = 2
'9851' = 2
'9852' = 2
'9859' = 2
'9900' = 2
'9901' = 2
'9902' = 2
'9903' = 2
'9904' = 2
'9905' = 2
'9906' = 2
'9907' = 2
'9908' = 2
'9909' = 2
'9910' = 2
'9911' = 2
'9912' = 2
'9913' = 2
'9914' = 2
'9915' = 2
'9916' = 2
'9917' = 2
'9918' = 2
'9919' = 2
'9920' = 2
'9921' = 2
'9922' = 2
'9923' = 2
'9924' = 2
'9925' = 2
'9926' = 2
'9927' = 2
'9928' = 2
'9929' = 2
'9931' = 2
'9932' = 2
'9933' = 2
'9934' = 2
'9935' = 2
'9936' = 2
'9937' = 2
'9938' = 2
'9939' = 2
'9941' = 2
'9942' = 2
'9943' = 2
'9944' = 2
'9945' = 2
'9946' = 2
'9947' = 2
'9948' = 2
'9951' = 2
'9952' = 2
'9953' = 2
'9954' = 2
'9955' = 2
'9956' = 2
'9957' = 2
'9958' = 2
'9959' = 2
'9960' = 2
'9961' = 2
'9962' = 2
'9963' = 2
'9964' = 2
'9969' = 2
'9971' = 2
'9972' = 2
'9973' = 2
'9974' = 2
'9975' = 2
'9976' = 2
'9977' = 2
'9978' = 2
'9979' = 2
'9981' = 2
'9982' = 2
'9983' = 2
'9984' = 2
'9985' = 2
'9986' = 2
'9988' = 2
'9991' = 2
'9992' = 2
'9993' = 2
'9994' = 2
'9995' = 2
'9996' = 2
'9997' = 2
'9998' = 2
'9999' = 2
other  = 0
;


* -----------------------------------------------------
* ---   AREA FORMATS     ------------------------------
* ---   TRANSLATES FIPS STATE AND COUNTY CODE (SSCCC)
* ---   TO MSA (METROPOLITAN STATISTICAL AREA)
* -----------------------------------------------------;
/* MODIFIED FIPS */
value $M1AREA
'02013' = '02001'
'02016' = '02001'
'02020' = '02001'
'02050' = '02001'
'02060' = '02001'
'02068' = '02001'
'02070' = '02001'
'02090' = '02001'
'02100' = '02001'
'02110' = '02001'
'02122' = '02001'
'02130' = '02001'
'02150' = '02001'
'02164' = '02001'
'02170' = '02001'
'02180' = '02001'
'02185' = '02001'
'02188' = '02001'
'02201' = '02001'
'02220' = '02001'
'02232' = '02001'
'02240' = '02001'
'02261' = '02001'
'02270' = '02001'
'02280' = '02001'
'02282' = '02001'
'02290' = '02001'
'15005' = '15009'
'24510' = '24007'
'29510' = '29191'
'32510' = '32025'
'51515' = '51019'
'51520' = '51119'
'51530' = '51163'
'51540' = '51003'
'51560' = '51005'
'51570' = '51041'
'51580' = '51005'
'51590' = '51143'
'51595' = '51081'
'51600' = '51059'
'51610' = '51059'
'51620' = '51175'
'51630' = '51177'
'51640' = '51077'
'51660' = '51165'
'51670' = '51149'
'51678' = '51163'
'51680' = '51031'
'51683' = '51153'
'51685' = '51153'
'51690' = '51089'
'51710' = '51129'
'51720' = '51195'
'51730' = '51053'
'51735' = '51199'
'51740' = '51129'
'51750' = '51121'
'51760' = '51087'
'51770' = '51161'
'51775' = '51161'
'51780' = '51083'
'51790' = '51015'
'51800' = '51123'
'51820' = '51015'
'51830' = '51095'
'51840' = '51069'
;
/* OMB 1999 METRO AREA */
value $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 '
;
/* OMB 2003 METRO AREA */
value $M3AREA
'01001' = '33860'
'01003' = '19300'
'01005' = '21640'
'01007' = '13820'
'01009' = '13820'
'01015' = '11500'
'01017' = '46740'
'01021' = '13820'
'01031' = '21460'
'01033' = '22520'
'01037' = '10760'
'01043' = '18980'
'01045' = '21460'
'01047' = '42820'
'01049' = '22840'
'01051' = '33860'
'01055' = '23460'
'01061' = '20020'
'01063' = '46220'
'01065' = '46220'
'01067' = '20020'
'01069' = '20020'
'01071' = '42460'
'01073' = '13820'
'01077' = '22520'
'01079' = '19460'
'01081' = '12220'
'01083' = '26620'
'01085' = '33860'
'01087' = '46260'
'01089' = '26620'
'01095' = '10700'
'01097' = '33660'
'01101' = '33860'
'01103' = '19460'
'01109' = '45980'
'01113' = '17980'
'01115' = '13820'
'01117' = '13820'
'01121' = '45180'
'01123' = '10760'
'01125' = '46220'
'01127' = '13820'
'02020' = '11260'
'02090' = '21820'
'02110' = '27940'
'02130' = '28540'
'02150' = '28980'
'02170' = '11260'
'04003' = '43420'
'04005' = '22380'
'04007' = '37740'
'04009' = '40940'
'04011' = '40940'
'04013' = '38060'
'04015' = '29420'
'04019' = '46060'
'04021' = '38060'
'04023' = '35700'
'04025' = '39140'
'04027' = '49740'
'05005' = '34260'
'05007' = '22220'
'05009' = '25460'
'05013' = '15780'
'05019' = '11660'
'05025' = '38220'
'05027' = '31620'
'05031' = '27860'
'05033' = '22900'
'05035' = '32820'
'05045' = '30780'
'05047' = '22900'
'05051' = '26300'
'05053' = '30780'
'05055' = '37500'
'05057' = '26260'
'05063' = '12900'
'05069' = '38220'
'05079' = '38220'
'05085' = '30780'
'05087' = '22220'
'05091' = '45500'
'05093' = '14180'
'05099' = '26260'
'05101' = '25460'
'05103' = '15780'
'05105' = '30780'
'05107' = '48340'
'05111' = '27860'
'05115' = '40780'
'05119' = '30780'
'05123' = '22620'
'05125' = '30780'
'05131' = '22900'
'05139' = '20980'
'05143' = '22220'
'05145' = '42620'
'05149' = '40780'
'06001' = '41860'
'06007' = '17020'
'06013' = '41860'
'06015' = '18860'
'06017' = '40900'
'06019' = '23420'
'06023' = '21700'
'06025' = '20940'
'06027' = '13860'
'06029' = '12540'
'06031' = '25260'
'06033' = '17340'
'06035' = '45000'
'06037' = '31100'
'06039' = '31460'
'06041' = '41860'
'06045' = '46380'
'06047' = '32900'
'06053' = '41500'
'06055' = '34900'
'06057' = '46020'
'06059' = '31100'
'06061' = '40900'
'06065' = '40140'
'06067' = '40900'
'06069' = '41940'
'06071' = '40140'
'06073' = '41740'
'06075' = '41860'
'06077' = '44700'
'06079' = '42020'
'06081' = '41860'
'06083' = '42060'
'06085' = '41940'
'06087' = '42100'
'06089' = '39820'
'06095' = '46700'
'06097' = '42220'
'06099' = '33700'
'06101' = '49700'
'06103' = '39780'
'06107' = '47300'
'06109' = '38020'
'06111' = '37100'
'06113' = '40900'
'06115' = '49700'
'08001' = '19740'
'08005' = '19740'
'08013' = '14500'
'08014' = '19740'
'08019' = '19740'
'08031' = '19740'
'08035' = '19740'
'08037' = '20780'
'08039' = '19740'
'08041' = '17820'
'08043' = '15860'
'08047' = '19740'
'08059' = '19740'
'08065' = '20780'
'08067' = '20420'
'08069' = '22660'
'08075' = '44540'
'08077' = '24300'
'08085' = '33940'
'08087' = '22820'
'08093' = '19740'
'08101' = '39380'
'08117' = '43540'
'08119' = '17820'
'08123' = '24540'
'09001' = '14860'
'09003' = '25540'
'09005' = '45860'
'09007' = '25540'
'09009' = '35300'
'09011' = '35980'
'09013' = '25540'
'09015' = '48740'
'10001' = '20100'
'10003' = '37980'
'10005' = '42580'
'11001' = '47900'
'12001' = '23540'
'12003' = '27260'
'12005' = '37460'
'12009' = '37340'
'12011' = '33100'
'12015' = '39460'
'12017' = '26140'
'12019' = '27260'
'12021' = '34940'
'12023' = '29380'
'12027' = '11580'
'12031' = '27260'
'12033' = '37860'
'12035' = '37380'
'12039' = '45220'
'12041' = '23540'
'12049' = '48100'
'12051' = '17500'
'12053' = '45300'
'12055' = '42700'
'12057' = '45300'
'12061' = '46940'
'12065' = '45220'
'12069' = '36740'
'12071' = '15980'
'12073' = '45220'
'12081' = '42260'
'12083' = '36100'
'12085' = '38940'
'12086' = '33100'
'12087' = '28580'
'12089' = '27260'
'12091' = '23020'
'12093' = '36380'
'12095' = '36740'
'12097' = '36740'
'12099' = '33100'
'12101' = '45300'
'12103' = '45300'
'12105' = '29460'
'12107' = '37260'
'12109' = '27260'
'12111' = '38940'
'12113' = '37860'
'12115' = '42260'
'12117' = '36740'
'12119' = '45540'
'12127' = '19660'
'12129' = '45220'
'13003' = '20060'
'13007' = '10500'
'13009' = '33300'
'13013' = '12060'
'13015' = '12060'
'13017' = '22340'
'13021' = '31420'
'13025' = '15260'
'13027' = '46660'
'13029' = '42340'
'13031' = '44340'
'13033' = '12260'
'13035' = '12060'
'13039' = '41220'
'13045' = '12060'
'13047' = '16860'
'13051' = '42340'
'13053' = '17980'
'13055' = '44900'
'13057' = '12060'
'13059' = '12020'
'13063' = '12060'
'13067' = '12060'
'13069' = '20060'
'13071' = '34220'
'13073' = '12260'
'13077' = '12060'
'13079' = '31420'
'13081' = '18380'
'13083' = '16860'
'13085' = '12060'
'13087' = '12460'
'13089' = '12060'
'13095' = '10500'
'13097' = '12060'
'13101' = '46660'
'13103' = '42340'
'13113' = '12060'
'13115' = '40660'
'13117' = '12060'
'13121' = '12060'
'13127' = '15260'
'13129' = '15660'
'13135' = '12060'
'13137' = '18460'
'13139' = '23580'
'13141' = '33300'
'13143' = '12060'
'13145' = '17980'
'13149' = '12060'
'13151' = '12060'
'13153' = '47580'
'13155' = '22340'
'13159' = '12060'
'13167' = '20140'
'13169' = '31420'
'13171' = '12060'
'13173' = '46660'
'13175' = '20140'
'13177' = '10500'
'13179' = '25980'
'13183' = '25980'
'13185' = '46660'
'13189' = '12260'
'13191' = '15260'
'13195' = '12020'
'13197' = '17980'
'13199' = '12060'
'13207' = '31420'
'13209' = '47080'
'13213' = '19140'
'13215' = '17980'
'13217' = '12060'
'13219' = '12020'
'13221' = '12020'
'13223' = '12060'
'13225' = '22980'
'13227' = '12060'
'13229' = '48180'
'13231' = '12060'
'13233' = '16340'
'13239' = '21640'
'13245' = '12260'
'13247' = '12060'
'13249' = '11140'
'13255' = '12060'
'13257' = '45740'
'13261' = '11140'
'13273' = '10500'
'13275' = '45620'
'13277' = '45700'
'13279' = '47080'
'13285' = '29300'
'13289' = '31420'
'13293' = '45580'
'13295' = '16860'
'13297' = '12060'
'13299' = '48180'
'13305' = '27700'
'13313' = '19140'
'13321' = '10500'
'15001' = '25900'
'15003' = '26180'
'15007' = '28180'
'15009' = '27980'
'16001' = '14260'
'16005' = '38540'
'16011' = '13940'
'16015' = '14260'
'16019' = '26820'
'16027' = '14260'
'16031' = '15420'
'16039' = '34300'
'16041' = '30860'
'16043' = '39940'
'16045' = '14260'
'16051' = '26820'
'16053' = '46300'
'16055' = '17660'
'16057' = '34140'
'16065' = '39940'
'16067' = '15420'
'16069' = '30300'
'16073' = '14260'
'16075' = '36620'
'16077' = '38540'
'16081' = '27220'
'16083' = '46300'
'17001' = '39500'
'17003' = '16020'
'17005' = '41180'
'17007' = '40420'
'17011' = '36860'
'17013' = '41180'
'17019' = '16580'
'17021' = '45380'
'17027' = '41180'
'17029' = '16660'
'17031' = '16980'
'17035' = '16660'
'17037' = '16980'
'17043' = '16980'
'17049' = '20820'
'17053' = '16580'
'17057' = '15900'
'17063' = '16980'
'17065' = '34500'
'17071' = '15460'
'17073' = '19340'
'17077' = '16060'
'17081' = '34500'
'17083' = '41180'
'17089' = '16980'
'17091' = '28100'
'17093' = '16980'
'17095' = '23660'
'17097' = '16980'
'17099' = '36860'
'17103' = '19940'
'17105' = '38700'
'17107' = '30660'
'17109' = '31380'
'17111' = '16980'
'17113' = '14060'
'17115' = '19500'
'17117' = '41180'
'17119' = '41180'
'17121' = '16460'
'17123' = '37900'
'17127' = '37140'
'17129' = '44100'
'17131' = '19340'
'17133' = '41180'
'17137' = '27300'
'17141' = '40300'
'17143' = '37900'
'17147' = '16580'
'17155' = '36860'
'17161' = '19340'
'17163' = '41180'
'17165' = '25380'
'17167' = '44100'
'17171' = '27300'
'17175' = '37900'
'17177' = '23300'
'17179' = '37900'
'17183' = '19180'
'17187' = '23660'
'17195' = '44580'
'17197' = '16980'
'17199' = '32060'
'17201' = '40420'
'17203' = '37900'
'18001' = '19540'
'18003' = '23060'
'18005' = '18020'
'18007' = '29140'
'18011' = '26900'
'18013' = '26900'
'18015' = '29140'
'18017' = '30900'
'18019' = '31140'
'18021' = '45460'
'18023' = '23140'
'18027' = '47780'
'18029' = '17140'
'18031' = '24700'
'18033' = '12140'
'18035' = '34620'
'18037' = '27540'
'18039' = '21140'
'18041' = '18220'
'18043' = '31140'
'18047' = '17140'
'18051' = '21780'
'18053' = '31980'
'18055' = '14020'
'18057' = '26900'
'18059' = '26900'
'18061' = '31140'
'18063' = '26900'
'18065' = '35220'
'18067' = '29020'
'18069' = '26540'
'18071' = '42980'
'18073' = '16980'
'18077' = '31500'
'18079' = '35860'
'18081' = '26900'
'18083' = '47180'
'18085' = '47700'
'18089' = '16980'
'18091' = '33140'
'18093' = '13260'
'18095' = '11300'
'18097' = '26900'
'18099' = '38500'
'18103' = '37940'
'18105' = '14020'
'18107' = '18820'
'18109' = '26900'
'18111' = '16980'
'18113' = '28340'
'18115' = '17140'
'18119' = '14020'
'18125' = '27540'
'18127' = '16980'
'18129' = '21780'
'18133' = '26900'
'18141' = '43780'
'18143' = '42500'
'18145' = '26900'
'18151' = '11420'
'18153' = '45460'
'18157' = '29140'
'18159' = '29020'
'18163' = '21780'
'18165' = '45460'
'18167' = '45460'
'18169' = '47340'
'18173' = '21780'
'18175' = '31140'
'18177' = '39980'
'18179' = '23060'
'18183' = '23060'
'19011' = '16300'
'19013' = '47940'
'19015' = '14340'
'19017' = '47940'
'19021' = '44740'
'19033' = '32380'
'19041' = '43980'
'19045' = '17540'
'19049' = '19780'
'19057' = '15460'
'19059' = '44020'
'19061' = '20220'
'19075' = '47940'
'19077' = '19780'
'19085' = '36540'
'19099' = '35500'
'19103' = '26980'
'19105' = '16300'
'19111' = '28460'
'19113' = '16300'
'19115' = '34700'
'19121' = '19780'
'19123' = '36820'
'19125' = '37800'
'19127' = '32260'
'19129' = '36540'
'19139' = '34700'
'19153' = '19780'
'19155' = '36540'
'19163' = '19340'
'19169' = '11180'
'19179' = '36900'
'19181' = '19780'
'19183' = '26980'
'19187' = '22700'
'19193' = '43580'
'19195' = '32380'
'20005' = '11860'
'20009' = '24460'
'20015' = '48620'
'20017' = '21380'
'20035' = '49060'
'20037' = '38260'
'20043' = '41140'
'20045' = '29940'
'20051' = '25700'
'20055' = '23780'
'20057' = '19980'
'20059' = '28140'
'20061' = '31740'
'20079' = '48620'
'20085' = '45820'
'20087' = '45820'
'20091' = '28140'
'20099' = '37660'
'20103' = '28140'
'20107' = '28140'
'20111' = '21380'
'20113' = '32700'
'20121' = '28140'
'20125' = '17700'
'20139' = '45820'
'20143' = '41460'
'20149' = '31740'
'20155' = '26740'
'20161' = '31740'
'20169' = '41460'
'20173' = '48620'
'20175' = '30580'
'20177' = '45820'
'20191' = '48620'
'20197' = '45820'
'20209' = '28140'
'21005' = '23180'
'21007' = '37140'
'21009' = '23980'
'21011' = '34460'
'21013' = '33180'
'21015' = '17140'
'21017' = '30460'
'21019' = '26580'
'21021' = '19220'
'21023' = '17140'
'21029' = '31140'
'21035' = '34660'
'21037' = '17140'
'21047' = '17300'
'21049' = '30460'
'21059' = '36980'
'21061' = '14540'
'21067' = '30460'
'21073' = '23180'
'21075' = '46460'
'21077' = '17140'
'21081' = '17140'
'21083' = '32460'
'21089' = '26580'
'21091' = '36980'
'21093' = '21060'
'21101' = '21780'
'21103' = '31140'
'21107' = '31580'
'21111' = '31140'
'21113' = '30460'
'21117' = '17140'
'21123' = '21060'
'21125' = '30940'
'21135' = '32500'
'21137' = '19220'
'21139' = '37140'
'21145' = '37140'
'21149' = '36980'
'21151' = '40080'
'21161' = '32500'
'21163' = '31140'
'21165' = '34460'
'21169' = '23980'
'21173' = '34460'
'21177' = '16420'
'21179' = '31140'
'21185' = '31140'
'21191' = '17140'
'21199' = '43700'
'21203' = '40080'
'21209' = '30460'
'21211' = '31140'
'21215' = '31140'
'21217' = '15820'
'21221' = '17300'
'21223' = '31140'
'21227' = '14540'
'21233' = '21780'
'21235' = '18340'
'21239' = '30460'
'22001' = '18940'
'22005' = '12940'
'22007' = '38200'
'22011' = '19760'
'22015' = '43340'
'22017' = '43340'
'22019' = '29340'
'22023' = '29340'
'22029' = '35020'
'22031' = '43340'
'22033' = '12940'
'22037' = '12940'
'22043' = '10780'
'22045' = '35340'
'22047' = '12940'
'22049' = '40820'
'22051' = '35380'
'22053' = '27660'
'22055' = '29180'
'22057' = '26380'
'22061' = '40820'
'22063' = '12940'
'22065' = '45260'
'22067' = '12820'
'22069' = '35060'
'22071' = '35380'
'22073' = '33740'
'22075' = '35380'
'22077' = '12940'
'22079' = '10780'
'22087' = '35380'
'22089' = '35380'
'22091' = '12940'
'22095' = '35380'
'22097' = '36660'
'22099' = '29180'
'22101' = '34020'
'22103' = '35380'
'22105' = '25220'
'22109' = '26380'
'22111' = '33740'
'22113' = '10020'
'22115' = '22860'
'22117' = '14220'
'22119' = '33380'
'22121' = '12940'
'22125' = '12940'
'23001' = '30340'
'23005' = '38860'
'23011' = '12300'
'23013' = '40500'
'23019' = '12620'
'23023' = '38860'
'23031' = '38860'
'24001' = '19060'
'24003' = '12580'
'24005' = '12580'
'24009' = '47900'
'24013' = '12580'
'24015' = '37980'
'24017' = '47900'
'24019' = '15700'
'24021' = '47900'
'24025' = '12580'
'24027' = '12580'
'24031' = '47900'
'24033' = '47900'
'24035' = '12580'
'24037' = '30500'
'24039' = '41540'
'24041' = '20660'
'24043' = '25180'
'24045' = '41540'
'24047' = '36180'
'24510' = '12580'
'25001' = '12700'
'25003' = '38340'
'25005' = '39300'
'25009' = '14460'
'25011' = '44140'
'25013' = '44140'
'25015' = '44140'
'25017' = '14460'
'25021' = '14460'
'25023' = '14460'
'25025' = '14460'
'25027' = '49340'
'26005' = '10880'
'26007' = '10980'
'26015' = '24340'
'26017' = '13020'
'26019' = '45900'
'26021' = '35660'
'26023' = '17740'
'26025' = '12980'
'26027' = '43780'
'26033' = '42300'
'26037' = '29620'
'26041' = '21540'
'26043' = '27020'
'26045' = '29620'
'26049' = '22420'
'26055' = '45900'
'26057' = '10940'
'26061' = '26340'
'26065' = '29620'
'26067' = '24340'
'26073' = '34380'
'26075' = '27100'
'26077' = '28020'
'26079' = '45900'
'26081' = '24340'
'26083' = '26340'
'26087' = '19820'
'26089' = '45900'
'26091' = '10300'
'26093' = '19820'
'26099' = '19820'
'26103' = '32100'
'26107' = '13660'
'26109' = '31940'
'26111' = '33220'
'26113' = '15620'
'26115' = '33780'
'26121' = '34740'
'26123' = '24340'
'26125' = '19820'
'26139' = '26100'
'26145' = '40980'
'26147' = '19820'
'26149' = '44780'
'26155' = '37020'
'26159' = '28020'
'26161' = '11460'
'26163' = '19820'
'26165' = '15620'
'27003' = '33460'
'27007' = '13420'
'27009' = '41060'
'27013' = '31860'
'27015' = '35580'
'27017' = '20260'
'27019' = '33460'
'27021' = '14660'
'27025' = '33460'
'27027' = '22020'
'27035' = '14660'
'27037' = '33460'
'27039' = '40340'
'27041' = '10820'
'27047' = '10660'
'27049' = '39860'
'27053' = '33460'
'27055' = '29100'
'27059' = '33460'
'27067' = '48820'
'27083' = '32140'
'27085' = '26780'
'27091' = '21860'
'27099' = '12380'
'27103' = '31860'
'27105' = '49380'
'27109' = '40340'
'27111' = '22260'
'27119' = '24220'
'27123' = '33460'
'27131' = '22060'
'27137' = '20260'
'27139' = '33460'
'27141' = '33460'
'27145' = '41060'
'27147' = '36940'
'27157' = '40340'
'27163' = '33460'
'27167' = '47420'
'27169' = '49100'
'27171' = '33460'
'28001' = '35020'
'28003' = '18420'
'28005' = '32620'
'28011' = '17380'
'28015' = '24900'
'28023' = '32940'
'28025' = '48500'
'28027' = '17260'
'28029' = '27140'
'28033' = '32820'
'28035' = '25620'
'28039' = '37700'
'28043' = '24980'
'28045' = '25060'
'28047' = '25060'
'28049' = '27140'
'28057' = '46180'
'28059' = '37700'
'28061' = '29860'
'28067' = '29860'
'28069' = '32940'
'28071' = '37060'
'28073' = '25620'
'28075' = '32940'
'28081' = '46180'
'28083' = '24900'
'28085' = '15020'
'28087' = '18060'
'28089' = '27140'
'28093' = '32820'
'28105' = '44260'
'28109' = '38100'
'28111' = '25620'
'28113' = '32620'
'28115' = '46180'
'28121' = '27140'
'28127' = '27140'
'28131' = '25060'
'28133' = '26940'
'28137' = '32820'
'28143' = '32820'
'28149' = '46980'
'28151' = '24740'
'28163' = '49540'
'29001' = '28860'
'29003' = '41140'
'29007' = '33020'
'29013' = '28140'
'29017' = '16020'
'29019' = '17860'
'29021' = '41140'
'29023' = '38740'
'29025' = '28140'
'29027' = '27620'
'29031' = '16020'
'29037' = '28140'
'29043' = '44180'
'29045' = '28460'
'29047' = '28140'
'29049' = '28140'
'29051' = '27620'
'29059' = '44180'
'29063' = '41140'
'29069' = '28380'
'29071' = '41180'
'29077' = '44180'
'29089' = '17860'
'29091' = '48460'
'29095' = '28140'
'29097' = '27900'
'29099' = '41180'
'29101' = '47660'
'29105' = '30060'
'29107' = '28140'
'29111' = '39500'
'29113' = '41180'
'29119' = '22220'
'29127' = '25300'
'29135' = '27620'
'29145' = '27900'
'29147' = '32340'
'29151' = '27620'
'29159' = '42740'
'29161' = '40620'
'29165' = '28140'
'29167' = '44180'
'29169' = '22780'
'29173' = '25300'
'29175' = '33620'
'29177' = '28140'
'29183' = '41180'
'29187' = '22100'
'29189' = '41180'
'29195' = '32180'
'29197' = '28860'
'29201' = '43460'
'29209' = '14700'
'29213' = '14700'
'29219' = '41180'
'29221' = '41180'
'29225' = '44180'
'29510' = '41180'
'30009' = '13740'
'30013' = '24500'
'30029' = '28060'
'30031' = '14580'
'30041' = '25660'
'30043' = '25740'
'30049' = '25740'
'30063' = '33540'
'30093' = '15580'
'30111' = '13740'
'31001' = '25580'
'31007' = '42420'
'31019' = '28260'
'31025' = '36540'
'31035' = '25580'
'31043' = '43580'
'31047' = '30420'
'31051' = '43580'
'31053' = '23340'
'31055' = '36540'
'31067' = '13100'
'31073' = '30420'
'31079' = '24260'
'31093' = '24260'
'31099' = '28260'
'31109' = '30700'
'31111' = '35820'
'31113' = '35820'
'31117' = '35820'
'31119' = '35740'
'31121' = '24260'
'31139' = '35740'
'31141' = '18100'
'31153' = '36540'
'31155' = '36540'
'31157' = '42420'
'31159' = '30700'
'31167' = '35740'
'31177' = '36540'
'32001' = '21980'
'32003' = '29820'
'32005' = '23820'
'32007' = '21220'
'32011' = '21220'
'32023' = '37220'
'32029' = '39900'
'32031' = '39900'
'32510' = '16180'
'33001' = '29060'
'33005' = '28300'
'33007' = '13620'
'33009' = '30100'
'33011' = '31700'
'33013' = '18180'
'33015' = '14460'
'33017' = '14460'
'33019' = '17200'
'34001' = '12100'
'34003' = '35620'
'34005' = '37980'
'34007' = '37980'
'34009' = '36140'
'34011' = '47220'
'34013' = '35620'
'34015' = '37980'
'34017' = '35620'
'34019' = '35620'
'34021' = '45940'
'34023' = '35620'
'34025' = '35620'
'34027' = '35620'
'34029' = '35620'
'34031' = '35620'
'34033' = '37980'
'34035' = '35620'
'34037' = '35620'
'34039' = '35620'
'34041' = '10900'
'35001' = '10740'
'35005' = '40740'
'35006' = '24380'
'35009' = '17580'
'35013' = '29740'
'35015' = '16100'
'35017' = '43500'
'35025' = '26020'
'35028' = '31060'
'35029' = '19700'
'35031' = '23700'
'35035' = '10460'
'35039' = '21580'
'35041' = '38780'
'35043' = '10740'
'35045' = '22140'
'35047' = '29780'
'35049' = '42140'
'35055' = '45340'
'35057' = '10740'
'35061' = '10740'
'36001' = '10580'
'36005' = '35620'
'36007' = '13780'
'36009' = '36460'
'36011' = '12180'
'36013' = '27460'
'36015' = '21300'
'36019' = '38460'
'36021' = '26460'
'36023' = '18660'
'36027' = '39100'
'36029' = '15380'
'36033' = '31660'
'36035' = '24100'
'36037' = '12860'
'36043' = '46540'
'36045' = '48060'
'36047' = '35620'
'36051' = '40380'
'36053' = '45060'
'36055' = '40380'
'36057' = '11220'
'36059' = '35620'
'36061' = '35620'
'36063' = '15380'
'36065' = '46540'
'36067' = '45060'
'36069' = '40380'
'36071' = '39100'
'36073' = '40380'
'36075' = '45060'
'36077' = '36580'
'36079' = '35620'
'36081' = '35620'
'36083' = '10580'
'36085' = '35620'
'36087' = '35620'
'36089' = '36300'
'36091' = '10580'
'36093' = '10580'
'36095' = '10580'
'36099' = '42900'
'36101' = '18500'
'36103' = '35620'
'36107' = '13780'
'36109' = '27060'
'36111' = '28740'
'36113' = '24020'
'36115' = '24020'
'36117' = '40380'
'36119' = '35620'
'37001' = '15500'
'37003' = '25860'
'37007' = '16740'
'37013' = '47820'
'37019' = '48900'
'37021' = '11700'
'37023' = '25860'
'37025' = '16740'
'37027' = '25860'
'37029' = '21020'
'37031' = '33980'
'37035' = '25860'
'37037' = '20500'
'37045' = '43140'
'37049' = '35100'
'37051' = '22180'
'37053' = '47260'
'37055' = '28620'
'37057' = '45640'
'37059' = '49180'
'37063' = '20500'
'37065' = '40580'
'37067' = '49180'
'37069' = '39580'
'37071' = '16740'
'37079' = '24780'
'37081' = '24660'
'37083' = '40260'
'37085' = '20380'
'37087' = '11700'
'37089' = '11700'
'37093' = '22180'
'37097' = '44380'
'37101' = '39580'
'37103' = '35100'
'37105' = '41820'
'37107' = '28820'
'37109' = '30740'
'37115' = '11700'
'37119' = '16740'
'37125' = '43860'
'37127' = '40580'
'37129' = '48900'
'37131' = '40260'
'37133' = '27340'
'37135' = '20500'
'37137' = '35100'
'37139' = '21020'
'37141' = '48900'
'37143' = '21020'
'37145' = '20500'
'37147' = '24780'
'37151' = '24660'
'37153' = '40460'
'37155' = '31300'
'37157' = '24660'
'37159' = '41580'
'37161' = '22580'
'37165' = '29900'
'37167' = '10620'
'37169' = '49180'
'37171' = '34340'
'37175' = '14820'
'37179' = '16740'
'37181' = '25780'
'37183' = '39580'
'37189' = '14380'
'37191' = '24140'
'37193' = '35900'
'37195' = '48980'
'37197' = '49180'
'38007' = '19860'
'38015' = '13900'
'38017' = '22020'
'38035' = '24220'
'38049' = '33500'
'38059' = '13900'
'38075' = '33500'
'38077' = '47420'
'38089' = '19860'
'38093' = '27420'
'38101' = '33500'
'38105' = '48780'
'39003' = '30620'
'39005' = '11740'
'39007' = '11780'
'39009' = '11900'
'39011' = '47540'
'39013' = '48540'
'39015' = '17140'
'39017' = '17140'
'39019' = '15940'
'39021' = '46500'
'39023' = '44220'
'39025' = '17140'
'39027' = '48940'
'39029' = '20620'
'39031' = '18740'
'39033' = '15340'
'39035' = '17460'
'39037' = '24820'
'39039' = '19580'
'39041' = '18140'
'39043' = '41780'
'39045' = '18140'
'39047' = '47860'
'39049' = '18140'
'39051' = '45780'
'39053' = '38580'
'39055' = '17460'
'39057' = '19380'
'39059' = '15740'
'39061' = '17140'
'39063' = '22300'
'39077' = '35940'
'39081' = '48260'
'39083' = '34540'
'39085' = '17460'
'39087' = '26580'
'39089' = '18140'
'39091' = '13340'
'39093' = '17460'
'39095' = '45780'
'39097' = '18140'
'39099' = '49660'
'39101' = '32020'
'39103' = '17460'
'39107' = '16380'
'39109' = '19380'
'39113' = '19380'
'39117' = '18140'
'39119' = '49780'
'39123' = '45780'
'39129' = '18140'
'39133' = '10420'
'39135' = '19380'
'39139' = '31900'
'39141' = '17060'
'39143' = '23380'
'39145' = '39020'
'39147' = '45660'
'39149' = '43380'
'39151' = '15940'
'39153' = '10420'
'39155' = '49660'
'39157' = '35420'
'39159' = '18140'
'39161' = '46780'
'39165' = '17140'
'39167' = '37620'
'39169' = '49300'
'39173' = '45780'
'40009' = '21120'
'40013' = '20460'
'40017' = '36420'
'40019' = '11620'
'40021' = '45140'
'40027' = '36420'
'40031' = '30020'
'40037' = '46140'
'40047' = '21420'
'40051' = '36420'
'40065' = '11060'
'40071' = '38620'
'40079' = '22900'
'40081' = '36420'
'40083' = '36420'
'40085' = '11620'
'40087' = '36420'
'40101' = '34780'
'40109' = '36420'
'40111' = '46140'
'40113' = '46140'
'40115' = '33060'
'40117' = '46140'
'40119' = '44660'
'40121' = '32540'
'40123' = '10220'
'40125' = '43060'
'40131' = '46140'
'40135' = '22900'
'40137' = '20340'
'40139' = '25100'
'40143' = '46140'
'40145' = '46140'
'40147' = '12780'
'40153' = '49260'
'41003' = '18700'
'41005' = '38900'
'41007' = '11820'
'41009' = '38900'
'41011' = '18300'
'41013' = '39260'
'41015' = '15060'
'41017' = '13460'
'41019' = '40700'
'41027' = '26220'
'41029' = '32780'
'41033' = '24420'
'41035' = '28900'
'41039' = '21660'
'41043' = '10540'
'41045' = '36620'
'41047' = '41420'
'41049' = '37820'
'41051' = '38900'
'41053' = '41420'
'41059' = '37820'
'41061' = '29260'
'41065' = '17180'
'41067' = '38900'
'41071' = '38900'
'42001' = '23900'
'42003' = '38300'
'42005' = '38300'
'42007' = '38300'
'42011' = '39740'
'42013' = '11020'
'42015' = '42380'
'42017' = '37980'
'42019' = '38300'
'42021' = '27780'
'42025' = '10900'
'42027' = '44300'
'42029' = '37980'
'42033' = '20180'
'42035' = '30820'
'42037' = '14100'
'42039' = '32740'
'42041' = '25420'
'42043' = '25420'
'42045' = '37980'
'42047' = '41260'
'42049' = '21500'
'42051' = '38300'
'42055' = '16540'
'42061' = '26500'
'42063' = '26860'
'42069' = '42540'
'42071' = '29540'
'42073' = '35260'
'42075' = '30140'
'42077' = '10900'
'42079' = '42540'
'42081' = '48700'
'42083' = '14620'
'42085' = '49660'
'42087' = '30380'
'42089' = '20700'
'42091' = '37980'
'42093' = '14100'
'42095' = '10900'
'42097' = '44980'
'42099' = '25420'
'42101' = '37980'
'42103' = '35620'
'42107' = '39060'
'42109' = '42780'
'42111' = '43740'
'42119' = '30260'
'42121' = '36340'
'42123' = '47620'
'42125' = '38300'
'42129' = '38300'
'42131' = '42540'
'42133' = '49620'
'44001' = '39300'
'44003' = '39300'
'44005' = '39300'
'44007' = '39300'
'44009' = '39300'
'45003' = '12260'
'45007' = '11340'
'45013' = '25940'
'45015' = '16700'
'45017' = '17900'
'45019' = '16700'
'45021' = '23500'
'45023' = '16900'
'45029' = '47500'
'45031' = '22500'
'45033' = '19900'
'45035' = '16700'
'45037' = '12260'
'45039' = '17900'
'45041' = '22500'
'45043' = '23860'
'45045' = '24860'
'45047' = '24940'
'45051' = '34820'
'45053' = '25940'
'45055' = '17900'
'45057' = '29580'
'45059' = '24860'
'45063' = '17900'
'45069' = '13500'
'45071' = '35140'
'45073' = '42860'
'45075' = '36700'
'45077' = '24860'
'45079' = '17900'
'45081' = '17900'
'45083' = '43900'
'45085' = '44940'
'45087' = '46420'
'45091' = '16740'
'46005' = '26700'
'46011' = '15100'
'46013' = '10100'
'46027' = '46820'
'46029' = '47980'
'46035' = '33580'
'46045' = '10100'
'46057' = '47980'
'46061' = '33580'
'46065' = '38180'
'46081' = '43940'
'46083' = '43620'
'46087' = '43620'
'46093' = '39660'
'46099' = '43620'
'46103' = '39660'
'46117' = '38180'
'46125' = '43620'
'46127' = '43580'
'46135' = '49460'
'47001' = '28940'
'47003' = '43180'
'47009' = '28940'
'47011' = '17420'
'47013' = '29220'
'47015' = '34980'
'47019' = '27740'
'47021' = '34980'
'47023' = '27180'
'47029' = '35460'
'47031' = '46100'
'47035' = '18900'
'47037' = '34980'
'47043' = '34980'
'47045' = '20540'
'47047' = '32820'
'47051' = '46100'
'47053' = '26480'
'47057' = '34100'
'47059' = '24620'
'47063' = '34100'
'47065' = '16860'
'47073' = '28700'
'47075' = '15140'
'47079' = '37540'
'47081' = '34980'
'47087' = '18260'
'47089' = '34100'
'47093' = '28940'
'47099' = '29980'
'47105' = '28940'
'47107' = '11940'
'47111' = '34980'
'47113' = '27180'
'47115' = '16860'
'47117' = '30280'
'47119' = '17940'
'47125' = '17300'
'47127' = '46100'
'47131' = '46460'
'47133' = '18260'
'47139' = '17420'
'47141' = '18260'
'47145' = '25340'
'47147' = '34980'
'47149' = '34980'
'47153' = '16860'
'47155' = '42940'
'47157' = '32820'
'47159' = '34980'
'47161' = '17300'
'47163' = '28700'
'47165' = '34980'
'47167' = '32820'
'47169' = '34980'
'47171' = '27740'
'47173' = '28940'
'47177' = '32660'
'47179' = '27740'
'47183' = '32280'
'47187' = '34980'
'47189' = '34980'
'48001' = '37300'
'48003' = '11380'
'48005' = '31260'
'48007' = '18580'
'48009' = '48660'
'48011' = '11100'
'48013' = '41700'
'48015' = '26420'
'48019' = '41700'
'48021' = '12420'
'48025' = '13300'
'48027' = '28660'
'48029' = '41700'
'48037' = '45500'
'48039' = '26420'
'48041' = '17780'
'48049' = '15220'
'48051' = '17780'
'48055' = '12420'
'48057' = '47020'
'48059' = '10180'
'48061' = '15180'
'48065' = '11100'
'48071' = '26420'
'48073' = '27380'
'48077' = '48660'
'48085' = '19100'
'48091' = '41700'
'48097' = '23620'
'48099' = '28660'
'48107' = '31180'
'48113' = '19100'
'48115' = '29500'
'48117' = '25820'
'48119' = '19100'
'48121' = '19100'
'48135' = '36220'
'48139' = '19100'
'48141' = '21340'
'48143' = '44500'
'48147' = '14300'
'48157' = '26420'
'48167' = '26420'
'48175' = '47020'
'48179' = '37420'
'48181' = '43300'
'48183' = '30980'
'48187' = '41700'
'48189' = '38380'
'48199' = '13140'
'48201' = '26420'
'48203' = '32220'
'48209' = '12420'
'48213' = '11980'
'48215' = '32580'
'48219' = '30220'
'48221' = '24180'
'48223' = '44860'
'48227' = '13700'
'48231' = '19100'
'48233' = '14420'
'48235' = '41660'
'48245' = '13140'
'48249' = '10860'
'48251' = '19100'
'48253' = '10180'
'48257' = '19100'
'48259' = '41700'
'48261' = '28780'
'48265' = '28500'
'48273' = '28780'
'48277' = '37580'
'48281' = '28660'
'48291' = '26420'
'48303' = '31180'
'48309' = '47380'
'48321' = '13060'
'48323' = '20580'
'48325' = '41700'
'48329' = '33260'
'48339' = '26420'
'48341' = '20300'
'48347' = '34860'
'48349' = '18620'
'48353' = '45020'
'48355' = '18580'
'48361' = '13140'
'48363' = '33420'
'48367' = '19100'
'48375' = '11100'
'48381' = '11100'
'48389' = '37780'
'48393' = '37420'
'48395' = '17780'
'48397' = '19100'
'48401' = '30980'
'48407' = '26420'
'48409' = '18580'
'48415' = '43660'
'48423' = '46340'
'48425' = '24180'
'48427' = '40100'
'48439' = '19100'
'48441' = '10180'
'48449' = '34420'
'48451' = '41660'
'48453' = '12420'
'48459' = '30980'
'48463' = '46620'
'48465' = '19620'
'48469' = '47020'
'48471' = '26660'
'48473' = '26420'
'48477' = '14780'
'48479' = '29700'
'48481' = '20900'
'48485' = '48660'
'48487' = '46900'
'48489' = '39700'
'48491' = '12420'
'48493' = '41700'
'48497' = '19100'
'49003' = '14940'
'49005' = '30860'
'49007' = '39220'
'49011' = '36260'
'49021' = '16260'
'49023' = '39340'
'49029' = '36260'
'49035' = '41620'
'49043' = '41620'
'49045' = '41620'
'49047' = '46860'
'49049' = '39340'
'49051' = '25720'
'49053' = '41100'
'49057' = '36260'
'50003' = '13540'
'50007' = '15540'
'50009' = '13620'
'50011' = '15540'
'50013' = '15540'
'50017' = '30100'
'50021' = '40860'
'50023' = '12740'
'50027' = '30100'
'51003' = '16820'
'51007' = '40060'
'51009' = '31340'
'51011' = '31340'
'51013' = '47900'
'51015' = '44420'
'51019' = '31340'
'51023' = '40220'
'51031' = '31340'
'51033' = '40060'
'51036' = '40060'
'51041' = '40060'
'51043' = '47900'
'51045' = '40220'
'51047' = '19020'
'51049' = '40060'
'51053' = '40060'
'51059' = '47900'
'51061' = '47900'
'51065' = '16820'
'51067' = '40220'
'51069' = '49020'
'51071' = '13980'
'51073' = '47260'
'51075' = '40060'
'51079' = '16820'
'51085' = '40060'
'51087' = '40060'
'51089' = '32300'
'51093' = '47260'
'51095' = '47260'
'51097' = '40060'
'51101' = '40060'
'51107' = '47900'
'51109' = '40060'
'51115' = '47260'
'51121' = '13980'
'51125' = '16820'
'51127' = '40060'
'51143' = '19260'
'51145' = '40060'
'51149' = '40060'
'51153' = '47900'
'51155' = '13980'
'51161' = '40220'
'51165' = '25500'
'51169' = '28700'
'51177' = '47900'
'51179' = '47900'
'51181' = '47260'
'51183' = '40060'
'51185' = '14140'
'51187' = '47900'
'51191' = '28700'
'51199' = '47260'
'51510' = '47900'
'51515' = '31340'
'51520' = '28700'
'51540' = '16820'
'51550' = '47260'
'51570' = '40060'
'51590' = '19260'
'51600' = '47900'
'51610' = '47900'
'51630' = '47900'
'51650' = '47260'
'51660' = '25500'
'51670' = '40060'
'51680' = '31340'
'51683' = '47900'
'51685' = '47900'
'51690' = '32300'
'51700' = '47260'
'51710' = '47260'
'51730' = '40060'
'51735' = '47260'
'51740' = '47260'
'51750' = '13980'
'51760' = '40060'
'51770' = '40220'
'51775' = '40220'
'51790' = '44420'
'51800' = '47260'
'51810' = '47260'
'51820' = '44420'
'51830' = '47260'
'51840' = '49020'
'53003' = '30300'
'53005' = '28420'
'53007' = '48300'
'53009' = '38820'
'53011' = '38900'
'53015' = '31020'
'53017' = '48300'
'53021' = '28420'
'53025' = '34180'
'53027' = '10140'
'53029' = '36020'
'53033' = '42660'
'53035' = '14740'
'53037' = '21260'
'53041' = '16500'
'53045' = '43220'
'53053' = '42660'
'53057' = '34580'
'53059' = '38900'
'53061' = '42660'
'53063' = '44060'
'53067' = '36500'
'53071' = '47460'
'53073' = '13380'
'53075' = '39420'
'53077' = '49420'
'54003' = '25180'
'54005' = '16620'
'54009' = '48260'
'54011' = '26580'
'54015' = '16620'
'54017' = '17220'
'54019' = '36060'
'54027' = '49020'
'54029' = '48260'
'54033' = '17220'
'54037' = '47900'
'54039' = '16620'
'54043' = '16620'
'54049' = '21900'
'54051' = '48540'
'54053' = '38580'
'54055' = '14140'
'54057' = '19060'
'54061' = '34060'
'54065' = '25180'
'54069' = '48540'
'54073' = '37620'
'54077' = '34060'
'54079' = '16620'
'54081' = '13220'
'54091' = '17220'
'54099' = '26580'
'54105' = '37620'
'54107' = '37620'
'55009' = '24580'
'55015' = '11540'
'55017' = '20740'
'55021' = '31540'
'55025' = '31540'
'55027' = '13180'
'55031' = '20260'
'55033' = '32860'
'55035' = '20740'
'55037' = '27020'
'55039' = '22540'
'55043' = '38420'
'55045' = '33820'
'55049' = '31540'
'55055' = '48020'
'55059' = '16980'
'55061' = '24580'
'55063' = '29100'
'55069' = '32980'
'55071' = '31820'
'55073' = '48140'
'55075' = '31940'
'55079' = '33340'
'55083' = '24580'
'55087' = '11540'
'55089' = '33340'
'55093' = '33460'
'55097' = '44620'
'55101' = '39540'
'55105' = '27500'
'55109' = '33460'
'55111' = '12660'
'55117' = '43100'
'55127' = '48580'
'55131' = '33340'
'55133' = '33340'
'55139' = '36780'
'55141' = '49220'
'56001' = '29660'
'56005' = '23940'
'56013' = '40180'
'56021' = '16940'
'56025' = '16220'
'56033' = '43260'
'56037' = '40540'
'56039' = '27220'
'56041' = '21740'
;

run;

   
